package cl.json;

import android.app.Activity;
import android.content.ActivityNotFoundException;
import android.content.Intent;
import android.net.Uri;
import cl.json.social.EmailShare;
import cl.json.social.FacebookPagesManagerShare;
import cl.json.social.FacebookShare;
import cl.json.social.GenericShare;
import cl.json.social.GooglePlusShare;
import cl.json.social.InstagramShare;
import cl.json.social.MessengerShare;
import cl.json.social.PinterestShare;
import cl.json.social.SMSShare;
import cl.json.social.ShareIntent;
import cl.json.social.SnapChatShare;
import cl.json.social.TargetChosenReceiver;
import cl.json.social.TwitterShare;
import cl.json.social.WhatsAppShare;
import com.facebook.react.bridge.ActivityEventListener;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import java.io.PrintStream;
import java.util.HashMap;
import java.util.Map;
import javax.annotation.Nullable;

public class RNShareModule extends ReactContextBaseJavaModule implements ActivityEventListener {
    public static final int SHARE_REQUEST_CODE = 16845;
    private final ReactApplicationContext reactContext;

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return "RNShare";
    }

    @Override // com.facebook.react.bridge.ActivityEventListener
    public void onNewIntent(Intent intent) {
    }

    public void onActivityResult(int i, int i2, Intent intent) {
        if (i == 16845 && i2 == 0) {
            TargetChosenReceiver.a(true, false, "CANCELED");
        }
    }

    @Override // com.facebook.react.bridge.ActivityEventListener
    public void onActivityResult(Activity activity, int i, int i2, Intent intent) {
        onActivityResult(i, i2, intent);
    }

    private enum SHARES {
        facebook,
        generic,
        pagesmanager,
        twitter,
        whatsapp,
        instagram,
        googleplus,
        email,
        pinterest,
        messenger,
        snapchat,
        sms;

        public static ShareIntent a(String str, ReactApplicationContext reactApplicationContext) {
            switch (valueOf(str)) {
                case generic:
                    return new GenericShare(reactApplicationContext);
                case facebook:
                    return new FacebookShare(reactApplicationContext);
                case pagesmanager:
                    return new FacebookPagesManagerShare(reactApplicationContext);
                case twitter:
                    return new TwitterShare(reactApplicationContext);
                case whatsapp:
                    return new WhatsAppShare(reactApplicationContext);
                case instagram:
                    return new InstagramShare(reactApplicationContext);
                case googleplus:
                    return new GooglePlusShare(reactApplicationContext);
                case email:
                    return new EmailShare(reactApplicationContext);
                case pinterest:
                    return new PinterestShare(reactApplicationContext);
                case sms:
                    return new SMSShare(reactApplicationContext);
                case snapchat:
                    return new SnapChatShare(reactApplicationContext);
                case messenger:
                    return new MessengerShare(reactApplicationContext);
                default:
                    return null;
            }
        }
    }

    public RNShareModule(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
        reactApplicationContext.a(this);
        this.reactContext = reactApplicationContext;
    }

    @Override // com.facebook.react.bridge.BaseJavaModule
    @Nullable
    public Map<String, Object> getConstants() {
        HashMap hashMap = new HashMap();
        SHARES[] values = SHARES.values();
        for (SHARES shares : values) {
            hashMap.put(shares.toString().toUpperCase(), shares.toString());
        }
        return hashMap;
    }

    @ReactMethod
    public void open(ReadableMap readableMap, @android.support.annotation.Nullable Callback callback, @android.support.annotation.Nullable Callback callback2) {
        TargetChosenReceiver.a(callback2, callback);
        try {
            new GenericShare(this.reactContext).a(readableMap);
        } catch (ActivityNotFoundException e) {
            System.out.println("ERROR");
            System.out.println(e.getMessage());
            TargetChosenReceiver.a(false, "not_available");
        } catch (Exception e2) {
            System.out.println("ERROR");
            System.out.println(e2.getMessage());
            TargetChosenReceiver.a(false, e2.getMessage());
        }
    }

    @ReactMethod
    public void shareSingle(ReadableMap readableMap, @android.support.annotation.Nullable Callback callback, @android.support.annotation.Nullable Callback callback2) {
        System.out.println("SHARE SINGLE METHOD");
        TargetChosenReceiver.a(callback2, callback);
        if (ShareIntent.a("social", readableMap)) {
            try {
                ShareIntent a2 = SHARES.a(readableMap.f("social"), this.reactContext);
                if (a2 == null || !(a2 instanceof ShareIntent)) {
                    throw new ActivityNotFoundException("Invalid share activity");
                }
                a2.a(readableMap);
            } catch (ActivityNotFoundException e) {
                System.out.println("ERROR");
                System.out.println(e.getMessage());
                TargetChosenReceiver.a(false, e.getMessage());
            } catch (Exception e2) {
                System.out.println("ERROR");
                System.out.println(e2.getMessage());
                TargetChosenReceiver.a(false, e2.getMessage());
            }
        } else {
            TargetChosenReceiver.a(false, "key 'social' missing in options");
        }
    }

    @ReactMethod
    public void isPackageInstalled(String str, @android.support.annotation.Nullable Callback callback, @android.support.annotation.Nullable Callback callback2) {
        try {
            callback2.a(Boolean.valueOf(ShareIntent.a(str, this.reactContext)));
        } catch (Exception e) {
            PrintStream printStream = System.out;
            printStream.println("Error: " + e.getMessage());
            callback.a(e.getMessage());
        }
    }

    @ReactMethod
    public void isBase64File(String str, @android.support.annotation.Nullable Callback callback, @android.support.annotation.Nullable Callback callback2) {
        try {
            String scheme = Uri.parse(str).getScheme();
            if (scheme == null || !scheme.equals("data")) {
                callback2.a(false);
                return;
            }
            callback2.a(true);
        } catch (Exception e) {
            System.out.println("ERROR");
            System.out.println(e.getMessage());
            callback.a(e.getMessage());
        }
    }
}
