package com.alibaba.sdk.android.oss.internal;

import android.content.Context;
import android.os.Build;
import android.text.TextUtils;
import com.alibaba.sdk.android.oss.ClientConfiguration;
import com.alibaba.sdk.android.oss.ClientException;
import com.alibaba.sdk.android.oss.ServiceException;
import com.alibaba.sdk.android.oss.callback.OSSCompletedCallback;
import com.alibaba.sdk.android.oss.common.HttpMethod;
import com.alibaba.sdk.android.oss.common.OSSLog;
import com.alibaba.sdk.android.oss.common.auth.OSSCredentialProvider;
import com.alibaba.sdk.android.oss.common.utils.CRC64;
import com.alibaba.sdk.android.oss.common.utils.DateUtil;
import com.alibaba.sdk.android.oss.common.utils.OSSUtils;
import com.alibaba.sdk.android.oss.common.utils.VersionInfoUtils;
import com.alibaba.sdk.android.oss.exception.InconsistentException;
import com.alibaba.sdk.android.oss.internal.ResponseParsers;
import com.alibaba.sdk.android.oss.model.AbortMultipartUploadRequest;
import com.alibaba.sdk.android.oss.model.AbortMultipartUploadResult;
import com.alibaba.sdk.android.oss.model.AppendObjectRequest;
import com.alibaba.sdk.android.oss.model.AppendObjectResult;
import com.alibaba.sdk.android.oss.model.CompleteMultipartUploadRequest;
import com.alibaba.sdk.android.oss.model.CompleteMultipartUploadResult;
import com.alibaba.sdk.android.oss.model.CopyObjectRequest;
import com.alibaba.sdk.android.oss.model.CopyObjectResult;
import com.alibaba.sdk.android.oss.model.CreateBucketRequest;
import com.alibaba.sdk.android.oss.model.CreateBucketResult;
import com.alibaba.sdk.android.oss.model.DeleteBucketRequest;
import com.alibaba.sdk.android.oss.model.DeleteBucketResult;
import com.alibaba.sdk.android.oss.model.DeleteObjectRequest;
import com.alibaba.sdk.android.oss.model.DeleteObjectResult;
import com.alibaba.sdk.android.oss.model.GetBucketACLRequest;
import com.alibaba.sdk.android.oss.model.GetBucketACLResult;
import com.alibaba.sdk.android.oss.model.GetObjectMetaRequest;
import com.alibaba.sdk.android.oss.model.GetObjectMetaResult;
import com.alibaba.sdk.android.oss.model.GetObjectRequest;
import com.alibaba.sdk.android.oss.model.GetObjectResult;
import com.alibaba.sdk.android.oss.model.HeadObjectRequest;
import com.alibaba.sdk.android.oss.model.HeadObjectResult;
import com.alibaba.sdk.android.oss.model.InitiateMultipartUploadRequest;
import com.alibaba.sdk.android.oss.model.InitiateMultipartUploadResult;
import com.alibaba.sdk.android.oss.model.ListBucketsRequest;
import com.alibaba.sdk.android.oss.model.ListBucketsResult;
import com.alibaba.sdk.android.oss.model.ListObjectsRequest;
import com.alibaba.sdk.android.oss.model.ListObjectsResult;
import com.alibaba.sdk.android.oss.model.ListPartsRequest;
import com.alibaba.sdk.android.oss.model.ListPartsResult;
import com.alibaba.sdk.android.oss.model.OSSRequest;
import com.alibaba.sdk.android.oss.model.OSSResult;
import com.alibaba.sdk.android.oss.model.PartETag;
import com.alibaba.sdk.android.oss.model.PutObjectRequest;
import com.alibaba.sdk.android.oss.model.PutObjectResult;
import com.alibaba.sdk.android.oss.model.UploadPartRequest;
import com.alibaba.sdk.android.oss.model.UploadPartResult;
import com.alibaba.sdk.android.oss.network.ExecutionContext;
import com.alibaba.sdk.android.oss.network.OSSRequestTask;
import com.facebook.stetho.server.http.HttpHeaders;
import java.io.UnsupportedEncodingException;
import java.net.InetSocketAddress;
import java.net.Proxy;
import java.net.URI;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.TimeUnit;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLSession;
import okhttp3.Dispatcher;
import okhttp3.OkHttpClient;

public class InternalRequestOperation {

    /* renamed from: a  reason: collision with root package name */
    private static ExecutorService f1172a = Executors.newFixedThreadPool(5, new ThreadFactory() {
        /* class com.alibaba.sdk.android.oss.internal.InternalRequestOperation.AnonymousClass1 */

        public Thread newThread(Runnable runnable) {
            return new Thread(runnable, "oss-android-api-thread");
        }
    });
    private volatile URI b;
    private URI c;
    private OkHttpClient d;
    private Context e;
    private OSSCredentialProvider f;
    private int g = 2;
    private ClientConfiguration h;

    public InternalRequestOperation(Context context, URI uri, OSSCredentialProvider oSSCredentialProvider, ClientConfiguration clientConfiguration) {
        this.e = context;
        this.b = uri;
        this.f = oSSCredentialProvider;
        this.h = clientConfiguration;
        this.d = a(uri.getHost(), clientConfiguration);
    }

    private OkHttpClient a(final String str, ClientConfiguration clientConfiguration) {
        if (clientConfiguration.q() != null) {
            return clientConfiguration.q();
        }
        OkHttpClient.Builder hostnameVerifier = new OkHttpClient.Builder().followRedirects(clientConfiguration.p()).followSslRedirects(clientConfiguration.p()).retryOnConnectionFailure(false).cache(null).hostnameVerifier(new HostnameVerifier() {
            /* class com.alibaba.sdk.android.oss.internal.InternalRequestOperation.AnonymousClass2 */

            public boolean verify(String str, SSLSession sSLSession) {
                return HttpsURLConnection.getDefaultHostnameVerifier().verify(str, sSLSession);
            }
        });
        if (clientConfiguration != null) {
            Dispatcher dispatcher = new Dispatcher();
            dispatcher.setMaxRequests(clientConfiguration.b());
            hostnameVerifier.connectTimeout((long) clientConfiguration.d(), TimeUnit.MILLISECONDS).readTimeout((long) clientConfiguration.c(), TimeUnit.MILLISECONDS).writeTimeout((long) clientConfiguration.c(), TimeUnit.MILLISECONDS).dispatcher(dispatcher);
            if (!(clientConfiguration.h() == null || clientConfiguration.i() == 0)) {
                hostnameVerifier.proxy(new Proxy(Proxy.Type.HTTP, new InetSocketAddress(clientConfiguration.h(), clientConfiguration.i())));
            }
            this.g = clientConfiguration.f();
        }
        return hostnameVerifier.build();
    }

    public OSSAsyncTask<PutObjectResult> a(PutObjectRequest putObjectRequest, final OSSCompletedCallback<PutObjectRequest, PutObjectResult> oSSCompletedCallback) {
        OSSLog.b(" Internal putObject Start ");
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(putObjectRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.PUT);
        requestMessage.b(putObjectRequest.a());
        requestMessage.c(putObjectRequest.b());
        if (putObjectRequest.d() != null) {
            requestMessage.a(putObjectRequest.d());
        }
        if (putObjectRequest.c() != null) {
            requestMessage.d(putObjectRequest.c());
        }
        if (putObjectRequest.f() != null) {
            requestMessage.a(putObjectRequest.f());
        }
        if (putObjectRequest.i() != null) {
            requestMessage.a().put("x-oss-callback", OSSUtils.a(putObjectRequest.i()));
        }
        if (putObjectRequest.j() != null) {
            requestMessage.a().put("x-oss-callback-var", OSSUtils.a(putObjectRequest.j()));
        }
        OSSLog.b(" populateRequestMetadata ");
        OSSUtils.a(requestMessage.a(), putObjectRequest.e());
        OSSLog.b(" canonicalizeRequestMessage ");
        a(requestMessage, putObjectRequest);
        OSSLog.b(" ExecutionContext ");
        ExecutionContext executionContext = new ExecutionContext(a(), putObjectRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(new OSSCompletedCallback<PutObjectRequest, PutObjectResult>() {
                /* class com.alibaba.sdk.android.oss.internal.InternalRequestOperation.AnonymousClass3 */

                public void a(PutObjectRequest putObjectRequest, PutObjectResult putObjectResult) {
                    InternalRequestOperation.this.a(putObjectRequest, putObjectResult, oSSCompletedCallback);
                }

                public void a(PutObjectRequest putObjectRequest, ClientException clientException, ServiceException serviceException) {
                    oSSCompletedCallback.a(putObjectRequest, clientException, serviceException);
                }
            });
        }
        if (putObjectRequest.h() != null) {
            executionContext.a(putObjectRequest.h());
        }
        executionContext.a(putObjectRequest.g());
        OSSRequestTask oSSRequestTask = new OSSRequestTask(requestMessage, new ResponseParsers.PutObjectResponseParser(), executionContext, this.g);
        OSSLog.b(" call OSSRequestTask ");
        return OSSAsyncTask.a(f1172a.submit(oSSRequestTask), executionContext);
    }

    public OSSAsyncTask<CreateBucketResult> a(CreateBucketRequest createBucketRequest, OSSCompletedCallback<CreateBucketRequest, CreateBucketResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(createBucketRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.PUT);
        requestMessage.b(createBucketRequest.a());
        if (createBucketRequest.c() != null) {
            requestMessage.a().put("x-oss-acl", createBucketRequest.c().toString());
        }
        try {
            HashMap hashMap = new HashMap();
            if (createBucketRequest.b() != null) {
                hashMap.put("LocationConstraint", createBucketRequest.b());
            }
            hashMap.put("StorageClass", createBucketRequest.d().toString());
            requestMessage.c(hashMap);
            a(requestMessage, createBucketRequest);
            ExecutionContext executionContext = new ExecutionContext(a(), createBucketRequest, this.e);
            if (oSSCompletedCallback != null) {
                executionContext.a(oSSCompletedCallback);
            }
            return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.CreateBucketResponseParser(), executionContext, this.g)), executionContext);
        } catch (UnsupportedEncodingException e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public OSSAsyncTask<DeleteBucketResult> a(DeleteBucketRequest deleteBucketRequest, OSSCompletedCallback<DeleteBucketRequest, DeleteBucketResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(deleteBucketRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.DELETE);
        requestMessage.b(deleteBucketRequest.a());
        a(requestMessage, deleteBucketRequest);
        ExecutionContext executionContext = new ExecutionContext(a(), deleteBucketRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(oSSCompletedCallback);
        }
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.DeleteBucketResponseParser(), executionContext, this.g)), executionContext);
    }

    public OSSAsyncTask<GetBucketACLResult> a(GetBucketACLRequest getBucketACLRequest, OSSCompletedCallback<GetBucketACLRequest, GetBucketACLResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        linkedHashMap.put("acl", "");
        requestMessage.b(getBucketACLRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.GET);
        requestMessage.b(getBucketACLRequest.a());
        requestMessage.b(linkedHashMap);
        a(requestMessage, getBucketACLRequest);
        ExecutionContext executionContext = new ExecutionContext(a(), getBucketACLRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(oSSCompletedCallback);
        }
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.GetBucketACLResponseParser(), executionContext, this.g)), executionContext);
    }

    public OSSAsyncTask<AppendObjectResult> a(AppendObjectRequest appendObjectRequest, final OSSCompletedCallback<AppendObjectRequest, AppendObjectResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(appendObjectRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.POST);
        requestMessage.b(appendObjectRequest.b());
        requestMessage.c(appendObjectRequest.c());
        if (appendObjectRequest.e() != null) {
            requestMessage.a(appendObjectRequest.e());
        }
        if (appendObjectRequest.d() != null) {
            requestMessage.d(appendObjectRequest.d());
        }
        if (appendObjectRequest.f() != null) {
            requestMessage.a(appendObjectRequest.f());
        }
        requestMessage.k().put("append", "");
        requestMessage.k().put("position", String.valueOf(appendObjectRequest.a()));
        OSSUtils.a(requestMessage.a(), appendObjectRequest.g());
        a(requestMessage, appendObjectRequest);
        ExecutionContext executionContext = new ExecutionContext(a(), appendObjectRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(new OSSCompletedCallback<AppendObjectRequest, AppendObjectResult>() {
                /* class com.alibaba.sdk.android.oss.internal.InternalRequestOperation.AnonymousClass4 */

                public void a(AppendObjectRequest appendObjectRequest, AppendObjectResult appendObjectResult) {
                    boolean z = appendObjectRequest.l() == OSSRequest.CRC64Config.YES;
                    if (appendObjectRequest.i() != null && z) {
                        appendObjectResult.b(Long.valueOf(CRC64.a(appendObjectRequest.i().longValue(), appendObjectResult.d().longValue(), appendObjectResult.a() - appendObjectRequest.a())));
                    }
                    InternalRequestOperation.this.a(appendObjectRequest, appendObjectResult, oSSCompletedCallback);
                }

                public void a(AppendObjectRequest appendObjectRequest, ClientException clientException, ServiceException serviceException) {
                    oSSCompletedCallback.a(appendObjectRequest, clientException, serviceException);
                }
            });
        }
        executionContext.a(appendObjectRequest.h());
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.AppendObjectResponseParser(), executionContext, this.g)), executionContext);
    }

    public OSSAsyncTask<HeadObjectResult> a(HeadObjectRequest headObjectRequest, OSSCompletedCallback<HeadObjectRequest, HeadObjectResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(headObjectRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.HEAD);
        requestMessage.b(headObjectRequest.a());
        requestMessage.c(headObjectRequest.b());
        a(requestMessage, headObjectRequest);
        ExecutionContext executionContext = new ExecutionContext(a(), headObjectRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(oSSCompletedCallback);
        }
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.HeadObjectResponseParser(), executionContext, this.g)), executionContext);
    }

    public OSSAsyncTask<GetObjectMetaResult> a(GetObjectMetaRequest getObjectMetaRequest, OSSCompletedCallback<GetObjectMetaRequest, GetObjectMetaResult> oSSCompletedCallback) {
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        linkedHashMap.put("objectMeta", "");
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(getObjectMetaRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.HEAD);
        requestMessage.b(getObjectMetaRequest.a());
        requestMessage.c(getObjectMetaRequest.b());
        requestMessage.b(linkedHashMap);
        a(requestMessage, getObjectMetaRequest);
        ExecutionContext executionContext = new ExecutionContext(a(), getObjectMetaRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(oSSCompletedCallback);
        }
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.GetObjectMetaResponseParser(), executionContext, this.g)), executionContext);
    }

    public OSSAsyncTask<GetObjectResult> a(GetObjectRequest getObjectRequest, OSSCompletedCallback<GetObjectRequest, GetObjectResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(getObjectRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.GET);
        requestMessage.b(getObjectRequest.b());
        requestMessage.c(getObjectRequest.c());
        if (getObjectRequest.d() != null) {
            requestMessage.a().put("Range", getObjectRequest.d().toString());
        }
        if (getObjectRequest.e() != null) {
            requestMessage.k().put("x-oss-process", getObjectRequest.e());
        }
        a(requestMessage, getObjectRequest);
        if (getObjectRequest.a() != null) {
            for (Map.Entry<String, String> entry : getObjectRequest.a().entrySet()) {
                requestMessage.a().put(entry.getKey(), entry.getValue());
            }
        }
        ExecutionContext executionContext = new ExecutionContext(a(), getObjectRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(oSSCompletedCallback);
        }
        executionContext.a(getObjectRequest.f());
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.GetObjectResponseParser(), executionContext, this.g)), executionContext);
    }

    public OSSAsyncTask<CopyObjectResult> a(CopyObjectRequest copyObjectRequest, OSSCompletedCallback<CopyObjectRequest, CopyObjectResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(copyObjectRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.PUT);
        requestMessage.b(copyObjectRequest.c());
        requestMessage.c(copyObjectRequest.d());
        OSSUtils.a(copyObjectRequest, requestMessage.a());
        a(requestMessage, copyObjectRequest);
        ExecutionContext executionContext = new ExecutionContext(a(), copyObjectRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(oSSCompletedCallback);
        }
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.CopyObjectResponseParser(), executionContext, this.g)), executionContext);
    }

    public OSSAsyncTask<DeleteObjectResult> a(DeleteObjectRequest deleteObjectRequest, OSSCompletedCallback<DeleteObjectRequest, DeleteObjectResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(deleteObjectRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.DELETE);
        requestMessage.b(deleteObjectRequest.a());
        requestMessage.c(deleteObjectRequest.b());
        a(requestMessage, deleteObjectRequest);
        ExecutionContext executionContext = new ExecutionContext(a(), deleteObjectRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(oSSCompletedCallback);
        }
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.DeleteObjectResponseParser(), executionContext, this.g)), executionContext);
    }

    public OSSAsyncTask<ListBucketsResult> a(ListBucketsRequest listBucketsRequest, OSSCompletedCallback<ListBucketsRequest, ListBucketsResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(listBucketsRequest.k());
        requestMessage.a(HttpMethod.GET);
        requestMessage.a(this.c);
        requestMessage.b(this.b);
        a(requestMessage, listBucketsRequest);
        OSSUtils.a(listBucketsRequest, requestMessage.k());
        ExecutionContext executionContext = new ExecutionContext(a(), listBucketsRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(oSSCompletedCallback);
        }
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.ListBucketResponseParser(), executionContext, this.g)), executionContext);
    }

    public OSSAsyncTask<ListObjectsResult> a(ListObjectsRequest listObjectsRequest, OSSCompletedCallback<ListObjectsRequest, ListObjectsResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(listObjectsRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.GET);
        requestMessage.b(listObjectsRequest.a());
        a(requestMessage, listObjectsRequest);
        OSSUtils.a(listObjectsRequest, requestMessage.k());
        ExecutionContext executionContext = new ExecutionContext(a(), listObjectsRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(oSSCompletedCallback);
        }
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.ListObjectsResponseParser(), executionContext, this.g)), executionContext);
    }

    public OSSAsyncTask<InitiateMultipartUploadResult> a(InitiateMultipartUploadRequest initiateMultipartUploadRequest, OSSCompletedCallback<InitiateMultipartUploadRequest, InitiateMultipartUploadResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(initiateMultipartUploadRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.POST);
        requestMessage.b(initiateMultipartUploadRequest.a());
        requestMessage.c(initiateMultipartUploadRequest.b());
        requestMessage.k().put("uploads", "");
        if (initiateMultipartUploadRequest.f1224a) {
            requestMessage.k().put("sequential", "");
        }
        OSSUtils.a(requestMessage.a(), initiateMultipartUploadRequest.c());
        a(requestMessage, initiateMultipartUploadRequest);
        ExecutionContext executionContext = new ExecutionContext(a(), initiateMultipartUploadRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(oSSCompletedCallback);
        }
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.InitMultipartResponseParser(), executionContext, this.g)), executionContext);
    }

    public UploadPartResult a(UploadPartRequest uploadPartRequest) throws ClientException, ServiceException {
        UploadPartResult a2 = a(uploadPartRequest, (OSSCompletedCallback<UploadPartRequest, UploadPartResult>) null).a();
        a(uploadPartRequest, a2);
        return a2;
    }

    public OSSAsyncTask<UploadPartResult> a(UploadPartRequest uploadPartRequest, final OSSCompletedCallback<UploadPartRequest, UploadPartResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(uploadPartRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.PUT);
        requestMessage.b(uploadPartRequest.a());
        requestMessage.c(uploadPartRequest.b());
        requestMessage.k().put("uploadId", uploadPartRequest.c());
        requestMessage.k().put("partNumber", String.valueOf(uploadPartRequest.d()));
        requestMessage.a(uploadPartRequest.g());
        if (uploadPartRequest.e() != null) {
            requestMessage.a().put("Content-MD5", uploadPartRequest.e());
        }
        a(requestMessage, uploadPartRequest);
        ExecutionContext executionContext = new ExecutionContext(a(), uploadPartRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(new OSSCompletedCallback<UploadPartRequest, UploadPartResult>() {
                /* class com.alibaba.sdk.android.oss.internal.InternalRequestOperation.AnonymousClass5 */

                public void a(UploadPartRequest uploadPartRequest, UploadPartResult uploadPartResult) {
                    InternalRequestOperation.this.a(uploadPartRequest, uploadPartResult, oSSCompletedCallback);
                }

                public void a(UploadPartRequest uploadPartRequest, ClientException clientException, ServiceException serviceException) {
                    oSSCompletedCallback.a(uploadPartRequest, clientException, serviceException);
                }
            });
        }
        executionContext.a(uploadPartRequest.f());
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.UploadPartResponseParser(), executionContext, this.g)), executionContext);
    }

    public CompleteMultipartUploadResult a(CompleteMultipartUploadRequest completeMultipartUploadRequest) throws ClientException, ServiceException {
        CompleteMultipartUploadResult a2 = a(completeMultipartUploadRequest, (OSSCompletedCallback<CompleteMultipartUploadRequest, CompleteMultipartUploadResult>) null).a();
        if (a2.i() != null) {
            a2.b(Long.valueOf(a(completeMultipartUploadRequest.d())));
        }
        a(completeMultipartUploadRequest, a2);
        return a2;
    }

    public OSSAsyncTask<CompleteMultipartUploadResult> a(CompleteMultipartUploadRequest completeMultipartUploadRequest, final OSSCompletedCallback<CompleteMultipartUploadRequest, CompleteMultipartUploadResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(completeMultipartUploadRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.POST);
        requestMessage.b(completeMultipartUploadRequest.a());
        requestMessage.c(completeMultipartUploadRequest.b());
        requestMessage.a(OSSUtils.a(completeMultipartUploadRequest.d()));
        requestMessage.k().put("uploadId", completeMultipartUploadRequest.c());
        if (completeMultipartUploadRequest.e() != null) {
            requestMessage.a().put("x-oss-callback", OSSUtils.a(completeMultipartUploadRequest.e()));
        }
        if (completeMultipartUploadRequest.f() != null) {
            requestMessage.a().put("x-oss-callback-var", OSSUtils.a(completeMultipartUploadRequest.f()));
        }
        OSSUtils.a(requestMessage.a(), completeMultipartUploadRequest.g());
        a(requestMessage, completeMultipartUploadRequest);
        ExecutionContext executionContext = new ExecutionContext(a(), completeMultipartUploadRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(new OSSCompletedCallback<CompleteMultipartUploadRequest, CompleteMultipartUploadResult>() {
                /* class com.alibaba.sdk.android.oss.internal.InternalRequestOperation.AnonymousClass6 */

                public void a(CompleteMultipartUploadRequest completeMultipartUploadRequest, CompleteMultipartUploadResult completeMultipartUploadResult) {
                    if (completeMultipartUploadResult.i() != null) {
                        completeMultipartUploadResult.b(Long.valueOf(InternalRequestOperation.this.a((InternalRequestOperation) completeMultipartUploadRequest.d())));
                    }
                    InternalRequestOperation.this.a(completeMultipartUploadRequest, completeMultipartUploadResult, oSSCompletedCallback);
                }

                public void a(CompleteMultipartUploadRequest completeMultipartUploadRequest, ClientException clientException, ServiceException serviceException) {
                    oSSCompletedCallback.a(completeMultipartUploadRequest, clientException, serviceException);
                }
            });
        }
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.CompleteMultipartUploadResponseParser(), executionContext, this.g)), executionContext);
    }

    public OSSAsyncTask<AbortMultipartUploadResult> a(AbortMultipartUploadRequest abortMultipartUploadRequest, OSSCompletedCallback<AbortMultipartUploadRequest, AbortMultipartUploadResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(abortMultipartUploadRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.DELETE);
        requestMessage.b(abortMultipartUploadRequest.a());
        requestMessage.c(abortMultipartUploadRequest.b());
        requestMessage.k().put("uploadId", abortMultipartUploadRequest.c());
        a(requestMessage, abortMultipartUploadRequest);
        ExecutionContext executionContext = new ExecutionContext(a(), abortMultipartUploadRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(oSSCompletedCallback);
        }
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.AbortMultipartUploadResponseParser(), executionContext, this.g)), executionContext);
    }

    public OSSAsyncTask<ListPartsResult> a(ListPartsRequest listPartsRequest, OSSCompletedCallback<ListPartsRequest, ListPartsResult> oSSCompletedCallback) {
        RequestMessage requestMessage = new RequestMessage();
        requestMessage.b(listPartsRequest.k());
        requestMessage.b(this.b);
        requestMessage.a(HttpMethod.GET);
        requestMessage.b(listPartsRequest.a());
        requestMessage.c(listPartsRequest.b());
        requestMessage.k().put("uploadId", listPartsRequest.c());
        Integer d2 = listPartsRequest.d();
        if (d2 != null) {
            if (OSSUtils.a((long) d2.intValue(), 0, true, 1000, true)) {
                requestMessage.k().put("max-parts", d2.toString());
            } else {
                throw new IllegalArgumentException("MaxPartsOutOfRange: 1000");
            }
        }
        Integer e2 = listPartsRequest.e();
        if (e2 != null) {
            if (OSSUtils.a((long) e2.intValue(), 0, false, 10000, true)) {
                requestMessage.k().put("part-number-marker", e2.toString());
            } else {
                throw new IllegalArgumentException("PartNumberMarkerOutOfRange: 10000");
            }
        }
        a(requestMessage, listPartsRequest);
        ExecutionContext executionContext = new ExecutionContext(a(), listPartsRequest, this.e);
        if (oSSCompletedCallback != null) {
            executionContext.a(oSSCompletedCallback);
        }
        return OSSAsyncTask.a(f1172a.submit(new OSSRequestTask(requestMessage, new ResponseParsers.ListPartsResponseParser(), executionContext, this.g)), executionContext);
    }

    private boolean a(boolean z) {
        String str;
        boolean z2 = false;
        if (!z || this.e == null) {
            return false;
        }
        if (Build.VERSION.SDK_INT >= 14) {
            z2 = true;
        }
        if (z2) {
            str = System.getProperty("http.proxyHost");
        } else {
            str = android.net.Proxy.getHost(this.e);
        }
        String h2 = this.h.h();
        if (!TextUtils.isEmpty(h2)) {
            str = h2;
        }
        return TextUtils.isEmpty(str);
    }

    public OkHttpClient a() {
        return this.d;
    }

    private void a(RequestMessage requestMessage, OSSRequest oSSRequest) {
        Map a2 = requestMessage.a();
        if (a2.get("Date") == null) {
            a2.put("Date", DateUtil.b());
        }
        if ((requestMessage.f() == HttpMethod.POST || requestMessage.f() == HttpMethod.PUT) && OSSUtils.a((String) a2.get(HttpHeaders.CONTENT_TYPE))) {
            a2.put(HttpHeaders.CONTENT_TYPE, OSSUtils.b(null, requestMessage.l(), requestMessage.j()));
        }
        requestMessage.a(a(this.h.k()));
        requestMessage.a(this.f);
        requestMessage.e(this.h.n());
        requestMessage.f(this.h.o());
        requestMessage.e(this.h.m());
        requestMessage.a().put("User-Agent", VersionInfoUtils.a(this.h.j()));
        boolean z = false;
        if (requestMessage.a().containsKey("Range") || requestMessage.k().containsKey("x-oss-process")) {
            requestMessage.d(false);
        }
        requestMessage.c(OSSUtils.a(this.b.getHost(), this.h.g()));
        if (oSSRequest.l() == OSSRequest.CRC64Config.NULL) {
            z = this.h.l();
        } else if (oSSRequest.l() == OSSRequest.CRC64Config.YES) {
            z = true;
        }
        requestMessage.d(z);
        oSSRequest.a(z ? OSSRequest.CRC64Config.YES : OSSRequest.CRC64Config.NO);
    }

    private <Request extends OSSRequest, Result extends OSSResult> void a(Request request, Result result) throws ClientException {
        if (request.l() == OSSRequest.CRC64Config.YES) {
            try {
                OSSUtils.a(result.d(), result.i(), result.h());
            } catch (InconsistentException e2) {
                throw new ClientException(e2.getMessage(), e2);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private <Request extends OSSRequest, Result extends OSSResult> void a(Request request, Result result, OSSCompletedCallback<Request, Result> oSSCompletedCallback) {
        try {
            a(request, result);
            if (oSSCompletedCallback != null) {
                oSSCompletedCallback.a(request, result);
            }
        } catch (ClientException e2) {
            if (oSSCompletedCallback != null) {
                oSSCompletedCallback.a(request, e2, null);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private long a(List<PartETag> list) {
        long j = 0;
        for (PartETag partETag : list) {
            if (partETag.d() == 0 || partETag.c() <= 0) {
                return 0;
            }
            j = CRC64.a(j, partETag.d(), partETag.c());
        }
        return j;
    }

    public Context b() {
        return this.e;
    }

    public ClientConfiguration c() {
        return this.h;
    }

    /* renamed from: com.alibaba.sdk.android.oss.internal.InternalRequestOperation$7  reason: invalid class name */
    class AnonymousClass7 implements Callable {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ UnsupportedEncodingException f1178a;

        @Override // java.util.concurrent.Callable
        public Object call() throws Exception {
            throw this.f1178a;
        }
    }
}
