package com.alibaba.sdk.android.oss.internal;

import android.text.TextUtils;
import android.util.Xml;
import com.alibaba.sdk.android.oss.ClientException;
import com.alibaba.sdk.android.oss.ServiceException;
import com.alibaba.sdk.android.oss.common.OSSLog;
import com.alibaba.sdk.android.oss.common.utils.CRC64;
import com.alibaba.sdk.android.oss.common.utils.DateUtil;
import com.alibaba.sdk.android.oss.common.utils.OSSUtils;
import com.alibaba.sdk.android.oss.model.AbortMultipartUploadResult;
import com.alibaba.sdk.android.oss.model.AppendObjectResult;
import com.alibaba.sdk.android.oss.model.BucketLifecycleRule;
import com.alibaba.sdk.android.oss.model.CompleteMultipartUploadResult;
import com.alibaba.sdk.android.oss.model.CopyObjectResult;
import com.alibaba.sdk.android.oss.model.CreateBucketResult;
import com.alibaba.sdk.android.oss.model.DeleteBucketLifecycleResult;
import com.alibaba.sdk.android.oss.model.DeleteBucketLoggingResult;
import com.alibaba.sdk.android.oss.model.DeleteBucketResult;
import com.alibaba.sdk.android.oss.model.DeleteMultipleObjectResult;
import com.alibaba.sdk.android.oss.model.DeleteObjectResult;
import com.alibaba.sdk.android.oss.model.DeleteObjectTaggingResult;
import com.alibaba.sdk.android.oss.model.GetBucketACLResult;
import com.alibaba.sdk.android.oss.model.GetBucketInfoResult;
import com.alibaba.sdk.android.oss.model.GetBucketLifecycleResult;
import com.alibaba.sdk.android.oss.model.GetBucketLoggingResult;
import com.alibaba.sdk.android.oss.model.GetBucketRefererResult;
import com.alibaba.sdk.android.oss.model.GetObjectACLResult;
import com.alibaba.sdk.android.oss.model.GetObjectMetaResult;
import com.alibaba.sdk.android.oss.model.GetObjectResult;
import com.alibaba.sdk.android.oss.model.GetObjectTaggingResult;
import com.alibaba.sdk.android.oss.model.GetSymlinkResult;
import com.alibaba.sdk.android.oss.model.HeadObjectResult;
import com.alibaba.sdk.android.oss.model.ImagePersistResult;
import com.alibaba.sdk.android.oss.model.InitiateMultipartUploadResult;
import com.alibaba.sdk.android.oss.model.ListBucketsResult;
import com.alibaba.sdk.android.oss.model.ListMultipartUploadsResult;
import com.alibaba.sdk.android.oss.model.ListObjectsResult;
import com.alibaba.sdk.android.oss.model.ListPartsResult;
import com.alibaba.sdk.android.oss.model.OSSBucketSummary;
import com.alibaba.sdk.android.oss.model.OSSObjectSummary;
import com.alibaba.sdk.android.oss.model.ObjectMetadata;
import com.alibaba.sdk.android.oss.model.Owner;
import com.alibaba.sdk.android.oss.model.PartSummary;
import com.alibaba.sdk.android.oss.model.PutBucketLifecycleResult;
import com.alibaba.sdk.android.oss.model.PutBucketLoggingResult;
import com.alibaba.sdk.android.oss.model.PutBucketRefererResult;
import com.alibaba.sdk.android.oss.model.PutObjectResult;
import com.alibaba.sdk.android.oss.model.PutObjectTaggingResult;
import com.alibaba.sdk.android.oss.model.PutSymlinkResult;
import com.alibaba.sdk.android.oss.model.RestoreObjectResult;
import com.alibaba.sdk.android.oss.model.TriggerCallbackResult;
import com.alibaba.sdk.android.oss.model.UploadPartResult;
import com.facebook.stetho.server.http.HttpHeaders;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

public final class ResponseParsers {

    public static final class AbortMultipartUploadResponseParser extends AbstractResponseParser<AbortMultipartUploadResult> {
        public AbortMultipartUploadResult a(ResponseMessage responseMessage, AbortMultipartUploadResult abortMultipartUploadResult) throws Exception {
            return abortMultipartUploadResult;
        }
    }

    public static final class DeleteBucketLifecycleResponseParser extends AbstractResponseParser<DeleteBucketLifecycleResult> {
        public DeleteBucketLifecycleResult a(ResponseMessage responseMessage, DeleteBucketLifecycleResult deleteBucketLifecycleResult) throws Exception {
            return deleteBucketLifecycleResult;
        }
    }

    public static final class DeleteBucketLoggingResponseParser extends AbstractResponseParser<DeleteBucketLoggingResult> {
        public DeleteBucketLoggingResult a(ResponseMessage responseMessage, DeleteBucketLoggingResult deleteBucketLoggingResult) throws Exception {
            return deleteBucketLoggingResult;
        }
    }

    public static final class DeleteBucketResponseParser extends AbstractResponseParser<DeleteBucketResult> {
        public DeleteBucketResult a(ResponseMessage responseMessage, DeleteBucketResult deleteBucketResult) throws Exception {
            return deleteBucketResult;
        }
    }

    public static final class DeleteObjectResponseParser extends AbstractResponseParser<DeleteObjectResult> {
        public DeleteObjectResult a(ResponseMessage responseMessage, DeleteObjectResult deleteObjectResult) throws Exception {
            return deleteObjectResult;
        }
    }

    public static final class DeleteObjectTaggingResponseParser extends AbstractResponseParser<DeleteObjectTaggingResult> {
        /* access modifiers changed from: package-private */
        public DeleteObjectTaggingResult a(ResponseMessage responseMessage, DeleteObjectTaggingResult deleteObjectTaggingResult) throws Exception {
            return deleteObjectTaggingResult;
        }
    }

    public static final class ImagePersistResponseParser extends AbstractResponseParser<ImagePersistResult> {
        public ImagePersistResult a(ResponseMessage responseMessage, ImagePersistResult imagePersistResult) throws Exception {
            return imagePersistResult;
        }
    }

    public static final class PutBucketLifecycleResponseParser extends AbstractResponseParser<PutBucketLifecycleResult> {
        public PutBucketLifecycleResult a(ResponseMessage responseMessage, PutBucketLifecycleResult putBucketLifecycleResult) throws Exception {
            return putBucketLifecycleResult;
        }
    }

    public static final class PutBucketLoggingResponseParser extends AbstractResponseParser<PutBucketLoggingResult> {
        public PutBucketLoggingResult a(ResponseMessage responseMessage, PutBucketLoggingResult putBucketLoggingResult) throws Exception {
            return putBucketLoggingResult;
        }
    }

    public static final class PutBucketRefererResponseParser extends AbstractResponseParser<PutBucketRefererResult> {
        public PutBucketRefererResult a(ResponseMessage responseMessage, PutBucketRefererResult putBucketRefererResult) throws Exception {
            return putBucketRefererResult;
        }
    }

    public static final class PutObjectTaggingResponseParser extends AbstractResponseParser<PutObjectTaggingResult> {
        /* access modifiers changed from: package-private */
        public PutObjectTaggingResult a(ResponseMessage responseMessage, PutObjectTaggingResult putObjectTaggingResult) throws Exception {
            return putObjectTaggingResult;
        }
    }

    public static final class PutSymlinkResponseParser extends AbstractResponseParser<PutSymlinkResult> {
        /* access modifiers changed from: package-private */
        public PutSymlinkResult a(ResponseMessage responseMessage, PutSymlinkResult putSymlinkResult) throws Exception {
            return putSymlinkResult;
        }
    }

    public static final class RestoreObjectResponseParser extends AbstractResponseParser<RestoreObjectResult> {
        /* access modifiers changed from: package-private */
        public RestoreObjectResult a(ResponseMessage responseMessage, RestoreObjectResult restoreObjectResult) throws Exception {
            return restoreObjectResult;
        }
    }

    /* access modifiers changed from: private */
    public static CopyObjectResult b(InputStream inputStream, CopyObjectResult copyObjectResult) throws Exception {
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        while (eventType != 1) {
            if (eventType == 2) {
                String name = newPullParser.getName();
                if ("LastModified".equals(name)) {
                    copyObjectResult.a(DateUtil.b(newPullParser.nextText()));
                } else if ("ETag".equals(name)) {
                    copyObjectResult.a(newPullParser.nextText());
                }
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        return copyObjectResult;
    }

    /* access modifiers changed from: private */
    public static ListPartsResult b(InputStream inputStream, ListPartsResult listPartsResult) throws Exception {
        ArrayList arrayList = new ArrayList();
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        PartSummary partSummary = null;
        while (eventType != 1) {
            switch (eventType) {
                case 2:
                    String name = newPullParser.getName();
                    if (!"Bucket".equals(name)) {
                        if (!"Key".equals(name)) {
                            if (!"UploadId".equals(name)) {
                                if (!"PartNumberMarker".equals(name)) {
                                    if (!"NextPartNumberMarker".equals(name)) {
                                        if (!"MaxParts".equals(name)) {
                                            if (!"IsTruncated".equals(name)) {
                                                if (!"StorageClass".equals(name)) {
                                                    if (!"Part".equals(name)) {
                                                        if (!"PartNumber".equals(name)) {
                                                            if (!"LastModified".equals(name)) {
                                                                if (!"ETag".equals(name)) {
                                                                    if ("Size".equals(name)) {
                                                                        String nextText = newPullParser.nextText();
                                                                        if (!OSSUtils.a(nextText)) {
                                                                            partSummary.a(Long.valueOf(nextText).longValue());
                                                                            break;
                                                                        }
                                                                    }
                                                                } else {
                                                                    partSummary.a(newPullParser.nextText());
                                                                    break;
                                                                }
                                                            } else {
                                                                partSummary.a(DateUtil.b(newPullParser.nextText()));
                                                                break;
                                                            }
                                                        } else {
                                                            String nextText2 = newPullParser.nextText();
                                                            if (!OSSUtils.a(nextText2)) {
                                                                partSummary.a(Integer.valueOf(nextText2).intValue());
                                                                break;
                                                            }
                                                        }
                                                    } else {
                                                        partSummary = new PartSummary();
                                                        break;
                                                    }
                                                } else {
                                                    listPartsResult.d(newPullParser.nextText());
                                                    break;
                                                }
                                            } else {
                                                String nextText3 = newPullParser.nextText();
                                                if (!OSSUtils.a(nextText3)) {
                                                    listPartsResult.a(Boolean.valueOf(nextText3).booleanValue());
                                                    break;
                                                }
                                            }
                                        } else {
                                            String nextText4 = newPullParser.nextText();
                                            if (!OSSUtils.a(nextText4)) {
                                                listPartsResult.c(Integer.parseInt(nextText4));
                                                break;
                                            }
                                        }
                                    } else {
                                        String nextText5 = newPullParser.nextText();
                                        if (!OSSUtils.a(nextText5)) {
                                            listPartsResult.b(Integer.parseInt(nextText5));
                                            break;
                                        }
                                    }
                                } else {
                                    String nextText6 = newPullParser.nextText();
                                    if (!OSSUtils.a(nextText6)) {
                                        listPartsResult.a(Integer.parseInt(nextText6));
                                        break;
                                    }
                                }
                            } else {
                                listPartsResult.c(newPullParser.nextText());
                                break;
                            }
                        } else {
                            listPartsResult.b(newPullParser.nextText());
                            break;
                        }
                    } else {
                        listPartsResult.a(newPullParser.nextText());
                        break;
                    }
                    break;
                case 3:
                    if ("Part".equals(newPullParser.getName())) {
                        arrayList.add(partSummary);
                        break;
                    }
                    break;
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        if (arrayList.size() > 0) {
            listPartsResult.a(arrayList);
        }
        return listPartsResult;
    }

    /* access modifiers changed from: private */
    public static CompleteMultipartUploadResult b(InputStream inputStream, CompleteMultipartUploadResult completeMultipartUploadResult) throws Exception {
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        while (eventType != 1) {
            if (eventType == 2) {
                String name = newPullParser.getName();
                if ("Location".equals(name)) {
                    completeMultipartUploadResult.a(newPullParser.nextText());
                } else if ("Bucket".equals(name)) {
                    completeMultipartUploadResult.b(newPullParser.nextText());
                } else if ("Key".equals(name)) {
                    completeMultipartUploadResult.c(newPullParser.nextText());
                } else if ("ETag".equals(name)) {
                    completeMultipartUploadResult.d(newPullParser.nextText());
                }
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        return completeMultipartUploadResult;
    }

    /* access modifiers changed from: private */
    public static InitiateMultipartUploadResult b(InputStream inputStream, InitiateMultipartUploadResult initiateMultipartUploadResult) throws Exception {
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        while (eventType != 1) {
            if (eventType == 2) {
                String name = newPullParser.getName();
                if ("Bucket".equals(name)) {
                    initiateMultipartUploadResult.a(newPullParser.nextText());
                } else if ("Key".equals(name)) {
                    initiateMultipartUploadResult.b(newPullParser.nextText());
                } else if ("UploadId".equals(name)) {
                    initiateMultipartUploadResult.c(newPullParser.nextText());
                }
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        return initiateMultipartUploadResult;
    }

    /* access modifiers changed from: private */
    public static GetObjectACLResult b(InputStream inputStream, GetObjectACLResult getObjectACLResult) throws Exception {
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        while (eventType != 1) {
            if (eventType == 2) {
                String name = newPullParser.getName();
                if ("Grant".equals(name)) {
                    getObjectACLResult.c(newPullParser.nextText());
                } else if ("ID".equals(name)) {
                    getObjectACLResult.b(newPullParser.nextText());
                } else if ("DisplayName".equals(name)) {
                    getObjectACLResult.a(newPullParser.nextText());
                }
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        return getObjectACLResult;
    }

    /* access modifiers changed from: private */
    public static GetBucketInfoResult b(InputStream inputStream, GetBucketInfoResult getBucketInfoResult) throws Exception {
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        OSSBucketSummary oSSBucketSummary = null;
        Owner owner = null;
        while (eventType != 1) {
            switch (eventType) {
                case 2:
                    String name = newPullParser.getName();
                    if (name != null) {
                        if (!"Owner".equals(name)) {
                            if (!"ID".equals(name)) {
                                if (!"DisplayName".equals(name)) {
                                    if (!"Bucket".equals(name)) {
                                        if (!"CreationDate".equals(name)) {
                                            if (!"ExtranetEndpoint".equals(name)) {
                                                if (!"IntranetEndpoint".equals(name)) {
                                                    if (!"Location".equals(name)) {
                                                        if (!"Name".equals(name)) {
                                                            if (!"StorageClass".equals(name)) {
                                                                if ("Grant".equals(name) && oSSBucketSummary != null) {
                                                                    oSSBucketSummary.a(newPullParser.nextText());
                                                                    break;
                                                                }
                                                            } else if (oSSBucketSummary != null) {
                                                                oSSBucketSummary.g = newPullParser.nextText();
                                                                break;
                                                            }
                                                        } else if (oSSBucketSummary != null) {
                                                            oSSBucketSummary.f1235a = newPullParser.nextText();
                                                            break;
                                                        }
                                                    } else if (oSSBucketSummary != null) {
                                                        oSSBucketSummary.d = newPullParser.nextText();
                                                        break;
                                                    }
                                                } else if (oSSBucketSummary != null) {
                                                    oSSBucketSummary.f = newPullParser.nextText();
                                                    break;
                                                }
                                            } else if (oSSBucketSummary != null) {
                                                oSSBucketSummary.e = newPullParser.nextText();
                                                break;
                                            }
                                        } else if (oSSBucketSummary != null) {
                                            oSSBucketSummary.c = DateUtil.b(newPullParser.nextText());
                                            break;
                                        }
                                    } else {
                                        oSSBucketSummary = new OSSBucketSummary();
                                        break;
                                    }
                                } else if (owner != null) {
                                    owner.b(newPullParser.nextText());
                                    break;
                                }
                            } else if (owner != null) {
                                owner.a(newPullParser.nextText());
                                break;
                            }
                        } else {
                            owner = new Owner();
                            break;
                        }
                    }
                    break;
                case 3:
                    String name2 = newPullParser.getName();
                    if (name2 != null) {
                        if (!"Bucket".equals(name2)) {
                            if ("Owner".equals(name2) && oSSBucketSummary != null) {
                                oSSBucketSummary.b = owner;
                                break;
                            }
                        } else if (oSSBucketSummary != null) {
                            getBucketInfoResult.a(oSSBucketSummary);
                            break;
                        }
                    }
                    break;
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        return getBucketInfoResult;
    }

    /* access modifiers changed from: private */
    public static GetBucketACLResult b(InputStream inputStream, GetBucketACLResult getBucketACLResult) throws Exception {
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        while (eventType != 1) {
            if (eventType == 2) {
                String name = newPullParser.getName();
                if ("Grant".equals(name)) {
                    getBucketACLResult.c(newPullParser.nextText());
                } else if ("ID".equals(name)) {
                    getBucketACLResult.b(newPullParser.nextText());
                } else if ("DisplayName".equals(name)) {
                    getBucketACLResult.a(newPullParser.nextText());
                }
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        return getBucketACLResult;
    }

    /* access modifiers changed from: private */
    public static GetBucketRefererResult b(InputStream inputStream, GetBucketRefererResult getBucketRefererResult) throws Exception {
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        while (eventType != 1) {
            if (eventType == 2 && "Referer".equals(newPullParser.getName())) {
                getBucketRefererResult.a(newPullParser.nextText());
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        return getBucketRefererResult;
    }

    /* access modifiers changed from: private */
    public static GetBucketLoggingResult b(InputStream inputStream, GetBucketLoggingResult getBucketLoggingResult) throws Exception {
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        while (eventType != 1) {
            if (eventType == 2) {
                String name = newPullParser.getName();
                if ("LoggingEnabled".equals(name)) {
                    getBucketLoggingResult.a(true);
                } else if ("TargetBucket".equals(name)) {
                    getBucketLoggingResult.a(newPullParser.nextText());
                } else if ("TargetPrefix".equals(name)) {
                    getBucketLoggingResult.b(newPullParser.nextText());
                }
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        return getBucketLoggingResult;
    }

    /* access modifiers changed from: private */
    public static GetBucketLifecycleResult b(InputStream inputStream, GetBucketLifecycleResult getBucketLifecycleResult) throws Exception {
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        BucketLifecycleRule bucketLifecycleRule = null;
        String str = null;
        String str2 = null;
        String str3 = null;
        boolean z = false;
        boolean z2 = false;
        boolean z3 = false;
        while (eventType != 1) {
            switch (eventType) {
                case 2:
                    String name = newPullParser.getName();
                    if (!"Rule".equals(name)) {
                        if (!"ID".equals(name)) {
                            if (!"Prefix".equals(name)) {
                                if (!"Status".equals(name)) {
                                    if (!"Expiration".equals(name)) {
                                        if (!"AbortMultipartUpload".equals(name)) {
                                            if (!"Transition".equals(name)) {
                                                if (!"Days".equals(name)) {
                                                    if (!"Date".equals(name)) {
                                                        if ("StorageClass".equals(name)) {
                                                            String nextText = newPullParser.nextText();
                                                            if (bucketLifecycleRule != null) {
                                                                if ("IA".equals(nextText)) {
                                                                    bucketLifecycleRule.g(str2);
                                                                    bucketLifecycleRule.h(str3);
                                                                } else if ("Archive".equals(nextText)) {
                                                                    bucketLifecycleRule.i(str3);
                                                                    bucketLifecycleRule.j(str3);
                                                                }
                                                            }
                                                            str = nextText;
                                                            break;
                                                        }
                                                    } else {
                                                        String nextText2 = newPullParser.nextText();
                                                        if (bucketLifecycleRule != null) {
                                                            if (z) {
                                                                bucketLifecycleRule.d(nextText2);
                                                            } else if (z2) {
                                                                bucketLifecycleRule.f(nextText2);
                                                            } else if (z3 && str != null) {
                                                                if ("IA".equals(str)) {
                                                                    bucketLifecycleRule.h(nextText2);
                                                                } else if ("Archive".equals(str)) {
                                                                    bucketLifecycleRule.j(nextText2);
                                                                }
                                                            }
                                                        }
                                                        str3 = nextText2;
                                                        break;
                                                    }
                                                } else {
                                                    String nextText3 = newPullParser.nextText();
                                                    if (bucketLifecycleRule != null) {
                                                        if (z) {
                                                            bucketLifecycleRule.c(nextText3);
                                                        } else if (z2) {
                                                            bucketLifecycleRule.e(nextText3);
                                                        } else if (z3 && str != null) {
                                                            if ("IA".equals(str)) {
                                                                bucketLifecycleRule.g(nextText3);
                                                            } else if ("Archive".equals(str)) {
                                                                bucketLifecycleRule.i(nextText3);
                                                            }
                                                        }
                                                    }
                                                    str2 = nextText3;
                                                    break;
                                                }
                                            } else {
                                                z3 = true;
                                                break;
                                            }
                                        } else {
                                            z2 = true;
                                            break;
                                        }
                                    } else {
                                        z = true;
                                        break;
                                    }
                                } else if (!"Enabled".equals(newPullParser.nextText())) {
                                    bucketLifecycleRule.a(false);
                                    break;
                                } else {
                                    bucketLifecycleRule.a(true);
                                    break;
                                }
                            } else {
                                bucketLifecycleRule.b(newPullParser.nextText());
                                break;
                            }
                        } else {
                            bucketLifecycleRule.a(newPullParser.nextText());
                            break;
                        }
                    } else {
                        bucketLifecycleRule = new BucketLifecycleRule();
                        break;
                    }
                    break;
                case 3:
                    String name2 = newPullParser.getName();
                    if (!"Rule".equals(name2)) {
                        if (!"Expiration".equals(name2)) {
                            if (!"AbortMultipartUpload".equals(name2)) {
                                if ("Transition".equals(name2)) {
                                    str = null;
                                    str2 = null;
                                    str3 = null;
                                    z3 = false;
                                    break;
                                }
                            } else {
                                z2 = false;
                                break;
                            }
                        } else {
                            z = false;
                            break;
                        }
                    } else {
                        getBucketLifecycleResult.a(bucketLifecycleRule);
                        break;
                    }
                    break;
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        return getBucketLifecycleResult;
    }

    /* access modifiers changed from: private */
    public static DeleteMultipleObjectResult b(InputStream inputStream, DeleteMultipleObjectResult deleteMultipleObjectResult) throws Exception {
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        while (eventType != 1) {
            if (eventType == 2 && "Key".equals(newPullParser.getName())) {
                deleteMultipleObjectResult.a(newPullParser.nextText());
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        return deleteMultipleObjectResult;
    }

    /* access modifiers changed from: private */
    public static ListBucketsResult b(InputStream inputStream, ListBucketsResult listBucketsResult) throws Exception {
        listBucketsResult.b();
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        OSSBucketSummary oSSBucketSummary = null;
        while (eventType != 1) {
            switch (eventType) {
                case 2:
                    String name = newPullParser.getName();
                    if (name != null) {
                        if (!"Prefix".equals(name)) {
                            if (!"Marker".equals(name)) {
                                if (!"MaxKeys".equals(name)) {
                                    if (!"IsTruncated".equals(name)) {
                                        if (!"NextMarker".equals(name)) {
                                            if (!"ID".equals(name)) {
                                                if (!"DisplayName".equals(name)) {
                                                    if (!"Bucket".equals(name)) {
                                                        if (!"CreationDate".equals(name)) {
                                                            if (!"ExtranetEndpoint".equals(name)) {
                                                                if (!"IntranetEndpoint".equals(name)) {
                                                                    if (!"Location".equals(name)) {
                                                                        if (!"Name".equals(name)) {
                                                                            if ("StorageClass".equals(name) && oSSBucketSummary != null) {
                                                                                oSSBucketSummary.g = newPullParser.nextText();
                                                                                break;
                                                                            }
                                                                        } else if (oSSBucketSummary != null) {
                                                                            oSSBucketSummary.f1235a = newPullParser.nextText();
                                                                            break;
                                                                        }
                                                                    } else if (oSSBucketSummary != null) {
                                                                        oSSBucketSummary.d = newPullParser.nextText();
                                                                        break;
                                                                    }
                                                                } else if (oSSBucketSummary != null) {
                                                                    oSSBucketSummary.f = newPullParser.nextText();
                                                                    break;
                                                                }
                                                            } else if (oSSBucketSummary != null) {
                                                                oSSBucketSummary.e = newPullParser.nextText();
                                                                break;
                                                            }
                                                        } else if (oSSBucketSummary != null) {
                                                            oSSBucketSummary.c = DateUtil.b(newPullParser.nextText());
                                                            break;
                                                        }
                                                    } else {
                                                        oSSBucketSummary = new OSSBucketSummary();
                                                        break;
                                                    }
                                                } else {
                                                    listBucketsResult.e(newPullParser.nextText());
                                                    break;
                                                }
                                            } else {
                                                listBucketsResult.d(newPullParser.nextText());
                                                break;
                                            }
                                        } else {
                                            listBucketsResult.c(newPullParser.nextText());
                                            break;
                                        }
                                    } else {
                                        String nextText = newPullParser.nextText();
                                        if (nextText != null) {
                                            listBucketsResult.a(Boolean.valueOf(nextText).booleanValue());
                                            break;
                                        }
                                    }
                                } else {
                                    String nextText2 = newPullParser.nextText();
                                    if (nextText2 != null) {
                                        listBucketsResult.a(Integer.valueOf(nextText2).intValue());
                                        break;
                                    }
                                }
                            } else {
                                listBucketsResult.b(newPullParser.nextText());
                                break;
                            }
                        } else {
                            listBucketsResult.a(newPullParser.nextText());
                            break;
                        }
                    }
                    break;
                case 3:
                    if ("Bucket".equals(newPullParser.getName()) && oSSBucketSummary != null) {
                        listBucketsResult.a(oSSBucketSummary);
                        break;
                    }
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        return listBucketsResult;
    }

    /* access modifiers changed from: private */
    public static ListObjectsResult b(InputStream inputStream, ListObjectsResult listObjectsResult) throws Exception {
        listObjectsResult.c();
        listObjectsResult.b();
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        Owner owner = null;
        OSSObjectSummary oSSObjectSummary = null;
        boolean z = false;
        while (eventType != 1) {
            switch (eventType) {
                case 2:
                    String name = newPullParser.getName();
                    if (!"Name".equals(name)) {
                        if (!"Prefix".equals(name)) {
                            if (!"Marker".equals(name)) {
                                if (!"Delimiter".equals(name)) {
                                    if (!"EncodingType".equals(name)) {
                                        if (!"MaxKeys".equals(name)) {
                                            if (!"NextMarker".equals(name)) {
                                                if (!"IsTruncated".equals(name)) {
                                                    if (!"Contents".equals(name)) {
                                                        if (!"Key".equals(name)) {
                                                            if (!"LastModified".equals(name)) {
                                                                if (!"Size".equals(name)) {
                                                                    if (!"ETag".equals(name)) {
                                                                        if (!"Type".equals(name)) {
                                                                            if (!"StorageClass".equals(name)) {
                                                                                if (!"Owner".equals(name)) {
                                                                                    if (!"ID".equals(name)) {
                                                                                        if (!"DisplayName".equals(name)) {
                                                                                            if ("CommonPrefixes".equals(name)) {
                                                                                                z = true;
                                                                                                break;
                                                                                            }
                                                                                        } else {
                                                                                            owner.b(newPullParser.nextText());
                                                                                            break;
                                                                                        }
                                                                                    } else {
                                                                                        owner.a(newPullParser.nextText());
                                                                                        break;
                                                                                    }
                                                                                } else {
                                                                                    owner = new Owner();
                                                                                    break;
                                                                                }
                                                                            } else {
                                                                                oSSObjectSummary.d(newPullParser.nextText());
                                                                                break;
                                                                            }
                                                                        } else {
                                                                            oSSObjectSummary.e(newPullParser.nextText());
                                                                            break;
                                                                        }
                                                                    } else {
                                                                        oSSObjectSummary.c(newPullParser.nextText());
                                                                        break;
                                                                    }
                                                                } else {
                                                                    String nextText = newPullParser.nextText();
                                                                    if (!OSSUtils.a(nextText)) {
                                                                        oSSObjectSummary.a(Long.valueOf(nextText).longValue());
                                                                        break;
                                                                    }
                                                                }
                                                            } else {
                                                                oSSObjectSummary.a(DateUtil.b(newPullParser.nextText()));
                                                                break;
                                                            }
                                                        } else {
                                                            oSSObjectSummary.b(newPullParser.nextText());
                                                            break;
                                                        }
                                                    } else {
                                                        oSSObjectSummary = new OSSObjectSummary();
                                                        break;
                                                    }
                                                } else {
                                                    String nextText2 = newPullParser.nextText();
                                                    if (!OSSUtils.a(nextText2)) {
                                                        listObjectsResult.a(Boolean.valueOf(nextText2).booleanValue());
                                                        break;
                                                    }
                                                }
                                            } else {
                                                listObjectsResult.b(newPullParser.nextText());
                                                break;
                                            }
                                        } else {
                                            String nextText3 = newPullParser.nextText();
                                            if (!OSSUtils.a(nextText3)) {
                                                listObjectsResult.a(Integer.valueOf(nextText3).intValue());
                                                break;
                                            }
                                        }
                                    } else {
                                        listObjectsResult.g(newPullParser.nextText());
                                        break;
                                    }
                                } else {
                                    listObjectsResult.f(newPullParser.nextText());
                                    break;
                                }
                            } else {
                                listObjectsResult.e(newPullParser.nextText());
                                break;
                            }
                        } else if (!z) {
                            listObjectsResult.d(newPullParser.nextText());
                            break;
                        } else {
                            String nextText4 = newPullParser.nextText();
                            if (!OSSUtils.a(nextText4)) {
                                listObjectsResult.a(nextText4);
                                break;
                            }
                        }
                    } else {
                        listObjectsResult.c(newPullParser.nextText());
                        break;
                    }
                    break;
                case 3:
                    String name2 = newPullParser.getName();
                    if (!"Owner".equals(newPullParser.getName())) {
                        if (!"Contents".equals(name2)) {
                            if ("CommonPrefixes".equals(name2)) {
                                z = false;
                                break;
                            }
                        } else if (oSSObjectSummary != null) {
                            oSSObjectSummary.a(listObjectsResult.e());
                            listObjectsResult.a(oSSObjectSummary);
                            break;
                        }
                    } else if (owner != null) {
                        oSSObjectSummary.a(owner);
                        break;
                    }
                    break;
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        return listObjectsResult;
    }

    public static String a(String str) {
        if (str == null) {
            return null;
        }
        String trim = str.trim();
        if (trim.startsWith("\"")) {
            trim = trim.substring(1);
        }
        return trim.endsWith("\"") ? trim.substring(0, trim.length() - 1) : trim;
    }

    public static ObjectMetadata a(Map<String, String> map) throws Exception {
        try {
            ObjectMetadata objectMetadata = new ObjectMetadata();
            for (String str : map.keySet()) {
                if (str.indexOf("x-oss-meta-") >= 0) {
                    objectMetadata.a(str, map.get(str));
                } else {
                    if (!str.equalsIgnoreCase("Last-Modified")) {
                        if (!str.equalsIgnoreCase("Date")) {
                            if (str.equalsIgnoreCase(HttpHeaders.CONTENT_LENGTH)) {
                                objectMetadata.a(str, Long.valueOf(map.get(str)));
                            } else if (str.equalsIgnoreCase("ETag")) {
                                objectMetadata.a(str, (Object) a(map.get(str)));
                            } else {
                                objectMetadata.a(str, (Object) map.get(str));
                            }
                        }
                    }
                    try {
                        objectMetadata.a(str, DateUtil.a(map.get(str)));
                    } catch (ParseException e) {
                        throw new IOException(e.getMessage(), e);
                    }
                }
            }
            return objectMetadata;
        } catch (Exception e2) {
            throw new IOException(e2.getMessage(), e2);
        }
    }

    public static Exception a(ResponseMessage responseMessage, boolean z) {
        String str;
        String str2;
        String str3;
        String str4;
        String str5;
        String str6;
        int f = responseMessage.f();
        String header = responseMessage.g().header("x-oss-request-id");
        String str7 = null;
        if (!z) {
            try {
                String string = responseMessage.g().body().string();
                OSSLog.b("errorMessage  ：  \n " + string);
                ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(string.getBytes());
                XmlPullParser newPullParser = Xml.newPullParser();
                newPullParser.setInput(byteArrayInputStream, "utf-8");
                int eventType = newPullParser.getEventType();
                String str8 = null;
                str4 = null;
                String str9 = null;
                str2 = null;
                while (eventType != 1) {
                    if (eventType == 2) {
                        if ("Code".equals(newPullParser.getName())) {
                            str7 = newPullParser.nextText();
                        } else if ("Message".equals(newPullParser.getName())) {
                            str8 = newPullParser.nextText();
                        } else if ("RequestId".equals(newPullParser.getName())) {
                            header = newPullParser.nextText();
                        } else if ("HostId".equals(newPullParser.getName())) {
                            str4 = newPullParser.nextText();
                        } else if ("PartNumber".equals(newPullParser.getName())) {
                            str9 = newPullParser.nextText();
                        } else if ("PartEtag".equals(newPullParser.getName())) {
                            str2 = newPullParser.nextText();
                        }
                    }
                    eventType = newPullParser.next();
                    if (eventType == 4) {
                        eventType = newPullParser.next();
                    }
                }
                str6 = str7;
                str7 = str8;
                str5 = header;
                str3 = string;
                str = str9;
            } catch (IOException e) {
                return new ClientException(e.getMessage(), e);
            } catch (XmlPullParserException e2) {
                return new ClientException(e2.getMessage(), e2);
            }
        } else {
            str5 = header;
            str = null;
            str6 = null;
            str4 = null;
            str3 = null;
            str2 = null;
        }
        ServiceException serviceException = new ServiceException(f, str7, str6, str5, str4, str3);
        if (!TextUtils.isEmpty(str2)) {
            serviceException.b(str2);
        }
        if (!TextUtils.isEmpty(str)) {
            serviceException.a(str);
        }
        return serviceException;
    }

    /* access modifiers changed from: private */
    public static GetObjectTaggingResult b(InputStream inputStream, GetObjectTaggingResult getObjectTaggingResult) throws Exception {
        XmlPullParser newPullParser = Xml.newPullParser();
        newPullParser.setInput(inputStream, "utf-8");
        int eventType = newPullParser.getEventType();
        HashMap hashMap = new HashMap();
        String str = null;
        String str2 = null;
        while (eventType != 1) {
            String name = newPullParser.getName();
            switch (eventType) {
                case 2:
                    if (!"Key".equals(name)) {
                        if ("Value".equals(name)) {
                            str2 = newPullParser.nextText();
                            break;
                        }
                    } else {
                        str = newPullParser.nextText();
                        break;
                    }
                    break;
                case 3:
                    if ("Tag".equals(name)) {
                        if (!(str == null || str2 == null)) {
                            hashMap.put(str, str2);
                        }
                        str = null;
                        str2 = null;
                        break;
                    }
                    break;
            }
            eventType = newPullParser.next();
            if (eventType == 4) {
                eventType = newPullParser.next();
            }
        }
        getObjectTaggingResult.a(hashMap);
        return getObjectTaggingResult;
    }

    public static final class GetObjectMetaResponseParser extends AbstractResponseParser<GetObjectMetaResult> {
        public GetObjectMetaResult a(ResponseMessage responseMessage, GetObjectMetaResult getObjectMetaResult) throws Exception {
            getObjectMetaResult.a(ResponseParsers.a(getObjectMetaResult.g()));
            return getObjectMetaResult;
        }
    }

    public static final class PutObjectResponseParser extends AbstractResponseParser<PutObjectResult> {
        public PutObjectResult a(ResponseMessage responseMessage, PutObjectResult putObjectResult) throws IOException {
            putObjectResult.a(ResponseParsers.a((String) responseMessage.a().get("ETag")));
            String string = responseMessage.g().body().string();
            if (!TextUtils.isEmpty(string)) {
                putObjectResult.b(string);
            }
            return putObjectResult;
        }
    }

    public static final class AppendObjectResponseParser extends AbstractResponseParser<AppendObjectResult> {
        public AppendObjectResult a(ResponseMessage responseMessage, AppendObjectResult appendObjectResult) throws IOException {
            String str = (String) responseMessage.a().get("x-oss-next-append-position");
            if (str != null) {
                appendObjectResult.a(Long.valueOf(str));
            }
            appendObjectResult.a((String) responseMessage.a().get("x-oss-hash-crc64ecma"));
            return appendObjectResult;
        }
    }

    public static final class HeadObjectResponseParser extends AbstractResponseParser<HeadObjectResult> {
        public HeadObjectResult a(ResponseMessage responseMessage, HeadObjectResult headObjectResult) throws Exception {
            headObjectResult.a(ResponseParsers.a(headObjectResult.g()));
            return headObjectResult;
        }
    }

    public static final class GetObjectResponseParser extends AbstractResponseParser<GetObjectResult> {
        @Override // com.alibaba.sdk.android.oss.internal.AbstractResponseParser
        public boolean a() {
            return false;
        }

        public GetObjectResult a(ResponseMessage responseMessage, GetObjectResult getObjectResult) throws Exception {
            getObjectResult.a(ResponseParsers.a(getObjectResult.g()));
            getObjectResult.a(responseMessage.d());
            if (responseMessage.h().p()) {
                getObjectResult.a(new CheckCRC64DownloadInputStream(responseMessage.b(), new CRC64(), responseMessage.d(), getObjectResult.i().longValue(), getObjectResult.h()));
            } else {
                getObjectResult.a(responseMessage.b());
            }
            return getObjectResult;
        }
    }

    public static final class GetObjectACLResponseParser extends AbstractResponseParser<GetObjectACLResult> {
        /* access modifiers changed from: package-private */
        public GetObjectACLResult a(ResponseMessage responseMessage, GetObjectACLResult getObjectACLResult) throws Exception {
            return ResponseParsers.b(responseMessage.b(), getObjectACLResult);
        }
    }

    public static final class CopyObjectResponseParser extends AbstractResponseParser<CopyObjectResult> {
        public CopyObjectResult a(ResponseMessage responseMessage, CopyObjectResult copyObjectResult) throws Exception {
            return ResponseParsers.b(responseMessage.b(), copyObjectResult);
        }
    }

    public static final class CreateBucketResponseParser extends AbstractResponseParser<CreateBucketResult> {
        public CreateBucketResult a(ResponseMessage responseMessage, CreateBucketResult createBucketResult) throws Exception {
            if (createBucketResult.g().containsKey("Location")) {
                createBucketResult.f1205a = createBucketResult.g().get("Location");
            }
            return createBucketResult;
        }
    }

    public static final class GetBucketInfoResponseParser extends AbstractResponseParser<GetBucketInfoResult> {
        public GetBucketInfoResult a(ResponseMessage responseMessage, GetBucketInfoResult getBucketInfoResult) throws Exception {
            return ResponseParsers.b(responseMessage.b(), getBucketInfoResult);
        }
    }

    public static final class GetBucketACLResponseParser extends AbstractResponseParser<GetBucketACLResult> {
        public GetBucketACLResult a(ResponseMessage responseMessage, GetBucketACLResult getBucketACLResult) throws Exception {
            return ResponseParsers.b(responseMessage.b(), getBucketACLResult);
        }
    }

    public static final class GetBucketRefererResponseParser extends AbstractResponseParser<GetBucketRefererResult> {
        public GetBucketRefererResult a(ResponseMessage responseMessage, GetBucketRefererResult getBucketRefererResult) throws Exception {
            return ResponseParsers.b(responseMessage.b(), getBucketRefererResult);
        }
    }

    public static final class GetBucketLoggingResponseParser extends AbstractResponseParser<GetBucketLoggingResult> {
        public GetBucketLoggingResult a(ResponseMessage responseMessage, GetBucketLoggingResult getBucketLoggingResult) throws Exception {
            return ResponseParsers.b(responseMessage.b(), getBucketLoggingResult);
        }
    }

    public static final class GetBucketLifecycleResponseParser extends AbstractResponseParser<GetBucketLifecycleResult> {
        public GetBucketLifecycleResult a(ResponseMessage responseMessage, GetBucketLifecycleResult getBucketLifecycleResult) throws Exception {
            return ResponseParsers.b(responseMessage.b(), getBucketLifecycleResult);
        }
    }

    public static final class DeleteMultipleObjectResponseParser extends AbstractResponseParser<DeleteMultipleObjectResult> {
        /* access modifiers changed from: package-private */
        public DeleteMultipleObjectResult a(ResponseMessage responseMessage, DeleteMultipleObjectResult deleteMultipleObjectResult) throws Exception {
            return ResponseParsers.b(responseMessage.b(), deleteMultipleObjectResult);
        }
    }

    public static final class ListObjectsResponseParser extends AbstractResponseParser<ListObjectsResult> {
        public ListObjectsResult a(ResponseMessage responseMessage, ListObjectsResult listObjectsResult) throws Exception {
            return ResponseParsers.b(responseMessage.b(), listObjectsResult);
        }
    }

    public static final class ListBucketResponseParser extends AbstractResponseParser<ListBucketsResult> {
        /* access modifiers changed from: package-private */
        public ListBucketsResult a(ResponseMessage responseMessage, ListBucketsResult listBucketsResult) throws Exception {
            return ResponseParsers.b(responseMessage.b(), listBucketsResult);
        }
    }

    public static final class InitMultipartResponseParser extends AbstractResponseParser<InitiateMultipartUploadResult> {
        public InitiateMultipartUploadResult a(ResponseMessage responseMessage, InitiateMultipartUploadResult initiateMultipartUploadResult) throws Exception {
            return ResponseParsers.b(responseMessage.b(), initiateMultipartUploadResult);
        }
    }

    public static final class UploadPartResponseParser extends AbstractResponseParser<UploadPartResult> {
        public UploadPartResult a(ResponseMessage responseMessage, UploadPartResult uploadPartResult) throws Exception {
            uploadPartResult.a(ResponseParsers.a((String) responseMessage.a().get("ETag")));
            return uploadPartResult;
        }
    }

    public static final class CompleteMultipartUploadResponseParser extends AbstractResponseParser<CompleteMultipartUploadResult> {
        public CompleteMultipartUploadResult a(ResponseMessage responseMessage, CompleteMultipartUploadResult completeMultipartUploadResult) throws Exception {
            if (((String) responseMessage.a().get(HttpHeaders.CONTENT_TYPE)).equals("application/xml")) {
                return ResponseParsers.b(responseMessage.b(), completeMultipartUploadResult);
            }
            String string = responseMessage.g().body().string();
            if (TextUtils.isEmpty(string)) {
                return completeMultipartUploadResult;
            }
            completeMultipartUploadResult.e(string);
            return completeMultipartUploadResult;
        }
    }

    public static final class ListPartsResponseParser extends AbstractResponseParser<ListPartsResult> {
        public ListPartsResult a(ResponseMessage responseMessage, ListPartsResult listPartsResult) throws Exception {
            return ResponseParsers.b(responseMessage.b(), listPartsResult);
        }
    }

    public static final class ListMultipartUploadsResponseParser extends AbstractResponseParser<ListMultipartUploadsResult> {
        public ListMultipartUploadsResult a(ResponseMessage responseMessage, ListMultipartUploadsResult listMultipartUploadsResult) throws Exception {
            return listMultipartUploadsResult.a(responseMessage);
        }
    }

    public static final class TriggerCallbackResponseParser extends AbstractResponseParser<TriggerCallbackResult> {
        public TriggerCallbackResult a(ResponseMessage responseMessage, TriggerCallbackResult triggerCallbackResult) throws Exception {
            String string = responseMessage.g().body().string();
            if (!TextUtils.isEmpty(string)) {
                triggerCallbackResult.a(string);
            }
            return triggerCallbackResult;
        }
    }

    public static final class GetSymlinkResponseParser extends AbstractResponseParser<GetSymlinkResult> {
        /* access modifiers changed from: package-private */
        public GetSymlinkResult a(ResponseMessage responseMessage, GetSymlinkResult getSymlinkResult) throws Exception {
            getSymlinkResult.a((String) responseMessage.a().get("x-oss-symlink-target"));
            return getSymlinkResult;
        }
    }

    public static final class GetObjectTaggingResponseParser extends AbstractResponseParser<GetObjectTaggingResult> {
        /* access modifiers changed from: package-private */
        public GetObjectTaggingResult a(ResponseMessage responseMessage, GetObjectTaggingResult getObjectTaggingResult) throws Exception {
            return ResponseParsers.b(responseMessage.b(), getObjectTaggingResult);
        }
    }
}
