package com.facebook.react.flat;

import com.facebook.infer.annotation.Assertions;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.modules.fresco.FrescoModule;
import com.facebook.react.modules.i18nmanager.I18nUtil;
import com.facebook.react.uimanager.ReactShadowNode;
import com.facebook.react.uimanager.ReactStylesDiffMap;
import com.facebook.react.uimanager.UIImplementation;
import com.facebook.react.uimanager.ViewManager;
import com.facebook.react.views.text.ReactRawTextManager;
import com.facebook.react.views.text.ReactTextViewManager;
import com.facebook.react.views.text.ReactVirtualTextViewManager;
import com.facebook.react.views.view.ReactViewManager;
import com.facebook.yoga.YogaDirection;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import javax.annotation.Nullable;

public class FlatUIImplementation extends UIImplementation {
    private static final Map<String, Class<? extends ViewManager>> e = new HashMap();
    private final MoveProxy f;
    private final ReactApplicationContext g;
    @Nullable
    private RCTImageViewManager h;
    private final StateBuilder i;
    private final boolean j;

    static {
        e.put(ReactViewManager.REACT_CLASS, RCTViewManager.class);
        e.put(ReactTextViewManager.REACT_CLASS, RCTTextManager.class);
        e.put(ReactRawTextManager.REACT_CLASS, RCTRawTextManager.class);
        e.put(ReactVirtualTextViewManager.REACT_CLASS, RCTVirtualTextManager.class);
        e.put("RCTTextInlineImage", RCTTextInlineImageManager.class);
        e.put("RCTImageView", RCTImageViewManager.class);
        e.put("AndroidTextInput", RCTTextInputManager.class);
        e.put("AndroidViewPager", RCTViewPagerManager.class);
        e.put("ARTSurfaceView", FlatARTSurfaceViewManager.class);
        e.put("RCTModalHostView", RCTModalHostManager.class);
    }

    /* access modifiers changed from: protected */
    @Override // com.facebook.react.uimanager.UIImplementation
    public ReactShadowNode a() {
        if (this.h != null) {
            this.g.b(FrescoModule.class);
            DraweeRequestHelper.a(this.h.getDraweeControllerBuilder());
            this.h = null;
        }
        FlatRootShadowNode flatRootShadowNode = new FlatRootShadowNode();
        if (I18nUtil.a().a(this.g)) {
            flatRootShadowNode.a(YogaDirection.RTL);
        }
        return flatRootShadowNode;
    }

    /* access modifiers changed from: protected */
    @Override // com.facebook.react.uimanager.UIImplementation
    public ReactShadowNode a(String str) {
        ReactShadowNode a2 = super.a(str);
        return ((a2 instanceof FlatShadowNode) || a2.d()) ? a2 : new NativeViewWrapper(b(str));
    }

    /* access modifiers changed from: protected */
    @Override // com.facebook.react.uimanager.UIImplementation
    public void a(ReactShadowNode reactShadowNode, int i2, @Nullable ReactStylesDiffMap reactStylesDiffMap) {
        if (reactShadowNode instanceof FlatShadowNode) {
            FlatShadowNode flatShadowNode = (FlatShadowNode) reactShadowNode;
            if (reactStylesDiffMap != null) {
                flatShadowNode.a(reactStylesDiffMap);
            }
            if (flatShadowNode.C()) {
                this.i.a(flatShadowNode, reactStylesDiffMap);
                return;
            }
            return;
        }
        super.a(reactShadowNode, i2, reactStylesDiffMap);
    }

    /* access modifiers changed from: protected */
    @Override // com.facebook.react.uimanager.UIImplementation
    public void a(ReactShadowNode reactShadowNode, String str, ReactStylesDiffMap reactStylesDiffMap) {
        if (reactShadowNode instanceof FlatShadowNode) {
            FlatShadowNode flatShadowNode = (FlatShadowNode) reactShadowNode;
            flatShadowNode.a(reactStylesDiffMap);
            if (flatShadowNode.C()) {
                this.i.a(flatShadowNode, reactStylesDiffMap);
                return;
            }
            return;
        }
        super.a(reactShadowNode, str, reactStylesDiffMap);
    }

    @Override // com.facebook.react.uimanager.UIImplementation
    public void a(int i2, @Nullable ReadableArray readableArray, @Nullable ReadableArray readableArray2, @Nullable ReadableArray readableArray3, @Nullable ReadableArray readableArray4, @Nullable ReadableArray readableArray5) {
        ReactShadowNode b = b(i2);
        a(b, readableArray, readableArray2, readableArray5);
        a(b, readableArray3, readableArray4);
    }

    @Override // com.facebook.react.uimanager.UIImplementation
    public void a(int i2, ReadableArray readableArray) {
        ReactShadowNode b = b(i2);
        for (int i3 = 0; i3 < readableArray.a(); i3++) {
            a(b, b(readableArray.c(i3)), i3, i3 - 1);
        }
    }

    @Override // com.facebook.react.uimanager.UIImplementation
    public void a(int i2, Callback callback) {
        a(i2, false, callback);
    }

    private void a(int i2, boolean z, Callback callback) {
        FlatShadowNode flatShadowNode = (FlatShadowNode) b(i2);
        if (flatShadowNode.C()) {
            this.i.b(flatShadowNode);
            if (z) {
                super.b(i2, callback);
            } else {
                super.a(i2, callback);
            }
        } else {
            while (flatShadowNode != null && flatShadowNode.d()) {
                flatShadowNode = (FlatShadowNode) flatShadowNode.X();
            }
            if (flatShadowNode != null) {
                float at = flatShadowNode.at();
                float au = flatShadowNode.au();
                boolean C = flatShadowNode.C();
                float f2 = 0.0f;
                float af = C ? flatShadowNode.af() : 0.0f;
                if (C) {
                    f2 = flatShadowNode.ag();
                }
                while (!flatShadowNode.C()) {
                    if (!flatShadowNode.d()) {
                        af += flatShadowNode.af();
                        f2 += flatShadowNode.ag();
                    }
                    flatShadowNode = (FlatShadowNode) Assertions.a((FlatShadowNode) flatShadowNode.X());
                }
                float at2 = flatShadowNode.at();
                float au2 = flatShadowNode.au();
                this.i.a().a(flatShadowNode.V(), af / at2, f2 / au2, at / at2, au / au2, z, callback);
            }
        }
    }

    private void h(int i2) {
        FlatShadowNode flatShadowNode = (FlatShadowNode) b(i2);
        if (!flatShadowNode.D()) {
            flatShadowNode.B();
            this.i.b(flatShadowNode);
        }
    }

    @Override // com.facebook.react.uimanager.UIImplementation
    public void a(int i2, float f2, float f3, Callback callback) {
        h(i2);
        super.a(i2, f2, f3, callback);
    }

    @Override // com.facebook.react.uimanager.UIImplementation
    public void b(int i2, Callback callback) {
        a(i2, true, callback);
    }

    @Override // com.facebook.react.uimanager.UIImplementation
    public void a(int i2, int i3, Callback callback) {
        h(i2);
        super.a(i2, i3, callback);
    }

    @Override // com.facebook.react.uimanager.UIImplementation
    public void a(int i2, int i3, ReadableArray readableArray) {
        h(i2);
        this.i.a(i2, i3, readableArray);
    }

    @Override // com.facebook.react.uimanager.UIImplementation
    public void a(int i2, ReadableArray readableArray, Callback callback, Callback callback2) {
        h(i2);
        super.a(i2, readableArray, callback, callback2);
    }

    @Override // com.facebook.react.uimanager.UIImplementation
    public void a(int i2, int i3) {
        h(i2);
        super.a(i2, i3);
    }

    private void a(ReactShadowNode reactShadowNode, @Nullable ReadableArray readableArray, @Nullable ReadableArray readableArray2, @Nullable ReadableArray readableArray3) {
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        int i7;
        this.f.a(readableArray, readableArray2);
        int a2 = this.f.a() - 1;
        if (a2 == -1) {
            i2 = -1;
        } else {
            i2 = this.f.b(a2);
        }
        if (readableArray3 == null) {
            i3 = 0;
        } else {
            i3 = readableArray3.a();
        }
        int[] iArr = new int[i3];
        if (i3 > 0) {
            Assertions.b(readableArray3);
            for (int i8 = 0; i8 < i3; i8++) {
                iArr[i8] = readableArray3.c(i8);
            }
        }
        Arrays.sort(iArr);
        int i9 = Integer.MAX_VALUE;
        if (readableArray3 == null) {
            i4 = -1;
            i5 = -1;
        } else {
            i4 = iArr.length - 1;
            i5 = iArr[i4];
        }
        while (true) {
            if (i2 > i5) {
                a(b(reactShadowNode, i2, i9), a2);
                a2--;
                if (a2 == -1) {
                    i7 = -1;
                } else {
                    i7 = this.f.b(a2);
                }
                i9 = i2;
                i2 = i7;
            } else if (i5 > i2) {
                a(b(reactShadowNode, i5, i9), reactShadowNode);
                i4--;
                if (i4 == -1) {
                    i6 = -1;
                } else {
                    i6 = iArr[i4];
                }
                i5 = i6;
                i9 = i5;
            } else {
                return;
            }
        }
    }

    private void a(ReactShadowNode reactShadowNode, ReactShadowNode reactShadowNode2) {
        b(reactShadowNode, reactShadowNode2);
        a(reactShadowNode);
    }

    private void b(ReactShadowNode reactShadowNode, ReactShadowNode reactShadowNode2) {
        if (reactShadowNode instanceof FlatShadowNode) {
            FlatShadowNode flatShadowNode = (FlatShadowNode) reactShadowNode;
            if (flatShadowNode.C() && flatShadowNode.D()) {
                int i2 = -1;
                while (true) {
                    if (reactShadowNode2 == null) {
                        break;
                    }
                    if (reactShadowNode2 instanceof FlatShadowNode) {
                        FlatShadowNode flatShadowNode2 = (FlatShadowNode) reactShadowNode2;
                        if (flatShadowNode2.C() && flatShadowNode2.D() && flatShadowNode2.X() != null) {
                            i2 = flatShadowNode2.V();
                            break;
                        }
                    }
                    reactShadowNode2 = reactShadowNode2.X();
                }
                this.i.a(flatShadowNode, i2);
                return;
            }
        }
        int S = reactShadowNode.S();
        for (int i3 = 0; i3 != S; i3++) {
            b(reactShadowNode.e(i3), reactShadowNode);
        }
    }

    private void a(ReactShadowNode reactShadowNode, int i2) {
        this.f.a(i2, reactShadowNode);
    }

    private void a(ReactShadowNode reactShadowNode, @Nullable ReadableArray readableArray, @Nullable ReadableArray readableArray2) {
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        int i7;
        int i8 = 0;
        if (this.f.a() == 0) {
            i3 = Integer.MAX_VALUE;
            i2 = Integer.MAX_VALUE;
        } else {
            i2 = this.f.c(0);
            i3 = 0;
        }
        int i9 = -1;
        if (readableArray2 == null) {
            i8 = Integer.MAX_VALUE;
            i5 = 0;
            i4 = Integer.MAX_VALUE;
        } else {
            i5 = readableArray2.a();
            i4 = readableArray2.c(0);
        }
        while (true) {
            if (i4 < i2) {
                a(reactShadowNode, b(readableArray.c(i8)), i4, i9);
                i8++;
                if (i8 == i5) {
                    i7 = Integer.MAX_VALUE;
                } else {
                    i7 = readableArray2.c(i8);
                }
                i4 = i7;
                i9 = i4;
            } else if (i2 < i4) {
                a(reactShadowNode, this.f.a(i3), i2, i9);
                i3++;
                if (i3 == this.f.a()) {
                    i6 = Integer.MAX_VALUE;
                } else {
                    i6 = this.f.c(i3);
                }
                i9 = i2;
                i2 = i6;
            } else {
                return;
            }
        }
    }

    private static ReactShadowNode b(ReactShadowNode reactShadowNode, int i2, int i3) {
        if (i2 < i3) {
            return reactShadowNode.d(i2);
        }
        throw new RuntimeException("Invariant failure, needs sorting! " + i2 + " >= " + i3);
    }

    private static void a(ReactShadowNode reactShadowNode, ReactShadowNode reactShadowNode2, int i2, int i3) {
        if (i2 > i3) {
            reactShadowNode.a(reactShadowNode2, i2);
            return;
        }
        throw new RuntimeException("Invariant failure, needs sorting! " + i2 + " <= " + i3);
    }

    /* access modifiers changed from: protected */
    @Override // com.facebook.react.uimanager.UIImplementation
    public void b() {
        super.b();
        this.i.a(this.f2239a);
    }

    /* access modifiers changed from: protected */
    @Override // com.facebook.react.uimanager.UIImplementation
    public void a(ReactShadowNode reactShadowNode, float f2, float f3) {
        this.i.a((FlatRootShadowNode) reactShadowNode);
    }

    @Override // com.facebook.react.uimanager.UIImplementation
    public void a(int i2) {
        if (this.j) {
            c(i2);
        }
        this.i.a(i2);
    }

    @Override // com.facebook.react.uimanager.UIImplementation
    public void a(int i2, boolean z) {
        ReactShadowNode b = b(i2);
        while (b.d()) {
            b = b.X();
        }
        int V = b.V();
        while ((b instanceof FlatShadowNode) && !((FlatShadowNode) b).C()) {
            b = b.X();
        }
        FlatUIViewOperationQueue a2 = this.i.a();
        if (b != null) {
            V = b.V();
        }
        a2.a(V, i2, z);
    }
}
