package com.facebook.react.flat;

import android.graphics.Rect;
import android.os.Build;
import com.facebook.react.bridge.JSApplicationIllegalArgumentException;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.common.MapBuilder;
import com.facebook.react.uimanager.PixelUtil;
import com.facebook.react.uimanager.PointerEvents;
import com.facebook.react.uimanager.annotations.ReactProp;
import com.facebook.react.views.view.ReactDrawableHelper;
import java.util.Map;
import javax.annotation.Nullable;

public final class RCTViewManager extends FlatViewManager {
    private static final int CMD_HOTSPOT_UPDATE = 1;
    private static final int CMD_SET_PRESSED = 2;
    static final String REACT_CLASS = "RCTView";
    private static final int[] TMP_INT_ARRAY = new int[2];

    @Override // com.facebook.react.bridge.NativeModule, com.facebook.react.uimanager.ViewManager
    public String getName() {
        return "RCTView";
    }

    @Override // com.facebook.react.flat.FlatViewManager
    public /* bridge */ /* synthetic */ void removeAllViews(FlatViewGroup flatViewGroup) {
        super.removeAllViews(flatViewGroup);
    }

    @Override // com.facebook.react.flat.FlatViewManager
    public /* bridge */ /* synthetic */ void setBackgroundColor(FlatViewGroup flatViewGroup, int i) {
        super.setBackgroundColor(flatViewGroup, i);
    }

    @Override // com.facebook.react.uimanager.ViewManager
    public Map<String, Integer> getCommandsMap() {
        return MapBuilder.a("hotspotUpdate", 1, "setPressed", 2);
    }

    @Override // com.facebook.react.uimanager.ViewGroupManager, com.facebook.react.uimanager.ViewGroupManager, com.facebook.react.uimanager.ViewManager
    public RCTView createShadowNodeInstance() {
        return new RCTView();
    }

    @Override // com.facebook.react.uimanager.ViewGroupManager, com.facebook.react.uimanager.ViewManager
    public Class<RCTView> getShadowNodeClass() {
        return RCTView.class;
    }

    @ReactProp(a = "nativeBackgroundAndroid")
    public void setHotspot(FlatViewGroup flatViewGroup, @Nullable ReadableMap readableMap) {
        flatViewGroup.a(readableMap == null ? null : ReactDrawableHelper.a(flatViewGroup.getContext(), readableMap));
    }

    public void receiveCommand(FlatViewGroup flatViewGroup, int i, @Nullable ReadableArray readableArray) {
        switch (i) {
            case 1:
                if (readableArray == null || readableArray.a() != 2) {
                    throw new JSApplicationIllegalArgumentException("Illegal number of arguments for 'updateHotspot' command");
                } else if (Build.VERSION.SDK_INT >= 21) {
                    flatViewGroup.getLocationOnScreen(TMP_INT_ARRAY);
                    flatViewGroup.drawableHotspotChanged(PixelUtil.a(readableArray.b(0)) - ((float) TMP_INT_ARRAY[0]), PixelUtil.a(readableArray.b(1)) - ((float) TMP_INT_ARRAY[1]));
                    return;
                } else {
                    return;
                }
            case 2:
                if (readableArray == null || readableArray.a() != 1) {
                    throw new JSApplicationIllegalArgumentException("Illegal number of arguments for 'setPressed' command");
                }
                flatViewGroup.setPressed(readableArray.f(0));
                return;
            default:
                return;
        }
    }

    @ReactProp(a = "needsOffscreenAlphaCompositing")
    public void setNeedsOffscreenAlphaCompositing(FlatViewGroup flatViewGroup, boolean z) {
        flatViewGroup.a(z);
    }

    @ReactProp(a = "pointerEvents")
    public void setPointerEvents(FlatViewGroup flatViewGroup, @Nullable String str) {
        flatViewGroup.a(parsePointerEvents(str));
    }

    @ReactProp(a = "removeClippedSubviews")
    public void setRemoveClippedSubviews(FlatViewGroup flatViewGroup, boolean z) {
        flatViewGroup.b(z);
    }

    private static PointerEvents parsePointerEvents(@Nullable String str) {
        if (str != null) {
            char c = 65535;
            int hashCode = str.hashCode();
            if (hashCode != -2089141766) {
                if (hashCode != -2089112978) {
                    if (hashCode != 3005871) {
                        if (hashCode == 3387192 && str.equals("none")) {
                            c = 0;
                        }
                    } else if (str.equals("auto")) {
                        c = 1;
                    }
                } else if (str.equals("box-only")) {
                    c = 3;
                }
            } else if (str.equals("box-none")) {
                c = 2;
            }
            switch (c) {
                case 0:
                    return PointerEvents.NONE;
                case 1:
                    return PointerEvents.AUTO;
                case 2:
                    return PointerEvents.BOX_NONE;
                case 3:
                    return PointerEvents.BOX_ONLY;
            }
        }
        return PointerEvents.AUTO;
    }

    @ReactProp(a = "hitSlop")
    public void setHitSlop(FlatViewGroup flatViewGroup, @Nullable ReadableMap readableMap) {
        if (readableMap == null) {
            flatViewGroup.b((Rect) null);
        } else {
            flatViewGroup.b(new Rect((int) PixelUtil.a(readableMap.d("left")), (int) PixelUtil.a(readableMap.d("top")), (int) PixelUtil.a(readableMap.d("right")), (int) PixelUtil.a(readableMap.d("bottom"))));
        }
    }
}
