package com.facebook.react.modules.blob;

import android.content.res.Resources;
import android.database.Cursor;
import android.net.Uri;
import android.support.annotation.Nullable;
import android.webkit.MimeTypeMap;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.common.MapBuilder;
import com.facebook.react.module.annotations.ReactModule;
import com.facebook.react.modules.network.NetworkingModule;
import com.facebook.react.modules.websocket.WebSocketModule;
import com.facebook.stetho.common.Utf8Charset;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteBuffer;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.UUID;
import okhttp3.MediaType;
import okhttp3.RequestBody;
import okhttp3.ResponseBody;
import okio.ByteString;

@ReactModule
public class BlobModule extends ReactContextBaseJavaModule {
    protected static final String NAME = "BlobModule";
    private final Map<String, byte[]> mBlobs = new HashMap();
    private final NetworkingModule.RequestBodyHandler mNetworkingRequestBodyHandler = new NetworkingModule.RequestBodyHandler() {
        /* class com.facebook.react.modules.blob.BlobModule.AnonymousClass3 */

        @Override // com.facebook.react.modules.network.NetworkingModule.RequestBodyHandler
        public boolean a(ReadableMap readableMap) {
            return readableMap.a("blob");
        }

        @Override // com.facebook.react.modules.network.NetworkingModule.RequestBodyHandler
        public RequestBody a(ReadableMap readableMap, String str) {
            if (readableMap.a("type") && !readableMap.f("type").isEmpty()) {
                str = readableMap.f("type");
            }
            if (str == null) {
                str = "application/octet-stream";
            }
            ReadableMap g = readableMap.g("blob");
            return RequestBody.create(MediaType.parse(str), BlobModule.this.resolve(g.f("blobId"), g.e("offset"), g.e("size")));
        }
    };
    private final NetworkingModule.ResponseHandler mNetworkingResponseHandler = new NetworkingModule.ResponseHandler() {
        /* class com.facebook.react.modules.blob.BlobModule.AnonymousClass4 */

        @Override // com.facebook.react.modules.network.NetworkingModule.ResponseHandler
        public boolean a(String str) {
            return str.equals("blob");
        }

        @Override // com.facebook.react.modules.network.NetworkingModule.ResponseHandler
        public WritableMap a(ResponseBody responseBody) throws IOException {
            byte[] bytes = responseBody.bytes();
            WritableMap b = Arguments.b();
            b.putString("blobId", BlobModule.this.store(bytes));
            b.putInt("offset", 0);
            b.putInt("size", bytes.length);
            return b;
        }
    };
    private final NetworkingModule.UriHandler mNetworkingUriHandler = new NetworkingModule.UriHandler() {
        /* class com.facebook.react.modules.blob.BlobModule.AnonymousClass2 */

        @Override // com.facebook.react.modules.network.NetworkingModule.UriHandler
        public boolean a(Uri uri, String str) {
            String scheme = uri.getScheme();
            if (("http".equals(scheme) || "https".equals(scheme)) || !str.equals("blob")) {
                return false;
            }
            return true;
        }

        @Override // com.facebook.react.modules.network.NetworkingModule.UriHandler
        public WritableMap a(Uri uri) throws IOException {
            byte[] bytesFromUri = BlobModule.this.getBytesFromUri(uri);
            WritableMap b = Arguments.b();
            b.putString("blobId", BlobModule.this.store(bytesFromUri));
            b.putInt("offset", 0);
            b.putInt("size", bytesFromUri.length);
            b.putString("type", BlobModule.this.getMimeTypeFromUri(uri));
            b.putString("name", BlobModule.this.getNameFromUri(uri));
            b.putDouble("lastModified", (double) BlobModule.this.getLastModifiedFromUri(uri));
            return b;
        }
    };
    private final WebSocketModule.ContentHandler mWebSocketContentHandler = new WebSocketModule.ContentHandler() {
        /* class com.facebook.react.modules.blob.BlobModule.AnonymousClass1 */

        @Override // com.facebook.react.modules.websocket.WebSocketModule.ContentHandler
        public void a(String str, WritableMap writableMap) {
            writableMap.putString("data", str);
        }

        @Override // com.facebook.react.modules.websocket.WebSocketModule.ContentHandler
        public void a(ByteString byteString, WritableMap writableMap) {
            byte[] i = byteString.i();
            WritableMap b = Arguments.b();
            b.putString("blobId", BlobModule.this.store(i));
            b.putInt("offset", 0);
            b.putInt("size", i.length);
            writableMap.a("data", b);
            writableMap.putString("type", "blob");
        }
    };

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return NAME;
    }

    public BlobModule(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
    }

    @Override // com.facebook.react.bridge.BaseJavaModule
    @Nullable
    public Map<String, Object> getConstants() {
        Resources resources = getReactApplicationContext().getResources();
        int identifier = resources.getIdentifier("blob_provider_authority", "string", getReactApplicationContext().getPackageName());
        if (identifier == 0) {
            return null;
        }
        return MapBuilder.a("BLOB_URI_SCHEME", "content", "BLOB_URI_HOST", resources.getString(identifier));
    }

    public String store(byte[] bArr) {
        String uuid = UUID.randomUUID().toString();
        store(bArr, uuid);
        return uuid;
    }

    public void store(byte[] bArr, String str) {
        this.mBlobs.put(str, bArr);
    }

    public void remove(String str) {
        this.mBlobs.remove(str);
    }

    @Nullable
    public byte[] resolve(Uri uri) {
        String lastPathSegment = uri.getLastPathSegment();
        String queryParameter = uri.getQueryParameter("offset");
        int parseInt = queryParameter != null ? Integer.parseInt(queryParameter, 10) : 0;
        String queryParameter2 = uri.getQueryParameter("size");
        return resolve(lastPathSegment, parseInt, queryParameter2 != null ? Integer.parseInt(queryParameter2, 10) : -1);
    }

    @Nullable
    public byte[] resolve(String str, int i, int i2) {
        byte[] bArr = this.mBlobs.get(str);
        if (bArr == null) {
            return null;
        }
        if (i2 == -1) {
            i2 = bArr.length - i;
        }
        return (i > 0 || i2 != bArr.length) ? Arrays.copyOfRange(bArr, i, i2 + i) : bArr;
    }

    @Nullable
    public byte[] resolve(ReadableMap readableMap) {
        return resolve(readableMap.f("blobId"), readableMap.e("offset"), readableMap.e("size"));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private byte[] getBytesFromUri(Uri uri) throws IOException {
        InputStream openInputStream = getReactApplicationContext().getContentResolver().openInputStream(uri);
        if (openInputStream != null) {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            byte[] bArr = new byte[1024];
            while (true) {
                int read = openInputStream.read(bArr);
                if (read == -1) {
                    return byteArrayOutputStream.toByteArray();
                }
                byteArrayOutputStream.write(bArr, 0, read);
            }
        } else {
            throw new FileNotFoundException("File not found for " + uri);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getNameFromUri(Uri uri) {
        if (uri.getScheme().equals("file")) {
            return uri.getLastPathSegment();
        }
        Cursor query = getReactApplicationContext().getContentResolver().query(uri, new String[]{"_display_name"}, null, null, null);
        if (query != null) {
            try {
                if (query.moveToFirst()) {
                    return query.getString(0);
                }
                query.close();
            } finally {
                query.close();
            }
        }
        return uri.getLastPathSegment();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private long getLastModifiedFromUri(Uri uri) {
        if (uri.getScheme().equals("file")) {
            return new File(uri.toString()).lastModified();
        }
        return 0;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getMimeTypeFromUri(Uri uri) {
        String fileExtensionFromUrl;
        String type = getReactApplicationContext().getContentResolver().getType(uri);
        if (type == null && (fileExtensionFromUrl = MimeTypeMap.getFileExtensionFromUrl(uri.getPath())) != null) {
            type = MimeTypeMap.getSingleton().getMimeTypeFromExtension(fileExtensionFromUrl);
        }
        return type == null ? "" : type;
    }

    private WebSocketModule getWebSocketModule() {
        return (WebSocketModule) getReactApplicationContext().b(WebSocketModule.class);
    }

    @ReactMethod
    public void addNetworkingHandler() {
        NetworkingModule networkingModule = (NetworkingModule) getReactApplicationContext().b(NetworkingModule.class);
        networkingModule.addUriHandler(this.mNetworkingUriHandler);
        networkingModule.addRequestBodyHandler(this.mNetworkingRequestBodyHandler);
        networkingModule.addResponseHandler(this.mNetworkingResponseHandler);
    }

    @ReactMethod
    public void addWebSocketHandler(int i) {
        getWebSocketModule().setContentHandler(i, this.mWebSocketContentHandler);
    }

    @ReactMethod
    public void removeWebSocketHandler(int i) {
        getWebSocketModule().setContentHandler(i, null);
    }

    @ReactMethod
    public void sendOverSocket(ReadableMap readableMap, int i) {
        byte[] resolve = resolve(readableMap.f("blobId"), readableMap.e("offset"), readableMap.e("size"));
        if (resolve != null) {
            getWebSocketModule().sendBinary(ByteString.a(resolve), i);
        } else {
            getWebSocketModule().sendBinary((ByteString) null, i);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:17:0x0061  */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x0077  */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x0044 A[SYNTHETIC] */
    @ReactMethod
    public void createFromParts(ReadableArray readableArray, String str) {
        char c;
        ArrayList arrayList = new ArrayList(readableArray.a());
        int i = 0;
        for (int i2 = 0; i2 < readableArray.a(); i2++) {
            ReadableMap i3 = readableArray.i(i2);
            String f = i3.f("type");
            int hashCode = f.hashCode();
            if (hashCode != -891985903) {
                if (hashCode == 3026845 && f.equals("blob")) {
                    c = 0;
                    switch (c) {
                        case 0:
                            ReadableMap g = i3.g("data");
                            i += g.e("size");
                            arrayList.add(i2, resolve(g));
                            break;
                        case 1:
                            byte[] bytes = i3.f("data").getBytes(Charset.forName(Utf8Charset.NAME));
                            i += bytes.length;
                            arrayList.add(i2, bytes);
                            break;
                        default:
                            throw new IllegalArgumentException("Invalid type for blob: " + i3.f("type"));
                    }
                }
            } else if (f.equals("string")) {
                c = 1;
                switch (c) {
                }
            }
            c = 65535;
            switch (c) {
            }
        }
        ByteBuffer allocate = ByteBuffer.allocate(i);
        Iterator it = arrayList.iterator();
        while (it.hasNext()) {
            allocate.put((byte[]) it.next());
        }
        store(allocate.array(), str);
    }

    @ReactMethod
    public void release(String str) {
        remove(str);
    }
}
