package com.facebook.react.modules.datepicker;

import android.app.Activity;
import android.app.DatePickerDialog;
import android.content.DialogInterface;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentManager;
import android.widget.DatePicker;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableNativeMap;
import com.facebook.react.common.annotations.VisibleForTesting;
import com.facebook.react.module.annotations.ReactModule;
import javax.annotation.Nullable;

@ReactModule
public class DatePickerDialogModule extends ReactContextBaseJavaModule {
    static final String ACTION_DATE_SET = "dateSetAction";
    static final String ACTION_DISMISSED = "dismissedAction";
    static final String ARG_DATE = "date";
    static final String ARG_MAXDATE = "maxDate";
    static final String ARG_MINDATE = "minDate";
    static final String ARG_MODE = "mode";
    private static final String ERROR_NO_ACTIVITY = "E_NO_ACTIVITY";
    @VisibleForTesting
    public static final String FRAGMENT_TAG = "DatePickerAndroid";

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return FRAGMENT_TAG;
    }

    public DatePickerDialogModule(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
    }

    private class DatePickerDialogListener implements DatePickerDialog.OnDateSetListener, DialogInterface.OnDismissListener {
        private final Promise b;
        private boolean c = false;

        public DatePickerDialogListener(Promise promise) {
            this.b = promise;
        }

        public void onDateSet(DatePicker datePicker, int i, int i2, int i3) {
            if (!this.c && DatePickerDialogModule.this.getReactApplicationContext().b()) {
                WritableNativeMap writableNativeMap = new WritableNativeMap();
                writableNativeMap.putString("action", DatePickerDialogModule.ACTION_DATE_SET);
                writableNativeMap.putInt("year", i);
                writableNativeMap.putInt("month", i2);
                writableNativeMap.putInt("day", i3);
                this.b.a(writableNativeMap);
                this.c = true;
            }
        }

        public void onDismiss(DialogInterface dialogInterface) {
            if (!this.c && DatePickerDialogModule.this.getReactApplicationContext().b()) {
                WritableNativeMap writableNativeMap = new WritableNativeMap();
                writableNativeMap.putString("action", DatePickerDialogModule.ACTION_DISMISSED);
                this.b.a(writableNativeMap);
                this.c = true;
            }
        }
    }

    @ReactMethod
    public void open(@Nullable ReadableMap readableMap, Promise promise) {
        Activity currentActivity = getCurrentActivity();
        if (currentActivity == null) {
            promise.a(ERROR_NO_ACTIVITY, "Tried to open a DatePicker dialog while not attached to an Activity");
        } else if (currentActivity instanceof FragmentActivity) {
            FragmentManager supportFragmentManager = ((FragmentActivity) currentActivity).getSupportFragmentManager();
            DialogFragment dialogFragment = (DialogFragment) supportFragmentManager.a(FRAGMENT_TAG);
            if (dialogFragment != null) {
                dialogFragment.a();
            }
            SupportDatePickerDialogFragment supportDatePickerDialogFragment = new SupportDatePickerDialogFragment();
            if (readableMap != null) {
                supportDatePickerDialogFragment.g(createFragmentArguments(readableMap));
            }
            DatePickerDialogListener datePickerDialogListener = new DatePickerDialogListener(promise);
            supportDatePickerDialogFragment.a((DialogInterface.OnDismissListener) datePickerDialogListener);
            supportDatePickerDialogFragment.a((DatePickerDialog.OnDateSetListener) datePickerDialogListener);
            supportDatePickerDialogFragment.a(supportFragmentManager, FRAGMENT_TAG);
        } else {
            android.app.FragmentManager fragmentManager = currentActivity.getFragmentManager();
            android.app.DialogFragment dialogFragment2 = (android.app.DialogFragment) fragmentManager.findFragmentByTag(FRAGMENT_TAG);
            if (dialogFragment2 != null) {
                dialogFragment2.dismiss();
            }
            DatePickerDialogFragment datePickerDialogFragment = new DatePickerDialogFragment();
            if (readableMap != null) {
                datePickerDialogFragment.setArguments(createFragmentArguments(readableMap));
            }
            DatePickerDialogListener datePickerDialogListener2 = new DatePickerDialogListener(promise);
            datePickerDialogFragment.a((DialogInterface.OnDismissListener) datePickerDialogListener2);
            datePickerDialogFragment.a((DatePickerDialog.OnDateSetListener) datePickerDialogListener2);
            datePickerDialogFragment.show(fragmentManager, FRAGMENT_TAG);
        }
    }

    private Bundle createFragmentArguments(ReadableMap readableMap) {
        Bundle bundle = new Bundle();
        if (readableMap.a(ARG_DATE) && !readableMap.b(ARG_DATE)) {
            bundle.putLong(ARG_DATE, (long) readableMap.d(ARG_DATE));
        }
        if (readableMap.a(ARG_MINDATE) && !readableMap.b(ARG_MINDATE)) {
            bundle.putLong(ARG_MINDATE, (long) readableMap.d(ARG_MINDATE));
        }
        if (readableMap.a(ARG_MAXDATE) && !readableMap.b(ARG_MAXDATE)) {
            bundle.putLong(ARG_MAXDATE, (long) readableMap.d(ARG_MAXDATE));
        }
        if (readableMap.a(ARG_MODE) && !readableMap.b(ARG_MODE)) {
            bundle.putString(ARG_MODE, readableMap.f(ARG_MODE));
        }
        return bundle;
    }
}
