package com.facebook.react.modules.dialog;

import android.app.Activity;
import android.app.FragmentManager;
import android.content.DialogInterface;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import com.facebook.common.logging.FLog;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.LifecycleEventListener;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.UiThreadUtil;
import com.facebook.react.common.MapBuilder;
import com.facebook.react.module.annotations.ReactModule;
import java.util.Map;
import javax.annotation.Nullable;

@ReactModule
public class DialogModule extends ReactContextBaseJavaModule implements LifecycleEventListener {
    static final String ACTION_BUTTON_CLICKED = "buttonClicked";
    static final String ACTION_DISMISSED = "dismissed";
    static final Map<String, Object> CONSTANTS = MapBuilder.a(ACTION_BUTTON_CLICKED, ACTION_BUTTON_CLICKED, ACTION_DISMISSED, ACTION_DISMISSED, KEY_BUTTON_POSITIVE, -1, KEY_BUTTON_NEGATIVE, -2, KEY_BUTTON_NEUTRAL, -3);
    static final String FRAGMENT_TAG = "com.facebook.catalyst.react.dialog.DialogModule";
    static final String KEY_BUTTON_NEGATIVE = "buttonNegative";
    static final String KEY_BUTTON_NEUTRAL = "buttonNeutral";
    static final String KEY_BUTTON_POSITIVE = "buttonPositive";
    static final String KEY_CANCELABLE = "cancelable";
    static final String KEY_ITEMS = "items";
    static final String KEY_MESSAGE = "message";
    static final String KEY_TITLE = "title";
    static final String NAME = "DialogManagerAndroid";
    private boolean mIsInForeground;

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return NAME;
    }

    @Override // com.facebook.react.bridge.LifecycleEventListener
    public void onHostDestroy() {
    }

    public DialogModule(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
    }

    /* access modifiers changed from: private */
    public class FragmentManagerHelper {
        @Nullable
        private final FragmentManager b;
        @Nullable
        private final android.support.v4.app.FragmentManager c;
        @Nullable
        private Object d;

        private boolean b() {
            return this.c != null;
        }

        public FragmentManagerHelper(android.support.v4.app.FragmentManager fragmentManager) {
            this.b = null;
            this.c = fragmentManager;
        }

        public FragmentManagerHelper(FragmentManager fragmentManager) {
            this.b = fragmentManager;
            this.c = null;
        }

        public void a() {
            UiThreadUtil.b();
            if (this.d != null) {
                if (b()) {
                    ((SupportAlertFragment) this.d).a(this.c, DialogModule.FRAGMENT_TAG);
                } else {
                    ((AlertFragment) this.d).show(this.b, DialogModule.FRAGMENT_TAG);
                }
                this.d = null;
            }
        }

        private void c() {
            if (b()) {
                SupportAlertFragment supportAlertFragment = (SupportAlertFragment) this.c.a(DialogModule.FRAGMENT_TAG);
                if (supportAlertFragment != null) {
                    supportAlertFragment.a();
                    return;
                }
                return;
            }
            AlertFragment alertFragment = (AlertFragment) this.b.findFragmentByTag(DialogModule.FRAGMENT_TAG);
            if (alertFragment != null) {
                alertFragment.dismiss();
            }
        }

        public void a(boolean z, Bundle bundle, Callback callback) {
            UiThreadUtil.b();
            c();
            AlertFragmentListener alertFragmentListener = callback != null ? new AlertFragmentListener(callback) : null;
            if (b()) {
                SupportAlertFragment supportAlertFragment = new SupportAlertFragment(alertFragmentListener, bundle);
                if (z) {
                    if (bundle.containsKey(DialogModule.KEY_CANCELABLE)) {
                        supportAlertFragment.b(bundle.getBoolean(DialogModule.KEY_CANCELABLE));
                    }
                    supportAlertFragment.a(this.c, DialogModule.FRAGMENT_TAG);
                    return;
                }
                this.d = supportAlertFragment;
                return;
            }
            AlertFragment alertFragment = new AlertFragment(alertFragmentListener, bundle);
            if (z) {
                if (bundle.containsKey(DialogModule.KEY_CANCELABLE)) {
                    alertFragment.setCancelable(bundle.getBoolean(DialogModule.KEY_CANCELABLE));
                }
                alertFragment.show(this.b, DialogModule.FRAGMENT_TAG);
                return;
            }
            this.d = alertFragment;
        }
    }

    /* access modifiers changed from: package-private */
    public class AlertFragmentListener implements DialogInterface.OnClickListener, DialogInterface.OnDismissListener {
        private final Callback b;
        private boolean c = false;

        public AlertFragmentListener(Callback callback) {
            this.b = callback;
        }

        public void onClick(DialogInterface dialogInterface, int i) {
            if (!this.c && DialogModule.this.getReactApplicationContext().b()) {
                this.b.a(DialogModule.ACTION_BUTTON_CLICKED, Integer.valueOf(i));
                this.c = true;
            }
        }

        public void onDismiss(DialogInterface dialogInterface) {
            if (!this.c && DialogModule.this.getReactApplicationContext().b()) {
                this.b.a(DialogModule.ACTION_DISMISSED);
                this.c = true;
            }
        }
    }

    @Override // com.facebook.react.bridge.BaseJavaModule
    public Map<String, Object> getConstants() {
        return CONSTANTS;
    }

    @Override // com.facebook.react.bridge.BaseJavaModule, com.facebook.react.bridge.NativeModule
    public void initialize() {
        getReactApplicationContext().a(this);
    }

    @Override // com.facebook.react.bridge.LifecycleEventListener
    public void onHostPause() {
        this.mIsInForeground = false;
    }

    @Override // com.facebook.react.bridge.LifecycleEventListener
    public void onHostResume() {
        this.mIsInForeground = true;
        FragmentManagerHelper fragmentManagerHelper = getFragmentManagerHelper();
        if (fragmentManagerHelper != null) {
            fragmentManagerHelper.a();
        } else {
            FLog.c(DialogModule.class, "onHostResume called but no FragmentManager found");
        }
    }

    @ReactMethod
    public void showAlert(ReadableMap readableMap, Callback callback, final Callback callback2) {
        final FragmentManagerHelper fragmentManagerHelper = getFragmentManagerHelper();
        if (fragmentManagerHelper == null) {
            callback.a("Tried to show an alert while not attached to an Activity");
            return;
        }
        final Bundle bundle = new Bundle();
        if (readableMap.a(KEY_TITLE)) {
            bundle.putString(KEY_TITLE, readableMap.f(KEY_TITLE));
        }
        if (readableMap.a(KEY_MESSAGE)) {
            bundle.putString(KEY_MESSAGE, readableMap.f(KEY_MESSAGE));
        }
        if (readableMap.a(KEY_BUTTON_POSITIVE)) {
            bundle.putString("button_positive", readableMap.f(KEY_BUTTON_POSITIVE));
        }
        if (readableMap.a(KEY_BUTTON_NEGATIVE)) {
            bundle.putString("button_negative", readableMap.f(KEY_BUTTON_NEGATIVE));
        }
        if (readableMap.a(KEY_BUTTON_NEUTRAL)) {
            bundle.putString("button_neutral", readableMap.f(KEY_BUTTON_NEUTRAL));
        }
        if (readableMap.a(KEY_ITEMS)) {
            ReadableArray k = readableMap.k(KEY_ITEMS);
            CharSequence[] charSequenceArr = new CharSequence[k.a()];
            for (int i = 0; i < k.a(); i++) {
                charSequenceArr[i] = k.d(i);
            }
            bundle.putCharSequenceArray(KEY_ITEMS, charSequenceArr);
        }
        if (readableMap.a(KEY_CANCELABLE)) {
            bundle.putBoolean(KEY_CANCELABLE, readableMap.c(KEY_CANCELABLE));
        }
        UiThreadUtil.a(new Runnable() {
            /* class com.facebook.react.modules.dialog.DialogModule.AnonymousClass1 */

            public void run() {
                fragmentManagerHelper.a(DialogModule.this.mIsInForeground, bundle, callback2);
            }
        });
    }

    @Nullable
    private FragmentManagerHelper getFragmentManagerHelper() {
        Activity currentActivity = getCurrentActivity();
        if (currentActivity == null) {
            return null;
        }
        if (currentActivity instanceof FragmentActivity) {
            return new FragmentManagerHelper(((FragmentActivity) currentActivity).getSupportFragmentManager());
        }
        return new FragmentManagerHelper(currentActivity.getFragmentManager());
    }
}
