package com.facebook.react.modules.image;

import android.net.Uri;
import android.util.SparseArray;
import com.facebook.common.executors.CallerThreadExecutor;
import com.facebook.common.references.CloseableReference;
import com.facebook.datasource.BaseDataSubscriber;
import com.facebook.datasource.DataSource;
import com.facebook.drawee.backends.pipeline.Fresco;
import com.facebook.imagepipeline.core.ImagePipeline;
import com.facebook.imagepipeline.image.CloseableImage;
import com.facebook.imagepipeline.request.ImageRequestBuilder;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.GuardedAsyncTask;
import com.facebook.react.bridge.LifecycleEventListener;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.module.annotations.ReactModule;
import javax.annotation.Nullable;

@ReactModule
public class ImageLoaderModule extends ReactContextBaseJavaModule implements LifecycleEventListener {
    private static final String ERROR_GET_SIZE_FAILURE = "E_GET_SIZE_FAILURE";
    private static final String ERROR_INVALID_URI = "E_INVALID_URI";
    private static final String ERROR_PREFETCH_FAILURE = "E_PREFETCH_FAILURE";
    private final Object mCallerContext;
    private final Object mEnqueuedRequestMonitor;
    private final SparseArray<DataSource<Void>> mEnqueuedRequests;

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return "ImageLoader";
    }

    @Override // com.facebook.react.bridge.LifecycleEventListener
    public void onHostPause() {
    }

    @Override // com.facebook.react.bridge.LifecycleEventListener
    public void onHostResume() {
    }

    public ImageLoaderModule(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
        this.mEnqueuedRequestMonitor = new Object();
        this.mEnqueuedRequests = new SparseArray<>();
        this.mCallerContext = this;
    }

    public ImageLoaderModule(ReactApplicationContext reactApplicationContext, Object obj) {
        super(reactApplicationContext);
        this.mEnqueuedRequestMonitor = new Object();
        this.mEnqueuedRequests = new SparseArray<>();
        this.mCallerContext = obj;
    }

    @ReactMethod
    public void getSize(String str, final Promise promise) {
        if (str == null || str.isEmpty()) {
            promise.a(ERROR_INVALID_URI, "Cannot get the size of an image for an empty URI");
            return;
        }
        Fresco.c().a(ImageRequestBuilder.a(Uri.parse(str)).n(), this.mCallerContext).a(new BaseDataSubscriber<CloseableReference<CloseableImage>>() {
            /* class com.facebook.react.modules.image.ImageLoaderModule.AnonymousClass1 */

            /* access modifiers changed from: protected */
            @Override // com.facebook.datasource.BaseDataSubscriber
            public void e(DataSource<CloseableReference<CloseableImage>> dataSource) {
                if (dataSource.b()) {
                    CloseableReference<CloseableImage> d = dataSource.d();
                    if (d != null) {
                        try {
                            CloseableImage a2 = d.a();
                            WritableMap b2 = Arguments.b();
                            b2.putInt("width", a2.f());
                            b2.putInt("height", a2.g());
                            promise.a(b2);
                        } catch (Exception e) {
                            promise.a(ImageLoaderModule.ERROR_GET_SIZE_FAILURE, e);
                        } catch (Throwable th) {
                            CloseableReference.c(d);
                            throw th;
                        }
                        CloseableReference.c(d);
                        return;
                    }
                    promise.a(ImageLoaderModule.ERROR_GET_SIZE_FAILURE);
                }
            }

            /* access modifiers changed from: protected */
            @Override // com.facebook.datasource.BaseDataSubscriber
            public void f(DataSource<CloseableReference<CloseableImage>> dataSource) {
                promise.a(ImageLoaderModule.ERROR_GET_SIZE_FAILURE, dataSource.f());
            }
        }, CallerThreadExecutor.a());
    }

    @ReactMethod
    public void prefetchImage(String str, final int i, final Promise promise) {
        if (str == null || str.isEmpty()) {
            promise.a(ERROR_INVALID_URI, "Cannot prefetch an image for an empty URI");
            return;
        }
        DataSource<Void> c = Fresco.c().c(ImageRequestBuilder.a(Uri.parse(str)).n(), this.mCallerContext);
        AnonymousClass2 r0 = new BaseDataSubscriber<Void>() {
            /* class com.facebook.react.modules.image.ImageLoaderModule.AnonymousClass2 */

            /* access modifiers changed from: protected */
            @Override // com.facebook.datasource.BaseDataSubscriber
            public void e(DataSource<Void> dataSource) {
                if (dataSource.b()) {
                    try {
                        ImageLoaderModule.this.removeRequest(i);
                        promise.a((Object) true);
                    } finally {
                        dataSource.h();
                    }
                }
            }

            /* access modifiers changed from: protected */
            @Override // com.facebook.datasource.BaseDataSubscriber
            public void f(DataSource<Void> dataSource) {
                try {
                    ImageLoaderModule.this.removeRequest(i);
                    promise.a(ImageLoaderModule.ERROR_PREFETCH_FAILURE, dataSource.f());
                } finally {
                    dataSource.h();
                }
            }
        };
        registerRequest(i, c);
        c.a(r0, CallerThreadExecutor.a());
    }

    @ReactMethod
    public void abortRequest(int i) {
        DataSource<Void> removeRequest = removeRequest(i);
        if (removeRequest != null) {
            removeRequest.h();
        }
    }

    @ReactMethod
    public void queryCache(final ReadableArray readableArray, final Promise promise) {
        new GuardedAsyncTask<Void, Void>(getReactApplicationContext()) {
            /* class com.facebook.react.modules.image.ImageLoaderModule.AnonymousClass3 */

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public void b(Void... voidArr) {
                WritableMap b2 = Arguments.b();
                ImagePipeline c2 = Fresco.c();
                for (int i = 0; i < readableArray.a(); i++) {
                    String d = readableArray.d(i);
                    Uri parse = Uri.parse(d);
                    if (c2.a(parse)) {
                        b2.putString(d, "memory");
                    } else if (c2.b(parse)) {
                        b2.putString(d, "disk");
                    }
                }
                promise.a(b2);
            }
        }.executeOnExecutor(GuardedAsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
    }

    private void registerRequest(int i, DataSource<Void> dataSource) {
        synchronized (this.mEnqueuedRequestMonitor) {
            this.mEnqueuedRequests.put(i, dataSource);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    @Nullable
    private DataSource<Void> removeRequest(int i) {
        DataSource<Void> dataSource;
        synchronized (this.mEnqueuedRequestMonitor) {
            dataSource = this.mEnqueuedRequests.get(i);
            this.mEnqueuedRequests.remove(i);
        }
        return dataSource;
    }

    @Override // com.facebook.react.bridge.LifecycleEventListener
    public void onHostDestroy() {
        synchronized (this.mEnqueuedRequestMonitor) {
            int size = this.mEnqueuedRequests.size();
            for (int i = 0; i < size; i++) {
                DataSource<Void> valueAt = this.mEnqueuedRequests.valueAt(i);
                if (valueAt != null) {
                    valueAt.h();
                }
            }
            this.mEnqueuedRequests.clear();
        }
    }
}
