package com.facebook.react.modules.timepicker;

import android.app.Activity;
import android.app.TimePickerDialog;
import android.content.DialogInterface;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentManager;
import android.widget.TimePicker;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableNativeMap;
import com.facebook.react.common.annotations.VisibleForTesting;
import com.facebook.react.module.annotations.ReactModule;
import javax.annotation.Nullable;

@ReactModule
public class TimePickerDialogModule extends ReactContextBaseJavaModule {
    static final String ACTION_DISMISSED = "dismissedAction";
    static final String ACTION_TIME_SET = "timeSetAction";
    static final String ARG_HOUR = "hour";
    static final String ARG_IS24HOUR = "is24Hour";
    static final String ARG_MINUTE = "minute";
    static final String ARG_MODE = "mode";
    private static final String ERROR_NO_ACTIVITY = "E_NO_ACTIVITY";
    @VisibleForTesting
    public static final String FRAGMENT_TAG = "TimePickerAndroid";

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return FRAGMENT_TAG;
    }

    public TimePickerDialogModule(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
    }

    private class TimePickerDialogListener implements TimePickerDialog.OnTimeSetListener, DialogInterface.OnDismissListener {
        private final Promise b;
        private boolean c = false;

        public TimePickerDialogListener(Promise promise) {
            this.b = promise;
        }

        public void onTimeSet(TimePicker timePicker, int i, int i2) {
            if (!this.c && TimePickerDialogModule.this.getReactApplicationContext().b()) {
                WritableNativeMap writableNativeMap = new WritableNativeMap();
                writableNativeMap.putString("action", TimePickerDialogModule.ACTION_TIME_SET);
                writableNativeMap.putInt(TimePickerDialogModule.ARG_HOUR, i);
                writableNativeMap.putInt(TimePickerDialogModule.ARG_MINUTE, i2);
                this.b.a(writableNativeMap);
                this.c = true;
            }
        }

        public void onDismiss(DialogInterface dialogInterface) {
            if (!this.c && TimePickerDialogModule.this.getReactApplicationContext().b()) {
                WritableNativeMap writableNativeMap = new WritableNativeMap();
                writableNativeMap.putString("action", TimePickerDialogModule.ACTION_DISMISSED);
                this.b.a(writableNativeMap);
                this.c = true;
            }
        }
    }

    @ReactMethod
    public void open(@Nullable ReadableMap readableMap, Promise promise) {
        Activity currentActivity = getCurrentActivity();
        if (currentActivity == null) {
            promise.a(ERROR_NO_ACTIVITY, "Tried to open a TimePicker dialog while not attached to an Activity");
        } else if (currentActivity instanceof FragmentActivity) {
            FragmentManager supportFragmentManager = ((FragmentActivity) currentActivity).getSupportFragmentManager();
            DialogFragment dialogFragment = (DialogFragment) supportFragmentManager.a(FRAGMENT_TAG);
            if (dialogFragment != null) {
                dialogFragment.a();
            }
            SupportTimePickerDialogFragment supportTimePickerDialogFragment = new SupportTimePickerDialogFragment();
            if (readableMap != null) {
                supportTimePickerDialogFragment.g(createFragmentArguments(readableMap));
            }
            TimePickerDialogListener timePickerDialogListener = new TimePickerDialogListener(promise);
            supportTimePickerDialogFragment.a((DialogInterface.OnDismissListener) timePickerDialogListener);
            supportTimePickerDialogFragment.a((TimePickerDialog.OnTimeSetListener) timePickerDialogListener);
            supportTimePickerDialogFragment.a(supportFragmentManager, FRAGMENT_TAG);
        } else {
            android.app.FragmentManager fragmentManager = currentActivity.getFragmentManager();
            android.app.DialogFragment dialogFragment2 = (android.app.DialogFragment) fragmentManager.findFragmentByTag(FRAGMENT_TAG);
            if (dialogFragment2 != null) {
                dialogFragment2.dismiss();
            }
            TimePickerDialogFragment timePickerDialogFragment = new TimePickerDialogFragment();
            if (readableMap != null) {
                timePickerDialogFragment.setArguments(createFragmentArguments(readableMap));
            }
            TimePickerDialogListener timePickerDialogListener2 = new TimePickerDialogListener(promise);
            timePickerDialogFragment.a((DialogInterface.OnDismissListener) timePickerDialogListener2);
            timePickerDialogFragment.a((TimePickerDialog.OnTimeSetListener) timePickerDialogListener2);
            timePickerDialogFragment.show(fragmentManager, FRAGMENT_TAG);
        }
    }

    private Bundle createFragmentArguments(ReadableMap readableMap) {
        Bundle bundle = new Bundle();
        if (readableMap.a(ARG_HOUR) && !readableMap.b(ARG_HOUR)) {
            bundle.putInt(ARG_HOUR, readableMap.e(ARG_HOUR));
        }
        if (readableMap.a(ARG_MINUTE) && !readableMap.b(ARG_MINUTE)) {
            bundle.putInt(ARG_MINUTE, readableMap.e(ARG_MINUTE));
        }
        if (readableMap.a(ARG_IS24HOUR) && !readableMap.b(ARG_IS24HOUR)) {
            bundle.putBoolean(ARG_IS24HOUR, readableMap.c(ARG_IS24HOUR));
        }
        if (readableMap.a(ARG_MODE) && !readableMap.b(ARG_MODE)) {
            bundle.putString(ARG_MODE, readableMap.f(ARG_MODE));
        }
        return bundle;
    }
}
