package com.facebook.soloader;

import android.content.Context;
import android.os.Parcel;
import android.util.Log;
import java.io.Closeable;
import java.io.DataInput;
import java.io.DataOutput;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.RandomAccessFile;
import java.util.Arrays;

public abstract class UnpackingSoSource extends DirectorySoSource {
    private static final String DEPS_FILE_NAME = "dso_deps";
    private static final String LOCK_FILE_NAME = "dso_lock";
    private static final String MANIFEST_FILE_NAME = "dso_manifest";
    private static final byte MANIFEST_VERSION = 1;
    private static final byte STATE_CLEAN = 1;
    private static final byte STATE_DIRTY = 0;
    private static final String STATE_FILE_NAME = "dso_state";
    private static final String TAG = "fb-UnpackingSoSource";
    protected final Context mContext;

    /* access modifiers changed from: protected */
    public abstract Unpacker makeUnpacker() throws IOException;

    protected UnpackingSoSource(Context context, String str) {
        super(getSoStorePath(context, str), 1);
        this.mContext = context;
    }

    public static File getSoStorePath(Context context, String str) {
        return new File(context.getApplicationInfo().dataDir + "/" + str);
    }

    public static class Dso {
        public final String hash;
        public final String name;

        public Dso(String str, String str2) {
            this.name = str;
            this.hash = str2;
        }
    }

    public static final class DsoManifest {
        public final Dso[] dsos;

        public DsoManifest(Dso[] dsoArr) {
            this.dsos = dsoArr;
        }

        static final DsoManifest read(DataInput dataInput) throws IOException {
            if (dataInput.readByte() == 1) {
                int readInt = dataInput.readInt();
                if (readInt >= 0) {
                    Dso[] dsoArr = new Dso[readInt];
                    for (int i = 0; i < readInt; i++) {
                        dsoArr[i] = new Dso(dataInput.readUTF(), dataInput.readUTF());
                    }
                    return new DsoManifest(dsoArr);
                }
                throw new RuntimeException("illegal number of shared libraries");
            }
            throw new RuntimeException("wrong dso manifest version");
        }

        public final void write(DataOutput dataOutput) throws IOException {
            dataOutput.writeByte(1);
            dataOutput.writeInt(this.dsos.length);
            for (int i = 0; i < this.dsos.length; i++) {
                dataOutput.writeUTF(this.dsos[i].name);
                dataOutput.writeUTF(this.dsos[i].hash);
            }
        }
    }

    /* access modifiers changed from: protected */
    public static final class InputDso implements Closeable {
        public final InputStream content;
        public final Dso dso;

        public InputDso(Dso dso2, InputStream inputStream) {
            this.dso = dso2;
            this.content = inputStream;
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
            this.content.close();
        }
    }

    /* access modifiers changed from: protected */
    public static abstract class InputDsoIterator implements Closeable {
        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
        }

        public abstract boolean hasNext();

        public abstract InputDso next() throws IOException;

        protected InputDsoIterator() {
        }
    }

    /* access modifiers changed from: protected */
    public static abstract class Unpacker implements Closeable {
        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
        }

        /* access modifiers changed from: protected */
        public abstract DsoManifest getDsoManifest() throws IOException;

        /* access modifiers changed from: protected */
        public abstract InputDsoIterator openDsoIterator() throws IOException;

        protected Unpacker() {
        }
    }

    /* access modifiers changed from: private */
    /* JADX WARNING: Code restructure failed: missing block: B:11:?, code lost:
        r0.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:12:0x002c, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x002d, code lost:
        r3.addSuppressed(r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0031, code lost:
        r0.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:5:0x0022, code lost:
        r4 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:9:0x0026, code lost:
        if (r3 != null) goto L_0x0028;
     */
    public static void writeState(File file, byte b) throws IOException {
        RandomAccessFile randomAccessFile = new RandomAccessFile(file, "rw");
        randomAccessFile.seek(0);
        randomAccessFile.write(b);
        randomAccessFile.setLength(randomAccessFile.getFilePointer());
        randomAccessFile.getFD().sync();
        randomAccessFile.close();
        return;
        throw th;
    }

    private void deleteUnmentionedFiles(Dso[] dsoArr) throws IOException {
        String[] list = this.soDirectory.list();
        if (list != null) {
            for (String str : list) {
                if (!str.equals(STATE_FILE_NAME) && !str.equals(LOCK_FILE_NAME) && !str.equals(DEPS_FILE_NAME) && !str.equals(MANIFEST_FILE_NAME)) {
                    boolean z = false;
                    int i = 0;
                    while (!z && i < dsoArr.length) {
                        if (dsoArr[i].name.equals(str)) {
                            z = true;
                        }
                        i++;
                    }
                    if (!z) {
                        File file = new File(this.soDirectory, str);
                        Log.v(TAG, "deleting unaccounted-for file " + file);
                        SysUtil.dumbDeleteRecursive(file);
                    }
                }
            }
            return;
        }
        throw new IOException("unable to list directory " + this.soDirectory);
    }

    private void extractDso(InputDso inputDso, byte[] bArr) throws IOException {
        RandomAccessFile randomAccessFile;
        Log.i(TAG, "extracting DSO " + inputDso.dso.name);
        File file = new File(this.soDirectory, inputDso.dso.name);
        try {
            randomAccessFile = new RandomAccessFile(file, "rw");
        } catch (IOException e) {
            Log.w(TAG, "error overwriting " + file + " trying to delete and start over", e);
            file.delete();
            randomAccessFile = new RandomAccessFile(file, "rw");
        }
        try {
            int available = inputDso.content.available();
            if (available > 1) {
                SysUtil.fallocateIfSupported(randomAccessFile.getFD(), (long) available);
            }
            SysUtil.copyBytes(randomAccessFile, inputDso.content, Integer.MAX_VALUE, bArr);
            randomAccessFile.setLength(randomAccessFile.getFilePointer());
            if (!file.setExecutable(true, false)) {
                throw new IOException("cannot make file executable: " + file);
            }
        } finally {
            randomAccessFile.close();
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:4:0x0037, code lost:
        r11 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:54:0x00be, code lost:
        if (r11 != null) goto L_0x00c0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:56:?, code lost:
        r1.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:57:0x00c4, code lost:
        r12 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:58:0x00c5, code lost:
        r11.addSuppressed(r12);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:59:0x00c9, code lost:
        r1.close();
     */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x004a A[Catch:{ all -> 0x0037, Throwable -> 0x00c4 }] */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x0061 A[Catch:{ all -> 0x0037, Throwable -> 0x00c4 }] */
    private void regenerate(byte b, DsoManifest dsoManifest, InputDsoIterator inputDsoIterator) throws IOException {
        DsoManifest dsoManifest2;
        InputDso next;
        Throwable th;
        Throwable th2;
        Log.v(TAG, "regenerating DSO store " + getClass().getName());
        RandomAccessFile randomAccessFile = new RandomAccessFile(new File(this.soDirectory, MANIFEST_FILE_NAME), "rw");
        if (b == 1) {
            try {
                dsoManifest2 = DsoManifest.read(randomAccessFile);
            } catch (Exception e) {
                Log.i(TAG, "error reading existing DSO manifest", e);
            }
            if (dsoManifest2 == null) {
                dsoManifest2 = new DsoManifest(new Dso[0]);
            }
            deleteUnmentionedFiles(dsoManifest.dsos);
            byte[] bArr = new byte[32768];
            while (inputDsoIterator.hasNext()) {
                next = inputDsoIterator.next();
                boolean z = true;
                int i = 0;
                while (z) {
                    try {
                        if (i >= dsoManifest2.dsos.length) {
                            break;
                        }
                        if (dsoManifest2.dsos[i].name.equals(next.dso.name) && dsoManifest2.dsos[i].hash.equals(next.dso.hash)) {
                            z = false;
                        }
                        i++;
                    } catch (Throwable th3) {
                        th = th;
                        th2 = th3;
                    }
                }
                if (z) {
                    extractDso(next, bArr);
                }
                if (next != null) {
                    next.close();
                }
            }
            randomAccessFile.close();
            return;
        }
        dsoManifest2 = null;
        if (dsoManifest2 == null) {
        }
        deleteUnmentionedFiles(dsoManifest.dsos);
        byte[] bArr2 = new byte[32768];
        while (inputDsoIterator.hasNext()) {
        }
        randomAccessFile.close();
        return;
        if (next != null) {
            if (th != null) {
                try {
                    next.close();
                } catch (Throwable th4) {
                    th.addSuppressed(th4);
                }
            } else {
                next.close();
            }
        }
        throw th2;
        throw th2;
        throw th;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:12:0x003d, code lost:
        if (r12 != null) goto L_0x003f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:?, code lost:
        r0.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0043, code lost:
        r13 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x0044, code lost:
        r12.addSuppressed(r13);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0048, code lost:
        r0.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:37:0x00a9, code lost:
        r12 = th;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:38:0x00aa, code lost:
        r13 = null;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:42:0x00ae, code lost:
        r13 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:43:0x00af, code lost:
        r13 = r12;
        r12 = r13;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:52:0x00c3, code lost:
        r12 = th;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:53:0x00c4, code lost:
        r13 = null;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:57:0x00c8, code lost:
        r13 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:58:0x00c9, code lost:
        r13 = r12;
        r12 = r13;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:76:0x0117, code lost:
        r12 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:7:0x0038, code lost:
        r12 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:81:0x011c, code lost:
        if (r12 != null) goto L_0x011e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:83:?, code lost:
        r0.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:84:0x0122, code lost:
        r13 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:85:0x0123, code lost:
        r12.addSuppressed(r13);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:86:0x0127, code lost:
        r0.close();
     */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x00c3 A[ExcHandler: all (th java.lang.Throwable)] */
    private boolean refreshLocked(final FileLocker fileLocker, int i, final byte[] bArr) throws IOException {
        final DsoManifest dsoManifest;
        Unpacker makeUnpacker;
        Throwable th;
        Throwable th2;
        InputDsoIterator openDsoIterator;
        Throwable th3;
        Throwable th4;
        final File file = new File(this.soDirectory, STATE_FILE_NAME);
        RandomAccessFile randomAccessFile = new RandomAccessFile(file, "rw");
        byte b = randomAccessFile.readByte();
        if (b != 1) {
            Log.v(TAG, "dso store " + this.soDirectory + " regeneration interrupted: wiping clean");
            b = STATE_DIRTY;
        }
        randomAccessFile.close();
        final File file2 = new File(this.soDirectory, DEPS_FILE_NAME);
        RandomAccessFile randomAccessFile2 = new RandomAccessFile(file2, "rw");
        byte[] bArr2 = new byte[((int) randomAccessFile2.length())];
        if (randomAccessFile2.read(bArr2) != bArr2.length) {
            Log.v(TAG, "short read of so store deps file: marking unclean");
            b = STATE_DIRTY;
        }
        if (!Arrays.equals(bArr2, bArr)) {
            Log.v(TAG, "deps mismatch on deps store: regenerating");
            b = STATE_DIRTY;
        }
        if (b == 0) {
            Log.v(TAG, "so store dirty: regenerating");
            writeState(file, STATE_DIRTY);
            makeUnpacker = makeUnpacker();
            dsoManifest = makeUnpacker.getDsoManifest();
            openDsoIterator = makeUnpacker.openDsoIterator();
            regenerate(b, dsoManifest, openDsoIterator);
            if (openDsoIterator != null) {
                openDsoIterator.close();
            }
            if (makeUnpacker != null) {
                makeUnpacker.close();
            }
        } else {
            dsoManifest = null;
        }
        randomAccessFile2.close();
        if (dsoManifest == null) {
            return false;
        }
        AnonymousClass1 r9 = new Runnable() {
            /* class com.facebook.soloader.UnpackingSoSource.AnonymousClass1 */

            /* JADX WARNING: Code restructure failed: missing block: B:13:0x006c, code lost:
                r0 = move-exception;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:18:0x0071, code lost:
                if (r0 != null) goto L_0x0073;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:20:?, code lost:
                r2.close();
             */
            /* JADX WARNING: Code restructure failed: missing block: B:21:0x0077, code lost:
                r2 = move-exception;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:22:0x0078, code lost:
                r0.addSuppressed(r2);
             */
            /* JADX WARNING: Code restructure failed: missing block: B:23:0x007c, code lost:
                r2.close();
             */
            /* JADX WARNING: Code restructure failed: missing block: B:25:0x0080, code lost:
                r2 = move-exception;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:29:0x0084, code lost:
                if (r1 != null) goto L_0x0086;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:31:?, code lost:
                r0.close();
             */
            /* JADX WARNING: Code restructure failed: missing block: B:32:0x008a, code lost:
                r0 = move-exception;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:33:0x008b, code lost:
                r1.addSuppressed(r0);
             */
            /* JADX WARNING: Code restructure failed: missing block: B:34:0x008f, code lost:
                r0.close();
             */
            public void run() {
                try {
                    Log.v(UnpackingSoSource.TAG, "starting syncer worker");
                    RandomAccessFile randomAccessFile = new RandomAccessFile(file2, "rw");
                    randomAccessFile.write(bArr);
                    randomAccessFile.setLength(randomAccessFile.getFilePointer());
                    randomAccessFile.close();
                    RandomAccessFile randomAccessFile2 = new RandomAccessFile(new File(UnpackingSoSource.this.soDirectory, UnpackingSoSource.MANIFEST_FILE_NAME), "rw");
                    dsoManifest.write(randomAccessFile2);
                    randomAccessFile2.close();
                    SysUtil.fsyncRecursive(UnpackingSoSource.this.soDirectory);
                    UnpackingSoSource.writeState(file, (byte) 1);
                    try {
                        Log.v(UnpackingSoSource.TAG, "releasing dso store lock for " + UnpackingSoSource.this.soDirectory + " (from syncer thread)");
                        fileLocker.close();
                        return;
                    } catch (IOException e) {
                        throw new RuntimeException(e);
                    }
                    throw th;
                    throw th;
                } catch (Throwable th) {
                    Log.v(UnpackingSoSource.TAG, "releasing dso store lock for " + UnpackingSoSource.this.soDirectory + " (from syncer thread)");
                    fileLocker.close();
                    throw th;
                }
            }
        };
        if ((i & 1) != 0) {
            new Thread(r9, "SoSync:" + this.soDirectory.getName()).start();
        } else {
            r9.run();
        }
        return true;
        if (openDsoIterator != null) {
            if (th3 != null) {
                try {
                    openDsoIterator.close();
                } catch (Throwable th5) {
                }
            } else {
                openDsoIterator.close();
            }
        }
        throw th4;
        throw th4;
        throw th;
        throw th;
        if (makeUnpacker != null) {
            if (th != null) {
                try {
                    makeUnpacker.close();
                } catch (Throwable th6) {
                    th.addSuppressed(th6);
                }
            } else {
                makeUnpacker.close();
            }
        }
        throw th2;
        throw th2;
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0039, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x003e, code lost:
        if (r1 != null) goto L_0x0040;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0040, code lost:
        if (r0 != null) goto L_0x0042;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:?, code lost:
        r1.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0046, code lost:
        r1 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x0047, code lost:
        r0.addSuppressed(r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x004b, code lost:
        r1.close();
     */
    public byte[] getDepsBlock() throws IOException {
        Parcel obtain = Parcel.obtain();
        Unpacker makeUnpacker = makeUnpacker();
        Dso[] dsoArr = makeUnpacker.getDsoManifest().dsos;
        obtain.writeByte((byte) 1);
        obtain.writeInt(dsoArr.length);
        for (int i = 0; i < dsoArr.length; i++) {
            obtain.writeString(dsoArr[i].name);
            obtain.writeString(dsoArr[i].hash);
        }
        if (makeUnpacker != null) {
            makeUnpacker.close();
        }
        byte[] marshall = obtain.marshall();
        obtain.recycle();
        return marshall;
        throw th;
    }

    /* access modifiers changed from: protected */
    @Override // com.facebook.soloader.SoSource
    public void prepare(int i) throws IOException {
        SysUtil.mkdirOrThrow(this.soDirectory);
        FileLocker lock = FileLocker.lock(new File(this.soDirectory, LOCK_FILE_NAME));
        try {
            Log.v(TAG, "locked dso store " + this.soDirectory);
            if (refreshLocked(lock, i, getDepsBlock())) {
                lock = null;
            } else {
                Log.i(TAG, "dso store is up-to-date: " + this.soDirectory);
            }
            if (lock != null) {
                Log.v(TAG, "releasing dso store lock for " + this.soDirectory);
                lock.close();
                return;
            }
            Log.v(TAG, "not releasing dso store lock for " + this.soDirectory + " (syncer thread started)");
        } catch (Throwable th) {
            if (lock != null) {
                Log.v(TAG, "releasing dso store lock for " + this.soDirectory);
                lock.close();
            } else {
                Log.v(TAG, "not releasing dso store lock for " + this.soDirectory + " (syncer thread started)");
            }
            throw th;
        }
    }
}
