package com.facebook.stetho.common.android;

import android.support.annotation.Nullable;
import android.support.v4.view.ViewCompat;
import android.support.v4.view.accessibility.AccessibilityNodeInfoCompat;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.widget.AdapterView;
import android.widget.HorizontalScrollView;
import android.widget.ScrollView;
import android.widget.Spinner;
import java.util.List;

public final class AccessibilityUtil {
    private AccessibilityUtil() {
    }

    public static boolean hasText(@Nullable AccessibilityNodeInfoCompat accessibilityNodeInfoCompat) {
        if (accessibilityNodeInfoCompat == null) {
            return false;
        }
        return !TextUtils.isEmpty(accessibilityNodeInfoCompat.t()) || !TextUtils.isEmpty(accessibilityNodeInfoCompat.u());
    }

    public static boolean isSpeakingNode(@Nullable AccessibilityNodeInfoCompat accessibilityNodeInfoCompat, @Nullable View view) {
        int c;
        if (accessibilityNodeInfoCompat == null || view == null || !accessibilityNodeInfoCompat.j() || (c = ViewCompat.c(view)) == 4 || (c == 2 && accessibilityNodeInfoCompat.c() <= 0)) {
            return false;
        }
        if (accessibilityNodeInfoCompat.f() || hasText(accessibilityNodeInfoCompat) || hasNonActionableSpeakingDescendants(accessibilityNodeInfoCompat, view)) {
            return true;
        }
        return false;
    }

    public static boolean hasNonActionableSpeakingDescendants(@Nullable AccessibilityNodeInfoCompat accessibilityNodeInfoCompat, @Nullable View view) {
        if (accessibilityNodeInfoCompat == null || view == null || !(view instanceof ViewGroup)) {
            return false;
        }
        ViewGroup viewGroup = (ViewGroup) view;
        int childCount = viewGroup.getChildCount();
        for (int i = 0; i < childCount; i++) {
            View childAt = viewGroup.getChildAt(i);
            if (childAt != null) {
                AccessibilityNodeInfoCompat b = AccessibilityNodeInfoCompat.b();
                try {
                    ViewCompat.a(childAt, b);
                    if (!isAccessibilityFocusable(b, childAt) && isSpeakingNode(b, childAt)) {
                        b.v();
                        return true;
                    }
                } finally {
                    b.v();
                }
            }
        }
        return false;
    }

    public static boolean isAccessibilityFocusable(@Nullable AccessibilityNodeInfoCompat accessibilityNodeInfoCompat, @Nullable View view) {
        if (accessibilityNodeInfoCompat == null || view == null || !accessibilityNodeInfoCompat.j()) {
            return false;
        }
        if (isActionableForAccessibility(accessibilityNodeInfoCompat)) {
            return true;
        }
        if (!isTopLevelScrollItem(accessibilityNodeInfoCompat, view) || !isSpeakingNode(accessibilityNodeInfoCompat, view)) {
            return false;
        }
        return true;
    }

    public static boolean isTopLevelScrollItem(@Nullable AccessibilityNodeInfoCompat accessibilityNodeInfoCompat, @Nullable View view) {
        View view2;
        if (accessibilityNodeInfoCompat == null || view == null || (view2 = (View) ViewCompat.g(view)) == null) {
            return false;
        }
        if (accessibilityNodeInfoCompat.q()) {
            return true;
        }
        List<AccessibilityNodeInfoCompat.AccessibilityActionCompat> x = accessibilityNodeInfoCompat.x();
        if (x.contains(4096) || x.contains(8192)) {
            return true;
        }
        if (view2 instanceof Spinner) {
            return false;
        }
        if ((view2 instanceof AdapterView) || (view2 instanceof ScrollView) || (view2 instanceof HorizontalScrollView)) {
            return true;
        }
        return false;
    }

    public static boolean isActionableForAccessibility(@Nullable AccessibilityNodeInfoCompat accessibilityNodeInfoCompat) {
        if (accessibilityNodeInfoCompat == null) {
            return false;
        }
        if (accessibilityNodeInfoCompat.m() || accessibilityNodeInfoCompat.n() || accessibilityNodeInfoCompat.h()) {
            return true;
        }
        List<AccessibilityNodeInfoCompat.AccessibilityActionCompat> x = accessibilityNodeInfoCompat.x();
        if (x.contains(16) || x.contains(32) || x.contains(1)) {
            return true;
        }
        return false;
    }

    public static boolean hasFocusableAncestor(@Nullable AccessibilityNodeInfoCompat accessibilityNodeInfoCompat, @Nullable View view) {
        if (accessibilityNodeInfoCompat == null || view == null) {
            return false;
        }
        ViewParent g = ViewCompat.g(view);
        if (!(g instanceof View)) {
            return false;
        }
        AccessibilityNodeInfoCompat b = AccessibilityNodeInfoCompat.b();
        try {
            ViewCompat.a((View) g, b);
            if (b == null) {
                return false;
            }
            if (isAccessibilityFocusable(b, (View) g)) {
                b.v();
                return true;
            } else if (hasFocusableAncestor(b, (View) g)) {
                b.v();
                return true;
            } else {
                b.v();
                return false;
            }
        } finally {
            b.v();
        }
    }
}
