package com.facebook.stetho.inspector.elements.android;

import android.support.annotation.Nullable;
import android.support.v4.view.ViewCompat;
import android.support.v4.view.accessibility.AccessibilityNodeInfoCompat;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.widget.EditText;
import com.facebook.stetho.common.android.AccessibilityUtil;
import com.tencent.smtt.sdk.TbsListener;

public final class AccessibilityNodeInfoWrapper {
    public static AccessibilityNodeInfoCompat createNodeInfoFromView(View view) {
        AccessibilityNodeInfoCompat b = AccessibilityNodeInfoCompat.b();
        ViewCompat.a(view, b);
        return b;
    }

    public static boolean getIsAccessibilityFocused(View view) {
        AccessibilityNodeInfoCompat createNodeInfoFromView = createNodeInfoFromView(view);
        boolean k = createNodeInfoFromView.k();
        createNodeInfoFromView.v();
        return k;
    }

    public static boolean getIgnored(View view) {
        int c = ViewCompat.c(view);
        if (c == 2 || c == 4) {
            return true;
        }
        for (ViewParent parent = view.getParent(); parent instanceof View; parent = parent.getParent()) {
            if (ViewCompat.c((View) parent) == 4) {
                return true;
            }
        }
        AccessibilityNodeInfoCompat createNodeInfoFromView = createNodeInfoFromView(view);
        try {
            if (!createNodeInfoFromView.j()) {
                return true;
            }
            if (AccessibilityUtil.isAccessibilityFocusable(createNodeInfoFromView, view)) {
                if (createNodeInfoFromView.c() <= 0) {
                    createNodeInfoFromView.v();
                    return false;
                } else if (AccessibilityUtil.isSpeakingNode(createNodeInfoFromView, view)) {
                    createNodeInfoFromView.v();
                    return false;
                } else {
                    createNodeInfoFromView.v();
                    return true;
                }
            } else if (AccessibilityUtil.hasFocusableAncestor(createNodeInfoFromView, view) || !AccessibilityUtil.hasText(createNodeInfoFromView)) {
                createNodeInfoFromView.v();
                return true;
            } else {
                createNodeInfoFromView.v();
                return false;
            }
        } finally {
            createNodeInfoFromView.v();
        }
    }

    public static String getIgnoredReasons(View view) {
        int c = ViewCompat.c(view);
        if (c == 2) {
            return "View has importantForAccessibility set to 'NO'.";
        }
        if (c == 4) {
            return "View has importantForAccessibility set to 'NO_HIDE_DESCENDANTS'.";
        }
        for (ViewParent parent = view.getParent(); parent instanceof View; parent = parent.getParent()) {
            if (ViewCompat.c((View) parent) == 4) {
                return "An ancestor View has importantForAccessibility set to 'NO_HIDE_DESCENDANTS'.";
            }
        }
        AccessibilityNodeInfoCompat createNodeInfoFromView = createNodeInfoFromView(view);
        try {
            if (!createNodeInfoFromView.j()) {
                return "View is not visible.";
            }
            if (AccessibilityUtil.isAccessibilityFocusable(createNodeInfoFromView, view)) {
                createNodeInfoFromView.v();
                return "View is actionable, but has no description.";
            } else if (AccessibilityUtil.hasText(createNodeInfoFromView)) {
                createNodeInfoFromView.v();
                return "View is not actionable, and an ancestor View has co-opted its description.";
            } else {
                createNodeInfoFromView.v();
                return "View is not actionable and has no description.";
            }
        } finally {
            createNodeInfoFromView.v();
        }
    }

    @Nullable
    public static String getFocusableReasons(View view) {
        AccessibilityNodeInfoCompat createNodeInfoFromView = createNodeInfoFromView(view);
        try {
            boolean hasText = AccessibilityUtil.hasText(createNodeInfoFromView);
            boolean f = createNodeInfoFromView.f();
            boolean hasNonActionableSpeakingDescendants = AccessibilityUtil.hasNonActionableSpeakingDescendants(createNodeInfoFromView, view);
            if (AccessibilityUtil.isActionableForAccessibility(createNodeInfoFromView)) {
                if (createNodeInfoFromView.c() <= 0) {
                    return "View is actionable and has no children.";
                }
                if (hasText) {
                    createNodeInfoFromView.v();
                    return "View is actionable and has a description.";
                } else if (f) {
                    createNodeInfoFromView.v();
                    return "View is actionable and checkable.";
                } else if (hasNonActionableSpeakingDescendants) {
                    createNodeInfoFromView.v();
                    return "View is actionable and has non-actionable descendants with descriptions.";
                }
            }
            if (AccessibilityUtil.isTopLevelScrollItem(createNodeInfoFromView, view)) {
                if (hasText) {
                    createNodeInfoFromView.v();
                    return "View is a direct child of a scrollable container and has a description.";
                } else if (f) {
                    createNodeInfoFromView.v();
                    return "View is a direct child of a scrollable container and is checkable.";
                } else if (hasNonActionableSpeakingDescendants) {
                    createNodeInfoFromView.v();
                    return "View is a direct child of a scrollable container and has non-actionable descendants with descriptions.";
                }
            }
            if (hasText) {
                createNodeInfoFromView.v();
                return "View has a description and is not actionable, but has no actionable ancestor.";
            }
            createNodeInfoFromView.v();
            return null;
        } finally {
            createNodeInfoFromView.v();
        }
    }

    @Nullable
    public static String getActions(View view) {
        AccessibilityNodeInfoCompat createNodeInfoFromView = createNodeInfoFromView(view);
        try {
            StringBuilder sb = new StringBuilder();
            for (AccessibilityNodeInfoCompat.AccessibilityActionCompat accessibilityActionCompat : createNodeInfoFromView.x()) {
                if (sb.length() > 0) {
                    sb.append(", ");
                }
                switch (accessibilityActionCompat.a()) {
                    case 1:
                        sb.append("focus");
                        break;
                    case 2:
                        sb.append("clear-focus");
                        break;
                    case 4:
                        sb.append("select");
                        break;
                    case 8:
                        sb.append("clear-selection");
                        break;
                    case 16:
                        sb.append("click");
                        break;
                    case 32:
                        sb.append("long-click");
                        break;
                    case 64:
                        sb.append("accessibility-focus");
                        break;
                    case TbsListener.ErrorCode.DOWNLOAD_INTERRUPT /*{ENCODED_INT: 128}*/:
                        sb.append("clear-accessibility-focus");
                        break;
                    case 256:
                        sb.append("next-at-movement-granularity");
                        break;
                    case 512:
                        sb.append("previous-at-movement-granularity");
                        break;
                    case 1024:
                        sb.append("next-html-element");
                        break;
                    case 2048:
                        sb.append("previous-html-element");
                        break;
                    case 4096:
                        sb.append("scroll-forward");
                        break;
                    case 8192:
                        sb.append("scroll-backward");
                        break;
                    case 16384:
                        sb.append("copy");
                        break;
                    case 32768:
                        sb.append("paste");
                        break;
                    case 65536:
                        sb.append("cut");
                        break;
                    case 131072:
                        sb.append("set-selection");
                        break;
                    default:
                        CharSequence b = accessibilityActionCompat.b();
                        if (b != null) {
                            sb.append(b);
                            break;
                        } else {
                            sb.append("unknown");
                            break;
                        }
                }
            }
            return sb.length() > 0 ? sb.toString() : null;
        } finally {
            createNodeInfoFromView.v();
        }
    }

    @Nullable
    public static CharSequence getDescription(View view) {
        AccessibilityNodeInfoCompat createNodeInfoFromView = createNodeInfoFromView(view);
        try {
            CharSequence u = createNodeInfoFromView.u();
            CharSequence t = createNodeInfoFromView.t();
            boolean z = !TextUtils.isEmpty(t);
            boolean z2 = view instanceof EditText;
            if (!(TextUtils.isEmpty(u) || (z2 && z))) {
                return u;
            }
            if (z) {
                createNodeInfoFromView.v();
                return t;
            }
            String str = null;
            if (view instanceof ViewGroup) {
                StringBuilder sb = new StringBuilder();
                ViewGroup viewGroup = (ViewGroup) view;
                int childCount = viewGroup.getChildCount();
                for (int i = 0; i < childCount; i++) {
                    View childAt = viewGroup.getChildAt(i);
                    AccessibilityNodeInfoCompat b = AccessibilityNodeInfoCompat.b();
                    ViewCompat.a(childAt, b);
                    CharSequence description = (!AccessibilityUtil.isSpeakingNode(b, childAt) || AccessibilityUtil.isAccessibilityFocusable(b, childAt)) ? null : getDescription(childAt);
                    if (!TextUtils.isEmpty(description)) {
                        if (sb.length() > 0) {
                            sb.append(", ");
                        }
                        sb.append(description);
                    }
                    b.v();
                }
                if (sb.length() > 0) {
                    str = sb.toString();
                }
                createNodeInfoFromView.v();
                return str;
            }
            createNodeInfoFromView.v();
            return null;
        } finally {
            createNodeInfoFromView.v();
        }
    }
}
