package com.microsoft.codepush.react;

import android.app.Activity;
import android.content.Context;
import android.os.AsyncTask;
import android.os.Handler;
import android.os.Looper;
import android.provider.Settings;
import com.facebook.react.ReactApplication;
import com.facebook.react.ReactInstanceManager;
import com.facebook.react.ReactRootView;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.JSBundleLoader;
import com.facebook.react.bridge.LifecycleEventListener;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.modules.core.ChoreographerCompat;
import com.facebook.react.modules.core.DeviceEventManagerModule;
import com.facebook.react.modules.core.ReactChoreographer;
import java.io.IOException;
import java.lang.reflect.Field;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class CodePushNativeModule extends ReactContextBaseJavaModule {
    private String mBinaryContentsHash = null;
    private String mClientUniqueId = null;
    private CodePush mCodePush;
    private LifecycleEventListener mLifecycleEventListener = null;
    private int mMinimumBackgroundDuration = 0;
    private SettingsManager mSettingsManager;
    private CodePushTelemetryManager mTelemetryManager;
    private CodePushUpdateManager mUpdateManager;

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return "CodePush";
    }

    public CodePushNativeModule(ReactApplicationContext reactApplicationContext, CodePush codePush, CodePushUpdateManager codePushUpdateManager, CodePushTelemetryManager codePushTelemetryManager, SettingsManager settingsManager) {
        super(reactApplicationContext);
        this.mCodePush = codePush;
        this.mSettingsManager = settingsManager;
        this.mTelemetryManager = codePushTelemetryManager;
        this.mUpdateManager = codePushUpdateManager;
        this.mBinaryContentsHash = CodePushUpdateUtils.a(reactApplicationContext, this.mCodePush.l());
        this.mClientUniqueId = Settings.Secure.getString(reactApplicationContext.getContentResolver(), "android_id");
    }

    @Override // com.facebook.react.bridge.BaseJavaModule
    public Map<String, Object> getConstants() {
        HashMap hashMap = new HashMap();
        hashMap.put("codePushInstallModeImmediate", Integer.valueOf(CodePushInstallMode.IMMEDIATE.a()));
        hashMap.put("codePushInstallModeOnNextRestart", Integer.valueOf(CodePushInstallMode.ON_NEXT_RESTART.a()));
        hashMap.put("codePushInstallModeOnNextResume", Integer.valueOf(CodePushInstallMode.ON_NEXT_RESUME.a()));
        hashMap.put("codePushInstallModeOnNextSuspend", Integer.valueOf(CodePushInstallMode.ON_NEXT_SUSPEND.a()));
        hashMap.put("codePushUpdateStateRunning", Integer.valueOf(CodePushUpdateState.RUNNING.a()));
        hashMap.put("codePushUpdateStatePending", Integer.valueOf(CodePushUpdateState.PENDING.a()));
        hashMap.put("codePushUpdateStateLatest", Integer.valueOf(CodePushUpdateState.LATEST.a()));
        return hashMap;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void loadBundleLegacy() {
        final Activity currentActivity = getCurrentActivity();
        if (currentActivity != null) {
            this.mCodePush.k();
            currentActivity.runOnUiThread(new Runnable() {
                /* class com.microsoft.codepush.react.CodePushNativeModule.AnonymousClass1 */

                public void run() {
                    currentActivity.recreate();
                }
            });
        }
    }

    private void setJSBundle(ReactInstanceManager reactInstanceManager, String str) throws IllegalAccessException {
        JSBundleLoader jSBundleLoader;
        try {
            if (str.toLowerCase().startsWith("assets://")) {
                jSBundleLoader = JSBundleLoader.a((Context) getReactApplicationContext(), str, false);
            } else {
                jSBundleLoader = JSBundleLoader.a(str);
            }
            Field declaredField = reactInstanceManager.getClass().getDeclaredField("mBundleLoader");
            declaredField.setAccessible(true);
            declaredField.set(reactInstanceManager, jSBundleLoader);
        } catch (Exception unused) {
            CodePushUtils.b("Unable to set JSBundle - CodePush may not support this version of React Native");
            throw new IllegalAccessException("Could not setJSBundle");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void loadBundle() {
        clearLifecycleEventListener();
        this.mCodePush.a();
        try {
            final ReactInstanceManager resolveInstanceManager = resolveInstanceManager();
            if (resolveInstanceManager != null) {
                setJSBundle(resolveInstanceManager, this.mCodePush.b(this.mCodePush.d()));
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.microsoft.codepush.react.CodePushNativeModule.AnonymousClass2 */

                    public void run() {
                        try {
                            resolveInstanceManager.d();
                            CodePushNativeModule.this.mCodePush.j();
                        } catch (Exception unused) {
                            CodePushNativeModule.this.loadBundleLegacy();
                        }
                    }
                });
            }
        } catch (Exception unused) {
            loadBundleLegacy();
        }
    }

    private void resetReactRootViews(ReactInstanceManager reactInstanceManager) throws NoSuchFieldException, IllegalAccessException {
        Field declaredField = reactInstanceManager.getClass().getDeclaredField("mAttachedRootViews");
        declaredField.setAccessible(true);
        List<ReactRootView> list = (List) declaredField.get(reactInstanceManager);
        for (ReactRootView reactRootView : list) {
            reactRootView.removeAllViews();
            reactRootView.setId(-1);
        }
        declaredField.set(reactInstanceManager, list);
    }

    private void clearLifecycleEventListener() {
        if (this.mLifecycleEventListener != null) {
            getReactApplicationContext().b(this.mLifecycleEventListener);
            this.mLifecycleEventListener = null;
        }
    }

    private ReactInstanceManager resolveInstanceManager() throws NoSuchFieldException, IllegalAccessException {
        ReactInstanceManager q = CodePush.q();
        if (q != null) {
            return q;
        }
        Activity currentActivity = getCurrentActivity();
        if (currentActivity == null) {
            return null;
        }
        return ((ReactApplication) currentActivity.getApplication()).getReactNativeHost().a();
    }

    @ReactMethod
    public void downloadUpdate(final ReadableMap readableMap, final boolean z, final Promise promise) {
        new AsyncTask<Void, Void, Void>() {
            /* class com.microsoft.codepush.react.CodePushNativeModule.AnonymousClass3 */

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public Void doInBackground(Void... voidArr) {
                try {
                    JSONObject a2 = CodePushUtils.a(readableMap);
                    CodePushUtils.a(a2, "binaryModifiedTime", "" + CodePushNativeModule.this.mCodePush.f());
                    CodePushNativeModule.this.mUpdateManager.a(a2, CodePushNativeModule.this.mCodePush.d(), new DownloadProgressCallback() {
                        /* class com.microsoft.codepush.react.CodePushNativeModule.AnonymousClass3.AnonymousClass1 */
                        private boolean b = false;
                        private DownloadProgress c = null;

                        @Override // com.microsoft.codepush.react.DownloadProgressCallback
                        public void a(DownloadProgress downloadProgress) {
                            if (z) {
                                this.c = downloadProgress;
                                if (this.c.b()) {
                                    a();
                                } else if (!this.b) {
                                    this.b = true;
                                    CodePushNativeModule.this.getReactApplicationContext().a(new Runnable() {
                                        /* class com.microsoft.codepush.react.CodePushNativeModule.AnonymousClass3.AnonymousClass1.AnonymousClass1 */

                                        public void run() {
                                            ReactChoreographer.b().a(ReactChoreographer.CallbackType.TIMERS_EVENTS, new ChoreographerCompat.FrameCallback() {
                                                /* class com.microsoft.codepush.react.CodePushNativeModule.AnonymousClass3.AnonymousClass1.AnonymousClass1.AnonymousClass1 */

                                                @Override // com.facebook.react.modules.core.ChoreographerCompat.FrameCallback
                                                public void b(long j) {
                                                    if (!AnonymousClass1.this.c.b()) {
                                                        AnonymousClass1.this.a();
                                                    }
                                                    AnonymousClass1.this.b = false;
                                                }
                                            });
                                        }
                                    });
                                }
                            }
                        }

                        public void a() {
                            ((DeviceEventManagerModule.RCTDeviceEventEmitter) CodePushNativeModule.this.getReactApplicationContext().a(DeviceEventManagerModule.RCTDeviceEventEmitter.class)).emit("CodePushDownloadProgress", this.c.a());
                        }
                    }, CodePushNativeModule.this.mCodePush.e());
                    promise.a(CodePushUtils.a(CodePushNativeModule.this.mUpdateManager.c(CodePushUtils.a(readableMap, "packageHash"))));
                    return null;
                } catch (CodePushInvalidUpdateException e) {
                    CodePushUtils.a(e);
                    CodePushNativeModule.this.mSettingsManager.a(CodePushUtils.a(readableMap));
                    promise.a((Throwable) e);
                    return null;
                } catch (CodePushUnknownException | IOException e2) {
                    CodePushUtils.a(e2);
                    promise.a(e2);
                    return null;
                }
            }
        }.executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
    }

    @ReactMethod
    public void getConfiguration(Promise promise) {
        try {
            WritableMap b = Arguments.b();
            b.putString("appVersion", this.mCodePush.c());
            b.putString("clientUniqueId", this.mClientUniqueId);
            b.putString("deploymentKey", this.mCodePush.g());
            b.putString("serverUrl", this.mCodePush.i());
            if (this.mBinaryContentsHash != null) {
                b.putString("packageHash", this.mBinaryContentsHash);
            }
            promise.a(b);
        } catch (CodePushUnknownException e) {
            CodePushUtils.a(e);
            promise.a(e);
        }
    }

    @ReactMethod
    public void getUpdateMetadata(final int i, final Promise promise) {
        new AsyncTask<Void, Void, Void>() {
            /* class com.microsoft.codepush.react.CodePushNativeModule.AnonymousClass4 */

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public Void doInBackground(Void... voidArr) {
                try {
                    JSONObject e = CodePushNativeModule.this.mUpdateManager.e();
                    if (e == null) {
                        promise.a((Object) null);
                        return null;
                    }
                    Boolean bool = false;
                    if (e.has("packageHash")) {
                        bool = Boolean.valueOf(CodePushNativeModule.this.mSettingsManager.b(e.optString("packageHash", null)));
                    }
                    if (i == CodePushUpdateState.PENDING.a() && !bool.booleanValue()) {
                        promise.a((Object) null);
                        return null;
                    } else if (i != CodePushUpdateState.RUNNING.a() || !bool.booleanValue()) {
                        if (CodePushNativeModule.this.mCodePush.m()) {
                            CodePushUtils.a(e, "_isDebugOnly", true);
                        }
                        CodePushUtils.a(e, "isPending", bool);
                        promise.a(CodePushUtils.a(e));
                        return null;
                    } else {
                        JSONObject f = CodePushNativeModule.this.mUpdateManager.f();
                        if (f == null) {
                            promise.a((Object) null);
                            return null;
                        }
                        promise.a(CodePushUtils.a(f));
                        return null;
                    }
                } catch (CodePushUnknownException e2) {
                    CodePushUtils.a(e2);
                    promise.a((Throwable) e2);
                }
            }
        }.executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
    }

    @ReactMethod
    public void getNewStatusReport(final Promise promise) {
        new AsyncTask<Void, Void, Void>() {
            /* class com.microsoft.codepush.react.CodePushNativeModule.AnonymousClass5 */

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public Void doInBackground(Void... voidArr) {
                WritableMap b2;
                try {
                    if (CodePushNativeModule.this.mCodePush.n()) {
                        CodePushNativeModule.this.mCodePush.a(false);
                        JSONArray a2 = CodePushNativeModule.this.mSettingsManager.a();
                        if (a2 != null && a2.length() > 0) {
                            try {
                                WritableMap a3 = CodePushNativeModule.this.mTelemetryManager.a(CodePushUtils.a(a2.getJSONObject(a2.length() - 1)));
                                if (a3 != null) {
                                    promise.a(a3);
                                    return null;
                                }
                            } catch (JSONException e) {
                                throw new CodePushUnknownException("Unable to read failed updates information stored in SharedPreferences.", e);
                            }
                        }
                    } else if (CodePushNativeModule.this.mCodePush.b()) {
                        JSONObject e2 = CodePushNativeModule.this.mUpdateManager.e();
                        if (!(e2 == null || (b2 = CodePushNativeModule.this.mTelemetryManager.b(CodePushUtils.a(e2))) == null)) {
                            promise.a(b2);
                            return null;
                        }
                    } else if (CodePushNativeModule.this.mCodePush.m()) {
                        WritableMap a4 = CodePushNativeModule.this.mTelemetryManager.a(CodePushNativeModule.this.mCodePush.c());
                        if (a4 != null) {
                            promise.a(a4);
                            return null;
                        }
                    } else {
                        WritableMap a5 = CodePushNativeModule.this.mTelemetryManager.a();
                        if (a5 != null) {
                            promise.a(a5);
                            return null;
                        }
                    }
                    promise.a((Object) "");
                } catch (CodePushUnknownException e3) {
                    CodePushUtils.a(e3);
                    promise.a((Throwable) e3);
                }
                return null;
            }
        }.executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
    }

    @ReactMethod
    public void installUpdate(final ReadableMap readableMap, final int i, final int i2, final Promise promise) {
        new AsyncTask<Void, Void, Void>() {
            /* class com.microsoft.codepush.react.CodePushNativeModule.AnonymousClass6 */

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public Void doInBackground(Void... voidArr) {
                try {
                    CodePushNativeModule.this.mUpdateManager.a(CodePushUtils.a(readableMap), CodePushNativeModule.this.mSettingsManager.b(null));
                    String a2 = CodePushUtils.a(readableMap, "packageHash");
                    if (a2 != null) {
                        CodePushNativeModule.this.mSettingsManager.a(a2, false);
                        if (i == CodePushInstallMode.ON_NEXT_RESUME.a() || i == CodePushInstallMode.IMMEDIATE.a() || i == CodePushInstallMode.ON_NEXT_SUSPEND.a()) {
                            CodePushNativeModule.this.mMinimumBackgroundDuration = i2;
                            if (CodePushNativeModule.this.mLifecycleEventListener == null) {
                                CodePushNativeModule.this.mLifecycleEventListener = new LifecycleEventListener() {
                                    /* class com.microsoft.codepush.react.CodePushNativeModule.AnonymousClass6.AnonymousClass1 */
                                    private Date b = null;
                                    private Handler c = new Handler(Looper.getMainLooper());
                                    private Runnable d = new Runnable() {
                                        /* class com.microsoft.codepush.react.CodePushNativeModule.AnonymousClass6.AnonymousClass1.AnonymousClass1 */

                                        public void run() {
                                            CodePushUtils.b("Loading bundle on suspend");
                                            CodePushNativeModule.this.loadBundle();
                                        }
                                    };

                                    @Override // com.facebook.react.bridge.LifecycleEventListener
                                    public void onHostDestroy() {
                                    }

                                    @Override // com.facebook.react.bridge.LifecycleEventListener
                                    public void onHostResume() {
                                        this.c.removeCallbacks(this.d);
                                        if (this.b != null) {
                                            long time = (new Date().getTime() - this.b.getTime()) / 1000;
                                            if (i == CodePushInstallMode.IMMEDIATE.a() || time >= ((long) CodePushNativeModule.this.mMinimumBackgroundDuration)) {
                                                CodePushUtils.b("Loading bundle on resume");
                                                CodePushNativeModule.this.loadBundle();
                                            }
                                        }
                                    }

                                    @Override // com.facebook.react.bridge.LifecycleEventListener
                                    public void onHostPause() {
                                        this.b = new Date();
                                        if (i == CodePushInstallMode.ON_NEXT_SUSPEND.a() && CodePushNativeModule.this.mSettingsManager.b(null)) {
                                            this.c.postDelayed(this.d, (long) (i2 * 1000));
                                        }
                                    }
                                };
                                CodePushNativeModule.this.getReactApplicationContext().a(CodePushNativeModule.this.mLifecycleEventListener);
                            }
                        }
                        promise.a((Object) "");
                        return null;
                    }
                    throw new CodePushUnknownException("Update package to be installed has no hash.");
                } catch (CodePushUnknownException e2) {
                    CodePushUtils.a(e2);
                    promise.a((Throwable) e2);
                }
            }
        }.executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
    }

    @ReactMethod
    public void isFailedUpdate(String str, Promise promise) {
        try {
            promise.a(Boolean.valueOf(this.mSettingsManager.a(str)));
        } catch (CodePushUnknownException e) {
            CodePushUtils.a(e);
            promise.a((Throwable) e);
        }
    }

    @ReactMethod
    public void isFirstRun(String str, Promise promise) {
        try {
            promise.a(Boolean.valueOf(this.mCodePush.b() && str != null && str.length() > 0 && str.equals(this.mUpdateManager.c())));
        } catch (CodePushUnknownException e) {
            CodePushUtils.a(e);
            promise.a((Throwable) e);
        }
    }

    @ReactMethod
    public void notifyApplicationReady(Promise promise) {
        try {
            this.mSettingsManager.d();
            promise.a("");
        } catch (CodePushUnknownException e) {
            CodePushUtils.a(e);
            promise.a((Throwable) e);
        }
    }

    @ReactMethod
    public void recordStatusReported(ReadableMap readableMap) {
        try {
            this.mTelemetryManager.a(readableMap);
        } catch (CodePushUnknownException e) {
            CodePushUtils.a(e);
        }
    }

    @ReactMethod
    public void restartApp(boolean z, Promise promise) {
        if (z) {
            try {
                if (!this.mSettingsManager.b(null)) {
                    promise.a((Object) false);
                    return;
                }
            } catch (CodePushUnknownException e) {
                CodePushUtils.a(e);
                promise.a((Throwable) e);
                return;
            }
        }
        loadBundle();
        promise.a((Object) true);
    }

    @ReactMethod
    public void saveStatusReportForRetry(ReadableMap readableMap) {
        try {
            this.mTelemetryManager.b(readableMap);
        } catch (CodePushUnknownException e) {
            CodePushUtils.a(e);
        }
    }

    @ReactMethod
    public void downloadAndReplaceCurrentBundle(String str) {
        CodePush codePush = this.mCodePush;
        if (CodePush.o()) {
            try {
                this.mUpdateManager.a(str, this.mCodePush.d());
            } catch (IOException e) {
                throw new CodePushUnknownException("Unable to replace current bundle", e);
            } catch (CodePushMalformedDataException | CodePushUnknownException e2) {
                CodePushUtils.a(e2);
            }
        }
    }
}
