package com.nimbusds.jose.crypto;

import com.nimbusds.jose.JOSEException;
import com.nimbusds.jose.JWSAlgorithm;
import java.security.InvalidAlgorithmParameterException;
import java.security.NoSuchAlgorithmException;
import java.security.Provider;
import java.security.Signature;
import java.security.spec.MGF1ParameterSpec;
import java.security.spec.PSSParameterSpec;

class RSASSA {
    protected static Signature a(JWSAlgorithm jWSAlgorithm, Provider provider) throws JOSEException {
        String str;
        Signature signature;
        PSSParameterSpec pSSParameterSpec;
        PSSParameterSpec pSSParameterSpec2 = null;
        if (jWSAlgorithm.equals(JWSAlgorithm.e)) {
            str = "SHA256withRSA";
        } else if (jWSAlgorithm.equals(JWSAlgorithm.f)) {
            str = "SHA384withRSA";
        } else if (jWSAlgorithm.equals(JWSAlgorithm.g)) {
            str = "SHA512withRSA";
        } else {
            if (jWSAlgorithm.equals(JWSAlgorithm.k)) {
                str = "SHA256withRSAandMGF1";
                pSSParameterSpec = new PSSParameterSpec("SHA256", "MGF1", MGF1ParameterSpec.SHA256, 32, 1);
            } else if (jWSAlgorithm.equals(JWSAlgorithm.l)) {
                str = "SHA384withRSAandMGF1";
                pSSParameterSpec = new PSSParameterSpec("SHA384", "MGF1", MGF1ParameterSpec.SHA384, 48, 1);
            } else if (jWSAlgorithm.equals(JWSAlgorithm.m)) {
                str = "SHA512withRSAandMGF1";
                pSSParameterSpec = new PSSParameterSpec("SHA512", "MGF1", MGF1ParameterSpec.SHA512, 64, 1);
            } else {
                throw new JOSEException(AlgorithmSupportMessage.a(jWSAlgorithm, RSASSAProvider.f2675a));
            }
            pSSParameterSpec2 = pSSParameterSpec;
        }
        if (provider != null) {
            try {
                signature = Signature.getInstance(str, provider);
            } catch (NoSuchAlgorithmException e) {
                throw new JOSEException("Unsupported RSASSA algorithm: " + e.getMessage(), e);
            }
        } else {
            signature = Signature.getInstance(str);
        }
        if (pSSParameterSpec2 != null) {
            try {
                signature.setParameter(pSSParameterSpec2);
            } catch (InvalidAlgorithmParameterException e2) {
                throw new JOSEException("Invalid RSASSA-PSS salt length parameter: " + e2.getMessage(), e2);
            }
        }
        return signature;
    }

    private RSASSA() {
    }
}
