package com.nimbusds.jose.crypto;

import com.nimbusds.jose.CriticalHeaderParamsAware;
import com.nimbusds.jose.JOSEException;
import com.nimbusds.jose.JWSHeader;
import com.nimbusds.jose.JWSVerifier;
import com.nimbusds.jose.jca.JCAContext;
import com.nimbusds.jose.util.Base64URL;
import java.security.InvalidKeyException;
import java.security.Signature;
import java.security.SignatureException;
import java.security.interfaces.RSAPublicKey;
import java.util.Set;
import net.jcip.annotations.ThreadSafe;

@ThreadSafe
public class RSASSAVerifier extends RSASSAProvider implements CriticalHeaderParamsAware, JWSVerifier {
    private final CriticalHeaderParamsDeferral b;
    private final RSAPublicKey c;

    @Override // com.nimbusds.jose.crypto.BaseJWSProvider
    public /* bridge */ /* synthetic */ Set a() {
        return super.a();
    }

    @Override // com.nimbusds.jose.crypto.BaseJWSProvider
    public /* bridge */ /* synthetic */ JCAContext b() {
        return super.b();
    }

    public RSASSAVerifier(RSAPublicKey rSAPublicKey) {
        this(rSAPublicKey, null);
    }

    public RSASSAVerifier(RSAPublicKey rSAPublicKey, Set<String> set) {
        this.b = new CriticalHeaderParamsDeferral();
        if (rSAPublicKey != null) {
            this.c = rSAPublicKey;
            this.b.a(set);
            return;
        }
        throw new IllegalArgumentException("The public RSA key must not be null");
    }

    @Override // com.nimbusds.jose.JWSVerifier
    public boolean a(JWSHeader jWSHeader, byte[] bArr, Base64URL base64URL) throws JOSEException {
        if (!this.b.a(jWSHeader)) {
            return false;
        }
        Signature a2 = RSASSA.a(jWSHeader.b(), b().a());
        try {
            a2.initVerify(this.c);
            try {
                a2.update(bArr);
                return a2.verify(base64URL.a());
            } catch (SignatureException unused) {
                return false;
            }
        } catch (InvalidKeyException e) {
            throw new JOSEException("Invalid public RSA key: " + e.getMessage(), e);
        }
    }
}
