package com.openinstall.openinstallLibrary;

import android.app.Activity;
import android.content.Intent;
import android.text.TextUtils;
import android.util.Log;
import com.facebook.react.bridge.ActivityEventListener;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.modules.core.DeviceEventManagerModule;
import com.fm.openinstall.Configuration;
import com.fm.openinstall.OpenInstall;
import com.fm.openinstall.listener.AppInstallAdapter;
import com.fm.openinstall.listener.AppInstallRetryAdapter;
import com.fm.openinstall.listener.AppWakeUpAdapter;
import com.fm.openinstall.listener.AppWakeUpListener;
import com.fm.openinstall.model.AppData;
import com.fm.openinstall.model.Error;

public class OpeninstallModule extends ReactContextBaseJavaModule {
    public static final String EVENT = "OpeninstallWakeupCallBack";
    private static final String TAG = "OpenInstallModule";
    private boolean alwaysCallback = false;
    private Configuration configuration = null;
    private final ReactContext context;
    private boolean initialized = false;
    private boolean registerWakeup = false;
    private WritableMap wakeupDataHolder = null;
    private Intent wakeupIntent = null;

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return "OpeninstallModule";
    }

    public OpeninstallModule(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
        this.context = reactApplicationContext;
        reactApplicationContext.a(new ActivityEventListener() {
            /* class com.openinstall.openinstallLibrary.OpeninstallModule.AnonymousClass1 */

            @Override // com.facebook.react.bridge.ActivityEventListener
            public void onActivityResult(Activity activity, int i, int i2, Intent intent) {
            }

            @Override // com.facebook.react.bridge.ActivityEventListener
            public void onNewIntent(Intent intent) {
                Log.d(OpeninstallModule.TAG, "onNewIntent");
                OpeninstallModule.this.getWakeUp(intent, null);
            }
        });
    }

    private boolean optBoolean(ReadableMap readableMap, String str) {
        if (!readableMap.a(str) || readableMap.b(str)) {
            return false;
        }
        return readableMap.c(str);
    }

    private String optString(ReadableMap readableMap, String str) {
        if (readableMap.a(str)) {
            return readableMap.f(str);
        }
        return null;
    }

    @ReactMethod
    public void config(ReadableMap readableMap) {
        Configuration.Builder builder = new Configuration.Builder();
        builder.a(optBoolean(readableMap, "adEnabled"));
        builder.a(optString(readableMap, "oaid"));
        builder.b(optString(readableMap, "gaid"));
        if (optBoolean(readableMap, "macDisabled")) {
            builder.b();
        }
        if (optBoolean(readableMap, "imeiDisabled")) {
            builder.a();
        }
        this.configuration = builder.c();
        Log.d(TAG, String.format("Configuration: adEnabled = %s, oaid = %s, gaid = %s, macDisabled = %s, imeiDisabled = %s", Boolean.valueOf(this.configuration.a()), this.configuration.b(), this.configuration.c(), Boolean.valueOf(this.configuration.e()), Boolean.valueOf(this.configuration.d())));
    }

    @ReactMethod
    public void serialEnabled(boolean z) {
        OpenInstall.b(z);
    }

    @ReactMethod
    public void clipBoardEnabled(boolean z) {
        OpenInstall.a(z);
    }

    @ReactMethod
    public void init() {
        if (this.context.j()) {
            OpenInstall.a(this.context.k(), this.configuration);
        } else {
            Log.w(TAG, "init with context, not activity");
            OpenInstall.a(this.context, this.configuration);
        }
        initialized();
    }

    private void initialized() {
        this.initialized = true;
        if (this.wakeupIntent != null) {
            OpenInstall.a(this.wakeupIntent, new AppWakeUpAdapter() {
                /* class com.openinstall.openinstallLibrary.OpeninstallModule.AnonymousClass2 */

                @Override // com.fm.openinstall.listener.AppWakeUpAdapter
                public void a(AppData appData) {
                    OpeninstallModule.this.wakeupIntent = null;
                    if (appData != null) {
                        Log.d(OpeninstallModule.TAG, "getWakeUp : wakeupData = " + appData.toString());
                        ((DeviceEventManagerModule.RCTDeviceEventEmitter) OpeninstallModule.this.getReactApplicationContext().a(DeviceEventManagerModule.RCTDeviceEventEmitter.class)).emit(OpeninstallModule.EVENT, OpeninstallModule.this.parseData(appData));
                    }
                }
            });
        }
    }

    @ReactMethod
    public void getWakeUp(Callback callback) {
        Log.d(TAG, "getWakeUp");
        this.registerWakeup = true;
        if (this.wakeupDataHolder != null) {
            ((DeviceEventManagerModule.RCTDeviceEventEmitter) getReactApplicationContext().a(DeviceEventManagerModule.RCTDeviceEventEmitter.class)).emit(EVENT, this.wakeupDataHolder);
            this.wakeupDataHolder = null;
            return;
        }
        Activity currentActivity = getCurrentActivity();
        if (currentActivity != null) {
            getWakeUp(currentActivity.getIntent(), callback);
        }
    }

    @ReactMethod
    public void getWakeUpAlwaysCallback(Callback callback) {
        Log.d(TAG, "getWakeUpAlwaysCallback");
        this.alwaysCallback = true;
        this.registerWakeup = true;
        if (this.wakeupDataHolder != null) {
            ((DeviceEventManagerModule.RCTDeviceEventEmitter) getReactApplicationContext().a(DeviceEventManagerModule.RCTDeviceEventEmitter.class)).emit(EVENT, this.wakeupDataHolder);
            this.wakeupDataHolder = null;
            return;
        }
        Activity currentActivity = getCurrentActivity();
        if (currentActivity != null) {
            getWakeUp(currentActivity.getIntent(), callback);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void getWakeUp(Intent intent, Callback callback) {
        if (!this.initialized) {
            this.wakeupIntent = intent;
        } else if (this.alwaysCallback) {
            OpenInstall.b(intent, new AppWakeUpListener() {
                /* class com.openinstall.openinstallLibrary.OpeninstallModule.AnonymousClass3 */

                @Override // com.fm.openinstall.listener.AppWakeUpListener
                public void a(AppData appData, Error error) {
                    if (error != null) {
                        Log.d(OpeninstallModule.TAG, "getWakeUpAlwaysCallback : " + error.toString());
                    }
                    WritableMap parseData = OpeninstallModule.this.parseData(appData);
                    if (OpeninstallModule.this.registerWakeup) {
                        ((DeviceEventManagerModule.RCTDeviceEventEmitter) OpeninstallModule.this.getReactApplicationContext().a(DeviceEventManagerModule.RCTDeviceEventEmitter.class)).emit(OpeninstallModule.EVENT, parseData);
                    } else {
                        OpeninstallModule.this.wakeupDataHolder = parseData;
                    }
                }
            });
        } else {
            OpenInstall.a(intent, new AppWakeUpAdapter() {
                /* class com.openinstall.openinstallLibrary.OpeninstallModule.AnonymousClass4 */

                @Override // com.fm.openinstall.listener.AppWakeUpAdapter
                public void a(AppData appData) {
                    WritableMap parseData = OpeninstallModule.this.parseData(appData);
                    if (OpeninstallModule.this.registerWakeup) {
                        ((DeviceEventManagerModule.RCTDeviceEventEmitter) OpeninstallModule.this.getReactApplicationContext().a(DeviceEventManagerModule.RCTDeviceEventEmitter.class)).emit(OpeninstallModule.EVENT, parseData);
                    } else {
                        OpeninstallModule.this.wakeupDataHolder = parseData;
                    }
                }
            });
        }
    }

    @ReactMethod
    public void getInstall(Integer num, final Callback callback) {
        Log.d(TAG, "getInstall");
        OpenInstall.a(new AppInstallAdapter() {
            /* class com.openinstall.openinstallLibrary.OpeninstallModule.AnonymousClass5 */

            @Override // com.fm.openinstall.listener.AppInstallAdapter
            public void a(AppData appData) {
                Log.d(OpeninstallModule.TAG, "getInstall : data = " + appData.toString());
                callback.a(OpeninstallModule.this.parseData(appData));
            }
        }, num.intValue());
    }

    @ReactMethod
    public void getInstallCanRetry(Integer num, final Callback callback) {
        Log.d(TAG, "getInstallCanRetry");
        OpenInstall.a((AppInstallRetryAdapter) new AppInstallRetryAdapter() {
            /* class com.openinstall.openinstallLibrary.OpeninstallModule.AnonymousClass6 */

            @Override // com.fm.openinstall.listener.AppInstallRetryAdapter
            public void a(AppData appData, boolean z) {
                WritableMap parseData = OpeninstallModule.this.parseData(appData);
                parseData.putBoolean("retry", z);
                callback.a(parseData);
            }
        }, num.intValue());
    }

    @ReactMethod
    public void reportRegister() {
        Log.d(TAG, "reportRegister");
        OpenInstall.b();
    }

    @ReactMethod
    public void reportEffectPoint(String str, Integer num) {
        Log.d(TAG, "reportEffectPoint");
        if (!TextUtils.isEmpty(str) && num.intValue() >= 0) {
            OpenInstall.a(str, (long) num.intValue());
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private WritableMap parseData(AppData appData) {
        WritableMap b = Arguments.b();
        if (appData != null) {
            b.putString("channel", appData.a());
            b.putString("data", appData.b());
        }
        return b;
    }
}
