package com.reactlibrary;

import com.alibaba.sdk.android.oss.OSS;
import com.alibaba.sdk.android.oss.common.OSSLog;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.reactlibrary.AliyunAuthManager;

public class RNAliyunOssModule extends ReactContextBaseJavaModule {
    private AliyunAuthManager mAuth;
    private AliyunBucketManager mBucketManager;
    private AliyunDownloadManager mDownloadManager;
    private OSS mOSS;
    private AliyunObjectManager mObjectManager;
    private AliyunUploadManager mUploadManager;

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return "RNAliyunOSS";
    }

    public RNAliyunOssModule(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
        this.mAuth = new AliyunAuthManager(reactApplicationContext.getApplicationContext(), new AliyunAuthManager.AuthListener() {
            /* class com.reactlibrary.RNAliyunOssModule.AnonymousClass1 */

            @Override // com.reactlibrary.AliyunAuthManager.AuthListener
            public void a(OSS oss) {
                RNAliyunOssModule.this.init(oss);
            }
        });
    }

    @ReactMethod
    public void enableDevMode() {
        OSSLog.a();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void init(OSS oss) {
        this.mOSS = oss;
        this.mBucketManager = new AliyunBucketManager(this.mOSS);
        this.mObjectManager = new AliyunObjectManager(this.mOSS);
        this.mUploadManager = new AliyunUploadManager(this.mOSS);
        this.mDownloadManager = new AliyunDownloadManager(this.mOSS);
    }

    @ReactMethod
    public void initWithSigner(String str, String str2, String str3, ReadableMap readableMap) {
        this.mAuth.a(str, str2, str3, readableMap);
    }

    @ReactMethod
    public void initWithPlainTextAccessKey(String str, String str2, String str3, ReadableMap readableMap) {
        this.mAuth.b(str, str2, str3, readableMap);
    }

    @ReactMethod
    public void initWithSecurityToken(String str, String str2, String str3, String str4, ReadableMap readableMap) {
        this.mAuth.a(str, str2, str3, str4, readableMap);
    }

    @ReactMethod
    public void initWithServerSTS(String str, String str2, ReadableMap readableMap) {
        this.mAuth.a(str, str2, readableMap);
    }

    @ReactMethod
    public void asyncUpload(String str, String str2, String str3, ReadableMap readableMap, Promise promise) {
        this.mUploadManager.a(getReactApplicationContext(), str, str2, str3, readableMap, promise);
    }

    @ReactMethod
    public void asyncAppendObject(String str, String str2, String str3, ReadableMap readableMap, Promise promise) {
        this.mUploadManager.b(getReactApplicationContext(), str, str2, str3, readableMap, promise);
    }

    @ReactMethod
    public void asyncResumableUpload(String str, String str2, String str3, ReadableMap readableMap, Promise promise) {
        this.mUploadManager.c(getReactApplicationContext(), str, str2, str3, readableMap, promise);
    }

    @ReactMethod
    public void initMultipartUpload(String str, String str2, Promise promise) {
        this.mUploadManager.a(str, str2, promise);
    }

    @ReactMethod
    public void multipartUpload(String str, String str2, String str3, String str4, ReadableMap readableMap, Promise promise) {
        this.mUploadManager.a(getReactApplicationContext(), str, str2, str3, str4, readableMap, promise);
    }

    @ReactMethod
    public void abortMultipartUpload(String str, String str2, String str3, Promise promise) {
        this.mUploadManager.a(str, str2, str3, promise);
    }

    @ReactMethod
    public void listParts(String str, String str2, String str3, Promise promise) {
        this.mUploadManager.b(str, str2, str3, promise);
    }

    @ReactMethod
    public void asyncDownload(String str, String str2, String str3, ReadableMap readableMap, Promise promise) {
        this.mDownloadManager.a(getReactApplicationContext(), str, str2, str3, readableMap, promise);
    }

    @ReactMethod
    public void asyncCreateBucket(String str, String str2, String str3, Promise promise) {
        this.mBucketManager.a(str, str2, str3, promise);
    }

    @ReactMethod
    public void asyncGetBucketACL(String str, Promise promise) {
        this.mBucketManager.a(str, promise);
    }

    @ReactMethod
    public void asyncListBuckets(Promise promise) {
        this.mBucketManager.a(promise);
    }

    @ReactMethod
    public void asyncDeleteBucket(String str, Promise promise) {
        this.mBucketManager.b(str, promise);
    }

    @ReactMethod
    public void asyncHeadObject(String str, String str2, Promise promise) {
        this.mObjectManager.a(str, str2, promise);
    }

    @ReactMethod
    public void asyncListObjects(String str, ReadableMap readableMap, Promise promise) {
        this.mObjectManager.a(str, readableMap, promise);
    }

    @ReactMethod
    public void asyncCopyObject(String str, String str2, String str3, String str4, ReadableMap readableMap, Promise promise) {
        this.mObjectManager.a(str, str2, str3, str4, readableMap, promise);
    }

    @ReactMethod
    public void doesObjectExist(String str, String str2, Promise promise) {
        this.mObjectManager.b(str, str2, promise);
    }

    @ReactMethod
    public void asyncDeleteObject(String str, String str2, Promise promise) {
        this.mObjectManager.c(str, str2, promise);
    }
}
