package org.apache.commons.lang3.reflect;

import java.lang.reflect.AccessibleObject;
import java.lang.reflect.Array;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Member;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.util.Objects;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.ClassUtils;
import org.apache.commons.lang3.Validate;

public class MethodUtils {
    public static Object a(Object obj, String str) throws NoSuchMethodException, IllegalAccessException, InvocationTargetException {
        return a(obj, str, ArrayUtils.f3367a, null);
    }

    public static Object a(Object obj, String str, Object... objArr) throws NoSuchMethodException, IllegalAccessException, InvocationTargetException {
        Object[] b = ArrayUtils.b(objArr);
        return a(obj, str, b, ClassUtils.a(b));
    }

    public static Object a(Object obj, boolean z, String str, Object[] objArr, Class<?>[] clsArr) throws NoSuchMethodException, IllegalAccessException, InvocationTargetException {
        Method method;
        String str2;
        Class<?>[] a2 = ArrayUtils.a(clsArr);
        Object[] b = ArrayUtils.b(objArr);
        if (z) {
            str2 = "No such method: ";
            method = c(obj.getClass(), str, a2);
            if (method != null && !method.isAccessible()) {
                method.setAccessible(true);
            }
        } else {
            str2 = "No such accessible method: ";
            method = b(obj.getClass(), str, a2);
        }
        if (method != null) {
            return method.invoke(obj, a(method, b));
        }
        throw new NoSuchMethodException(str2 + str + "() on object: " + obj.getClass().getName());
    }

    public static Object a(Object obj, String str, Object[] objArr, Class<?>[] clsArr) throws NoSuchMethodException, IllegalAccessException, InvocationTargetException {
        return a(obj, false, str, objArr, clsArr);
    }

    private static Object[] a(Method method, Object[] objArr) {
        return method.isVarArgs() ? a(objArr, method.getParameterTypes()) : objArr;
    }

    static Object[] a(Object[] objArr, Class<?>[] clsArr) {
        if (objArr.length == clsArr.length && objArr[objArr.length - 1].getClass().equals(clsArr[clsArr.length - 1])) {
            return objArr;
        }
        Object[] objArr2 = new Object[clsArr.length];
        System.arraycopy(objArr, 0, objArr2, 0, clsArr.length - 1);
        Class<?> componentType = clsArr[clsArr.length - 1].getComponentType();
        int length = (objArr.length - clsArr.length) + 1;
        Object newInstance = Array.newInstance(ClassUtils.e(componentType), length);
        System.arraycopy(objArr, clsArr.length - 1, newInstance, 0, length);
        if (componentType.isPrimitive()) {
            newInstance = ArrayUtils.b(newInstance);
        }
        objArr2[clsArr.length - 1] = newInstance;
        return objArr2;
    }

    public static Method a(Class<?> cls, String str, Class<?>... clsArr) {
        try {
            return a(cls.getMethod(str, clsArr));
        } catch (NoSuchMethodException unused) {
            return null;
        }
    }

    public static Method a(Method method) {
        if (!MemberUtils.a((Member) method)) {
            return null;
        }
        Class<?> declaringClass = method.getDeclaringClass();
        if (Modifier.isPublic(declaringClass.getModifiers())) {
            return method;
        }
        String name = method.getName();
        Class<?>[] parameterTypes = method.getParameterTypes();
        Method e = e(declaringClass, name, parameterTypes);
        return e == null ? d(declaringClass, name, parameterTypes) : e;
    }

    private static Method d(Class<?> cls, String str, Class<?>... clsArr) {
        for (Class<? super Object> superclass = cls.getSuperclass(); superclass != null; superclass = superclass.getSuperclass()) {
            if (Modifier.isPublic(superclass.getModifiers())) {
                try {
                    return superclass.getMethod(str, clsArr);
                } catch (NoSuchMethodException unused) {
                    return null;
                }
            }
        }
        return null;
    }

    private static Method e(Class<?> cls, String str, Class<?>... clsArr) {
        while (cls != null) {
            Class<?>[] interfaces = cls.getInterfaces();
            for (Class<?> cls2 : interfaces) {
                if (Modifier.isPublic(cls2.getModifiers())) {
                    try {
                        return cls2.getDeclaredMethod(str, clsArr);
                    } catch (NoSuchMethodException unused) {
                        Method e = e(cls2, str, clsArr);
                        if (e != null) {
                            return e;
                        }
                    }
                }
            }
            cls = cls.getSuperclass();
        }
        return null;
    }

    public static Method b(Class<?> cls, String str, Class<?>... clsArr) {
        Method a2;
        try {
            Method method = cls.getMethod(str, clsArr);
            MemberUtils.a((AccessibleObject) method);
            return method;
        } catch (NoSuchMethodException unused) {
            Method[] methods = cls.getMethods();
            Method method2 = null;
            for (Method method3 : methods) {
                if (method3.getName().equals(str) && MemberUtils.a(method3, clsArr) && (a2 = a(method3)) != null && (method2 == null || MemberUtils.a(a2, method2, clsArr) < 0)) {
                    method2 = a2;
                }
            }
            if (method2 != null) {
                MemberUtils.a((AccessibleObject) method2);
            }
            if (method2 != null && method2.isVarArgs() && method2.getParameterTypes().length > 0 && clsArr.length > 0) {
                Class<?>[] parameterTypes = method2.getParameterTypes();
                String name = ClassUtils.e(parameterTypes[parameterTypes.length - 1].getComponentType()).getName();
                String name2 = clsArr[clsArr.length - 1].getName();
                String name3 = clsArr[clsArr.length - 1].getSuperclass().getName();
                if (name.equals(name2) || name.equals(name3)) {
                    return method2;
                }
                return null;
            }
            return method2;
        }
    }

    public static Method c(Class<?> cls, String str, Class<?>... clsArr) {
        Validate.a(cls, "Null class not allowed.", new Object[0]);
        Validate.a((CharSequence) str, "Null or blank methodName not allowed.", new Object[0]);
        Method[] declaredMethods = cls.getDeclaredMethods();
        for (Class<?> cls2 : ClassUtils.b(cls)) {
            declaredMethods = (Method[]) ArrayUtils.b((Object[]) declaredMethods, (Object[]) cls2.getDeclaredMethods());
        }
        Method method = null;
        for (Method method2 : declaredMethods) {
            if (str.equals(method2.getName()) && Objects.deepEquals(clsArr, method2.getParameterTypes())) {
                return method2;
            }
            if (str.equals(method2.getName()) && ClassUtils.a(clsArr, method2.getParameterTypes(), true) && (method == null || a(clsArr, method2.getParameterTypes()) < a(clsArr, method.getParameterTypes()))) {
                method = method2;
            }
        }
        return method;
    }

    private static int a(Class<?>[] clsArr, Class<?>[] clsArr2) {
        if (!ClassUtils.a(clsArr, clsArr2, true)) {
            return -1;
        }
        int i = 0;
        for (int i2 = 0; i2 < clsArr.length; i2++) {
            if (!clsArr[i2].equals(clsArr2[i2])) {
                i = (!ClassUtils.a(clsArr[i2], clsArr2[i2], true) || ClassUtils.a(clsArr[i2], clsArr2[i2], false)) ? i + 2 : i + 1;
            }
        }
        return i;
    }
}
