package android.support.v4.app;

import android.app.Notification;
import android.app.NotificationManager;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.content.pm.ResolveInfo;
import android.os.Build;
import android.os.DeadObjectException;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.os.RemoteException;
import android.provider.Settings;
import android.support.v4.app.INotificationSideChannel;
import android.support.v4.os.BuildCompat;
import android.util.Log;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;

public final class NotificationManagerCompat {

    /* renamed from: a  reason: collision with root package name */
    private static final int f139a = h.a();
    private static final Object b = new Object();
    private static String c;
    private static Set<String> d = new HashSet();
    private static final Object g = new Object();
    private static final Impl h;
    private final Context e;
    private final NotificationManager f = ((NotificationManager) this.e.getSystemService("notification"));

    interface Impl {
        int a();

        boolean a(Context context, NotificationManager notificationManager);
    }

    /* access modifiers changed from: private */
    public interface Task {
        void a(INotificationSideChannel iNotificationSideChannel) throws RemoteException;
    }

    static {
        if (BuildCompat.a()) {
            h = new ImplApi24();
        } else if (Build.VERSION.SDK_INT >= 19) {
            h = new ImplKitKat();
        } else if (Build.VERSION.SDK_INT >= 14) {
            h = new ImplIceCreamSandwich();
        } else if (Build.VERSION.SDK_INT >= 5) {
            h = new ImplEclair();
        } else {
            h = new ImplBase();
        }
    }

    public static NotificationManagerCompat a(Context context) {
        return new NotificationManagerCompat(context);
    }

    private NotificationManagerCompat(Context context) {
        this.e = context;
    }

    static class ImplBase implements Impl {
        @Override // android.support.v4.app.NotificationManagerCompat.Impl
        public int a() {
            return 1;
        }

        @Override // android.support.v4.app.NotificationManagerCompat.Impl
        public boolean a(Context context, NotificationManager notificationManager) {
            return true;
        }

        ImplBase() {
        }
    }

    static class ImplEclair extends ImplBase {
        ImplEclair() {
        }
    }

    static class ImplIceCreamSandwich extends ImplEclair {
        @Override // android.support.v4.app.NotificationManagerCompat.ImplBase, android.support.v4.app.NotificationManagerCompat.Impl
        public int a() {
            return 33;
        }

        ImplIceCreamSandwich() {
        }
    }

    static class ImplKitKat extends ImplIceCreamSandwich {
        ImplKitKat() {
        }

        @Override // android.support.v4.app.NotificationManagerCompat.ImplBase, android.support.v4.app.NotificationManagerCompat.Impl
        public boolean a(Context context, NotificationManager notificationManager) {
            return NotificationManagerCompatKitKat.a(context);
        }
    }

    static class ImplApi24 extends ImplKitKat {
        ImplApi24() {
        }

        @Override // android.support.v4.app.NotificationManagerCompat.ImplKitKat, android.support.v4.app.NotificationManagerCompat.ImplBase, android.support.v4.app.NotificationManagerCompat.Impl
        public boolean a(Context context, NotificationManager notificationManager) {
            return NotificationManagerCompatApi24.a(notificationManager);
        }
    }

    public boolean a() {
        return h.a(this.e, this.f);
    }

    public static Set<String> b(Context context) {
        Set<String> set;
        String string = Settings.Secure.getString(context.getContentResolver(), "enabled_notification_listeners");
        synchronized (b) {
            if (string != null) {
                try {
                    if (!string.equals(c)) {
                        String[] split = string.split(":");
                        HashSet hashSet = new HashSet(split.length);
                        for (String str : split) {
                            ComponentName unflattenFromString = ComponentName.unflattenFromString(str);
                            if (unflattenFromString != null) {
                                hashSet.add(unflattenFromString.getPackageName());
                            }
                        }
                        d = hashSet;
                        c = string;
                    }
                } catch (Throwable th) {
                    throw th;
                }
            }
            set = d;
        }
        return set;
    }

    private static class SideChannelManager implements ServiceConnection, Handler.Callback {

        /* renamed from: a  reason: collision with root package name */
        private final Context f143a;
        private final Handler b;
        private final Map<ComponentName, ListenerRecord> c;
        private Set<String> d;

        public boolean handleMessage(Message message) {
            switch (message.what) {
                case 0:
                    a((Task) message.obj);
                    return true;
                case 1:
                    ServiceConnectedEvent serviceConnectedEvent = (ServiceConnectedEvent) message.obj;
                    a(serviceConnectedEvent.f142a, serviceConnectedEvent.b);
                    return true;
                case 2:
                    a((ComponentName) message.obj);
                    return true;
                case 3:
                    b((ComponentName) message.obj);
                    return true;
                default:
                    return false;
            }
        }

        private void a(Task task) {
            a();
            for (ListenerRecord listenerRecord : this.c.values()) {
                listenerRecord.d.add(task);
                d(listenerRecord);
            }
        }

        private void a(ComponentName componentName, IBinder iBinder) {
            ListenerRecord listenerRecord = this.c.get(componentName);
            if (listenerRecord != null) {
                listenerRecord.c = INotificationSideChannel.Stub.a(iBinder);
                listenerRecord.e = 0;
                d(listenerRecord);
            }
        }

        private void a(ComponentName componentName) {
            ListenerRecord listenerRecord = this.c.get(componentName);
            if (listenerRecord != null) {
                b(listenerRecord);
            }
        }

        private void b(ComponentName componentName) {
            ListenerRecord listenerRecord = this.c.get(componentName);
            if (listenerRecord != null) {
                d(listenerRecord);
            }
        }

        public void onServiceConnected(ComponentName componentName, IBinder iBinder) {
            if (Log.isLoggable("NotifManCompat", 3)) {
                Log.d("NotifManCompat", "Connected to service " + componentName);
            }
            this.b.obtainMessage(1, new ServiceConnectedEvent(componentName, iBinder)).sendToTarget();
        }

        public void onServiceDisconnected(ComponentName componentName) {
            if (Log.isLoggable("NotifManCompat", 3)) {
                Log.d("NotifManCompat", "Disconnected from service " + componentName);
            }
            this.b.obtainMessage(2, componentName).sendToTarget();
        }

        private void a() {
            Set<String> b2 = NotificationManagerCompat.b(this.f143a);
            if (!b2.equals(this.d)) {
                this.d = b2;
                List<ResolveInfo> queryIntentServices = this.f143a.getPackageManager().queryIntentServices(new Intent().setAction("android.support.BIND_NOTIFICATION_SIDE_CHANNEL"), 4);
                HashSet<ComponentName> hashSet = new HashSet();
                for (ResolveInfo resolveInfo : queryIntentServices) {
                    if (b2.contains(resolveInfo.serviceInfo.packageName)) {
                        ComponentName componentName = new ComponentName(resolveInfo.serviceInfo.packageName, resolveInfo.serviceInfo.name);
                        if (resolveInfo.serviceInfo.permission != null) {
                            Log.w("NotifManCompat", "Permission present on component " + componentName + ", not adding listener record.");
                        } else {
                            hashSet.add(componentName);
                        }
                    }
                }
                for (ComponentName componentName2 : hashSet) {
                    if (!this.c.containsKey(componentName2)) {
                        if (Log.isLoggable("NotifManCompat", 3)) {
                            Log.d("NotifManCompat", "Adding listener record for " + componentName2);
                        }
                        this.c.put(componentName2, new ListenerRecord(componentName2));
                    }
                }
                Iterator<Map.Entry<ComponentName, ListenerRecord>> it = this.c.entrySet().iterator();
                while (it.hasNext()) {
                    Map.Entry<ComponentName, ListenerRecord> next = it.next();
                    if (!hashSet.contains(next.getKey())) {
                        if (Log.isLoggable("NotifManCompat", 3)) {
                            Log.d("NotifManCompat", "Removing listener record for " + next.getKey());
                        }
                        b(next.getValue());
                        it.remove();
                    }
                }
            }
        }

        private boolean a(ListenerRecord listenerRecord) {
            if (listenerRecord.b) {
                return true;
            }
            listenerRecord.b = this.f143a.bindService(new Intent("android.support.BIND_NOTIFICATION_SIDE_CHANNEL").setComponent(listenerRecord.f144a), this, NotificationManagerCompat.f139a);
            if (listenerRecord.b) {
                listenerRecord.e = 0;
            } else {
                Log.w("NotifManCompat", "Unable to bind to listener " + listenerRecord.f144a);
                this.f143a.unbindService(this);
            }
            return listenerRecord.b;
        }

        private void b(ListenerRecord listenerRecord) {
            if (listenerRecord.b) {
                this.f143a.unbindService(this);
                listenerRecord.b = false;
            }
            listenerRecord.c = null;
        }

        private void c(ListenerRecord listenerRecord) {
            if (!this.b.hasMessages(3, listenerRecord.f144a)) {
                listenerRecord.e++;
                if (listenerRecord.e > 6) {
                    Log.w("NotifManCompat", "Giving up on delivering " + listenerRecord.d.size() + " tasks to " + listenerRecord.f144a + " after " + listenerRecord.e + " retries");
                    listenerRecord.d.clear();
                    return;
                }
                int i = (1 << (listenerRecord.e - 1)) * 1000;
                if (Log.isLoggable("NotifManCompat", 3)) {
                    Log.d("NotifManCompat", "Scheduling retry for " + i + " ms");
                }
                this.b.sendMessageDelayed(this.b.obtainMessage(3, listenerRecord.f144a), (long) i);
            }
        }

        private void d(ListenerRecord listenerRecord) {
            if (Log.isLoggable("NotifManCompat", 3)) {
                Log.d("NotifManCompat", "Processing component " + listenerRecord.f144a + ", " + listenerRecord.d.size() + " queued tasks");
            }
            if (!listenerRecord.d.isEmpty()) {
                if (!a(listenerRecord) || listenerRecord.c == null) {
                    c(listenerRecord);
                    return;
                }
                while (true) {
                    Task peek = listenerRecord.d.peek();
                    if (peek == null) {
                        break;
                    }
                    try {
                        if (Log.isLoggable("NotifManCompat", 3)) {
                            Log.d("NotifManCompat", "Sending task " + peek);
                        }
                        peek.a(listenerRecord.c);
                        listenerRecord.d.remove();
                    } catch (DeadObjectException unused) {
                        if (Log.isLoggable("NotifManCompat", 3)) {
                            Log.d("NotifManCompat", "Remote service has died: " + listenerRecord.f144a);
                        }
                    } catch (RemoteException e) {
                        Log.w("NotifManCompat", "RemoteException communicating with " + listenerRecord.f144a, e);
                    }
                }
                if (!listenerRecord.d.isEmpty()) {
                    c(listenerRecord);
                }
            }
        }

        /* access modifiers changed from: private */
        public static class ListenerRecord {

            /* renamed from: a  reason: collision with root package name */
            public final ComponentName f144a;
            public boolean b = false;
            public INotificationSideChannel c;
            public LinkedList<Task> d = new LinkedList<>();
            public int e = 0;

            public ListenerRecord(ComponentName componentName) {
                this.f144a = componentName;
            }
        }
    }

    private static class ServiceConnectedEvent {

        /* renamed from: a  reason: collision with root package name */
        final ComponentName f142a;
        final IBinder b;

        public ServiceConnectedEvent(ComponentName componentName, IBinder iBinder) {
            this.f142a = componentName;
            this.b = iBinder;
        }
    }

    private static class NotifyTask implements Task {

        /* renamed from: a  reason: collision with root package name */
        final String f141a;
        final int b;
        final String c;
        final Notification d;

        @Override // android.support.v4.app.NotificationManagerCompat.Task
        public void a(INotificationSideChannel iNotificationSideChannel) throws RemoteException {
            iNotificationSideChannel.a(this.f141a, this.b, this.c, this.d);
        }

        public String toString() {
            return "NotifyTask[" + "packageName:" + this.f141a + ", id:" + this.b + ", tag:" + this.c + "]";
        }
    }

    private static class CancelTask implements Task {

        /* renamed from: a  reason: collision with root package name */
        final String f140a;
        final int b;
        final String c;
        final boolean d;

        @Override // android.support.v4.app.NotificationManagerCompat.Task
        public void a(INotificationSideChannel iNotificationSideChannel) throws RemoteException {
            if (this.d) {
                iNotificationSideChannel.a(this.f140a);
            } else {
                iNotificationSideChannel.a(this.f140a, this.b, this.c);
            }
        }

        public String toString() {
            return "CancelTask[" + "packageName:" + this.f140a + ", id:" + this.b + ", tag:" + this.c + ", all:" + this.d + "]";
        }
    }
}
