package android.support.v4.media;

import android.content.ComponentName;
import android.content.Context;
import android.content.ServiceConnection;
import android.os.Binder;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.os.Messenger;
import android.os.Parcel;
import android.os.Parcelable;
import android.os.RemoteException;
import android.support.annotation.NonNull;
import android.support.v4.app.BundleCompat;
import android.support.v4.media.MediaBrowserCompatApi21;
import android.support.v4.media.MediaBrowserCompatApi23;
import android.support.v4.media.MediaBrowserCompatApi24;
import android.support.v4.media.session.MediaSessionCompat;
import android.support.v4.os.BuildCompat;
import android.support.v4.os.ResultReceiver;
import android.support.v4.util.ArrayMap;
import android.util.Log;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

public final class MediaBrowserCompat {

    /* renamed from: a  reason: collision with root package name */
    private static final boolean f186a = Log.isLoggable("MediaBrowserCompat", 3);

    interface MediaBrowserImpl {
    }

    static class MediaBrowserImplApi23 extends MediaBrowserImplApi21 {
    }

    static class MediaBrowserImplApi24 extends MediaBrowserImplApi23 {
    }

    interface MediaBrowserServiceCallbackImpl {
        void a(Messenger messenger);

        void a(Messenger messenger, String str, MediaSessionCompat.Token token, Bundle bundle);

        void a(Messenger messenger, String str, List list, Bundle bundle);
    }

    public static class MediaItem implements Parcelable {
        public static final Parcelable.Creator<MediaItem> CREATOR = new Parcelable.Creator<MediaItem>() {
            /* class android.support.v4.media.MediaBrowserCompat.MediaItem.AnonymousClass1 */

            /* renamed from: a */
            public MediaItem createFromParcel(Parcel parcel) {
                return new MediaItem(parcel);
            }

            /* renamed from: a */
            public MediaItem[] newArray(int i) {
                return new MediaItem[i];
            }
        };

        /* renamed from: a  reason: collision with root package name */
        private final int f203a;
        private final MediaDescriptionCompat b;

        @Retention(RetentionPolicy.SOURCE)
        public @interface Flags {
        }

        public int describeContents() {
            return 0;
        }

        private MediaItem(Parcel parcel) {
            this.f203a = parcel.readInt();
            this.b = MediaDescriptionCompat.CREATOR.createFromParcel(parcel);
        }

        public void writeToParcel(Parcel parcel, int i) {
            parcel.writeInt(this.f203a);
            this.b.writeToParcel(parcel, i);
        }

        public String toString() {
            return "MediaItem{" + "mFlags=" + this.f203a + ", mDescription=" + this.b + '}';
        }
    }

    public static class ConnectionCallback {

        /* renamed from: a  reason: collision with root package name */
        final Object f188a;
        private ConnectionCallbackInternal b;

        /* access modifiers changed from: package-private */
        public interface ConnectionCallbackInternal {
            void a();

            void b();

            void c();
        }

        public void a() {
        }

        public void b() {
        }

        public void c() {
        }

        public ConnectionCallback() {
            if (Build.VERSION.SDK_INT >= 21) {
                this.f188a = MediaBrowserCompatApi21.a((MediaBrowserCompatApi21.ConnectionCallback) new StubApi21());
            } else {
                this.f188a = null;
            }
        }

        private class StubApi21 implements MediaBrowserCompatApi21.ConnectionCallback {
            private StubApi21() {
            }

            @Override // android.support.v4.media.MediaBrowserCompatApi21.ConnectionCallback
            public void a() {
                if (ConnectionCallback.this.b != null) {
                    ConnectionCallback.this.b.a();
                }
                ConnectionCallback.this.a();
            }

            @Override // android.support.v4.media.MediaBrowserCompatApi21.ConnectionCallback
            public void b() {
                if (ConnectionCallback.this.b != null) {
                    ConnectionCallback.this.b.b();
                }
                ConnectionCallback.this.b();
            }

            @Override // android.support.v4.media.MediaBrowserCompatApi21.ConnectionCallback
            public void c() {
                if (ConnectionCallback.this.b != null) {
                    ConnectionCallback.this.b.c();
                }
                ConnectionCallback.this.c();
            }
        }
    }

    public static abstract class SubscriptionCallback {

        /* renamed from: a  reason: collision with root package name */
        private final Object f206a;
        private final IBinder b;
        private WeakReference<Subscription> c;

        public void a(@NonNull String str) {
        }

        public void a(@NonNull String str, @NonNull Bundle bundle) {
        }

        public void a(@NonNull String str, List<MediaItem> list) {
        }

        public void a(@NonNull String str, List<MediaItem> list, @NonNull Bundle bundle) {
        }

        public SubscriptionCallback() {
            if (Build.VERSION.SDK_INT >= 24 || BuildCompat.a()) {
                this.f206a = MediaBrowserCompatApi24.a(new StubApi24());
                this.b = null;
            } else if (Build.VERSION.SDK_INT >= 21) {
                this.f206a = MediaBrowserCompatApi21.a((MediaBrowserCompatApi21.SubscriptionCallback) new StubApi21());
                this.b = new Binder();
            } else {
                this.f206a = null;
                this.b = new Binder();
            }
        }

        private class StubApi21 implements MediaBrowserCompatApi21.SubscriptionCallback {
            private StubApi21() {
            }

            @Override // android.support.v4.media.MediaBrowserCompatApi21.SubscriptionCallback
            public void a(@NonNull String str, List<Parcel> list) {
                Subscription subscription = SubscriptionCallback.this.c == null ? null : (Subscription) SubscriptionCallback.this.c.get();
                if (subscription == null) {
                    SubscriptionCallback.this.a(str, a(list));
                    return;
                }
                List<MediaItem> a2 = a(list);
                List<SubscriptionCallback> b = subscription.b();
                List<Bundle> a3 = subscription.a();
                for (int i = 0; i < b.size(); i++) {
                    Bundle bundle = a3.get(i);
                    if (bundle == null) {
                        SubscriptionCallback.this.a(str, a2);
                    } else {
                        SubscriptionCallback.this.a(str, a(a2, bundle), bundle);
                    }
                }
            }

            @Override // android.support.v4.media.MediaBrowserCompatApi21.SubscriptionCallback
            public void a(@NonNull String str) {
                SubscriptionCallback.this.a(str);
            }

            /* access modifiers changed from: package-private */
            public List<MediaItem> a(List<Parcel> list) {
                if (list == null) {
                    return null;
                }
                ArrayList arrayList = new ArrayList();
                for (Parcel parcel : list) {
                    parcel.setDataPosition(0);
                    arrayList.add(MediaItem.CREATOR.createFromParcel(parcel));
                    parcel.recycle();
                }
                return arrayList;
            }

            /* access modifiers changed from: package-private */
            public List<MediaItem> a(List<MediaItem> list, Bundle bundle) {
                if (list == null) {
                    return null;
                }
                int i = bundle.getInt("android.media.browse.extra.PAGE", -1);
                int i2 = bundle.getInt("android.media.browse.extra.PAGE_SIZE", -1);
                if (i == -1 && i2 == -1) {
                    return list;
                }
                int i3 = i2 * i;
                int i4 = i3 + i2;
                if (i < 0 || i2 < 1 || i3 >= list.size()) {
                    return Collections.EMPTY_LIST;
                }
                if (i4 > list.size()) {
                    i4 = list.size();
                }
                return list.subList(i3, i4);
            }
        }

        private class StubApi24 extends StubApi21 implements MediaBrowserCompatApi24.SubscriptionCallback {
            private StubApi24() {
                super();
            }

            @Override // android.support.v4.media.MediaBrowserCompatApi24.SubscriptionCallback
            public void a(@NonNull String str, List<Parcel> list, @NonNull Bundle bundle) {
                SubscriptionCallback.this.a(str, a(list), bundle);
            }

            @Override // android.support.v4.media.MediaBrowserCompatApi24.SubscriptionCallback
            public void a(@NonNull String str, @NonNull Bundle bundle) {
                SubscriptionCallback.this.a(str, bundle);
            }
        }
    }

    public static abstract class ItemCallback {

        /* renamed from: a  reason: collision with root package name */
        final Object f190a;

        public void a(MediaItem mediaItem) {
        }

        public void a(@NonNull String str) {
        }

        public ItemCallback() {
            if (Build.VERSION.SDK_INT >= 23) {
                this.f190a = MediaBrowserCompatApi23.a(new StubApi23());
            } else {
                this.f190a = null;
            }
        }

        private class StubApi23 implements MediaBrowserCompatApi23.ItemCallback {
            private StubApi23() {
            }

            @Override // android.support.v4.media.MediaBrowserCompatApi23.ItemCallback
            public void a(Parcel parcel) {
                parcel.setDataPosition(0);
                parcel.recycle();
                ItemCallback.this.a(MediaItem.CREATOR.createFromParcel(parcel));
            }

            @Override // android.support.v4.media.MediaBrowserCompatApi23.ItemCallback
            public void a(@NonNull String str) {
                ItemCallback.this.a(str);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public static class MediaBrowserImplBase implements MediaBrowserImpl, MediaBrowserServiceCallbackImpl {

        /* renamed from: a  reason: collision with root package name */
        private final Context f196a;
        private final ComponentName b;
        private final ConnectionCallback c;
        private final Bundle d;
        private final CallbackHandler e;
        private final ArrayMap<String, Subscription> f;
        private int g;
        private MediaServiceConnection h;
        private ServiceBinderWrapper i;
        private Messenger j;
        private String k;
        private MediaSessionCompat.Token l;
        private Bundle m;

        /* renamed from: android.support.v4.media.MediaBrowserCompat$MediaBrowserImplBase$1  reason: invalid class name */
        class AnonymousClass1 implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ ServiceConnection f197a;
            final /* synthetic */ MediaBrowserImplBase b;

            public void run() {
                if (this.f197a == this.b.h) {
                    this.b.b();
                    this.b.c.c();
                }
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void b() {
            if (this.h != null) {
                this.f196a.unbindService(this.h);
            }
            this.g = 0;
            this.h = null;
            this.i = null;
            this.j = null;
            this.e.a(null);
            this.k = null;
            this.l = null;
        }

        /* renamed from: android.support.v4.media.MediaBrowserCompat$MediaBrowserImplBase$2  reason: invalid class name */
        class AnonymousClass2 implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ ItemCallback f198a;
            final /* synthetic */ String b;

            public void run() {
                this.f198a.a(this.b);
            }
        }

        /* renamed from: android.support.v4.media.MediaBrowserCompat$MediaBrowserImplBase$3  reason: invalid class name */
        class AnonymousClass3 implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ ItemCallback f199a;
            final /* synthetic */ String b;

            public void run() {
                this.f199a.a(this.b);
            }
        }

        @Override // android.support.v4.media.MediaBrowserCompat.MediaBrowserServiceCallbackImpl
        public void a(Messenger messenger, String str, MediaSessionCompat.Token token, Bundle bundle) {
            if (a(messenger, "onConnect")) {
                if (this.g != 1) {
                    Log.w("MediaBrowserCompat", "onConnect from service while mState=" + a(this.g) + "... ignoring");
                    return;
                }
                this.k = str;
                this.l = token;
                this.m = bundle;
                this.g = 2;
                if (MediaBrowserCompat.f186a) {
                    Log.d("MediaBrowserCompat", "ServiceCallbacks.onConnect...");
                    a();
                }
                this.c.a();
                try {
                    for (Map.Entry<String, Subscription> entry : this.f.entrySet()) {
                        String key = entry.getKey();
                        Subscription value = entry.getValue();
                        List<SubscriptionCallback> b2 = value.b();
                        List<Bundle> a2 = value.a();
                        for (int i2 = 0; i2 < b2.size(); i2++) {
                            this.i.a(key, b2.get(i2).b, a2.get(i2), this.j);
                        }
                    }
                } catch (RemoteException unused) {
                    Log.d("MediaBrowserCompat", "addSubscription failed with RemoteException.");
                }
            }
        }

        @Override // android.support.v4.media.MediaBrowserCompat.MediaBrowserServiceCallbackImpl
        public void a(Messenger messenger) {
            Log.e("MediaBrowserCompat", "onConnectFailed for " + this.b);
            if (a(messenger, "onConnectFailed")) {
                if (this.g != 1) {
                    Log.w("MediaBrowserCompat", "onConnect from service while mState=" + a(this.g) + "... ignoring");
                    return;
                }
                b();
                this.c.c();
            }
        }

        @Override // android.support.v4.media.MediaBrowserCompat.MediaBrowserServiceCallbackImpl
        public void a(Messenger messenger, String str, List list, Bundle bundle) {
            if (a(messenger, "onLoadChildren")) {
                if (MediaBrowserCompat.f186a) {
                    Log.d("MediaBrowserCompat", "onLoadChildren for " + this.b + " id=" + str);
                }
                Subscription subscription = this.f.get(str);
                if (subscription != null) {
                    SubscriptionCallback a2 = subscription.a(bundle);
                    if (a2 == null) {
                        return;
                    }
                    if (bundle == null) {
                        a2.a(str, list);
                    } else {
                        a2.a(str, list, bundle);
                    }
                } else if (MediaBrowserCompat.f186a) {
                    Log.d("MediaBrowserCompat", "onLoadChildren for id that isn't subscribed id=" + str);
                }
            }
        }

        private static String a(int i2) {
            switch (i2) {
                case 0:
                    return "CONNECT_STATE_DISCONNECTED";
                case 1:
                    return "CONNECT_STATE_CONNECTING";
                case 2:
                    return "CONNECT_STATE_CONNECTED";
                case 3:
                    return "CONNECT_STATE_SUSPENDED";
                default:
                    return "UNKNOWN/" + i2;
            }
        }

        private boolean a(Messenger messenger, String str) {
            if (this.j == messenger) {
                return true;
            }
            if (this.g == 0) {
                return false;
            }
            Log.i("MediaBrowserCompat", str + " for " + this.b + " with mCallbacksMessenger=" + this.j + " this=" + this);
            return false;
        }

        /* access modifiers changed from: package-private */
        public void a() {
            Log.d("MediaBrowserCompat", "MediaBrowserCompat...");
            Log.d("MediaBrowserCompat", "  mServiceComponent=" + this.b);
            Log.d("MediaBrowserCompat", "  mCallback=" + this.c);
            Log.d("MediaBrowserCompat", "  mRootHints=" + this.d);
            Log.d("MediaBrowserCompat", "  mState=" + a(this.g));
            Log.d("MediaBrowserCompat", "  mServiceConnection=" + this.h);
            Log.d("MediaBrowserCompat", "  mServiceBinderWrapper=" + this.i);
            Log.d("MediaBrowserCompat", "  mCallbacksMessenger=" + this.j);
            Log.d("MediaBrowserCompat", "  mRootId=" + this.k);
            Log.d("MediaBrowserCompat", "  mMediaSessionToken=" + this.l);
        }

        /* access modifiers changed from: private */
        public class MediaServiceConnection implements ServiceConnection {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ MediaBrowserImplBase f200a;

            public void onServiceConnected(final ComponentName componentName, final IBinder iBinder) {
                a(new Runnable() {
                    /* class android.support.v4.media.MediaBrowserCompat.MediaBrowserImplBase.MediaServiceConnection.AnonymousClass1 */

                    public void run() {
                        if (MediaBrowserCompat.f186a) {
                            Log.d("MediaBrowserCompat", "MediaServiceConnection.onServiceConnected name=" + componentName + " binder=" + iBinder);
                            MediaServiceConnection.this.f200a.a();
                        }
                        if (MediaServiceConnection.this.a((MediaServiceConnection) "onServiceConnected")) {
                            MediaServiceConnection.this.f200a.i = new ServiceBinderWrapper(iBinder, MediaServiceConnection.this.f200a.d);
                            MediaServiceConnection.this.f200a.j = new Messenger(MediaServiceConnection.this.f200a.e);
                            MediaServiceConnection.this.f200a.e.a(MediaServiceConnection.this.f200a.j);
                            MediaServiceConnection.this.f200a.g = 1;
                            try {
                                if (MediaBrowserCompat.f186a) {
                                    Log.d("MediaBrowserCompat", "ServiceCallbacks.onConnect...");
                                    MediaServiceConnection.this.f200a.a();
                                }
                                MediaServiceConnection.this.f200a.i.a(MediaServiceConnection.this.f200a.f196a, MediaServiceConnection.this.f200a.j);
                            } catch (RemoteException unused) {
                                Log.w("MediaBrowserCompat", "RemoteException during connect for " + MediaServiceConnection.this.f200a.b);
                                if (MediaBrowserCompat.f186a) {
                                    Log.d("MediaBrowserCompat", "ServiceCallbacks.onConnect...");
                                    MediaServiceConnection.this.f200a.a();
                                }
                            }
                        }
                    }
                });
            }

            public void onServiceDisconnected(final ComponentName componentName) {
                a(new Runnable() {
                    /* class android.support.v4.media.MediaBrowserCompat.MediaBrowserImplBase.MediaServiceConnection.AnonymousClass2 */

                    public void run() {
                        if (MediaBrowserCompat.f186a) {
                            Log.d("MediaBrowserCompat", "MediaServiceConnection.onServiceDisconnected name=" + componentName + " this=" + this + " mServiceConnection=" + MediaServiceConnection.this.f200a.h);
                            MediaServiceConnection.this.f200a.a();
                        }
                        if (MediaServiceConnection.this.a((MediaServiceConnection) "onServiceDisconnected")) {
                            MediaServiceConnection.this.f200a.i = null;
                            MediaServiceConnection.this.f200a.j = null;
                            MediaServiceConnection.this.f200a.e.a(null);
                            MediaServiceConnection.this.f200a.g = 3;
                            MediaServiceConnection.this.f200a.c.b();
                        }
                    }
                });
            }

            private void a(Runnable runnable) {
                if (Thread.currentThread() == this.f200a.e.getLooper().getThread()) {
                    runnable.run();
                } else {
                    this.f200a.e.post(runnable);
                }
            }

            /* access modifiers changed from: private */
            /* access modifiers changed from: public */
            private boolean a(String str) {
                if (this.f200a.h == this) {
                    return true;
                }
                if (this.f200a.g == 0) {
                    return false;
                }
                Log.i("MediaBrowserCompat", str + " for " + this.f200a.b + " with mServiceConnection=" + this.f200a.h + " this=" + this);
                return false;
            }
        }
    }

    static class MediaBrowserImplApi21 implements ConnectionCallback.ConnectionCallbackInternal, MediaBrowserImpl, MediaBrowserServiceCallbackImpl {

        /* renamed from: a  reason: collision with root package name */
        protected final Object f192a;
        protected final Bundle b;
        protected final CallbackHandler c;
        protected ServiceBinderWrapper d;
        protected Messenger e;
        private final ArrayMap<String, Subscription> f;

        @Override // android.support.v4.media.MediaBrowserCompat.MediaBrowserServiceCallbackImpl
        public void a(Messenger messenger) {
        }

        @Override // android.support.v4.media.MediaBrowserCompat.MediaBrowserServiceCallbackImpl
        public void a(Messenger messenger, String str, MediaSessionCompat.Token token, Bundle bundle) {
        }

        @Override // android.support.v4.media.MediaBrowserCompat.ConnectionCallback.ConnectionCallbackInternal
        public void c() {
        }

        /* renamed from: android.support.v4.media.MediaBrowserCompat$MediaBrowserImplApi21$1  reason: invalid class name */
        class AnonymousClass1 implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ ItemCallback f193a;
            final /* synthetic */ String b;

            public void run() {
                this.f193a.a(this.b);
            }
        }

        /* renamed from: android.support.v4.media.MediaBrowserCompat$MediaBrowserImplApi21$2  reason: invalid class name */
        class AnonymousClass2 implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ ItemCallback f194a;

            public void run() {
                this.f194a.a((MediaItem) null);
            }
        }

        /* renamed from: android.support.v4.media.MediaBrowserCompat$MediaBrowserImplApi21$3  reason: invalid class name */
        class AnonymousClass3 implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ ItemCallback f195a;
            final /* synthetic */ String b;

            public void run() {
                this.f195a.a(this.b);
            }
        }

        @Override // android.support.v4.media.MediaBrowserCompat.ConnectionCallback.ConnectionCallbackInternal
        public void a() {
            IBinder a2;
            Bundle a3 = MediaBrowserCompatApi21.a(this.f192a);
            if (a3 != null && (a2 = BundleCompat.a(a3, "extra_messenger")) != null) {
                this.d = new ServiceBinderWrapper(a2, this.b);
                this.e = new Messenger(this.c);
                this.c.a(this.e);
                try {
                    this.d.a(this.e);
                } catch (RemoteException unused) {
                    Log.i("MediaBrowserCompat", "Remote error registering client messenger.");
                }
            }
        }

        @Override // android.support.v4.media.MediaBrowserCompat.ConnectionCallback.ConnectionCallbackInternal
        public void b() {
            this.d = null;
            this.e = null;
            this.c.a(null);
        }

        @Override // android.support.v4.media.MediaBrowserCompat.MediaBrowserServiceCallbackImpl
        public void a(Messenger messenger, String str, List list, Bundle bundle) {
            if (this.e == messenger) {
                Subscription subscription = this.f.get(str);
                if (subscription != null) {
                    SubscriptionCallback a2 = subscription.a(bundle);
                    if (a2 == null) {
                        return;
                    }
                    if (bundle == null) {
                        a2.a(str, list);
                    } else {
                        a2.a(str, list, bundle);
                    }
                } else if (MediaBrowserCompat.f186a) {
                    Log.d("MediaBrowserCompat", "onLoadChildren for id that isn't subscribed id=" + str);
                }
            }
        }
    }

    /* access modifiers changed from: private */
    public static class Subscription {

        /* renamed from: a  reason: collision with root package name */
        private final List<SubscriptionCallback> f205a = new ArrayList();
        private final List<Bundle> b = new ArrayList();

        public List<Bundle> a() {
            return this.b;
        }

        public List<SubscriptionCallback> b() {
            return this.f205a;
        }

        public SubscriptionCallback a(Bundle bundle) {
            for (int i = 0; i < this.b.size(); i++) {
                if (MediaBrowserCompatUtils.a(this.b.get(i), bundle)) {
                    return this.f205a.get(i);
                }
            }
            return null;
        }
    }

    /* access modifiers changed from: private */
    public static class CallbackHandler extends Handler {

        /* renamed from: a  reason: collision with root package name */
        private final WeakReference<MediaBrowserServiceCallbackImpl> f187a;
        private WeakReference<Messenger> b;

        public void handleMessage(Message message) {
            if (this.b != null && this.b.get() != null && this.f187a.get() != null) {
                Bundle data = message.getData();
                data.setClassLoader(MediaSessionCompat.class.getClassLoader());
                switch (message.what) {
                    case 1:
                        this.f187a.get().a(this.b.get(), data.getString("data_media_item_id"), (MediaSessionCompat.Token) data.getParcelable("data_media_session_token"), data.getBundle("data_root_hints"));
                        return;
                    case 2:
                        this.f187a.get().a(this.b.get());
                        return;
                    case 3:
                        this.f187a.get().a(this.b.get(), data.getString("data_media_item_id"), data.getParcelableArrayList("data_media_item_list"), data.getBundle("data_options"));
                        return;
                    default:
                        Log.w("MediaBrowserCompat", "Unhandled message: " + message + "\n  Client version: " + 1 + "\n  Service version: " + message.arg1);
                        return;
                }
            }
        }

        /* access modifiers changed from: package-private */
        public void a(Messenger messenger) {
            this.b = new WeakReference<>(messenger);
        }
    }

    /* access modifiers changed from: private */
    public static class ServiceBinderWrapper {

        /* renamed from: a  reason: collision with root package name */
        private Messenger f204a;
        private Bundle b;

        public ServiceBinderWrapper(IBinder iBinder, Bundle bundle) {
            this.f204a = new Messenger(iBinder);
            this.b = bundle;
        }

        /* access modifiers changed from: package-private */
        public void a(Context context, Messenger messenger) throws RemoteException {
            Bundle bundle = new Bundle();
            bundle.putString("data_package_name", context.getPackageName());
            bundle.putBundle("data_root_hints", this.b);
            a(1, bundle, messenger);
        }

        /* access modifiers changed from: package-private */
        public void a(String str, IBinder iBinder, Bundle bundle, Messenger messenger) throws RemoteException {
            Bundle bundle2 = new Bundle();
            bundle2.putString("data_media_item_id", str);
            BundleCompat.a(bundle2, "data_callback_token", iBinder);
            bundle2.putBundle("data_options", bundle);
            a(3, bundle2, messenger);
        }

        /* access modifiers changed from: package-private */
        public void a(Messenger messenger) throws RemoteException {
            Bundle bundle = new Bundle();
            bundle.putBundle("data_root_hints", this.b);
            a(6, bundle, messenger);
        }

        private void a(int i, Bundle bundle, Messenger messenger) throws RemoteException {
            Message obtain = Message.obtain();
            obtain.what = i;
            obtain.arg1 = 1;
            obtain.setData(bundle);
            obtain.replyTo = messenger;
            this.f204a.send(obtain);
        }
    }

    private static class ItemReceiver extends ResultReceiver {
        private final String d;
        private final ItemCallback e;

        /* access modifiers changed from: protected */
        @Override // android.support.v4.os.ResultReceiver
        public void a(int i, Bundle bundle) {
            bundle.setClassLoader(MediaBrowserCompat.class.getClassLoader());
            if (i != 0 || bundle == null || !bundle.containsKey("media_item")) {
                this.e.a(this.d);
                return;
            }
            Parcelable parcelable = bundle.getParcelable("media_item");
            if (parcelable instanceof MediaItem) {
                this.e.a((MediaItem) parcelable);
            } else {
                this.e.a(this.d);
            }
        }
    }
}
