package com.alibaba.fastjson;

import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.util.TypeUtils;
import java.io.Serializable;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Set;

public class JSONObject extends JSON implements Serializable, Cloneable, InvocationHandler, Map<String, Object> {
    private final Map<String, Object> f;

    public JSONObject() {
        this(16, false);
    }

    public JSONObject(Map<String, Object> map) {
        this.f = map;
    }

    public JSONObject(boolean z) {
        this(16, z);
    }

    public JSONObject(int i, boolean z) {
        if (z) {
            this.f = new LinkedHashMap(i);
        } else {
            this.f = new HashMap(i);
        }
    }

    public int size() {
        return this.f.size();
    }

    public boolean isEmpty() {
        return this.f.isEmpty();
    }

    public boolean containsKey(Object obj) {
        return this.f.containsKey(obj);
    }

    public boolean containsValue(Object obj) {
        return this.f.containsValue(obj);
    }

    @Override // java.util.Map
    public Object get(Object obj) {
        return this.f.get(obj);
    }

    /* renamed from: a */
    public Object put(String str, Object obj) {
        return this.f.put(str, obj);
    }

    @Override // java.util.Map
    public void putAll(Map<? extends String, ? extends Object> map) {
        this.f.putAll(map);
    }

    public void clear() {
        this.f.clear();
    }

    @Override // java.util.Map
    public Object remove(Object obj) {
        return this.f.remove(obj);
    }

    @Override // java.util.Map
    public Set<String> keySet() {
        return this.f.keySet();
    }

    @Override // java.util.Map
    public Collection<Object> values() {
        return this.f.values();
    }

    @Override // java.util.Map
    public Set<Map.Entry<String, Object>> entrySet() {
        return this.f.entrySet();
    }

    @Override // java.lang.Object
    public Object clone() {
        return new JSONObject(new LinkedHashMap(this.f));
    }

    public boolean equals(Object obj) {
        return this.f.equals(obj);
    }

    public int hashCode() {
        return this.f.hashCode();
    }

    @Override // java.lang.reflect.InvocationHandler
    public Object invoke(Object obj, Method method, Object[] objArr) throws Throwable {
        Class<?>[] parameterTypes = method.getParameterTypes();
        String str = null;
        if (parameterTypes.length == 1) {
            if (method.getName().equals("equals")) {
                return Boolean.valueOf(equals(objArr[0]));
            }
            if (method.getReturnType() == Void.TYPE) {
                JSONField jSONField = (JSONField) method.getAnnotation(JSONField.class);
                String b = (jSONField == null || jSONField.b().length() == 0) ? null : jSONField.b();
                if (b == null) {
                    String name = method.getName();
                    if (name.startsWith("set")) {
                        String substring = name.substring(3);
                        if (substring.length() != 0) {
                            b = Character.toLowerCase(substring.charAt(0)) + substring.substring(1);
                        } else {
                            throw new JSONException("illegal setter");
                        }
                    } else {
                        throw new JSONException("illegal setter");
                    }
                }
                this.f.put(b, objArr[0]);
                return null;
            }
            throw new JSONException("illegal setter");
        } else if (parameterTypes.length != 0) {
            throw new UnsupportedOperationException(method.toGenericString());
        } else if (method.getReturnType() != Void.TYPE) {
            JSONField jSONField2 = (JSONField) method.getAnnotation(JSONField.class);
            if (!(jSONField2 == null || jSONField2.b().length() == 0)) {
                str = jSONField2.b();
            }
            if (str == null) {
                String name2 = method.getName();
                if (name2.startsWith("get")) {
                    String substring2 = name2.substring(3);
                    if (substring2.length() != 0) {
                        str = Character.toLowerCase(substring2.charAt(0)) + substring2.substring(1);
                    } else {
                        throw new JSONException("illegal getter");
                    }
                } else if (name2.startsWith("is")) {
                    String substring3 = name2.substring(2);
                    if (substring3.length() != 0) {
                        str = Character.toLowerCase(substring3.charAt(0)) + substring3.substring(1);
                    } else {
                        throw new JSONException("illegal getter");
                    }
                } else if (name2.startsWith("hashCode")) {
                    return Integer.valueOf(hashCode());
                } else {
                    if (name2.startsWith("toString")) {
                        return toString();
                    }
                    throw new JSONException("illegal getter");
                }
            }
            return TypeUtils.a(this.f.get(str), method.getGenericReturnType(), ParserConfig.f1106a);
        } else {
            throw new JSONException("illegal getter");
        }
    }
}
