package com.alibaba.fastjson.parser;

import com.alibaba.fastjson.PropertyNamingStrategy;
import com.alibaba.fastjson.annotation.JSONType;
import com.alibaba.fastjson.parser.deserializer.FieldDeserializer;
import com.alibaba.fastjson.parser.deserializer.ObjectDeserializer;
import com.alibaba.fastjson.serializer.ArrayCodec;
import com.alibaba.fastjson.serializer.BigDecimalCodec;
import com.alibaba.fastjson.serializer.BooleanCodec;
import com.alibaba.fastjson.serializer.CollectionCodec;
import com.alibaba.fastjson.serializer.DateCodec;
import com.alibaba.fastjson.serializer.IntegerCodec;
import com.alibaba.fastjson.serializer.MiscCodec;
import com.alibaba.fastjson.serializer.NumberCodec;
import com.alibaba.fastjson.serializer.StringCodec;
import com.alibaba.fastjson.util.FieldInfo;
import com.alibaba.fastjson.util.IdentityHashMap;
import java.io.Closeable;
import java.io.Serializable;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.lang.reflect.WildcardType;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.net.URI;
import java.net.URL;
import java.nio.charset.Charset;
import java.sql.Time;
import java.sql.Timestamp;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collection;
import java.util.Currency;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Set;
import java.util.TimeZone;
import java.util.TreeMap;
import java.util.UUID;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import java.util.regex.Pattern;

public class ParserConfig {

    /* renamed from: a  reason: collision with root package name */
    public static ParserConfig f1106a = new ParserConfig();
    public final SymbolTable b = new SymbolTable(16384);
    public PropertyNamingStrategy c;
    private final IdentityHashMap<ObjectDeserializer> d = new IdentityHashMap<>(1024);

    public ParserConfig() {
        this.d.a(SimpleDateFormat.class, MiscCodec.f1123a);
        this.d.a(Date.class, DateCodec.f1117a);
        this.d.a(Calendar.class, DateCodec.f1117a);
        this.d.a(Map.class, MapDeserializer.f1104a);
        this.d.a(HashMap.class, MapDeserializer.f1104a);
        this.d.a(LinkedHashMap.class, MapDeserializer.f1104a);
        this.d.a(TreeMap.class, MapDeserializer.f1104a);
        this.d.a(ConcurrentMap.class, MapDeserializer.f1104a);
        this.d.a(ConcurrentHashMap.class, MapDeserializer.f1104a);
        this.d.a(Collection.class, CollectionCodec.f1116a);
        this.d.a(List.class, CollectionCodec.f1116a);
        this.d.a(ArrayList.class, CollectionCodec.f1116a);
        this.d.a(Object.class, JavaObjectDeserializer.f1103a);
        this.d.a(String.class, StringCodec.f1130a);
        this.d.a(Character.TYPE, MiscCodec.f1123a);
        this.d.a(Character.class, MiscCodec.f1123a);
        this.d.a(Byte.TYPE, NumberCodec.f1124a);
        this.d.a(Byte.class, NumberCodec.f1124a);
        this.d.a(Short.TYPE, NumberCodec.f1124a);
        this.d.a(Short.class, NumberCodec.f1124a);
        this.d.a(Integer.TYPE, IntegerCodec.f1120a);
        this.d.a(Integer.class, IntegerCodec.f1120a);
        this.d.a(Long.TYPE, IntegerCodec.f1120a);
        this.d.a(Long.class, IntegerCodec.f1120a);
        this.d.a(BigInteger.class, BigDecimalCodec.f1114a);
        this.d.a(BigDecimal.class, BigDecimalCodec.f1114a);
        this.d.a(Float.TYPE, NumberCodec.f1124a);
        this.d.a(Float.class, NumberCodec.f1124a);
        this.d.a(Double.TYPE, NumberCodec.f1124a);
        this.d.a(Double.class, NumberCodec.f1124a);
        this.d.a(Boolean.TYPE, BooleanCodec.f1115a);
        this.d.a(Boolean.class, BooleanCodec.f1115a);
        this.d.a(Class.class, MiscCodec.f1123a);
        this.d.a(char[].class, ArrayCodec.f1111a);
        this.d.a(Object[].class, ArrayCodec.f1111a);
        this.d.a(UUID.class, MiscCodec.f1123a);
        this.d.a(TimeZone.class, MiscCodec.f1123a);
        this.d.a(Locale.class, MiscCodec.f1123a);
        this.d.a(Currency.class, MiscCodec.f1123a);
        this.d.a(URI.class, MiscCodec.f1123a);
        this.d.a(URL.class, MiscCodec.f1123a);
        this.d.a(Pattern.class, MiscCodec.f1123a);
        this.d.a(Charset.class, MiscCodec.f1123a);
        this.d.a(Number.class, NumberCodec.f1124a);
        this.d.a(StackTraceElement.class, MiscCodec.f1123a);
        this.d.a(Serializable.class, JavaObjectDeserializer.f1103a);
        this.d.a(Cloneable.class, JavaObjectDeserializer.f1103a);
        this.d.a(Comparable.class, JavaObjectDeserializer.f1103a);
        this.d.a(Closeable.class, JavaObjectDeserializer.f1103a);
    }

    public ObjectDeserializer a(Type type) {
        ObjectDeserializer a2 = this.d.a(type);
        if (a2 != null) {
            return a2;
        }
        if (type instanceof Class) {
            return a((Class) type, type);
        }
        if (!(type instanceof ParameterizedType)) {
            return JavaObjectDeserializer.f1103a;
        }
        Type rawType = ((ParameterizedType) type).getRawType();
        if (rawType instanceof Class) {
            return a((Class) rawType, type);
        }
        return a(rawType);
    }

    public ObjectDeserializer a(Class<?> cls, Type type) {
        ObjectDeserializer objectDeserializer;
        JSONType jSONType;
        Class<?> e;
        ObjectDeserializer a2 = this.d.a(type);
        if (a2 != null) {
            return a2;
        }
        if (type == null) {
            type = cls;
        }
        ObjectDeserializer a3 = this.d.a(type);
        if (a3 != null) {
            return a3;
        }
        if (!a(cls) && (jSONType = (JSONType) cls.getAnnotation(JSONType.class)) != null && (e = jSONType.e()) != Void.class) {
            return a(e, e);
        }
        if ((type instanceof WildcardType) || (type instanceof TypeVariable) || (type instanceof ParameterizedType)) {
            a3 = this.d.a(cls);
        }
        if (a3 != null) {
            return a3;
        }
        ObjectDeserializer a4 = this.d.a(type);
        if (a4 != null) {
            return a4;
        }
        if (cls.isEnum()) {
            objectDeserializer = new EnumDeserializer(cls);
        } else if (cls.isArray()) {
            objectDeserializer = ArrayCodec.f1111a;
        } else if (cls == Set.class || cls == HashSet.class || cls == Collection.class || cls == List.class || cls == ArrayList.class) {
            objectDeserializer = CollectionCodec.f1116a;
        } else if (Collection.class.isAssignableFrom(cls)) {
            objectDeserializer = CollectionCodec.f1116a;
        } else if (Map.class.isAssignableFrom(cls)) {
            objectDeserializer = MapDeserializer.f1104a;
        } else {
            objectDeserializer = Throwable.class.isAssignableFrom(cls) ? new ThrowableDeserializer(this, cls) : new JavaBeanDeserializer(this, cls, type);
        }
        a(type, objectDeserializer);
        return objectDeserializer;
    }

    public FieldDeserializer a(ParserConfig parserConfig, Class<?> cls, FieldInfo fieldInfo) {
        Class<?> cls2 = fieldInfo.f;
        if (cls2 == List.class || cls2 == ArrayList.class || (cls2.isArray() && !cls2.getComponentType().isPrimitive())) {
            return new ListTypeFieldDeserializer(parserConfig, cls, fieldInfo);
        }
        return new DefaultFieldDeserializer(parserConfig, cls, fieldInfo);
    }

    public void a(Type type, ObjectDeserializer objectDeserializer) {
        this.d.a(type, objectDeserializer);
    }

    public static boolean a(Class<?> cls) {
        return cls.isPrimitive() || cls == Boolean.class || cls == Character.class || cls == Byte.class || cls == Short.class || cls == Integer.class || cls == Long.class || cls == Float.class || cls == Double.class || cls == BigInteger.class || cls == BigDecimal.class || cls == String.class || cls == Date.class || cls == java.sql.Date.class || cls == Time.class || cls == Timestamp.class;
    }
}
