package com.alibaba.fastjson.util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.PropertyNamingStrategy;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONType;
import com.alibaba.fastjson.parser.JSONLexer;
import com.alibaba.fastjson.parser.JavaBeanDeserializer;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.parser.deserializer.ObjectDeserializer;
import com.alibaba.fastjson.serializer.SerializerFeature;
import java.lang.reflect.AccessibleObject;
import java.lang.reflect.Array;
import java.lang.reflect.Field;
import java.lang.reflect.Member;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Proxy;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.lang.reflect.WildcardType;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.security.AccessControlException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collection;
import java.util.Collections;
import java.util.Currency;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;

public class TypeUtils {

    /* renamed from: a  reason: collision with root package name */
    public static boolean f1135a = false;
    private static boolean b = true;
    private static ConcurrentMap<String, Class<?>> c = new ConcurrentHashMap();

    public static final String a(Object obj) {
        if (obj == null) {
            return null;
        }
        return obj.toString();
    }

    public static final Byte b(Object obj) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof Number) {
            return Byte.valueOf(((Number) obj).byteValue());
        }
        if (obj instanceof String) {
            String str = (String) obj;
            if (str.length() == 0 || "null".equals(str)) {
                return null;
            }
            return Byte.valueOf(Byte.parseByte(str));
        }
        throw new JSONException("can not cast to byte, value : " + obj);
    }

    public static final Short c(Object obj) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof Number) {
            return Short.valueOf(((Number) obj).shortValue());
        }
        if (obj instanceof String) {
            String str = (String) obj;
            if (str.length() == 0 || "null".equals(str)) {
                return null;
            }
            return Short.valueOf(Short.parseShort(str));
        }
        throw new JSONException("can not cast to short, value : " + obj);
    }

    public static final BigDecimal d(Object obj) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof BigDecimal) {
            return (BigDecimal) obj;
        }
        if (obj instanceof BigInteger) {
            return new BigDecimal((BigInteger) obj);
        }
        String obj2 = obj.toString();
        if (obj2.length() == 0 || "null".equals(obj2)) {
            return null;
        }
        return new BigDecimal(obj2);
    }

    public static final BigInteger e(Object obj) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof BigInteger) {
            return (BigInteger) obj;
        }
        if ((obj instanceof Float) || (obj instanceof Double)) {
            return BigInteger.valueOf(((Number) obj).longValue());
        }
        String obj2 = obj.toString();
        if (obj2.length() == 0 || "null".equals(obj2)) {
            return null;
        }
        return new BigInteger(obj2);
    }

    public static final Float f(Object obj) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof Number) {
            return Float.valueOf(((Number) obj).floatValue());
        }
        if (obj instanceof String) {
            String obj2 = obj.toString();
            if (obj2.length() == 0 || "null".equals(obj2)) {
                return null;
            }
            return Float.valueOf(Float.parseFloat(obj2));
        }
        throw new JSONException("can not cast to float, value : " + obj);
    }

    public static final Double g(Object obj) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof Number) {
            return Double.valueOf(((Number) obj).doubleValue());
        }
        if (obj instanceof String) {
            String obj2 = obj.toString();
            if (obj2.length() == 0 || "null".equals(obj2)) {
                return null;
            }
            return Double.valueOf(Double.parseDouble(obj2));
        }
        throw new JSONException("can not cast to double, value : " + obj);
    }

    public static final Date h(Object obj) {
        String str;
        if (obj == null) {
            return null;
        }
        if (obj instanceof Calendar) {
            return ((Calendar) obj).getTime();
        }
        if (obj instanceof Date) {
            return (Date) obj;
        }
        long j = -1;
        if (obj instanceof Number) {
            j = ((Number) obj).longValue();
        }
        if (obj instanceof String) {
            String str2 = (String) obj;
            if (str2.indexOf(45) != -1) {
                if (str2.length() == JSON.d.length()) {
                    str = JSON.d;
                } else if (str2.length() == 10) {
                    str = "yyyy-MM-dd";
                } else {
                    str = str2.length() == "yyyy-MM-dd HH:mm:ss".length() ? "yyyy-MM-dd HH:mm:ss" : "yyyy-MM-dd HH:mm:ss.SSS";
                }
                SimpleDateFormat simpleDateFormat = new SimpleDateFormat(str, JSON.b);
                simpleDateFormat.setTimeZone(JSON.f1091a);
                try {
                    return simpleDateFormat.parse(str2);
                } catch (ParseException unused) {
                    throw new JSONException("can not cast to Date, value : " + str2);
                }
            } else if (str2.length() == 0 || "null".equals(str2)) {
                return null;
            } else {
                j = Long.parseLong(str2);
            }
        }
        if (j >= 0) {
            return new Date(j);
        }
        throw new JSONException("can not cast to Date, value : " + obj);
    }

    public static final Long i(Object obj) {
        Calendar calendar = null;
        if (obj == null) {
            return null;
        }
        if (obj instanceof Number) {
            return Long.valueOf(((Number) obj).longValue());
        }
        if (obj instanceof String) {
            String str = (String) obj;
            if (str.length() == 0 || "null".equals(str)) {
                return null;
            }
            try {
                return Long.valueOf(Long.parseLong(str));
            } catch (NumberFormatException unused) {
                JSONLexer jSONLexer = new JSONLexer(str);
                if (jSONLexer.a(false)) {
                    calendar = jSONLexer.c();
                }
                jSONLexer.a();
                if (calendar != null) {
                    return Long.valueOf(calendar.getTimeInMillis());
                }
            }
        }
        throw new JSONException("can not cast to long, value : " + obj);
    }

    public static final Integer j(Object obj) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof Integer) {
            return (Integer) obj;
        }
        if (obj instanceof Number) {
            return Integer.valueOf(((Number) obj).intValue());
        }
        if (obj instanceof String) {
            String str = (String) obj;
            if (str.length() == 0 || "null".equals(str)) {
                return null;
            }
            return Integer.valueOf(Integer.parseInt(str));
        }
        throw new JSONException("can not cast to int, value : " + obj);
    }

    public static final byte[] k(Object obj) {
        if (obj instanceof byte[]) {
            return (byte[]) obj;
        }
        if (obj instanceof String) {
            return JSONLexer.a((String) obj);
        }
        throw new JSONException("can not cast to int, value : " + obj);
    }

    public static final Boolean l(Object obj) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof Boolean) {
            return (Boolean) obj;
        }
        if (obj instanceof Number) {
            boolean z = true;
            if (((Number) obj).intValue() != 1) {
                z = false;
            }
            return Boolean.valueOf(z);
        }
        if (obj instanceof String) {
            String str = (String) obj;
            if (str.length() == 0 || "null".equals(str)) {
                return null;
            }
            if ("true".equalsIgnoreCase(str) || "1".equals(str)) {
                return Boolean.TRUE;
            }
            if ("false".equalsIgnoreCase(str) || "0".equals(str)) {
                return Boolean.FALSE;
            }
        }
        throw new JSONException("can not cast to int, value : " + obj);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r4v0, resolved type: java.lang.Object */
    /* JADX WARN: Multi-variable type inference failed */
    public static final <T> T a(Object obj, Class<T> cls, ParserConfig parserConfig) {
        T t;
        if (obj == 0) {
            return null;
        }
        if (cls == null) {
            throw new IllegalArgumentException("clazz is null");
        } else if (cls == obj.getClass()) {
            return obj;
        } else {
            if (!(obj instanceof Map)) {
                if (cls.isArray()) {
                    if (obj instanceof Collection) {
                        Collection<Object> collection = (Collection) obj;
                        int i = 0;
                        T t2 = (T) Array.newInstance(cls.getComponentType(), collection.size());
                        for (Object obj2 : collection) {
                            Array.set(t2, i, a(obj2, (Class) cls.getComponentType(), parserConfig));
                            i++;
                        }
                        return t2;
                    } else if (cls == byte[].class) {
                        return (T) k(obj);
                    }
                }
                if (cls.isAssignableFrom(obj.getClass())) {
                    return obj;
                }
                if (cls == Boolean.TYPE || cls == Boolean.class) {
                    return (T) l(obj);
                }
                if (cls == Byte.TYPE || cls == Byte.class) {
                    return (T) b(obj);
                }
                if (cls == Short.TYPE || cls == Short.class) {
                    return (T) c(obj);
                }
                if (cls == Integer.TYPE || cls == Integer.class) {
                    return (T) j(obj);
                }
                if (cls == Long.TYPE || cls == Long.class) {
                    return (T) i(obj);
                }
                if (cls == Float.TYPE || cls == Float.class) {
                    return (T) f(obj);
                }
                if (cls == Double.TYPE || cls == Double.class) {
                    return (T) g(obj);
                }
                if (cls == String.class) {
                    return (T) a(obj);
                }
                if (cls == BigDecimal.class) {
                    return (T) d(obj);
                }
                if (cls == BigInteger.class) {
                    return (T) e(obj);
                }
                if (cls == Date.class) {
                    return (T) h(obj);
                }
                if (cls.isEnum()) {
                    return (T) b(obj, cls, parserConfig);
                }
                if (Calendar.class.isAssignableFrom(cls)) {
                    Date h = h(obj);
                    if (cls == Calendar.class) {
                        t = (T) Calendar.getInstance(JSON.f1091a, JSON.b);
                    } else {
                        try {
                            t = cls.newInstance();
                        } catch (Exception e) {
                            throw new JSONException("can not cast to : " + cls.getName(), e);
                        }
                    }
                    t.setTime(h);
                    return t;
                }
                if (obj instanceof String) {
                    String str = (String) obj;
                    if (str.length() == 0 || "null".equals(str)) {
                        return null;
                    }
                    if (cls == Currency.class) {
                        return (T) Currency.getInstance(str);
                    }
                }
                throw new JSONException("can not cast to : " + cls.getName());
            } else if (cls == Map.class) {
                return obj;
            } else {
                Map map = (Map) obj;
                return (cls != Object.class || map.containsKey("@type")) ? (T) a((Map<String, Object>) map, (Class) cls, parserConfig) : obj;
            }
        }
    }

    public static final <T> T b(Object obj, Class<T> cls, ParserConfig parserConfig) {
        try {
            if (obj instanceof String) {
                String str = (String) obj;
                if (str.length() == 0) {
                    return null;
                }
                return (T) Enum.valueOf(cls, str);
            }
            if (obj instanceof Number) {
                int intValue = ((Number) obj).intValue();
                T[] enumConstants = cls.getEnumConstants();
                if (intValue < enumConstants.length) {
                    return enumConstants[intValue];
                }
            }
            throw new JSONException("can not cast to : " + cls.getName());
        } catch (Exception e) {
            throw new JSONException("can not cast to : " + cls.getName(), e);
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: java.lang.Object */
    /* JADX WARN: Multi-variable type inference failed */
    public static final <T> T a(Object obj, Type type, ParserConfig parserConfig) {
        if (obj == 0) {
            return null;
        }
        if (type instanceof Class) {
            return (T) a(obj, (Class) type, parserConfig);
        }
        if (type instanceof ParameterizedType) {
            return (T) a(obj, (ParameterizedType) type, parserConfig);
        }
        if (obj instanceof String) {
            String str = (String) obj;
            if (str.length() == 0 || "null".equals(str)) {
                return null;
            }
        }
        if (type instanceof TypeVariable) {
            return obj;
        }
        throw new JSONException("can not cast to : " + type);
    }

    public static final <T> T a(Object obj, ParameterizedType parameterizedType, ParserConfig parserConfig) {
        Type rawType = parameterizedType.getRawType();
        if (rawType == Set.class || rawType == HashSet.class || rawType == TreeSet.class || rawType == List.class || rawType == ArrayList.class) {
            Type type = parameterizedType.getActualTypeArguments()[0];
            if (obj instanceof Iterable) {
                T t = (rawType == Set.class || rawType == HashSet.class) ? (T) new HashSet() : rawType == TreeSet.class ? (T) new TreeSet() : (T) new ArrayList();
                for (T t2 : (Iterable) obj) {
                    t.add(a(t2, type, parserConfig));
                }
                return t;
            }
        }
        if (rawType == Map.class || rawType == HashMap.class) {
            Type type2 = parameterizedType.getActualTypeArguments()[0];
            Type type3 = parameterizedType.getActualTypeArguments()[1];
            if (obj instanceof Map) {
                T t3 = (T) new HashMap();
                for (Map.Entry entry : ((Map) obj).entrySet()) {
                    t3.put(a(entry.getKey(), type2, parserConfig), a(entry.getValue(), type3, parserConfig));
                }
                return t3;
            }
        }
        if (obj instanceof String) {
            String str = (String) obj;
            if (str.length() == 0 || "null".equals(str)) {
                return null;
            }
        }
        if (parameterizedType.getActualTypeArguments().length == 1 && (parameterizedType.getActualTypeArguments()[0] instanceof WildcardType)) {
            return (T) a(obj, rawType, parserConfig);
        }
        throw new JSONException("can not cast to : " + parameterizedType);
    }

    public static final <T> T a(Map<String, Object> map, Class<T> cls, ParserConfig parserConfig) {
        JSONObject jSONObject;
        int i = 0;
        if (cls == StackTraceElement.class) {
            try {
                String str = (String) map.get("className");
                String str2 = (String) map.get("methodName");
                String str3 = (String) map.get("fileName");
                Number number = (Number) map.get("lineNumber");
                if (number != null) {
                    i = number.intValue();
                }
                return (T) new StackTraceElement(str, str2, str3, i);
            } catch (Exception e) {
                throw new JSONException(e.getMessage(), e);
            }
        } else {
            Object obj = map.get("@type");
            JavaBeanDeserializer javaBeanDeserializer = null;
            if (obj instanceof String) {
                String str4 = (String) obj;
                Class<?> a2 = a(str4, (ClassLoader) null);
                if (a2 == null) {
                    throw new ClassNotFoundException(str4 + " not found");
                } else if (!a2.equals(cls)) {
                    return (T) a(map, (Class) a2, parserConfig);
                }
            }
            if (cls.isInterface()) {
                if (map instanceof JSONObject) {
                    jSONObject = (JSONObject) map;
                } else {
                    jSONObject = new JSONObject(map);
                }
                return (T) Proxy.newProxyInstance(Thread.currentThread().getContextClassLoader(), new Class[]{cls}, jSONObject);
            }
            if (parserConfig == null) {
                parserConfig = ParserConfig.f1106a;
            }
            ObjectDeserializer a3 = parserConfig.a(cls);
            if (a3 instanceof JavaBeanDeserializer) {
                javaBeanDeserializer = (JavaBeanDeserializer) a3;
            }
            if (javaBeanDeserializer != null) {
                return (T) javaBeanDeserializer.a(map, parserConfig);
            }
            throw new JSONException("can not get javaBeanDeserializer");
        }
    }

    static {
        c.put("byte", Byte.TYPE);
        c.put("short", Short.TYPE);
        c.put("int", Integer.TYPE);
        c.put("long", Long.TYPE);
        c.put("float", Float.TYPE);
        c.put("double", Double.TYPE);
        c.put("boolean", Boolean.TYPE);
        c.put("char", Character.TYPE);
        c.put("[byte", byte[].class);
        c.put("[short", short[].class);
        c.put("[int", int[].class);
        c.put("[long", long[].class);
        c.put("[float", float[].class);
        c.put("[double", double[].class);
        c.put("[boolean", boolean[].class);
        c.put("[char", char[].class);
        c.put(HashMap.class.getName(), HashMap.class);
    }

    /* JADX WARNING: Removed duplicated region for block: B:30:0x006f A[Catch:{ Exception -> 0x007e }] */
    public static Class<?> a(String str, ClassLoader classLoader) {
        Class<?> cls;
        Exception e;
        Class<?> cls2;
        Exception e2;
        ClassLoader contextClassLoader;
        Exception e3;
        if (str == null || str.length() == 0) {
            return null;
        }
        Class<?> cls3 = c.get(str);
        if (cls3 != null) {
            return cls3;
        }
        if (str.charAt(0) == '[') {
            return Array.newInstance(a(str.substring(1), classLoader), 0).getClass();
        }
        if (str.startsWith("L") && str.endsWith(";")) {
            return a(str.substring(1, str.length() - 1), classLoader);
        }
        if (classLoader != null) {
            try {
                cls = classLoader.loadClass(str);
                try {
                    c.put(str, cls);
                    return cls;
                } catch (Exception e4) {
                    e3 = e4;
                    e3.printStackTrace();
                    try {
                        contextClassLoader = Thread.currentThread().getContextClassLoader();
                        if (contextClassLoader != null) {
                        }
                    } catch (Exception e5) {
                        e2 = e5;
                        e2.printStackTrace();
                        cls2 = Class.forName(str);
                        try {
                            c.put(str, cls2);
                            return cls2;
                        } catch (Exception e6) {
                            e = e6;
                            e.printStackTrace();
                            return cls2;
                        }
                    }
                    try {
                        cls2 = Class.forName(str);
                        c.put(str, cls2);
                        return cls2;
                    } catch (Exception e7) {
                        e = e7;
                        cls2 = cls;
                        e.printStackTrace();
                        return cls2;
                    }
                }
            } catch (Exception e8) {
                e3 = e8;
                cls = cls3;
                e3.printStackTrace();
                contextClassLoader = Thread.currentThread().getContextClassLoader();
                if (contextClassLoader != null) {
                }
                cls2 = Class.forName(str);
                c.put(str, cls2);
                return cls2;
            }
        } else {
            cls = cls3;
            contextClassLoader = Thread.currentThread().getContextClassLoader();
            if (contextClassLoader != null) {
                Class<?> loadClass = contextClassLoader.loadClass(str);
                try {
                    c.put(str, loadClass);
                    return loadClass;
                } catch (Exception e9) {
                    e2 = e9;
                    cls = loadClass;
                    e2.printStackTrace();
                    cls2 = Class.forName(str);
                    c.put(str, cls2);
                    return cls2;
                }
            }
            cls2 = Class.forName(str);
            c.put(str, cls2);
            return cls2;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:119:0x02c5, code lost:
        if (r0 == null) goto L_0x02e5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:73:0x01c8, code lost:
        if (r0 == null) goto L_0x01e7;
     */
    /* JADX WARNING: Removed duplicated region for block: B:126:0x02d7  */
    public static List<FieldInfo> a(Class<?> cls, int i, boolean z, JSONType jSONType, Map<String, String> map, boolean z2, boolean z3, boolean z4, PropertyNamingStrategy propertyNamingStrategy) {
        boolean z5;
        String[] strArr;
        int i2;
        int i3;
        Method[] methodArr;
        int i4;
        int i5;
        Field[] fieldArr;
        LinkedHashMap linkedHashMap;
        Field[] fieldArr2;
        LinkedHashMap linkedHashMap2;
        int i6;
        int i7;
        PropertyNamingStrategy propertyNamingStrategy2;
        Field[] fieldArr3;
        Method method;
        String str;
        String substring;
        JSONField jSONField;
        int i8;
        int i9;
        String str2;
        JSONField jSONField2;
        Class<?> cls2 = cls;
        int i10 = i;
        JSONType jSONType2 = jSONType;
        Map<String, String> map2 = map;
        PropertyNamingStrategy propertyNamingStrategy3 = propertyNamingStrategy;
        LinkedHashMap linkedHashMap3 = new LinkedHashMap();
        Field[] declaredFields = cls.getDeclaredFields();
        if (!z) {
            Method[] methods = cls.getMethods();
            int length = methods.length;
            int i11 = 0;
            while (i11 < length) {
                Method method2 = methods[i11];
                String name = method2.getName();
                if ((method2.getModifiers() & 8) == 0 && !method2.getReturnType().equals(Void.TYPE) && method2.getParameterTypes().length == 0 && method2.getReturnType() != ClassLoader.class && method2.getDeclaringClass() != Object.class && (!name.equals("getMetaClass") || !method2.getReturnType().getName().equals("groovy.lang.MetaClass"))) {
                    JSONField jSONField3 = z3 ? (JSONField) method2.getAnnotation(JSONField.class) : null;
                    if (jSONField3 == null && z3) {
                        jSONField3 = a(cls2, method2);
                    }
                    if (jSONField3 == null) {
                        i5 = i11;
                        i4 = length;
                        methodArr = methods;
                        fieldArr2 = declaredFields;
                        propertyNamingStrategy2 = propertyNamingStrategy3;
                        linkedHashMap2 = linkedHashMap3;
                        i7 = 0;
                        i6 = 0;
                    } else if (jSONField3.d()) {
                        i7 = jSONField3.a();
                        i6 = SerializerFeature.a(jSONField3.f());
                        if (jSONField3.b().length() != 0) {
                            String b2 = jSONField3.b();
                            if (map2 == null || (b2 = map2.get(b2)) != null) {
                                a(cls2, method2, i10);
                                i5 = i11;
                                i4 = length;
                                methodArr = methods;
                                fieldArr2 = declaredFields;
                                linkedHashMap2 = linkedHashMap3;
                                linkedHashMap2.put(b2, new FieldInfo(b2, method2, null, cls, null, i7, i6, jSONField3, null, true));
                                linkedHashMap = linkedHashMap2;
                                fieldArr = fieldArr2;
                                i11 = i5 + 1;
                                linkedHashMap3 = linkedHashMap;
                                declaredFields = fieldArr;
                                length = i4;
                                methods = methodArr;
                                propertyNamingStrategy3 = propertyNamingStrategy;
                                cls2 = cls;
                                i10 = i;
                                jSONType2 = jSONType;
                                map2 = map;
                            }
                        } else {
                            i5 = i11;
                            i4 = length;
                            methodArr = methods;
                            fieldArr2 = declaredFields;
                            propertyNamingStrategy2 = propertyNamingStrategy3;
                            linkedHashMap2 = linkedHashMap3;
                        }
                    }
                    if (name.startsWith("get")) {
                        if (name.length() >= 4 && !name.equals("getClass")) {
                            char charAt = name.charAt(3);
                            if (Character.isUpperCase(charAt)) {
                                str2 = f1135a ? a(name.substring(3)) : Character.toLowerCase(name.charAt(3)) + name.substring(4);
                            } else if (charAt == '_') {
                                str2 = name.substring(4);
                            } else if (charAt == 'f') {
                                str2 = name.substring(3);
                            } else if (name.length() >= 5 && Character.isUpperCase(name.charAt(4))) {
                                str2 = a(name.substring(3));
                            }
                            if (!a(cls2, jSONType2, str2)) {
                                Field a2 = a(cls2, str2, fieldArr2);
                                if (a2 != null) {
                                    JSONField jSONField4 = z3 ? (JSONField) a2.getAnnotation(JSONField.class) : null;
                                    if (jSONField4 != null) {
                                        if (jSONField4.d()) {
                                            int a3 = jSONField4.a();
                                            int a4 = SerializerFeature.a(jSONField4.f());
                                            if (jSONField4.b().length() != 0) {
                                                str2 = jSONField4.b();
                                                if (map2 != null) {
                                                    str2 = map2.get(str2);
                                                }
                                            }
                                            jSONField2 = jSONField4;
                                            i6 = a4;
                                            i7 = a3;
                                        }
                                        fieldArr = fieldArr2;
                                        linkedHashMap = linkedHashMap2;
                                        i11 = i5 + 1;
                                        linkedHashMap3 = linkedHashMap;
                                        declaredFields = fieldArr;
                                        length = i4;
                                        methods = methodArr;
                                        propertyNamingStrategy3 = propertyNamingStrategy;
                                        cls2 = cls;
                                        i10 = i;
                                        jSONType2 = jSONType;
                                        map2 = map;
                                    } else {
                                        jSONField2 = jSONField4;
                                    }
                                } else {
                                    jSONField2 = null;
                                }
                                if (propertyNamingStrategy2 != null) {
                                    str2 = propertyNamingStrategy2.a(str2);
                                }
                                if (map2 == null || (str2 = map2.get(str2)) != null) {
                                    a(cls2, method2, i);
                                    str = name;
                                    method = method2;
                                    fieldArr3 = fieldArr2;
                                    linkedHashMap = linkedHashMap2;
                                    linkedHashMap.put(str2, new FieldInfo(str2, method2, a2, cls, null, i7, i6, jSONField3, jSONField2, z4));
                                }
                                fieldArr = fieldArr2;
                                linkedHashMap = linkedHashMap2;
                                i11 = i5 + 1;
                                linkedHashMap3 = linkedHashMap;
                                declaredFields = fieldArr;
                                length = i4;
                                methods = methodArr;
                                propertyNamingStrategy3 = propertyNamingStrategy;
                                cls2 = cls;
                                i10 = i;
                                jSONType2 = jSONType;
                                map2 = map;
                            }
                        }
                        linkedHashMap = linkedHashMap2;
                        fieldArr = fieldArr2;
                        i11 = i5 + 1;
                        linkedHashMap3 = linkedHashMap;
                        declaredFields = fieldArr;
                        length = i4;
                        methods = methodArr;
                        propertyNamingStrategy3 = propertyNamingStrategy;
                        cls2 = cls;
                        i10 = i;
                        jSONType2 = jSONType;
                        map2 = map;
                    } else {
                        str = name;
                        method = method2;
                        linkedHashMap = linkedHashMap2;
                        fieldArr3 = fieldArr2;
                    }
                    if (str.startsWith("is") && str.length() >= 3) {
                        char charAt2 = str.charAt(2);
                        if (Character.isUpperCase(charAt2)) {
                            substring = f1135a ? a(str.substring(2)) : Character.toLowerCase(str.charAt(2)) + str.substring(3);
                        } else if (charAt2 == '_') {
                            substring = str.substring(3);
                        } else if (charAt2 == 'f') {
                            substring = str.substring(2);
                        }
                        Field a5 = a(cls2, substring, fieldArr3);
                        if (a5 == null) {
                            a5 = a(cls2, str, fieldArr3);
                        }
                        if (a5 != null) {
                            JSONField jSONField5 = z3 ? (JSONField) a5.getAnnotation(JSONField.class) : null;
                            if (jSONField5 != null) {
                                if (jSONField5.d()) {
                                    int a6 = jSONField5.a();
                                    int a7 = SerializerFeature.a(jSONField5.f());
                                    if (jSONField5.b().length() != 0) {
                                        substring = jSONField5.b();
                                        if (map2 != null) {
                                            substring = map2.get(substring);
                                        }
                                    }
                                    jSONField = jSONField5;
                                    i9 = a6;
                                    i8 = a7;
                                    if (propertyNamingStrategy != null) {
                                        substring = propertyNamingStrategy.a(substring);
                                    }
                                    if (map2 == null || (substring = map2.get(substring)) != null) {
                                        a(cls2, a5, i);
                                        a(cls2, method, i);
                                        fieldArr = fieldArr3;
                                        linkedHashMap.put(substring, new FieldInfo(substring, method, a5, cls, null, i9, i8, jSONField3, jSONField, z4));
                                        i11 = i5 + 1;
                                        linkedHashMap3 = linkedHashMap;
                                        declaredFields = fieldArr;
                                        length = i4;
                                        methods = methodArr;
                                        propertyNamingStrategy3 = propertyNamingStrategy;
                                        cls2 = cls;
                                        i10 = i;
                                        jSONType2 = jSONType;
                                        map2 = map;
                                    }
                                }
                                fieldArr = fieldArr3;
                                i11 = i5 + 1;
                                linkedHashMap3 = linkedHashMap;
                                declaredFields = fieldArr;
                                length = i4;
                                methods = methodArr;
                                propertyNamingStrategy3 = propertyNamingStrategy;
                                cls2 = cls;
                                i10 = i;
                                jSONType2 = jSONType;
                                map2 = map;
                            } else {
                                jSONField = jSONField5;
                            }
                        } else {
                            jSONField = null;
                        }
                        i9 = i7;
                        i8 = i6;
                        if (propertyNamingStrategy != null) {
                        }
                        a(cls2, a5, i);
                        a(cls2, method, i);
                        fieldArr = fieldArr3;
                        linkedHashMap.put(substring, new FieldInfo(substring, method, a5, cls, null, i9, i8, jSONField3, jSONField, z4));
                        i11 = i5 + 1;
                        linkedHashMap3 = linkedHashMap;
                        declaredFields = fieldArr;
                        length = i4;
                        methods = methodArr;
                        propertyNamingStrategy3 = propertyNamingStrategy;
                        cls2 = cls;
                        i10 = i;
                        jSONType2 = jSONType;
                        map2 = map;
                    }
                    fieldArr = fieldArr3;
                    i11 = i5 + 1;
                    linkedHashMap3 = linkedHashMap;
                    declaredFields = fieldArr;
                    length = i4;
                    methods = methodArr;
                    propertyNamingStrategy3 = propertyNamingStrategy;
                    cls2 = cls;
                    i10 = i;
                    jSONType2 = jSONType;
                    map2 = map;
                }
                i5 = i11;
                i4 = length;
                methodArr = methods;
                fieldArr = declaredFields;
                linkedHashMap = linkedHashMap3;
                i11 = i5 + 1;
                linkedHashMap3 = linkedHashMap;
                declaredFields = fieldArr;
                length = i4;
                methods = methodArr;
                propertyNamingStrategy3 = propertyNamingStrategy;
                cls2 = cls;
                i10 = i;
                jSONType2 = jSONType;
                map2 = map;
            }
        }
        ArrayList<Field> arrayList = new ArrayList(declaredFields.length);
        for (Field field : declaredFields) {
            if ((field.getModifiers() & 8) == 0 && !field.getName().equals("this$0") && (field.getModifiers() & 1) != 0) {
                arrayList.add(field);
            }
        }
        Class<? super Object> superclass = cls.getSuperclass();
        while (superclass != null && superclass != Object.class) {
            Field[] declaredFields2 = superclass.getDeclaredFields();
            for (Field field2 : declaredFields2) {
                if ((field2.getModifiers() & 8) == 0 && (field2.getModifiers() & 1) != 0) {
                    arrayList.add(field2);
                }
            }
            superclass = superclass.getSuperclass();
        }
        for (Field field3 : arrayList) {
            JSONField jSONField6 = z3 ? (JSONField) field3.getAnnotation(JSONField.class) : null;
            String name2 = field3.getName();
            if (jSONField6 == null) {
                i3 = 0;
                i2 = 0;
            } else if (jSONField6.d()) {
                int a8 = jSONField6.a();
                int a9 = SerializerFeature.a(jSONField6.f());
                if (jSONField6.b().length() != 0) {
                    name2 = jSONField6.b();
                }
                i3 = a8;
                i2 = a9;
            }
            if (map == null || (name2 = map.get(name2)) != null) {
                if (propertyNamingStrategy != null) {
                    name2 = propertyNamingStrategy.a(name2);
                }
                if (!linkedHashMap3.containsKey(name2)) {
                    a(cls, field3, i);
                    linkedHashMap3.put(name2, new FieldInfo(name2, null, field3, cls, null, i3, i2, null, jSONField6, z4));
                }
            }
        }
        ArrayList arrayList2 = new ArrayList();
        if (jSONType != null) {
            strArr = jSONType.a();
            if (strArr != null && strArr.length == linkedHashMap3.size()) {
                int length2 = strArr.length;
                int i12 = 0;
                while (true) {
                    if (i12 >= length2) {
                        z5 = true;
                        break;
                    } else if (!linkedHashMap3.containsKey(strArr[i12])) {
                        break;
                    } else {
                        i12++;
                    }
                }
            }
        } else {
            strArr = null;
        }
        z5 = false;
        if (z5) {
            for (String str3 : strArr) {
                arrayList2.add((FieldInfo) linkedHashMap3.get(str3));
            }
        } else {
            for (FieldInfo fieldInfo : linkedHashMap3.values()) {
                arrayList2.add(fieldInfo);
            }
            if (z2) {
                Collections.sort(arrayList2);
            }
        }
        return arrayList2;
    }

    public static JSONField a(Class<?> cls, Method method) {
        boolean z;
        JSONField jSONField;
        boolean z2;
        JSONField jSONField2;
        for (Class<?> cls2 : cls.getInterfaces()) {
            Method[] methods = cls2.getMethods();
            for (Method method2 : methods) {
                if (method2.getName().equals(method.getName())) {
                    Class<?>[] parameterTypes = method2.getParameterTypes();
                    Class<?>[] parameterTypes2 = method.getParameterTypes();
                    if (parameterTypes.length != parameterTypes2.length) {
                        continue;
                    } else {
                        int i = 0;
                        while (true) {
                            if (i >= parameterTypes.length) {
                                z2 = true;
                                break;
                            } else if (!parameterTypes[i].equals(parameterTypes2[i])) {
                                z2 = false;
                                break;
                            } else {
                                i++;
                            }
                        }
                        if (z2 && (jSONField2 = (JSONField) method2.getAnnotation(JSONField.class)) != null) {
                            return jSONField2;
                        }
                    }
                }
            }
        }
        Class<? super Object> superclass = cls.getSuperclass();
        if (superclass != null && Modifier.isAbstract(superclass.getModifiers())) {
            Class<?>[] parameterTypes3 = method.getParameterTypes();
            Method[] methods2 = superclass.getMethods();
            for (Method method3 : methods2) {
                Class<?>[] parameterTypes4 = method3.getParameterTypes();
                if (parameterTypes4.length == parameterTypes3.length && method3.getName().equals(method.getName())) {
                    int i2 = 0;
                    while (true) {
                        if (i2 >= parameterTypes3.length) {
                            z = true;
                            break;
                        } else if (!parameterTypes4[i2].equals(parameterTypes3[i2])) {
                            z = false;
                            break;
                        } else {
                            i2++;
                        }
                    }
                    if (z && (jSONField = (JSONField) method3.getAnnotation(JSONField.class)) != null) {
                        return jSONField;
                    }
                }
            }
        }
        return null;
    }

    private static boolean a(Class<?> cls, JSONType jSONType, String str) {
        if (!(jSONType == null || jSONType.b() == null)) {
            for (String str2 : jSONType.b()) {
                if (str.equalsIgnoreCase(str2)) {
                    return true;
                }
            }
        }
        Class<? super Object> superclass = cls.getSuperclass();
        if (superclass == Object.class || superclass == null || !a(superclass, (JSONType) superclass.getAnnotation(JSONType.class), str)) {
            return false;
        }
        return true;
    }

    public static boolean a(Type type) {
        Type genericSuperclass;
        if (type instanceof ParameterizedType) {
            return true;
        }
        if (!(type instanceof Class) || (genericSuperclass = ((Class) type).getGenericSuperclass()) == Object.class || !a(genericSuperclass)) {
            return false;
        }
        return true;
    }

    public static Type b(Type type) {
        return type instanceof Class ? b(((Class) type).getGenericSuperclass()) : type;
    }

    public static Class<?> c(Type type) {
        if (type.getClass() == Class.class) {
            return (Class) type;
        }
        if (type instanceof ParameterizedType) {
            return c(((ParameterizedType) type).getRawType());
        }
        if (type instanceof TypeVariable) {
            return (Class) ((TypeVariable) type).getBounds()[0];
        }
        return Object.class;
    }

    public static String a(String str) {
        if (str == null || str.length() == 0 || (str.length() > 1 && Character.isUpperCase(str.charAt(1)) && Character.isUpperCase(str.charAt(0)))) {
            return str;
        }
        char[] charArray = str.toCharArray();
        charArray[0] = Character.toLowerCase(charArray[0]);
        return new String(charArray);
    }

    public static boolean a(Class<?> cls, Member member, int i) {
        if (member == null || !b) {
            return false;
        }
        Class<? super Object> superclass = cls.getSuperclass();
        if ((superclass == null || superclass == Object.class) && (member.getModifiers() & 1) != 0 && (i & 1) != 0) {
            return false;
        }
        try {
            ((AccessibleObject) member).setAccessible(true);
            return true;
        } catch (AccessControlException unused) {
            b = false;
            return false;
        }
    }

    public static Field a(Class<?> cls, String str, Field[] fieldArr) {
        Field b2 = b(cls, str, fieldArr);
        if (b2 == null) {
            b2 = b(cls, "_" + str, fieldArr);
        }
        if (b2 == null) {
            b2 = b(cls, "m_" + str, fieldArr);
        }
        if (b2 != null) {
            return b2;
        }
        return b(cls, "m" + str.substring(0, 1).toUpperCase() + str.substring(1), fieldArr);
    }

    private static Field b(Class<?> cls, String str, Field[] fieldArr) {
        for (Field field : fieldArr) {
            if (str.equals(field.getName())) {
                return field;
            }
        }
        Class<? super Object> superclass = cls.getSuperclass();
        if (superclass == null || superclass == Object.class) {
            return null;
        }
        return a(superclass, str, superclass.getDeclaredFields());
    }
}
