package com.facebook.cache.disk;

import android.os.Environment;
import com.facebook.binaryresource.BinaryResource;
import com.facebook.binaryresource.FileBinaryResource;
import com.facebook.cache.common.CacheErrorLogger;
import com.facebook.cache.common.WriterCallback;
import com.facebook.cache.disk.DiskStorage;
import com.facebook.common.file.FileTree;
import com.facebook.common.file.FileTreeVisitor;
import com.facebook.common.file.FileUtils;
import com.facebook.common.internal.CountingOutputStream;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.internal.VisibleForTesting;
import com.facebook.common.time.Clock;
import com.facebook.common.time.SystemClock;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.concurrent.TimeUnit;
import javax.annotation.Nullable;

public class DefaultDiskStorage implements DiskStorage {

    /* renamed from: a  reason: collision with root package name */
    static final long f1440a = TimeUnit.MINUTES.toMillis(30);
    private static final Class<?> b = DefaultDiskStorage.class;
    private final File c;
    private final boolean d;
    private final File e;
    private final CacheErrorLogger f;
    private final Clock g = SystemClock.b();

    public DefaultDiskStorage(File file, int i, CacheErrorLogger cacheErrorLogger) {
        Preconditions.a(file);
        this.c = file;
        this.d = a(file, cacheErrorLogger);
        this.e = new File(this.c, a(i));
        this.f = cacheErrorLogger;
        g();
    }

    private static boolean a(File file, CacheErrorLogger cacheErrorLogger) {
        String str;
        IOException e2;
        try {
            File externalStorageDirectory = Environment.getExternalStorageDirectory();
            if (externalStorageDirectory == null) {
                return false;
            }
            String file2 = externalStorageDirectory.toString();
            try {
                str = file.getCanonicalPath();
                try {
                    return str.contains(file2);
                } catch (IOException e3) {
                    e2 = e3;
                    CacheErrorLogger.CacheErrorCategory cacheErrorCategory = CacheErrorLogger.CacheErrorCategory.OTHER;
                    Class<?> cls = b;
                    cacheErrorLogger.a(cacheErrorCategory, cls, "failed to read folder to check if external: " + str, e2);
                    return false;
                }
            } catch (IOException e4) {
                e2 = e4;
                str = null;
                CacheErrorLogger.CacheErrorCategory cacheErrorCategory2 = CacheErrorLogger.CacheErrorCategory.OTHER;
                Class<?> cls2 = b;
                cacheErrorLogger.a(cacheErrorCategory2, cls2, "failed to read folder to check if external: " + str, e2);
                return false;
            }
        } catch (Exception e5) {
            cacheErrorLogger.a(CacheErrorLogger.CacheErrorCategory.OTHER, b, "failed to get the external storage directory!", e5);
            return false;
        }
    }

    @VisibleForTesting
    static String a(int i) {
        return String.format(null, "%s.ols%d.%d", "v2", 100, Integer.valueOf(i));
    }

    @Override // com.facebook.cache.disk.DiskStorage
    public boolean a() {
        return this.d;
    }

    private void g() {
        boolean z = true;
        if (this.c.exists()) {
            if (!this.e.exists()) {
                FileTree.b(this.c);
            } else {
                z = false;
            }
        }
        if (z) {
            try {
                FileUtils.a(this.e);
            } catch (FileUtils.CreateDirectoryException unused) {
                CacheErrorLogger cacheErrorLogger = this.f;
                CacheErrorLogger.CacheErrorCategory cacheErrorCategory = CacheErrorLogger.CacheErrorCategory.WRITE_CREATE_DIR;
                Class<?> cls = b;
                cacheErrorLogger.a(cacheErrorCategory, cls, "version directory could not be created: " + this.e, null);
            }
        }
    }

    private static class IncompleteFileException extends IOException {

        /* renamed from: a  reason: collision with root package name */
        public final long f1445a;
        public final long b;

        public IncompleteFileException(long j, long j2) {
            super("File was not written completely. Expected: " + j + ", found: " + j2);
            this.f1445a = j;
            this.b = j2;
        }
    }

    /* access modifiers changed from: package-private */
    @VisibleForTesting
    public File a(String str) {
        return new File(e(str));
    }

    private String c(String str) {
        String valueOf = String.valueOf(Math.abs(str.hashCode() % 100));
        return this.e + File.separator + valueOf;
    }

    private File d(String str) {
        return new File(c(str));
    }

    /* access modifiers changed from: private */
    public class EntriesCollector implements FileTreeVisitor {
        private final List<DiskStorage.Entry> b;

        @Override // com.facebook.common.file.FileTreeVisitor
        public void a(File file) {
        }

        @Override // com.facebook.common.file.FileTreeVisitor
        public void c(File file) {
        }

        private EntriesCollector() {
            this.b = new ArrayList();
        }

        @Override // com.facebook.common.file.FileTreeVisitor
        public void b(File file) {
            FileInfo b2 = DefaultDiskStorage.this.b((DefaultDiskStorage) file);
            if (b2 != null && b2.f1443a == FileType.CONTENT) {
                this.b.add(new EntryImpl(b2.b, file));
            }
        }

        public List<DiskStorage.Entry> a() {
            return Collections.unmodifiableList(this.b);
        }
    }

    private class PurgingVisitor implements FileTreeVisitor {
        private boolean b;

        private PurgingVisitor() {
        }

        @Override // com.facebook.common.file.FileTreeVisitor
        public void a(File file) {
            if (!this.b && file.equals(DefaultDiskStorage.this.e)) {
                this.b = true;
            }
        }

        @Override // com.facebook.common.file.FileTreeVisitor
        public void b(File file) {
            if (!this.b || !d(file)) {
                file.delete();
            }
        }

        @Override // com.facebook.common.file.FileTreeVisitor
        public void c(File file) {
            if (!DefaultDiskStorage.this.c.equals(file) && !this.b) {
                file.delete();
            }
            if (this.b && file.equals(DefaultDiskStorage.this.e)) {
                this.b = false;
            }
        }

        private boolean d(File file) {
            FileInfo b2 = DefaultDiskStorage.this.b((DefaultDiskStorage) file);
            boolean z = false;
            if (b2 == null) {
                return false;
            }
            if (b2.f1443a == FileType.TEMP) {
                return e(file);
            }
            if (b2.f1443a == FileType.CONTENT) {
                z = true;
            }
            Preconditions.b(z);
            return true;
        }

        private boolean e(File file) {
            return file.lastModified() > DefaultDiskStorage.this.g.a() - DefaultDiskStorage.f1440a;
        }
    }

    @Override // com.facebook.cache.disk.DiskStorage
    public void b() {
        FileTree.a(this.c, new PurgingVisitor());
    }

    private void a(File file, String str) throws IOException {
        try {
            FileUtils.a(file);
        } catch (FileUtils.CreateDirectoryException e2) {
            this.f.a(CacheErrorLogger.CacheErrorCategory.WRITE_CREATE_DIR, b, str, e2);
            throw e2;
        }
    }

    @Override // com.facebook.cache.disk.DiskStorage
    public DiskStorage.Inserter a(String str, Object obj) throws IOException {
        FileInfo fileInfo = new FileInfo(FileType.TEMP, str);
        File d2 = d(fileInfo.b);
        if (!d2.exists()) {
            a(d2, "insert");
        }
        try {
            return new InserterImpl(str, fileInfo.a(d2));
        } catch (IOException e2) {
            this.f.a(CacheErrorLogger.CacheErrorCategory.WRITE_CREATE_TEMPFILE, b, "insert", e2);
            throw e2;
        }
    }

    @Override // com.facebook.cache.disk.DiskStorage
    public BinaryResource b(String str, Object obj) {
        File a2 = a(str);
        if (!a2.exists()) {
            return null;
        }
        a2.setLastModified(this.g.a());
        return FileBinaryResource.a(a2);
    }

    private String e(String str) {
        FileInfo fileInfo = new FileInfo(FileType.CONTENT, str);
        return fileInfo.a(c(fileInfo.b));
    }

    @Override // com.facebook.cache.disk.DiskStorage
    public boolean c(String str, Object obj) {
        return a(str, false);
    }

    private boolean a(String str, boolean z) {
        File a2 = a(str);
        boolean exists = a2.exists();
        if (z && exists) {
            a2.setLastModified(this.g.a());
        }
        return exists;
    }

    @Override // com.facebook.cache.disk.DiskStorage
    public long a(DiskStorage.Entry entry) {
        return a(((EntryImpl) entry).c().c());
    }

    @Override // com.facebook.cache.disk.DiskStorage
    public long b(String str) {
        return a(a(str));
    }

    private long a(File file) {
        if (!file.exists()) {
            return 0;
        }
        long length = file.length();
        if (file.delete()) {
            return length;
        }
        return -1;
    }

    @Override // com.facebook.cache.disk.DiskStorage
    public void c() {
        FileTree.a(this.c);
    }

    /* renamed from: d */
    public List<DiskStorage.Entry> e() throws IOException {
        EntriesCollector entriesCollector = new EntriesCollector();
        FileTree.a(this.e, entriesCollector);
        return entriesCollector.a();
    }

    @VisibleForTesting
    static class EntryImpl implements DiskStorage.Entry {

        /* renamed from: a  reason: collision with root package name */
        private final String f1442a;
        private final FileBinaryResource b;
        private long c;
        private long d;

        private EntryImpl(String str, File file) {
            Preconditions.a(file);
            this.f1442a = (String) Preconditions.a(str);
            this.b = FileBinaryResource.a(file);
            this.c = -1;
            this.d = -1;
        }

        @Override // com.facebook.cache.disk.DiskStorage.Entry
        public String a() {
            return this.f1442a;
        }

        @Override // com.facebook.cache.disk.DiskStorage.Entry
        public long b() {
            if (this.d < 0) {
                this.d = this.b.c().lastModified();
            }
            return this.d;
        }

        public FileBinaryResource c() {
            return this.b;
        }

        @Override // com.facebook.cache.disk.DiskStorage.Entry
        public long d() {
            if (this.c < 0) {
                this.c = this.b.b();
            }
            return this.c;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private FileInfo b(File file) {
        FileInfo b2 = FileInfo.b(file);
        if (b2 == null) {
            return null;
        }
        if (d(b2.b).equals(file.getParentFile())) {
            return b2;
        }
        return null;
    }

    /* access modifiers changed from: private */
    public enum FileType {
        CONTENT(".cnt"),
        TEMP(".tmp");
        
        public final String c;

        private FileType(String str) {
            this.c = str;
        }

        public static FileType a(String str) {
            if (".cnt".equals(str)) {
                return CONTENT;
            }
            if (".tmp".equals(str)) {
                return TEMP;
            }
            return null;
        }
    }

    /* access modifiers changed from: private */
    public static class FileInfo {

        /* renamed from: a  reason: collision with root package name */
        public final FileType f1443a;
        public final String b;

        private FileInfo(FileType fileType, String str) {
            this.f1443a = fileType;
            this.b = str;
        }

        public String toString() {
            return this.f1443a + "(" + this.b + ")";
        }

        public String a(String str) {
            return str + File.separator + this.b + this.f1443a.c;
        }

        public File a(File file) throws IOException {
            return File.createTempFile(this.b + ".", ".tmp", file);
        }

        @Nullable
        public static FileInfo b(File file) {
            FileType a2;
            String name = file.getName();
            int lastIndexOf = name.lastIndexOf(46);
            if (lastIndexOf <= 0 || (a2 = FileType.a(name.substring(lastIndexOf))) == null) {
                return null;
            }
            String substring = name.substring(0, lastIndexOf);
            if (a2.equals(FileType.TEMP)) {
                int lastIndexOf2 = substring.lastIndexOf(46);
                if (lastIndexOf2 <= 0) {
                    return null;
                }
                substring = substring.substring(0, lastIndexOf2);
            }
            return new FileInfo(a2, substring);
        }
    }

    @VisibleForTesting
    class InserterImpl implements DiskStorage.Inserter {
        @VisibleForTesting

        /* renamed from: a  reason: collision with root package name */
        final File f1446a;
        private final String c;

        public InserterImpl(String str, File file) {
            this.c = str;
            this.f1446a = file;
        }

        /* JADX INFO: finally extract failed */
        @Override // com.facebook.cache.disk.DiskStorage.Inserter
        public void a(WriterCallback writerCallback, Object obj) throws IOException {
            try {
                FileOutputStream fileOutputStream = new FileOutputStream(this.f1446a);
                try {
                    CountingOutputStream countingOutputStream = new CountingOutputStream(fileOutputStream);
                    writerCallback.a(countingOutputStream);
                    countingOutputStream.flush();
                    long a2 = countingOutputStream.a();
                    fileOutputStream.close();
                    if (this.f1446a.length() != a2) {
                        throw new IncompleteFileException(a2, this.f1446a.length());
                    }
                } catch (Throwable th) {
                    fileOutputStream.close();
                    throw th;
                }
            } catch (FileNotFoundException e) {
                DefaultDiskStorage.this.f.a(CacheErrorLogger.CacheErrorCategory.WRITE_UPDATE_FILE_NOT_FOUND, DefaultDiskStorage.b, "updateResource", e);
                throw e;
            }
        }

        @Override // com.facebook.cache.disk.DiskStorage.Inserter
        public BinaryResource a(Object obj) throws IOException {
            CacheErrorLogger.CacheErrorCategory cacheErrorCategory;
            File a2 = DefaultDiskStorage.this.a(this.c);
            try {
                FileUtils.a(this.f1446a, a2);
                if (a2.exists()) {
                    a2.setLastModified(DefaultDiskStorage.this.g.a());
                }
                return FileBinaryResource.a(a2);
            } catch (FileUtils.RenameException e) {
                Throwable cause = e.getCause();
                if (cause == null) {
                    cacheErrorCategory = CacheErrorLogger.CacheErrorCategory.WRITE_RENAME_FILE_OTHER;
                } else if (cause instanceof FileUtils.ParentDirNotFoundException) {
                    cacheErrorCategory = CacheErrorLogger.CacheErrorCategory.WRITE_RENAME_FILE_TEMPFILE_PARENT_NOT_FOUND;
                } else if (cause instanceof FileNotFoundException) {
                    cacheErrorCategory = CacheErrorLogger.CacheErrorCategory.WRITE_RENAME_FILE_TEMPFILE_NOT_FOUND;
                } else {
                    cacheErrorCategory = CacheErrorLogger.CacheErrorCategory.WRITE_RENAME_FILE_OTHER;
                }
                DefaultDiskStorage.this.f.a(cacheErrorCategory, DefaultDiskStorage.b, "commit", e);
                throw e;
            }
        }

        @Override // com.facebook.cache.disk.DiskStorage.Inserter
        public boolean a() {
            return !this.f1446a.exists() || this.f1446a.delete();
        }
    }
}
