package com.facebook.cache.disk;

import android.content.Context;
import com.facebook.binaryresource.BinaryResource;
import com.facebook.cache.common.CacheErrorLogger;
import com.facebook.cache.common.CacheEventListener;
import com.facebook.cache.common.CacheKey;
import com.facebook.cache.common.CacheKeyUtil;
import com.facebook.cache.common.WriterCallback;
import com.facebook.cache.disk.DiskStorage;
import com.facebook.common.disk.DiskTrimmable;
import com.facebook.common.disk.DiskTrimmableRegistry;
import com.facebook.common.internal.VisibleForTesting;
import com.facebook.common.logging.FLog;
import com.facebook.common.statfs.StatFsHelper;
import com.facebook.common.time.Clock;
import com.facebook.common.time.SystemClock;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.Executor;
import java.util.concurrent.TimeUnit;
import javax.annotation.Nullable;
import javax.annotation.concurrent.GuardedBy;
import javax.annotation.concurrent.ThreadSafe;

@ThreadSafe
public class DiskStorageCache implements FileCache, DiskTrimmable {
    private static final Class<?> b = DiskStorageCache.class;
    private static final long c = TimeUnit.HOURS.toMillis(2);
    private static final long d = TimeUnit.MINUTES.toMillis(30);
    @VisibleForTesting
    @GuardedBy

    /* renamed from: a  reason: collision with root package name */
    final Set<String> f1453a;
    private final long e;
    private final long f;
    private final CountDownLatch g;
    private long h;
    private final CacheEventListener i;
    private long j;
    private final long k;
    private final StatFsHelper l;
    private final DiskStorage m;
    private final EntryEvictionComparatorSupplier n;
    private final CacheErrorLogger o;
    private final boolean p;
    private final CacheStats q;
    private final Clock r;
    private final Object s = new Object();
    private boolean t;

    /* access modifiers changed from: package-private */
    @VisibleForTesting
    public static class CacheStats {

        /* renamed from: a  reason: collision with root package name */
        private boolean f1455a = false;
        private long b = -1;
        private long c = -1;

        CacheStats() {
        }

        public synchronized boolean a() {
            return this.f1455a;
        }

        public synchronized void b() {
            this.f1455a = false;
            this.c = -1;
            this.b = -1;
        }

        public synchronized void a(long j, long j2) {
            this.c = j2;
            this.b = j;
            this.f1455a = true;
        }

        public synchronized void b(long j, long j2) {
            if (this.f1455a) {
                this.b += j;
                this.c += j2;
            }
        }

        public synchronized long c() {
            return this.b;
        }

        public synchronized long d() {
            return this.c;
        }
    }

    public static class Params {

        /* renamed from: a  reason: collision with root package name */
        public final long f1456a;
        public final long b;
        public final long c;

        public Params(long j, long j2, long j3) {
            this.f1456a = j;
            this.b = j2;
            this.c = j3;
        }
    }

    public DiskStorageCache(DiskStorage diskStorage, EntryEvictionComparatorSupplier entryEvictionComparatorSupplier, Params params, CacheEventListener cacheEventListener, CacheErrorLogger cacheErrorLogger, @Nullable DiskTrimmableRegistry diskTrimmableRegistry, Context context, Executor executor, boolean z) {
        this.e = params.b;
        this.f = params.c;
        this.h = params.c;
        this.l = StatFsHelper.a();
        this.m = diskStorage;
        this.n = entryEvictionComparatorSupplier;
        this.j = -1;
        this.i = cacheEventListener;
        this.k = params.f1456a;
        this.o = cacheErrorLogger;
        this.q = new CacheStats();
        if (diskTrimmableRegistry != null) {
            diskTrimmableRegistry.a(this);
        }
        this.r = SystemClock.b();
        this.p = z;
        this.f1453a = new HashSet();
        if (this.p) {
            this.g = new CountDownLatch(1);
            executor.execute(new Runnable() {
                /* class com.facebook.cache.disk.DiskStorageCache.AnonymousClass1 */

                public void run() {
                    synchronized (DiskStorageCache.this.s) {
                        DiskStorageCache.this.d();
                    }
                    DiskStorageCache.this.t = true;
                    DiskStorageCache.this.g.countDown();
                }
            });
            return;
        }
        this.g = new CountDownLatch(0);
    }

    @Override // com.facebook.cache.disk.FileCache
    public BinaryResource a(CacheKey cacheKey) {
        BinaryResource binaryResource;
        SettableCacheEvent a2 = SettableCacheEvent.a().a(cacheKey);
        try {
            synchronized (this.s) {
                List<String> a3 = CacheKeyUtil.a(cacheKey);
                int i2 = 0;
                String str = null;
                binaryResource = null;
                while (true) {
                    if (i2 >= a3.size()) {
                        break;
                    }
                    str = a3.get(i2);
                    a2.a(str);
                    binaryResource = this.m.b(str, cacheKey);
                    if (binaryResource != null) {
                        break;
                    }
                    i2++;
                }
                if (binaryResource == null) {
                    this.i.b(a2);
                    this.f1453a.remove(str);
                } else {
                    this.i.a(a2);
                    this.f1453a.add(str);
                }
            }
            return binaryResource;
        } catch (IOException e2) {
            this.o.a(CacheErrorLogger.CacheErrorCategory.GENERIC_IO, b, "getResource", e2);
            a2.a(e2);
            this.i.e(a2);
            return null;
        } finally {
            a2.b();
        }
    }

    private DiskStorage.Inserter a(String str, CacheKey cacheKey) throws IOException {
        b();
        return this.m.a(str, cacheKey);
    }

    private BinaryResource a(DiskStorage.Inserter inserter, CacheKey cacheKey, String str) throws IOException {
        BinaryResource a2;
        synchronized (this.s) {
            a2 = inserter.a(cacheKey);
            this.f1453a.add(str);
            this.q.b(a2.b(), 1);
        }
        return a2;
    }

    @Override // com.facebook.cache.disk.FileCache
    public BinaryResource a(CacheKey cacheKey, WriterCallback writerCallback) throws IOException {
        String b2;
        SettableCacheEvent a2 = SettableCacheEvent.a().a(cacheKey);
        this.i.c(a2);
        synchronized (this.s) {
            b2 = CacheKeyUtil.b(cacheKey);
        }
        a2.a(b2);
        try {
            DiskStorage.Inserter a3 = a(b2, cacheKey);
            try {
                a3.a(writerCallback, cacheKey);
                BinaryResource a4 = a(a3, cacheKey, b2);
                a2.a(a4.b()).b(this.q.c());
                this.i.d(a2);
                a2.b();
                return a4;
            } finally {
                if (!a3.a()) {
                    FLog.d(b, "Failed to delete temp file");
                }
            }
        } catch (IOException e2) {
            a2.a(e2);
            this.i.f(a2);
            FLog.b(b, "Failed inserting a file into the cache", (Throwable) e2);
            throw e2;
        } catch (Throwable th) {
            a2.b();
            throw th;
        }
    }

    @Override // com.facebook.cache.disk.FileCache
    public void b(CacheKey cacheKey) {
        synchronized (this.s) {
            try {
                List<String> a2 = CacheKeyUtil.a(cacheKey);
                for (int i2 = 0; i2 < a2.size(); i2++) {
                    String str = a2.get(i2);
                    this.m.b(str);
                    this.f1453a.remove(str);
                }
            } catch (IOException e2) {
                CacheErrorLogger cacheErrorLogger = this.o;
                CacheErrorLogger.CacheErrorCategory cacheErrorCategory = CacheErrorLogger.CacheErrorCategory.DELETE_FILE;
                Class<?> cls = b;
                cacheErrorLogger.a(cacheErrorCategory, cls, "delete: " + e2.getMessage(), e2);
            }
        }
    }

    private void b() throws IOException {
        synchronized (this.s) {
            boolean d2 = d();
            c();
            long c2 = this.q.c();
            if (c2 > this.h && !d2) {
                this.q.b();
                d();
            }
            if (c2 > this.h) {
                a((this.h * 9) / 10, CacheEventListener.EvictionReason.CACHE_FULL);
            }
        }
    }

    @GuardedBy
    private void a(long j2, CacheEventListener.EvictionReason evictionReason) throws IOException {
        try {
            Collection<DiskStorage.Entry> a2 = a(this.m.e());
            long c2 = this.q.c();
            long j3 = c2 - j2;
            int i2 = 0;
            long j4 = 0;
            for (DiskStorage.Entry entry : a2) {
                if (j4 > j3) {
                    break;
                }
                long a3 = this.m.a(entry);
                this.f1453a.remove(entry.a());
                if (a3 > 0) {
                    i2++;
                    j4 += a3;
                    SettableCacheEvent c3 = SettableCacheEvent.a().a(entry.a()).a(evictionReason).a(a3).b(c2 - j4).c(j2);
                    this.i.g(c3);
                    c3.b();
                }
            }
            this.q.b(-j4, (long) (-i2));
            this.m.b();
        } catch (IOException e2) {
            CacheErrorLogger cacheErrorLogger = this.o;
            CacheErrorLogger.CacheErrorCategory cacheErrorCategory = CacheErrorLogger.CacheErrorCategory.EVICTION;
            Class<?> cls = b;
            cacheErrorLogger.a(cacheErrorCategory, cls, "evictAboveSize: " + e2.getMessage(), e2);
            throw e2;
        }
    }

    private Collection<DiskStorage.Entry> a(Collection<DiskStorage.Entry> collection) {
        long a2 = this.r.a() + c;
        ArrayList arrayList = new ArrayList(collection.size());
        ArrayList arrayList2 = new ArrayList(collection.size());
        for (DiskStorage.Entry entry : collection) {
            if (entry.b() > a2) {
                arrayList.add(entry);
            } else {
                arrayList2.add(entry);
            }
        }
        Collections.sort(arrayList2, this.n.a());
        arrayList.addAll(arrayList2);
        return arrayList;
    }

    @GuardedBy
    private void c() {
        if (this.l.a(this.m.a() ? StatFsHelper.StorageType.EXTERNAL : StatFsHelper.StorageType.INTERNAL, this.f - this.q.c())) {
            this.h = this.e;
        } else {
            this.h = this.f;
        }
    }

    @Override // com.facebook.cache.disk.FileCache
    public void a() {
        synchronized (this.s) {
            try {
                this.m.c();
                this.f1453a.clear();
                this.i.a();
            } catch (IOException e2) {
                CacheErrorLogger cacheErrorLogger = this.o;
                CacheErrorLogger.CacheErrorCategory cacheErrorCategory = CacheErrorLogger.CacheErrorCategory.EVICTION;
                Class<?> cls = b;
                cacheErrorLogger.a(cacheErrorCategory, cls, "clearAll: " + e2.getMessage(), e2);
            }
            this.q.b();
        }
    }

    @Override // com.facebook.cache.disk.FileCache
    public boolean c(CacheKey cacheKey) {
        synchronized (this.s) {
            List<String> a2 = CacheKeyUtil.a(cacheKey);
            for (int i2 = 0; i2 < a2.size(); i2++) {
                if (this.f1453a.contains(a2.get(i2))) {
                    return true;
                }
            }
            return false;
        }
    }

    @Override // com.facebook.cache.disk.FileCache
    public boolean d(CacheKey cacheKey) {
        synchronized (this.s) {
            if (c(cacheKey)) {
                return true;
            }
            try {
                List<String> a2 = CacheKeyUtil.a(cacheKey);
                for (int i2 = 0; i2 < a2.size(); i2++) {
                    String str = a2.get(i2);
                    if (this.m.c(str, cacheKey)) {
                        this.f1453a.add(str);
                        return true;
                    }
                }
                return false;
            } catch (IOException unused) {
                return false;
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    @GuardedBy
    private boolean d() {
        long a2 = this.r.a();
        if (!this.q.a() || this.j == -1 || a2 - this.j > d) {
            return e();
        }
        return false;
    }

    @GuardedBy
    private boolean e() {
        Set<String> set;
        long j2;
        long a2 = this.r.a();
        long j3 = c + a2;
        if (!this.p || !this.f1453a.isEmpty()) {
            set = this.p ? new HashSet<>() : null;
        } else {
            set = this.f1453a;
        }
        try {
            long j4 = -1;
            int i2 = 0;
            int i3 = 0;
            long j5 = 0;
            boolean z = false;
            int i4 = 0;
            for (DiskStorage.Entry entry : this.m.e()) {
                i4++;
                j5 += entry.d();
                if (entry.b() > j3) {
                    i2++;
                    j2 = j3;
                    int d2 = (int) (((long) i3) + entry.d());
                    j4 = Math.max(entry.b() - a2, j4);
                    i3 = d2;
                    z = true;
                } else {
                    j2 = j3;
                    if (this.p) {
                        set.add(entry.a());
                    }
                }
                j3 = j2;
            }
            if (z) {
                this.o.a(CacheErrorLogger.CacheErrorCategory.READ_INVALID_ENTRY, b, "Future timestamp found in " + i2 + " files , with a total size of " + i3 + " bytes, and a maximum time delta of " + j4 + "ms", null);
            }
            long j6 = (long) i4;
            if (!(this.q.d() == j6 && this.q.c() == j5)) {
                if (this.p && this.f1453a != set) {
                    this.f1453a.clear();
                    this.f1453a.addAll(set);
                }
                this.q.a(j5, j6);
            }
            this.j = a2;
            return true;
        } catch (IOException e2) {
            this.o.a(CacheErrorLogger.CacheErrorCategory.GENERIC_IO, b, "calcFileCacheSize: " + e2.getMessage(), e2);
            return false;
        }
    }
}
