package com.facebook.common.executors;

import com.facebook.common.logging.FLog;
import java.util.List;
import java.util.concurrent.AbstractExecutorService;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.Executor;
import java.util.concurrent.RejectedExecutionException;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicInteger;

public class ConstrainedExecutorService extends AbstractExecutorService {

    /* renamed from: a  reason: collision with root package name */
    private static final Class<?> f1464a = ConstrainedExecutorService.class;
    private final String b;
    private final Executor c;
    private volatile int d;
    private final BlockingQueue<Runnable> e;
    private final Worker f;
    private final AtomicInteger g;
    private final AtomicInteger h;

    public boolean isShutdown() {
        return false;
    }

    public boolean isTerminated() {
        return false;
    }

    public void execute(Runnable runnable) {
        if (runnable == null) {
            throw new NullPointerException("runnable parameter is null");
        } else if (this.e.offer(runnable)) {
            int size = this.e.size();
            int i = this.h.get();
            if (size > i && this.h.compareAndSet(i, size)) {
                FLog.a(f1464a, "%s: max pending work in queue = %d", this.b, Integer.valueOf(size));
            }
            b();
        } else {
            throw new RejectedExecutionException(this.b + " queue is full, size=" + this.e.size());
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void b() {
        int i = this.g.get();
        while (i < this.d) {
            int i2 = i + 1;
            if (this.g.compareAndSet(i, i2)) {
                FLog.a(f1464a, "%s: starting worker %d of %d", this.b, Integer.valueOf(i2), Integer.valueOf(this.d));
                this.c.execute(this.f);
                return;
            }
            FLog.a(f1464a, "%s: race in startWorkerIfNeeded; retrying", this.b);
            i = this.g.get();
        }
    }

    public void shutdown() {
        throw new UnsupportedOperationException();
    }

    @Override // java.util.concurrent.ExecutorService
    public List<Runnable> shutdownNow() {
        throw new UnsupportedOperationException();
    }

    @Override // java.util.concurrent.ExecutorService
    public boolean awaitTermination(long j, TimeUnit timeUnit) throws InterruptedException {
        throw new UnsupportedOperationException();
    }

    /* access modifiers changed from: private */
    public class Worker implements Runnable {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ ConstrainedExecutorService f1465a;

        public void run() {
            AtomicInteger atomicInteger;
            boolean isEmpty;
            try {
                Runnable runnable = (Runnable) this.f1465a.e.poll();
                if (runnable != null) {
                    runnable.run();
                } else {
                    FLog.a(ConstrainedExecutorService.f1464a, "%s: Worker has nothing to run", this.f1465a.b);
                }
                if (isEmpty) {
                    FLog.a(ConstrainedExecutorService.f1464a, "%s: worker finished; %d workers left", this.f1465a.b, Integer.valueOf(atomicInteger.decrementAndGet()));
                }
            } finally {
                int decrementAndGet = this.f1465a.g.decrementAndGet();
                if (!this.f1465a.e.isEmpty()) {
                    this.f1465a.b();
                } else {
                    FLog.a(ConstrainedExecutorService.f1464a, "%s: worker finished; %d workers left", this.f1465a.b, Integer.valueOf(decrementAndGet));
                }
            }
        }
    }
}
