package com.facebook.common.memory;

import com.facebook.common.internal.Preconditions;
import com.facebook.common.logging.FLog;
import com.facebook.common.references.ResourceReleaser;
import java.io.IOException;
import java.io.InputStream;
import javax.annotation.concurrent.NotThreadSafe;

@NotThreadSafe
public class PooledByteArrayBufferedInputStream extends InputStream {

    /* renamed from: a  reason: collision with root package name */
    private final InputStream f1480a;
    private final byte[] b;
    private final ResourceReleaser<byte[]> c;
    private int d = 0;
    private int e = 0;
    private boolean f = false;

    public PooledByteArrayBufferedInputStream(InputStream inputStream, byte[] bArr, ResourceReleaser<byte[]> resourceReleaser) {
        this.f1480a = (InputStream) Preconditions.a(inputStream);
        this.b = (byte[]) Preconditions.a(bArr);
        this.c = (ResourceReleaser) Preconditions.a(resourceReleaser);
    }

    @Override // java.io.InputStream
    public int read() throws IOException {
        Preconditions.b(this.e <= this.d);
        b();
        if (!a()) {
            return -1;
        }
        byte[] bArr = this.b;
        int i = this.e;
        this.e = i + 1;
        return bArr[i] & 255;
    }

    @Override // java.io.InputStream
    public int read(byte[] bArr, int i, int i2) throws IOException {
        Preconditions.b(this.e <= this.d);
        b();
        if (!a()) {
            return -1;
        }
        int min = Math.min(this.d - this.e, i2);
        System.arraycopy(this.b, this.e, bArr, i, min);
        this.e += min;
        return min;
    }

    @Override // java.io.InputStream
    public int available() throws IOException {
        Preconditions.b(this.e <= this.d);
        b();
        return (this.d - this.e) + this.f1480a.available();
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable, java.io.InputStream
    public void close() throws IOException {
        if (!this.f) {
            this.f = true;
            this.c.a(this.b);
            super.close();
        }
    }

    @Override // java.io.InputStream
    public long skip(long j) throws IOException {
        Preconditions.b(this.e <= this.d);
        b();
        long j2 = (long) (this.d - this.e);
        if (j2 >= j) {
            this.e = (int) (((long) this.e) + j);
            return j;
        }
        this.e = this.d;
        return j2 + this.f1480a.skip(j - j2);
    }

    private boolean a() throws IOException {
        if (this.e < this.d) {
            return true;
        }
        int read = this.f1480a.read(this.b);
        if (read <= 0) {
            return false;
        }
        this.d = read;
        this.e = 0;
        return true;
    }

    private void b() throws IOException {
        if (this.f) {
            throw new IOException("stream already closed");
        }
    }

    /* access modifiers changed from: protected */
    @Override // java.lang.Object
    public void finalize() throws Throwable {
        if (!this.f) {
            FLog.d("PooledByteInputStream", "Finalized without closing");
            close();
        }
        super.finalize();
    }
}
