package com.facebook.common.references;

import com.facebook.common.internal.Closeables;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.logging.FLog;
import java.io.Closeable;
import java.io.IOException;
import java.lang.ref.PhantomReference;
import java.lang.ref.ReferenceQueue;
import javax.annotation.Nullable;
import javax.annotation.concurrent.GuardedBy;

public abstract class CloseableReference<T> implements Closeable, Cloneable {

    /* renamed from: a  reason: collision with root package name */
    private static Class<CloseableReference> f1483a = CloseableReference.class;
    private static final ResourceReleaser<Closeable> b = new ResourceReleaser<Closeable>() {
        /* class com.facebook.common.references.CloseableReference.AnonymousClass1 */

        public void a(Closeable closeable) {
            try {
                Closeables.a(closeable, true);
            } catch (IOException unused) {
            }
        }
    };
    private static volatile boolean c = true;

    public abstract T a();

    /* renamed from: b */
    public abstract CloseableReference<T> clone();

    public abstract CloseableReference<T> c();

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public abstract void close();

    public abstract boolean d();

    public abstract int e();

    @Nullable
    public static <T extends Closeable> CloseableReference<T> a(@Nullable T t) {
        if (t == null) {
            return null;
        }
        return b(t, b);
    }

    @Nullable
    public static <T> CloseableReference<T> a(@Nullable T t, ResourceReleaser<T> resourceReleaser) {
        if (t == null) {
            return null;
        }
        return b(t, resourceReleaser);
    }

    private static <T> CloseableReference<T> b(@Nullable T t, ResourceReleaser<T> resourceReleaser) {
        if (c) {
            return new CloseableReferenceWithFinalizer(t, resourceReleaser);
        }
        return new CloseableReferenceWithoutFinalizer(t, resourceReleaser);
    }

    public static boolean a(@Nullable CloseableReference<?> closeableReference) {
        return closeableReference != null && closeableReference.d();
    }

    @Nullable
    public static <T> CloseableReference<T> b(@Nullable CloseableReference<T> closeableReference) {
        if (closeableReference != null) {
            return closeableReference.c();
        }
        return null;
    }

    public static void c(@Nullable CloseableReference<?> closeableReference) {
        if (closeableReference != null) {
            closeableReference.close();
        }
    }

    /* access modifiers changed from: private */
    public static class CloseableReferenceWithoutFinalizer<T> extends CloseableReference<T> {

        /* renamed from: a  reason: collision with root package name */
        private static final ReferenceQueue<CloseableReference> f1485a = new ReferenceQueue<>();
        private final SharedReference<T> b;
        private final Destructor c;

        /* access modifiers changed from: private */
        public static class Destructor extends PhantomReference<CloseableReference> {
            @GuardedBy

            /* renamed from: a  reason: collision with root package name */
            private static Destructor f1486a;
            private final SharedReference b;
            @GuardedBy
            private Destructor c;
            @GuardedBy
            private Destructor d;
            @GuardedBy
            private boolean e;

            public Destructor(CloseableReferenceWithoutFinalizer closeableReferenceWithoutFinalizer, ReferenceQueue<? super CloseableReference> referenceQueue) {
                super(closeableReferenceWithoutFinalizer, referenceQueue);
                this.b = closeableReferenceWithoutFinalizer.b;
                synchronized (Destructor.class) {
                    if (f1486a != null) {
                        f1486a.c = this;
                        this.d = f1486a;
                    }
                    f1486a = this;
                }
            }

            public synchronized boolean a() {
                return this.e;
            }

            /* JADX WARNING: Code restructure failed: missing block: B:12:0x0010, code lost:
                if (r5.d == null) goto L_0x0018;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:13:0x0012, code lost:
                r5.d.c = r5.c;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:15:0x001a, code lost:
                if (r5.c == null) goto L_0x0023;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:16:0x001c, code lost:
                r5.c.d = r5.d;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:17:0x0023, code lost:
                com.facebook.common.references.CloseableReference.CloseableReferenceWithoutFinalizer.Destructor.f1486a = r5.d;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:18:0x0027, code lost:
                monitor-exit(com.facebook.common.references.CloseableReference.CloseableReferenceWithoutFinalizer.Destructor.class);
             */
            /* JADX WARNING: Code restructure failed: missing block: B:19:0x0028, code lost:
                if (r6 != false) goto L_0x005e;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:20:0x002a, code lost:
                com.facebook.common.logging.FLog.b((java.lang.Class<?>) com.facebook.common.references.CloseableReference.f1483a, "GCed without closing: %x %x (type = %s)", java.lang.Integer.valueOf(java.lang.System.identityHashCode(r5)), java.lang.Integer.valueOf(java.lang.System.identityHashCode(r5.b)), r5.b.a().getClass().getSimpleName());
             */
            /* JADX WARNING: Code restructure failed: missing block: B:21:0x005e, code lost:
                r5.b.d();
             */
            /* JADX WARNING: Code restructure failed: missing block: B:22:0x0063, code lost:
                return;
             */
            /* JADX WARNING: Code restructure failed: missing block: B:9:0x000d, code lost:
                monitor-enter(com.facebook.common.references.CloseableReference.CloseableReferenceWithoutFinalizer.Destructor.class);
             */
            public void a(boolean z) {
                synchronized (this) {
                    if (!this.e) {
                        this.e = true;
                    }
                }
            }
        }

        static {
            new Thread(new Runnable() {
                /* class com.facebook.common.references.CloseableReference.CloseableReferenceWithoutFinalizer.AnonymousClass1 */

                /* JADX WARNING: Can't wrap try/catch for region: R(2:0|1) */
                /* JADX WARNING: Missing exception handler attribute for start block: B:0:0x0000 */
                /* JADX WARNING: Removed duplicated region for block: B:0:0x0000 A[LOOP:0: B:0:0x0000->B:1:?, LOOP_START, SYNTHETIC, Splitter:B:0:0x0000] */
                public void run() {
                    while (true) {
                        ((Destructor) CloseableReferenceWithoutFinalizer.f1485a.remove()).a(false);
                    }
                }
            }, "CloseableReferenceDestructorThread").start();
        }

        private CloseableReferenceWithoutFinalizer(SharedReference<T> sharedReference) {
            this.b = (SharedReference) Preconditions.a(sharedReference);
            sharedReference.c();
            this.c = new Destructor(this, f1485a);
        }

        private CloseableReferenceWithoutFinalizer(T t, ResourceReleaser<T> resourceReleaser) {
            this.b = new SharedReference<>(t, resourceReleaser);
            this.c = new Destructor(this, f1485a);
        }

        @Override // com.facebook.common.references.CloseableReference, java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            this.c.a(true);
        }

        @Override // com.facebook.common.references.CloseableReference
        public T a() {
            T a2;
            synchronized (this.c) {
                Preconditions.b(!this.c.a());
                a2 = this.b.a();
            }
            return a2;
        }

        @Override // com.facebook.common.references.CloseableReference
        /* renamed from: b */
        public CloseableReference<T> clone() {
            CloseableReferenceWithoutFinalizer closeableReferenceWithoutFinalizer;
            synchronized (this.c) {
                Preconditions.b(!this.c.a());
                closeableReferenceWithoutFinalizer = new CloseableReferenceWithoutFinalizer(this.b);
            }
            return closeableReferenceWithoutFinalizer;
        }

        @Override // com.facebook.common.references.CloseableReference
        public CloseableReference<T> c() {
            synchronized (this.c) {
                if (this.c.a()) {
                    return null;
                }
                return new CloseableReferenceWithoutFinalizer(this.b);
            }
        }

        @Override // com.facebook.common.references.CloseableReference
        public boolean d() {
            return !this.c.a();
        }

        @Override // com.facebook.common.references.CloseableReference
        public int e() {
            int identityHashCode;
            synchronized (this.c) {
                identityHashCode = d() ? System.identityHashCode(this.b.a()) : 0;
            }
            return identityHashCode;
        }
    }

    /* access modifiers changed from: private */
    public static class CloseableReferenceWithFinalizer<T> extends CloseableReference<T> {
        @GuardedBy

        /* renamed from: a  reason: collision with root package name */
        private boolean f1484a;
        private final SharedReference<T> b;

        private CloseableReferenceWithFinalizer(SharedReference<T> sharedReference) {
            this.f1484a = false;
            this.b = (SharedReference) Preconditions.a(sharedReference);
            sharedReference.c();
        }

        private CloseableReferenceWithFinalizer(T t, ResourceReleaser<T> resourceReleaser) {
            this.f1484a = false;
            this.b = new SharedReference<>(t, resourceReleaser);
        }

        /* access modifiers changed from: protected */
        @Override // java.lang.Object
        public void finalize() throws Throwable {
            try {
                synchronized (this) {
                    if (!this.f1484a) {
                        FLog.b((Class<?>) CloseableReference.f1483a, "Finalized without closing: %x %x (type = %s)", Integer.valueOf(System.identityHashCode(this)), Integer.valueOf(System.identityHashCode(this.b)), this.b.a().getClass().getSimpleName());
                        close();
                        super.finalize();
                    }
                }
            } finally {
                super.finalize();
            }
        }

        @Override // com.facebook.common.references.CloseableReference
        public synchronized T a() {
            Preconditions.b(!this.f1484a);
            return this.b.a();
        }

        @Override // com.facebook.common.references.CloseableReference
        /* renamed from: b */
        public synchronized CloseableReference<T> clone() {
            Preconditions.b(d());
            return new CloseableReferenceWithFinalizer(this.b);
        }

        @Override // com.facebook.common.references.CloseableReference
        public synchronized CloseableReference<T> c() {
            if (!d()) {
                return null;
            }
            return clone();
        }

        @Override // com.facebook.common.references.CloseableReference
        public synchronized boolean d() {
            return !this.f1484a;
        }

        @Override // com.facebook.common.references.CloseableReference
        public int e() {
            if (d()) {
                return System.identityHashCode(this.b.a());
            }
            return 0;
        }

        @Override // com.facebook.common.references.CloseableReference, java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            synchronized (this) {
                if (!this.f1484a) {
                    this.f1484a = true;
                    this.b.d();
                }
            }
        }
    }
}
