package com.facebook.drawee.backends.pipeline;

import android.content.res.Resources;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import com.facebook.cache.common.CacheKey;
import com.facebook.common.internal.ImmutableList;
import com.facebook.common.internal.Objects;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.internal.Supplier;
import com.facebook.common.logging.FLog;
import com.facebook.common.references.CloseableReference;
import com.facebook.datasource.DataSource;
import com.facebook.drawable.base.DrawableWithCaches;
import com.facebook.drawee.components.DeferredReleaser;
import com.facebook.drawee.controller.AbstractDraweeController;
import com.facebook.drawee.debug.DebugControllerOverlayDrawable;
import com.facebook.drawee.drawable.OrientedDrawable;
import com.facebook.drawee.drawable.ScaleTypeDrawable;
import com.facebook.drawee.drawable.ScalingUtils;
import com.facebook.drawee.interfaces.DraweeHierarchy;
import com.facebook.imagepipeline.animated.factory.AnimatedDrawableFactory;
import com.facebook.imagepipeline.cache.MemoryCache;
import com.facebook.imagepipeline.image.CloseableImage;
import com.facebook.imagepipeline.image.CloseableStaticBitmap;
import com.facebook.imagepipeline.image.ImageInfo;
import java.util.Iterator;
import java.util.concurrent.Executor;
import javax.annotation.Nullable;

public class PipelineDraweeController extends AbstractDraweeController<CloseableReference<CloseableImage>, ImageInfo> {

    /* renamed from: a  reason: collision with root package name */
    private static final Class<?> f1519a = PipelineDraweeController.class;
    private final Resources b;
    private final AnimatedDrawableFactory c;
    @Nullable
    private final ImmutableList<DrawableFactory> d;
    @Nullable
    private MemoryCache<CacheKey, CloseableImage> e;
    private CacheKey f;
    private Supplier<DataSource<CloseableReference<CloseableImage>>> g;
    private boolean h;
    private final DrawableFactory i = new DrawableFactory() {
        /* class com.facebook.drawee.backends.pipeline.PipelineDraweeController.AnonymousClass1 */

        @Override // com.facebook.drawee.backends.pipeline.DrawableFactory
        public boolean a(CloseableImage closeableImage) {
            return true;
        }

        @Override // com.facebook.drawee.backends.pipeline.DrawableFactory
        public Drawable b(CloseableImage closeableImage) {
            if (closeableImage instanceof CloseableStaticBitmap) {
                CloseableStaticBitmap closeableStaticBitmap = (CloseableStaticBitmap) closeableImage;
                BitmapDrawable bitmapDrawable = new BitmapDrawable(PipelineDraweeController.this.b, closeableStaticBitmap.a());
                return (closeableStaticBitmap.h() == 0 || closeableStaticBitmap.h() == -1) ? bitmapDrawable : new OrientedDrawable(bitmapDrawable, closeableStaticBitmap.h());
            } else if (PipelineDraweeController.this.c != null) {
                return PipelineDraweeController.this.c.a(closeableImage);
            } else {
                return null;
            }
        }
    };

    public PipelineDraweeController(Resources resources, DeferredReleaser deferredReleaser, AnimatedDrawableFactory animatedDrawableFactory, Executor executor, MemoryCache<CacheKey, CloseableImage> memoryCache, Supplier<DataSource<CloseableReference<CloseableImage>>> supplier, String str, CacheKey cacheKey, Object obj, @Nullable ImmutableList<DrawableFactory> immutableList) {
        super(deferredReleaser, executor, str, obj);
        this.b = resources;
        this.c = animatedDrawableFactory;
        this.e = memoryCache;
        this.f = cacheKey;
        this.d = immutableList;
        a(supplier);
    }

    public void a(Supplier<DataSource<CloseableReference<CloseableImage>>> supplier, String str, CacheKey cacheKey, Object obj) {
        super.a(str, obj);
        a(supplier);
        this.f = cacheKey;
    }

    public void a(boolean z) {
        this.h = z;
    }

    private void a(Supplier<DataSource<CloseableReference<CloseableImage>>> supplier) {
        this.g = supplier;
        a((CloseableImage) null);
    }

    /* access modifiers changed from: protected */
    @Override // com.facebook.drawee.controller.AbstractDraweeController
    public DataSource<CloseableReference<CloseableImage>> a() {
        if (FLog.a(2)) {
            FLog.a(f1519a, "controller %x: getDataSource", Integer.valueOf(System.identityHashCode(this)));
        }
        return this.g.b();
    }

    /* access modifiers changed from: protected */
    /* renamed from: a */
    public Drawable d(CloseableReference<CloseableImage> closeableReference) {
        Drawable b2;
        Preconditions.b(CloseableReference.a((CloseableReference<?>) closeableReference));
        CloseableImage a2 = closeableReference.a();
        a(a2);
        if (this.d != null) {
            Iterator<DrawableFactory> it = this.d.iterator();
            while (it.hasNext()) {
                DrawableFactory next = it.next();
                if (next.a(a2) && (b2 = next.b(a2)) != null) {
                    return b2;
                }
            }
        }
        Drawable b3 = this.i.b(a2);
        if (b3 != null) {
            return b3;
        }
        throw new UnsupportedOperationException("Unrecognized image class: " + a2);
    }

    @Override // com.facebook.drawee.interfaces.DraweeController, com.facebook.drawee.controller.AbstractDraweeController
    public void a(@Nullable DraweeHierarchy draweeHierarchy) {
        super.a(draweeHierarchy);
        a((CloseableImage) null);
    }

    private void a(@Nullable CloseableImage closeableImage) {
        ScaleTypeDrawable a2;
        if (this.h) {
            Drawable j = j();
            if (j == null) {
                j = new DebugControllerOverlayDrawable();
                b(j);
            }
            if (j instanceof DebugControllerOverlayDrawable) {
                DebugControllerOverlayDrawable debugControllerOverlayDrawable = (DebugControllerOverlayDrawable) j;
                debugControllerOverlayDrawable.a(e());
                DraweeHierarchy i2 = i();
                ScalingUtils.ScaleType scaleType = null;
                if (!(i2 == null || (a2 = ScalingUtils.a(i2.a())) == null)) {
                    scaleType = a2.b();
                }
                debugControllerOverlayDrawable.a(scaleType);
                if (closeableImage != null) {
                    debugControllerOverlayDrawable.a(closeableImage.f(), closeableImage.g());
                    debugControllerOverlayDrawable.a(closeableImage.b());
                    return;
                }
                debugControllerOverlayDrawable.a();
            }
        }
    }

    /* access modifiers changed from: protected */
    /* renamed from: b */
    public ImageInfo c(CloseableReference<CloseableImage> closeableReference) {
        Preconditions.b(CloseableReference.a((CloseableReference<?>) closeableReference));
        return closeableReference.a();
    }

    /* access modifiers changed from: protected */
    /* renamed from: c */
    public int b(@Nullable CloseableReference<CloseableImage> closeableReference) {
        if (closeableReference != null) {
            return closeableReference.e();
        }
        return 0;
    }

    /* access modifiers changed from: protected */
    /* renamed from: d */
    public void a(@Nullable CloseableReference<CloseableImage> closeableReference) {
        CloseableReference.c(closeableReference);
    }

    /* access modifiers changed from: protected */
    @Override // com.facebook.drawee.controller.AbstractDraweeController
    public void a(@Nullable Drawable drawable) {
        if (drawable instanceof DrawableWithCaches) {
            ((DrawableWithCaches) drawable).a();
        }
    }

    /* access modifiers changed from: protected */
    /* renamed from: b */
    public CloseableReference<CloseableImage> c() {
        if (this.e == null || this.f == null) {
            return null;
        }
        CloseableReference<CloseableImage> a2 = this.e.a(this.f);
        if (a2 == null || a2.a().d().c()) {
            return a2;
        }
        a2.close();
        return null;
    }

    @Override // com.facebook.drawee.controller.AbstractDraweeController
    public String toString() {
        return Objects.a(this).a("super", super.toString()).a("dataSourceSupplier", this.g).toString();
    }
}
