package com.facebook.drawee.controller;

import android.graphics.drawable.Animatable;
import android.graphics.drawable.Drawable;
import android.view.MotionEvent;
import com.facebook.common.internal.Objects;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.logging.FLog;
import com.facebook.datasource.BaseDataSubscriber;
import com.facebook.datasource.DataSource;
import com.facebook.drawee.components.DeferredReleaser;
import com.facebook.drawee.components.DraweeEventTracker;
import com.facebook.drawee.components.RetryManager;
import com.facebook.drawee.gestures.GestureDetector;
import com.facebook.drawee.interfaces.DraweeController;
import com.facebook.drawee.interfaces.DraweeHierarchy;
import com.facebook.drawee.interfaces.SettableDraweeHierarchy;
import java.util.concurrent.Executor;
import javax.annotation.Nullable;
import javax.annotation.concurrent.NotThreadSafe;

@NotThreadSafe
public abstract class AbstractDraweeController<T, INFO> implements DeferredReleaser.Releasable, GestureDetector.ClickListener, DraweeController {

    /* renamed from: a  reason: collision with root package name */
    private static final Class<?> f1530a = AbstractDraweeController.class;
    private final DraweeEventTracker b = DraweeEventTracker.a();
    private final DeferredReleaser c;
    private final Executor d;
    @Nullable
    private RetryManager e;
    @Nullable
    private GestureDetector f;
    @Nullable
    private ControllerListener<INFO> g;
    @Nullable
    private ControllerViewportVisibilityListener h;
    @Nullable
    private SettableDraweeHierarchy i;
    @Nullable
    private Drawable j;
    private String k;
    private Object l;
    private boolean m;
    private boolean n;
    private boolean o;
    private boolean p;
    private boolean q;
    @Nullable
    private String r;
    @Nullable
    private DataSource<T> s;
    @Nullable
    private T t;
    @Nullable
    private Drawable u;

    /* access modifiers changed from: protected */
    public abstract DataSource<T> a();

    /* access modifiers changed from: protected */
    public abstract void a(@Nullable Drawable drawable);

    /* access modifiers changed from: protected */
    public abstract void a(@Nullable T t2);

    /* access modifiers changed from: protected */
    public T c() {
        return null;
    }

    /* access modifiers changed from: protected */
    @Nullable
    public abstract INFO c(T t2);

    /* access modifiers changed from: protected */
    public abstract Drawable d(T t2);

    /* access modifiers changed from: private */
    public static class InternalForwardingListener<INFO> extends ForwardingControllerListener<INFO> {
        private InternalForwardingListener() {
        }

        public static <INFO> InternalForwardingListener<INFO> a(ControllerListener<? super INFO> controllerListener, ControllerListener<? super INFO> controllerListener2) {
            InternalForwardingListener<INFO> internalForwardingListener = new InternalForwardingListener<>();
            internalForwardingListener.a(controllerListener);
            internalForwardingListener.a(controllerListener2);
            return internalForwardingListener;
        }
    }

    public AbstractDraweeController(DeferredReleaser deferredReleaser, Executor executor, String str, Object obj) {
        this.c = deferredReleaser;
        this.d = executor;
        a(str, obj, true);
    }

    /* access modifiers changed from: protected */
    public void a(String str, Object obj) {
        a(str, obj, false);
    }

    private void a(String str, Object obj, boolean z) {
        this.b.a(DraweeEventTracker.Event.ON_INIT_CONTROLLER);
        if (!z && this.c != null) {
            this.c.b(this);
        }
        this.m = false;
        this.o = false;
        b();
        this.q = false;
        if (this.e != null) {
            this.e.a();
        }
        if (this.f != null) {
            this.f.a();
            this.f.a(this);
        }
        if (this.g instanceof InternalForwardingListener) {
            ((InternalForwardingListener) this.g).a();
        } else {
            this.g = null;
        }
        this.h = null;
        if (this.i != null) {
            this.i.b();
            this.i.a((Drawable) null);
            this.i = null;
        }
        this.j = null;
        if (FLog.a(2)) {
            FLog.a(f1530a, "controller %x %s -> %s: initialize", Integer.valueOf(System.identityHashCode(this)), this.k, str);
        }
        this.k = str;
        this.l = obj;
    }

    @Override // com.facebook.drawee.components.DeferredReleaser.Releasable
    public void d() {
        this.b.a(DraweeEventTracker.Event.ON_RELEASE_CONTROLLER);
        if (this.e != null) {
            this.e.b();
        }
        if (this.f != null) {
            this.f.b();
        }
        if (this.i != null) {
            this.i.b();
        }
        b();
    }

    private void b() {
        boolean z = this.n;
        this.n = false;
        this.p = false;
        if (this.s != null) {
            this.s.h();
            this.s = null;
        }
        if (this.u != null) {
            a(this.u);
        }
        if (this.r != null) {
            this.r = null;
        }
        this.u = null;
        if (this.t != null) {
            b("release", this.t);
            a((Object) this.t);
            this.t = null;
        }
        if (z) {
            h().a(this.k);
        }
    }

    public String e() {
        return this.k;
    }

    /* access modifiers changed from: protected */
    @Nullable
    public RetryManager f() {
        return this.e;
    }

    /* access modifiers changed from: protected */
    public void a(@Nullable RetryManager retryManager) {
        this.e = retryManager;
    }

    /* access modifiers changed from: protected */
    @Nullable
    public GestureDetector g() {
        return this.f;
    }

    /* access modifiers changed from: protected */
    public void a(@Nullable GestureDetector gestureDetector) {
        this.f = gestureDetector;
        if (this.f != null) {
            this.f.a(this);
        }
    }

    /* access modifiers changed from: protected */
    public void b(boolean z) {
        this.q = z;
    }

    public void a(@Nullable String str) {
        this.r = str;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: com.facebook.drawee.controller.ControllerListener<? super INFO> */
    /* JADX WARN: Multi-variable type inference failed */
    public void a(ControllerListener<? super INFO> controllerListener) {
        Preconditions.a(controllerListener);
        if (this.g instanceof InternalForwardingListener) {
            ((InternalForwardingListener) this.g).a(controllerListener);
        } else if (this.g != null) {
            this.g = InternalForwardingListener.a(this.g, controllerListener);
        } else {
            this.g = controllerListener;
        }
    }

    /* access modifiers changed from: protected */
    public ControllerListener<INFO> h() {
        if (this.g == null) {
            return BaseControllerListener.a();
        }
        return this.g;
    }

    public void a(@Nullable ControllerViewportVisibilityListener controllerViewportVisibilityListener) {
        this.h = controllerViewportVisibilityListener;
    }

    @Override // com.facebook.drawee.interfaces.DraweeController
    @Nullable
    public DraweeHierarchy i() {
        return this.i;
    }

    @Override // com.facebook.drawee.interfaces.DraweeController
    public void a(@Nullable DraweeHierarchy draweeHierarchy) {
        if (FLog.a(2)) {
            FLog.a(f1530a, "controller %x %s: setHierarchy: %s", Integer.valueOf(System.identityHashCode(this)), this.k, draweeHierarchy);
        }
        this.b.a(draweeHierarchy != null ? DraweeEventTracker.Event.ON_SET_HIERARCHY : DraweeEventTracker.Event.ON_CLEAR_HIERARCHY);
        if (this.n) {
            this.c.b(this);
            d();
        }
        if (this.i != null) {
            this.i.a((Drawable) null);
            this.i = null;
        }
        if (draweeHierarchy != null) {
            Preconditions.a(draweeHierarchy instanceof SettableDraweeHierarchy);
            this.i = (SettableDraweeHierarchy) draweeHierarchy;
            this.i.a(this.j);
        }
    }

    /* access modifiers changed from: protected */
    public void b(@Nullable Drawable drawable) {
        this.j = drawable;
        if (this.i != null) {
            this.i.a(this.j);
        }
    }

    /* access modifiers changed from: protected */
    @Nullable
    public Drawable j() {
        return this.j;
    }

    @Override // com.facebook.drawee.interfaces.DraweeController
    public void k() {
        if (FLog.a(2)) {
            FLog.a(f1530a, "controller %x %s: onAttach: %s", Integer.valueOf(System.identityHashCode(this)), this.k, this.n ? "request already submitted" : "request needs submit");
        }
        this.b.a(DraweeEventTracker.Event.ON_ATTACH_CONTROLLER);
        Preconditions.a(this.i);
        this.c.b(this);
        this.m = true;
        if (!this.n) {
            o();
        }
    }

    @Override // com.facebook.drawee.interfaces.DraweeController
    public void l() {
        if (FLog.a(2)) {
            FLog.a(f1530a, "controller %x %s: onDetach", Integer.valueOf(System.identityHashCode(this)), this.k);
        }
        this.b.a(DraweeEventTracker.Event.ON_DETACH_CONTROLLER);
        this.m = false;
        this.c.a(this);
    }

    @Override // com.facebook.drawee.interfaces.DraweeController
    public boolean a(MotionEvent motionEvent) {
        if (FLog.a(2)) {
            FLog.a(f1530a, "controller %x %s: onTouchEvent %s", Integer.valueOf(System.identityHashCode(this)), this.k, motionEvent);
        }
        if (this.f == null) {
            return false;
        }
        if (!this.f.c() && !m()) {
            return false;
        }
        this.f.a(motionEvent);
        return true;
    }

    /* access modifiers changed from: protected */
    public boolean m() {
        return q();
    }

    private boolean q() {
        return this.p && this.e != null && this.e.c();
    }

    @Override // com.facebook.drawee.gestures.GestureDetector.ClickListener
    public boolean n() {
        if (FLog.a(2)) {
            FLog.a(f1530a, "controller %x %s: onClick", Integer.valueOf(System.identityHashCode(this)), this.k);
        }
        if (!q()) {
            return false;
        }
        this.e.d();
        this.i.b();
        o();
        return true;
    }

    /* access modifiers changed from: protected */
    public void o() {
        T c2 = c();
        if (c2 != null) {
            this.s = null;
            this.n = true;
            this.p = false;
            this.b.a(DraweeEventTracker.Event.ON_SUBMIT_CACHE_HIT);
            h().a(this.k, this.l);
            a(this.k, this.s, c2, 1.0f, true, true);
            return;
        }
        this.b.a(DraweeEventTracker.Event.ON_DATASOURCE_SUBMIT);
        h().a(this.k, this.l);
        this.i.a(0.0f, true);
        this.n = true;
        this.p = false;
        this.s = a();
        if (FLog.a(2)) {
            FLog.a(f1530a, "controller %x %s: submitRequest: dataSource: %x", Integer.valueOf(System.identityHashCode(this)), this.k, Integer.valueOf(System.identityHashCode(this.s)));
        }
        final String str = this.k;
        final boolean c3 = this.s.c();
        this.s.a(new BaseDataSubscriber<T>() {
            /* class com.facebook.drawee.controller.AbstractDraweeController.AnonymousClass1 */

            @Override // com.facebook.datasource.BaseDataSubscriber
            public void e(DataSource<T> dataSource) {
                boolean b2 = dataSource.b();
                float g = dataSource.g();
                T d = dataSource.d();
                if (d != null) {
                    AbstractDraweeController.this.a(str, dataSource, d, g, b2, c3);
                } else if (b2) {
                    AbstractDraweeController.this.a((AbstractDraweeController) str, (String) dataSource, (DataSource) new NullPointerException(), (Throwable) true);
                }
            }

            @Override // com.facebook.datasource.BaseDataSubscriber
            public void f(DataSource<T> dataSource) {
                AbstractDraweeController.this.a((AbstractDraweeController) str, (String) dataSource, (DataSource) dataSource.f(), (Throwable) true);
            }

            @Override // com.facebook.datasource.BaseDataSubscriber, com.facebook.datasource.DataSubscriber
            public void d(DataSource<T> dataSource) {
                boolean b2 = dataSource.b();
                AbstractDraweeController.this.a((AbstractDraweeController) str, (String) dataSource, (DataSource) dataSource.g(), (float) b2);
            }
        }, this.d);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void a(String str, DataSource<T> dataSource, @Nullable T t2, float f2, boolean z, boolean z2) {
        if (!a(str, (DataSource) dataSource)) {
            b("ignore_old_datasource @ onNewResult", t2);
            a((Object) t2);
            dataSource.h();
            return;
        }
        this.b.a(z ? DraweeEventTracker.Event.ON_DATASOURCE_RESULT : DraweeEventTracker.Event.ON_DATASOURCE_RESULT_INT);
        try {
            Drawable d2 = d(t2);
            T t3 = this.t;
            Drawable drawable = this.u;
            this.t = t2;
            this.u = d2;
            if (z) {
                try {
                    b("set_final_result @ onNewResult", t2);
                    this.s = null;
                    this.i.a(d2, 1.0f, z2);
                    h().a(str, c(t2), p());
                } finally {
                    if (!(drawable == null || drawable == d2)) {
                        a(drawable);
                    }
                    if (!(t3 == null || t3 == t2)) {
                        b("release_previous_result @ onNewResult", t3);
                        a((Object) t3);
                    }
                }
            } else {
                b("set_intermediate_result @ onNewResult", t2);
                this.i.a(d2, f2, z2);
                h().b(str, (Object) c(t2));
            }
        } catch (Exception e2) {
            b("drawable_failed @ onNewResult", t2);
            a((Object) t2);
            a(str, dataSource, e2, z);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void a(String str, DataSource<T> dataSource, Throwable th, boolean z) {
        if (!a(str, (DataSource) dataSource)) {
            a("ignore_old_datasource @ onFailure", th);
            dataSource.h();
            return;
        }
        this.b.a(z ? DraweeEventTracker.Event.ON_DATASOURCE_FAILURE : DraweeEventTracker.Event.ON_DATASOURCE_FAILURE_INT);
        if (z) {
            a("final_failed @ onFailure", th);
            this.s = null;
            this.p = true;
            if (this.q && this.u != null) {
                this.i.a(this.u, 1.0f, true);
            } else if (q()) {
                this.i.b(th);
            } else {
                this.i.a(th);
            }
            h().b(this.k, th);
            return;
        }
        a("intermediate_failed @ onFailure", th);
        h().a(this.k, th);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void a(String str, DataSource<T> dataSource, float f2, boolean z) {
        if (!a(str, (DataSource) dataSource)) {
            a("ignore_old_datasource @ onProgress", (Throwable) null);
            dataSource.h();
        } else if (!z) {
            this.i.a(f2, false);
        }
    }

    private boolean a(String str, DataSource<T> dataSource) {
        if (dataSource == null && this.s == null) {
            return true;
        }
        if (!str.equals(this.k) || dataSource != this.s || !this.n) {
            return false;
        }
        return true;
    }

    private void b(String str, T t2) {
        if (FLog.a(2)) {
            FLog.a(f1530a, "controller %x %s: %s: image: %s %x", Integer.valueOf(System.identityHashCode(this)), this.k, str, e(t2), Integer.valueOf(b((Object) t2)));
        }
    }

    private void a(String str, Throwable th) {
        if (FLog.a(2)) {
            FLog.a(f1530a, "controller %x %s: %s: failure: %s", Integer.valueOf(System.identityHashCode(this)), this.k, str, th);
        }
    }

    @Nullable
    public Animatable p() {
        if (this.u instanceof Animatable) {
            return (Animatable) this.u;
        }
        return null;
    }

    /* access modifiers changed from: protected */
    public String e(@Nullable T t2) {
        return t2 != null ? t2.getClass().getSimpleName() : "<null>";
    }

    /* access modifiers changed from: protected */
    public int b(@Nullable T t2) {
        return System.identityHashCode(t2);
    }

    public String toString() {
        return Objects.a(this).a("isAttached", this.m).a("isRequestSubmitted", this.n).a("hasFetchFailed", this.p).a("fetchedImage", b((Object) this.t)).a("events", this.b.toString()).toString();
    }
}
