package com.facebook.drawee.controller;

import android.content.Context;
import android.graphics.drawable.Animatable;
import com.facebook.common.internal.Objects;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.internal.Supplier;
import com.facebook.datasource.DataSource;
import com.facebook.datasource.DataSources;
import com.facebook.datasource.FirstAvailableDataSourceSupplier;
import com.facebook.datasource.IncreasingQualityDataSourceSupplier;
import com.facebook.drawee.components.RetryManager;
import com.facebook.drawee.controller.AbstractDraweeControllerBuilder;
import com.facebook.drawee.gestures.GestureDetector;
import com.facebook.drawee.interfaces.DraweeController;
import com.facebook.drawee.interfaces.SimpleDraweeControllerBuilder;
import com.facebook.infer.annotation.ReturnsOwnership;
import java.util.ArrayList;
import java.util.Set;
import java.util.concurrent.atomic.AtomicLong;
import javax.annotation.Nullable;

public abstract class AbstractDraweeControllerBuilder<BUILDER extends AbstractDraweeControllerBuilder<BUILDER, REQUEST, IMAGE, INFO>, REQUEST, IMAGE, INFO> implements SimpleDraweeControllerBuilder {

    /* renamed from: a  reason: collision with root package name */
    private static final ControllerListener<Object> f1532a = new BaseControllerListener<Object>() {
        /* class com.facebook.drawee.controller.AbstractDraweeControllerBuilder.AnonymousClass1 */

        @Override // com.facebook.drawee.controller.ControllerListener, com.facebook.drawee.controller.BaseControllerListener
        public void a(String str, @Nullable Object obj, @Nullable Animatable animatable) {
            if (animatable != null) {
                animatable.start();
            }
        }
    };
    private static final NullPointerException b = new NullPointerException("No image request was specified!");
    private static final AtomicLong r = new AtomicLong();
    private final Context c;
    private final Set<ControllerListener> d;
    @Nullable
    private Object e;
    @Nullable
    private REQUEST f;
    @Nullable
    private REQUEST g;
    @Nullable
    private REQUEST[] h;
    private boolean i;
    @Nullable
    private Supplier<DataSource<IMAGE>> j;
    @Nullable
    private ControllerListener<? super INFO> k;
    @Nullable
    private ControllerViewportVisibilityListener l;
    private boolean m;
    private boolean n;
    private boolean o;
    private String p;
    @Nullable
    private DraweeController q;

    public enum CacheLevel {
        FULL_FETCH,
        DISK_CACHE,
        BITMAP_MEMORY_CACHE
    }

    /* access modifiers changed from: protected */
    public abstract DataSource<IMAGE> a(REQUEST request, Object obj, CacheLevel cacheLevel);

    /* access modifiers changed from: protected */
    public abstract BUILDER c();

    /* access modifiers changed from: protected */
    @ReturnsOwnership
    public abstract AbstractDraweeController d();

    protected AbstractDraweeControllerBuilder(Context context, Set<ControllerListener> set) {
        this.c = context;
        this.d = set;
        a();
    }

    private void a() {
        this.e = null;
        this.f = null;
        this.g = null;
        this.h = null;
        this.i = true;
        this.k = null;
        this.l = null;
        this.m = false;
        this.n = false;
        this.q = null;
        this.p = null;
    }

    public BUILDER e() {
        a();
        return c();
    }

    /* renamed from: a */
    public BUILDER e(Object obj) {
        this.e = obj;
        return c();
    }

    @Nullable
    public Object f() {
        return this.e;
    }

    public BUILDER b(REQUEST request) {
        this.f = request;
        return c();
    }

    @Nullable
    public REQUEST g() {
        return this.f;
    }

    public BUILDER c(REQUEST request) {
        this.g = request;
        return c();
    }

    public boolean h() {
        return this.o;
    }

    public BUILDER a(boolean z) {
        this.n = z;
        return c();
    }

    public BUILDER a(ControllerListener<? super INFO> controllerListener) {
        this.k = controllerListener;
        return c();
    }

    @Nullable
    public ControllerViewportVisibilityListener i() {
        return this.l;
    }

    @Nullable
    public String j() {
        return this.p;
    }

    /* renamed from: a */
    public BUILDER b(@Nullable DraweeController draweeController) {
        this.q = draweeController;
        return c();
    }

    @Nullable
    public DraweeController k() {
        return this.q;
    }

    /* renamed from: l */
    public AbstractDraweeController q() {
        m();
        if (this.f == null && this.h == null && this.g != null) {
            this.f = this.g;
            this.g = null;
        }
        return n();
    }

    /* access modifiers changed from: protected */
    public void m() {
        boolean z = false;
        Preconditions.b(this.h == null || this.f == null, "Cannot specify both ImageRequest and FirstAvailableImageRequests!");
        if (this.j == null || (this.h == null && this.f == null && this.g == null)) {
            z = true;
        }
        Preconditions.b(z, "Cannot specify DataSourceSupplier with other ImageRequests! Use one or the other.");
    }

    /* access modifiers changed from: protected */
    public AbstractDraweeController n() {
        AbstractDraweeController d2 = d();
        d2.b(h());
        d2.a(j());
        d2.a(i());
        b(d2);
        a(d2);
        return d2;
    }

    protected static String o() {
        return String.valueOf(r.getAndIncrement());
    }

    /* access modifiers changed from: protected */
    public Supplier<DataSource<IMAGE>> p() {
        if (this.j != null) {
            return this.j;
        }
        Supplier<DataSource<IMAGE>> supplier = null;
        if (this.f != null) {
            supplier = d(this.f);
        } else if (this.h != null) {
            supplier = a(this.h, this.i);
        }
        if (!(supplier == null || this.g == null)) {
            ArrayList arrayList = new ArrayList(2);
            arrayList.add(supplier);
            arrayList.add(d(this.g));
            supplier = IncreasingQualityDataSourceSupplier.a(arrayList);
        }
        return supplier == null ? DataSources.b(b) : supplier;
    }

    /* access modifiers changed from: protected */
    public Supplier<DataSource<IMAGE>> a(REQUEST[] requestArr, boolean z) {
        ArrayList arrayList = new ArrayList(requestArr.length * 2);
        if (z) {
            for (REQUEST request : requestArr) {
                arrayList.add(a(request, CacheLevel.BITMAP_MEMORY_CACHE));
            }
        }
        for (REQUEST request2 : requestArr) {
            arrayList.add(d(request2));
        }
        return FirstAvailableDataSourceSupplier.a(arrayList);
    }

    /* access modifiers changed from: protected */
    public Supplier<DataSource<IMAGE>> d(REQUEST request) {
        return a(request, CacheLevel.FULL_FETCH);
    }

    /* access modifiers changed from: protected */
    public Supplier<DataSource<IMAGE>> a(final REQUEST request, final CacheLevel cacheLevel) {
        final Object f2 = f();
        return new Supplier<DataSource<IMAGE>>() {
            /* class com.facebook.drawee.controller.AbstractDraweeControllerBuilder.AnonymousClass2 */

            /* JADX DEBUG: Multi-variable search result rejected for r0v0, resolved type: com.facebook.drawee.controller.AbstractDraweeControllerBuilder */
            /* JADX WARN: Multi-variable type inference failed */
            /* renamed from: a */
            public DataSource<IMAGE> b() {
                return AbstractDraweeControllerBuilder.this.a(request, f2, cacheLevel);
            }

            public String toString() {
                return Objects.a(this).a("request", request.toString()).toString();
            }
        };
    }

    /* access modifiers changed from: protected */
    public void a(AbstractDraweeController abstractDraweeController) {
        if (this.d != null) {
            for (ControllerListener controllerListener : this.d) {
                abstractDraweeController.a(controllerListener);
            }
        }
        if (this.k != null) {
            abstractDraweeController.a((ControllerListener) this.k);
        }
        if (this.n) {
            abstractDraweeController.a((ControllerListener) f1532a);
        }
    }

    /* access modifiers changed from: protected */
    public void b(AbstractDraweeController abstractDraweeController) {
        if (this.m) {
            RetryManager f2 = abstractDraweeController.f();
            if (f2 == null) {
                f2 = new RetryManager();
                abstractDraweeController.a(f2);
            }
            f2.a(this.m);
            c(abstractDraweeController);
        }
    }

    /* access modifiers changed from: protected */
    public void c(AbstractDraweeController abstractDraweeController) {
        if (abstractDraweeController.g() == null) {
            abstractDraweeController.a(GestureDetector.a(this.c));
        }
    }
}
