package com.facebook.drawee.drawable;

import android.annotation.TargetApi;
import android.graphics.Canvas;
import android.graphics.ColorFilter;
import android.graphics.Matrix;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.drawable.Drawable;
import com.facebook.common.internal.Preconditions;
import javax.annotation.Nullable;

public class ArrayDrawable extends Drawable implements Drawable.Callback, TransformAwareDrawable, TransformCallback {

    /* renamed from: a  reason: collision with root package name */
    private TransformCallback f1538a;
    private final DrawableProperties b = new DrawableProperties();
    private final Drawable[] c;
    private final DrawableParent[] d;
    private final Rect e = new Rect();
    private boolean f;
    private boolean g;
    private boolean h;

    public ArrayDrawable(Drawable[] drawableArr) {
        this.f = false;
        this.g = false;
        this.h = false;
        Preconditions.a(drawableArr);
        this.c = drawableArr;
        for (int i = 0; i < this.c.length; i++) {
            DrawableUtils.a(this.c[i], this, this);
        }
        this.d = new DrawableParent[this.c.length];
    }

    public int a() {
        return this.c.length;
    }

    @Nullable
    public Drawable a(int i) {
        boolean z = false;
        Preconditions.a(i >= 0);
        if (i < this.c.length) {
            z = true;
        }
        Preconditions.a(z);
        return this.c[i];
    }

    @Nullable
    public Drawable a(int i, @Nullable Drawable drawable) {
        boolean z = true;
        Preconditions.a(i >= 0);
        if (i >= this.c.length) {
            z = false;
        }
        Preconditions.a(z);
        Drawable drawable2 = this.c[i];
        if (drawable != drawable2) {
            if (drawable != null && this.h) {
                drawable.mutate();
            }
            DrawableUtils.a(this.c[i], null, null);
            DrawableUtils.a(drawable, null, null);
            DrawableUtils.a(drawable, this.b);
            DrawableUtils.a(drawable, this);
            DrawableUtils.a(drawable, this, this);
            this.g = false;
            this.c[i] = drawable;
            invalidateSelf();
        }
        return drawable2;
    }

    public int getIntrinsicWidth() {
        int i = -1;
        for (int i2 = 0; i2 < this.c.length; i2++) {
            Drawable drawable = this.c[i2];
            if (drawable != null) {
                i = Math.max(i, drawable.getIntrinsicWidth());
            }
        }
        if (i > 0) {
            return i;
        }
        return -1;
    }

    public int getIntrinsicHeight() {
        int i = -1;
        for (int i2 = 0; i2 < this.c.length; i2++) {
            Drawable drawable = this.c[i2];
            if (drawable != null) {
                i = Math.max(i, drawable.getIntrinsicHeight());
            }
        }
        if (i > 0) {
            return i;
        }
        return -1;
    }

    /* access modifiers changed from: protected */
    public void onBoundsChange(Rect rect) {
        for (int i = 0; i < this.c.length; i++) {
            Drawable drawable = this.c[i];
            if (drawable != null) {
                drawable.setBounds(rect);
            }
        }
    }

    public boolean isStateful() {
        if (!this.g) {
            this.f = false;
            int i = 0;
            while (true) {
                boolean z = true;
                if (i >= this.c.length) {
                    break;
                }
                Drawable drawable = this.c[i];
                boolean z2 = this.f;
                if (drawable == null || !drawable.isStateful()) {
                    z = false;
                }
                this.f = z2 | z;
                i++;
            }
            this.g = true;
        }
        return this.f;
    }

    /* access modifiers changed from: protected */
    public boolean onStateChange(int[] iArr) {
        boolean z = false;
        for (int i = 0; i < this.c.length; i++) {
            Drawable drawable = this.c[i];
            if (drawable != null && drawable.setState(iArr)) {
                z = true;
            }
        }
        return z;
    }

    /* access modifiers changed from: protected */
    public boolean onLevelChange(int i) {
        boolean z = false;
        for (int i2 = 0; i2 < this.c.length; i2++) {
            Drawable drawable = this.c[i2];
            if (drawable != null && drawable.setLevel(i)) {
                z = true;
            }
        }
        return z;
    }

    public void draw(Canvas canvas) {
        for (int i = 0; i < this.c.length; i++) {
            Drawable drawable = this.c[i];
            if (drawable != null) {
                drawable.draw(canvas);
            }
        }
    }

    public boolean getPadding(Rect rect) {
        rect.left = 0;
        rect.top = 0;
        rect.right = 0;
        rect.bottom = 0;
        Rect rect2 = this.e;
        for (int i = 0; i < this.c.length; i++) {
            Drawable drawable = this.c[i];
            if (drawable != null) {
                drawable.getPadding(rect2);
                rect.left = Math.max(rect.left, rect2.left);
                rect.top = Math.max(rect.top, rect2.top);
                rect.right = Math.max(rect.right, rect2.right);
                rect.bottom = Math.max(rect.bottom, rect2.bottom);
            }
        }
        return true;
    }

    public Drawable mutate() {
        for (int i = 0; i < this.c.length; i++) {
            Drawable drawable = this.c[i];
            if (drawable != null) {
                drawable.mutate();
            }
        }
        this.h = true;
        return this;
    }

    public int getOpacity() {
        if (this.c.length == 0) {
            return -2;
        }
        int i = -1;
        for (int i2 = 1; i2 < this.c.length; i2++) {
            Drawable drawable = this.c[i2];
            if (drawable != null) {
                i = Drawable.resolveOpacity(i, drawable.getOpacity());
            }
        }
        return i;
    }

    public void setAlpha(int i) {
        this.b.a(i);
        for (int i2 = 0; i2 < this.c.length; i2++) {
            Drawable drawable = this.c[i2];
            if (drawable != null) {
                drawable.setAlpha(i);
            }
        }
    }

    public void setColorFilter(ColorFilter colorFilter) {
        this.b.a(colorFilter);
        for (int i = 0; i < this.c.length; i++) {
            Drawable drawable = this.c[i];
            if (drawable != null) {
                drawable.setColorFilter(colorFilter);
            }
        }
    }

    public void setDither(boolean z) {
        this.b.a(z);
        for (int i = 0; i < this.c.length; i++) {
            Drawable drawable = this.c[i];
            if (drawable != null) {
                drawable.setDither(z);
            }
        }
    }

    public void setFilterBitmap(boolean z) {
        this.b.b(z);
        for (int i = 0; i < this.c.length; i++) {
            Drawable drawable = this.c[i];
            if (drawable != null) {
                drawable.setFilterBitmap(z);
            }
        }
    }

    public boolean setVisible(boolean z, boolean z2) {
        boolean visible = super.setVisible(z, z2);
        for (int i = 0; i < this.c.length; i++) {
            Drawable drawable = this.c[i];
            if (drawable != null) {
                drawable.setVisible(z, z2);
            }
        }
        return visible;
    }

    public DrawableParent b(int i) {
        boolean z = false;
        Preconditions.a(i >= 0);
        if (i < this.d.length) {
            z = true;
        }
        Preconditions.a(z);
        if (this.d[i] == null) {
            this.d[i] = c(i);
        }
        return this.d[i];
    }

    private DrawableParent c(final int i) {
        return new DrawableParent() {
            /* class com.facebook.drawee.drawable.ArrayDrawable.AnonymousClass1 */

            @Override // com.facebook.drawee.drawable.DrawableParent
            public Drawable a(Drawable drawable) {
                return ArrayDrawable.this.a(i, drawable);
            }

            @Override // com.facebook.drawee.drawable.DrawableParent
            public Drawable a() {
                return ArrayDrawable.this.a(i);
            }
        };
    }

    public void invalidateDrawable(Drawable drawable) {
        invalidateSelf();
    }

    public void scheduleDrawable(Drawable drawable, Runnable runnable, long j) {
        scheduleSelf(runnable, j);
    }

    public void unscheduleDrawable(Drawable drawable, Runnable runnable) {
        unscheduleSelf(runnable);
    }

    @Override // com.facebook.drawee.drawable.TransformAwareDrawable
    public void a(TransformCallback transformCallback) {
        this.f1538a = transformCallback;
    }

    @Override // com.facebook.drawee.drawable.TransformCallback
    public void a(Matrix matrix) {
        if (this.f1538a != null) {
            this.f1538a.a(matrix);
        } else {
            matrix.reset();
        }
    }

    @Override // com.facebook.drawee.drawable.TransformCallback
    public void a(RectF rectF) {
        if (this.f1538a != null) {
            this.f1538a.a(rectF);
        } else {
            rectF.set(getBounds());
        }
    }

    @TargetApi(21)
    public void setHotspot(float f2, float f3) {
        for (int i = 0; i < this.c.length; i++) {
            Drawable drawable = this.c[i];
            if (drawable != null) {
                drawable.setHotspot(f2, f3);
            }
        }
    }
}
