package com.facebook.drawee.generic;

import android.content.res.Resources;
import android.graphics.Matrix;
import android.graphics.PointF;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.os.Build;
import com.facebook.common.internal.Preconditions;
import com.facebook.drawee.drawable.DrawableParent;
import com.facebook.drawee.drawable.ForwardingDrawable;
import com.facebook.drawee.drawable.MatrixDrawable;
import com.facebook.drawee.drawable.Rounded;
import com.facebook.drawee.drawable.RoundedBitmapDrawable;
import com.facebook.drawee.drawable.RoundedColorDrawable;
import com.facebook.drawee.drawable.RoundedCornersDrawable;
import com.facebook.drawee.drawable.ScaleTypeDrawable;
import com.facebook.drawee.drawable.ScalingUtils;
import com.facebook.drawee.generic.RoundingParams;
import javax.annotation.Nullable;

public class WrappingUtils {

    /* renamed from: a  reason: collision with root package name */
    private static final Drawable f1559a = new ColorDrawable(0);

    @Nullable
    static Drawable a(@Nullable Drawable drawable, @Nullable ScalingUtils.ScaleType scaleType) {
        return a(drawable, scaleType, (PointF) null);
    }

    @Nullable
    static Drawable a(@Nullable Drawable drawable, @Nullable ScalingUtils.ScaleType scaleType, @Nullable PointF pointF) {
        if (drawable == null || scaleType == null) {
            return drawable;
        }
        ScaleTypeDrawable scaleTypeDrawable = new ScaleTypeDrawable(drawable, scaleType);
        if (pointF != null) {
            scaleTypeDrawable.a(pointF);
        }
        return scaleTypeDrawable;
    }

    @Nullable
    static Drawable a(@Nullable Drawable drawable, @Nullable Matrix matrix) {
        return (drawable == null || matrix == null) ? drawable : new MatrixDrawable(drawable, matrix);
    }

    static ScaleTypeDrawable a(DrawableParent drawableParent, ScalingUtils.ScaleType scaleType) {
        Drawable a2 = a(drawableParent.a(f1559a), scaleType);
        drawableParent.a(a2);
        Preconditions.a(a2, "Parent has no child drawable!");
        return (ScaleTypeDrawable) a2;
    }

    static void a(DrawableParent drawableParent, @Nullable RoundingParams roundingParams) {
        Drawable a2 = drawableParent.a();
        if (roundingParams == null || roundingParams.c() != RoundingParams.RoundingMethod.OVERLAY_COLOR) {
            if (a2 instanceof RoundedCornersDrawable) {
                drawableParent.a(((RoundedCornersDrawable) a2).b(f1559a));
                f1559a.setCallback(null);
            }
        } else if (a2 instanceof RoundedCornersDrawable) {
            RoundedCornersDrawable roundedCornersDrawable = (RoundedCornersDrawable) a2;
            a((Rounded) roundedCornersDrawable, roundingParams);
            roundedCornersDrawable.a(roundingParams.d());
        } else {
            drawableParent.a(a(drawableParent.a(f1559a), roundingParams));
        }
    }

    static void a(DrawableParent drawableParent, @Nullable RoundingParams roundingParams, Resources resources) {
        DrawableParent a2 = a(drawableParent);
        Drawable a3 = a2.a();
        if (roundingParams == null || roundingParams.c() != RoundingParams.RoundingMethod.BITMAP_ONLY) {
            if (a3 instanceof Rounded) {
                a((Rounded) a3);
            }
        } else if (a3 instanceof Rounded) {
            a((Rounded) a3, roundingParams);
        } else if (a3 != null) {
            a2.a(f1559a);
            a2.a(b(a3, roundingParams, resources));
        }
    }

    static Drawable a(@Nullable Drawable drawable, @Nullable RoundingParams roundingParams) {
        if (drawable == null || roundingParams == null || roundingParams.c() != RoundingParams.RoundingMethod.OVERLAY_COLOR) {
            return drawable;
        }
        RoundedCornersDrawable roundedCornersDrawable = new RoundedCornersDrawable(drawable);
        a((Rounded) roundedCornersDrawable, roundingParams);
        roundedCornersDrawable.a(roundingParams.d());
        return roundedCornersDrawable;
    }

    static Drawable a(@Nullable Drawable drawable, @Nullable RoundingParams roundingParams, Resources resources) {
        if (drawable == null || roundingParams == null || roundingParams.c() != RoundingParams.RoundingMethod.BITMAP_ONLY) {
            return drawable;
        }
        if (!(drawable instanceof ForwardingDrawable)) {
            return b(drawable, roundingParams, resources);
        }
        DrawableParent a2 = a((ForwardingDrawable) drawable);
        a2.a(b(a2.a(f1559a), roundingParams, resources));
        return drawable;
    }

    private static Drawable b(Drawable drawable, RoundingParams roundingParams, Resources resources) {
        if (drawable instanceof BitmapDrawable) {
            BitmapDrawable bitmapDrawable = (BitmapDrawable) drawable;
            RoundedBitmapDrawable roundedBitmapDrawable = new RoundedBitmapDrawable(resources, bitmapDrawable.getBitmap(), bitmapDrawable.getPaint());
            a((Rounded) roundedBitmapDrawable, roundingParams);
            return roundedBitmapDrawable;
        } else if (!(drawable instanceof ColorDrawable) || Build.VERSION.SDK_INT < 11) {
            return drawable;
        } else {
            RoundedColorDrawable a2 = RoundedColorDrawable.a((ColorDrawable) drawable);
            a((Rounded) a2, roundingParams);
            return a2;
        }
    }

    static void a(Rounded rounded, RoundingParams roundingParams) {
        rounded.a(roundingParams.a());
        rounded.a(roundingParams.b());
        rounded.a(roundingParams.f(), roundingParams.e());
        rounded.b(roundingParams.g());
    }

    static void a(Rounded rounded) {
        rounded.a(false);
        rounded.a(0.0f);
        rounded.a(0, 0.0f);
        rounded.b(0.0f);
    }

    static DrawableParent a(DrawableParent drawableParent) {
        while (true) {
            Drawable a2 = drawableParent.a();
            if (a2 == drawableParent || !(a2 instanceof DrawableParent)) {
                return drawableParent;
            }
            drawableParent = (DrawableParent) a2;
        }
        return drawableParent;
    }
}
