package com.facebook.imagepipeline.backends.okhttp3;

import android.os.Looper;
import android.os.SystemClock;
import com.facebook.common.logging.FLog;
import com.facebook.imagepipeline.image.EncodedImage;
import com.facebook.imagepipeline.producers.BaseNetworkFetcher;
import com.facebook.imagepipeline.producers.BaseProducerContextCallbacks;
import com.facebook.imagepipeline.producers.Consumer;
import com.facebook.imagepipeline.producers.FetchState;
import com.facebook.imagepipeline.producers.NetworkFetcher;
import com.facebook.imagepipeline.producers.ProducerContext;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.Executor;
import okhttp3.CacheControl;
import okhttp3.Call;
import okhttp3.Callback;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.ResponseBody;

public class OkHttpNetworkFetcher extends BaseNetworkFetcher<OkHttpNetworkFetchState> {

    /* renamed from: a  reason: collision with root package name */
    private final Call.Factory f1579a;
    private Executor b;

    public static class OkHttpNetworkFetchState extends FetchState {

        /* renamed from: a  reason: collision with root package name */
        public long f1583a;
        public long b;
        public long c;

        public OkHttpNetworkFetchState(Consumer<EncodedImage> consumer, ProducerContext producerContext) {
            super(consumer, producerContext);
        }
    }

    public OkHttpNetworkFetcher(OkHttpClient okHttpClient) {
        this(okHttpClient, okHttpClient.dispatcher().executorService());
    }

    public OkHttpNetworkFetcher(Call.Factory factory, Executor executor) {
        this.f1579a = factory;
        this.b = executor;
    }

    /* renamed from: a */
    public OkHttpNetworkFetchState b(Consumer<EncodedImage> consumer, ProducerContext producerContext) {
        return new OkHttpNetworkFetchState(consumer, producerContext);
    }

    public void a(OkHttpNetworkFetchState okHttpNetworkFetchState, NetworkFetcher.Callback callback) {
        okHttpNetworkFetchState.f1583a = SystemClock.elapsedRealtime();
        try {
            a(okHttpNetworkFetchState, callback, new Request.Builder().cacheControl(new CacheControl.Builder().noStore().build()).url(okHttpNetworkFetchState.e().toString()).get().build());
        } catch (Exception e) {
            callback.a(e);
        }
    }

    /* renamed from: a */
    public void b(OkHttpNetworkFetchState okHttpNetworkFetchState, int i) {
        okHttpNetworkFetchState.c = SystemClock.elapsedRealtime();
    }

    /* renamed from: b */
    public Map<String, String> a(OkHttpNetworkFetchState okHttpNetworkFetchState, int i) {
        HashMap hashMap = new HashMap(4);
        hashMap.put("queue_time", Long.toString(okHttpNetworkFetchState.b - okHttpNetworkFetchState.f1583a));
        hashMap.put("fetch_time", Long.toString(okHttpNetworkFetchState.c - okHttpNetworkFetchState.b));
        hashMap.put("total_time", Long.toString(okHttpNetworkFetchState.c - okHttpNetworkFetchState.f1583a));
        hashMap.put("image_size", Integer.toString(i));
        return hashMap;
    }

    /* access modifiers changed from: protected */
    public void a(final OkHttpNetworkFetchState okHttpNetworkFetchState, final NetworkFetcher.Callback callback, Request request) {
        final Call newCall = this.f1579a.newCall(request);
        okHttpNetworkFetchState.b().a(new BaseProducerContextCallbacks() {
            /* class com.facebook.imagepipeline.backends.okhttp3.OkHttpNetworkFetcher.AnonymousClass1 */

            @Override // com.facebook.imagepipeline.producers.BaseProducerContextCallbacks, com.facebook.imagepipeline.producers.ProducerContextCallbacks
            public void a() {
                if (Looper.myLooper() != Looper.getMainLooper()) {
                    newCall.cancel();
                } else {
                    OkHttpNetworkFetcher.this.b.execute(new Runnable() {
                        /* class com.facebook.imagepipeline.backends.okhttp3.OkHttpNetworkFetcher.AnonymousClass1.AnonymousClass1 */

                        public void run() {
                            newCall.cancel();
                        }
                    });
                }
            }
        });
        newCall.enqueue(new Callback() {
            /* class com.facebook.imagepipeline.backends.okhttp3.OkHttpNetworkFetcher.AnonymousClass2 */

            @Override // okhttp3.Callback
            public void onResponse(Call call, Response response) throws IOException {
                okHttpNetworkFetchState.b = SystemClock.elapsedRealtime();
                ResponseBody body = response.body();
                try {
                    if (!response.isSuccessful()) {
                        OkHttpNetworkFetcher.this.a((OkHttpNetworkFetcher) call, (Call) new IOException("Unexpected HTTP code " + response), (Exception) callback);
                        try {
                            body.close();
                        } catch (Exception e) {
                            FLog.b("OkHttpNetworkFetchProducer", "Exception when closing response body", e);
                        }
                    } else {
                        long contentLength = body.contentLength();
                        if (contentLength < 0) {
                            contentLength = 0;
                        }
                        callback.a(body.byteStream(), (int) contentLength);
                        try {
                            body.close();
                        } catch (Exception e2) {
                            FLog.b("OkHttpNetworkFetchProducer", "Exception when closing response body", e2);
                        }
                    }
                } catch (Exception e3) {
                    OkHttpNetworkFetcher.this.a((OkHttpNetworkFetcher) call, (Call) e3, (Exception) callback);
                    body.close();
                } catch (Throwable th) {
                    try {
                        body.close();
                    } catch (Exception e4) {
                        FLog.b("OkHttpNetworkFetchProducer", "Exception when closing response body", e4);
                    }
                    throw th;
                }
            }

            @Override // okhttp3.Callback
            public void onFailure(Call call, IOException iOException) {
                OkHttpNetworkFetcher.this.a((OkHttpNetworkFetcher) call, (Call) iOException, (Exception) callback);
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void a(Call call, Exception exc, NetworkFetcher.Callback callback) {
        if (call.isCanceled()) {
            callback.a();
        } else {
            callback.a(exc);
        }
    }
}
