package com.facebook.imagepipeline.cache;

import bolts.Task;
import com.facebook.binaryresource.BinaryResource;
import com.facebook.cache.common.CacheKey;
import com.facebook.cache.common.WriterCallback;
import com.facebook.cache.disk.FileCache;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.logging.FLog;
import com.facebook.common.memory.PooledByteBuffer;
import com.facebook.common.memory.PooledByteBufferFactory;
import com.facebook.common.memory.PooledByteStreams;
import com.facebook.common.references.CloseableReference;
import com.facebook.imagepipeline.image.EncodedImage;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.concurrent.Callable;
import java.util.concurrent.CancellationException;
import java.util.concurrent.Executor;
import java.util.concurrent.atomic.AtomicBoolean;

public class BufferedDiskCache {

    /* renamed from: a  reason: collision with root package name */
    private static final Class<?> f1594a = BufferedDiskCache.class;
    private final FileCache b;
    private final PooledByteBufferFactory c;
    private final PooledByteStreams d;
    private final Executor e;
    private final Executor f;
    private final StagingArea g = StagingArea.a();
    private final ImageCacheStatsTracker h;

    public BufferedDiskCache(FileCache fileCache, PooledByteBufferFactory pooledByteBufferFactory, PooledByteStreams pooledByteStreams, Executor executor, Executor executor2, ImageCacheStatsTracker imageCacheStatsTracker) {
        this.b = fileCache;
        this.c = pooledByteBufferFactory;
        this.d = pooledByteStreams;
        this.e = executor;
        this.f = executor2;
        this.h = imageCacheStatsTracker;
    }

    public boolean a(CacheKey cacheKey) {
        return this.g.c(cacheKey) || this.b.c(cacheKey);
    }

    public Task<Boolean> b(CacheKey cacheKey) {
        if (a(cacheKey)) {
            return Task.a((Object) true);
        }
        return d(cacheKey);
    }

    private Task<Boolean> d(final CacheKey cacheKey) {
        try {
            return Task.a(new Callable<Boolean>() {
                /* class com.facebook.imagepipeline.cache.BufferedDiskCache.AnonymousClass1 */

                /* renamed from: a */
                public Boolean call() throws Exception {
                    return Boolean.valueOf(BufferedDiskCache.this.e(cacheKey));
                }
            }, this.e);
        } catch (Exception e2) {
            FLog.a(f1594a, e2, "Failed to schedule disk-cache read for %s", cacheKey.a());
            return Task.a(e2);
        }
    }

    public boolean c(CacheKey cacheKey) {
        if (a(cacheKey)) {
            return true;
        }
        return e(cacheKey);
    }

    public Task<EncodedImage> a(CacheKey cacheKey, AtomicBoolean atomicBoolean) {
        EncodedImage b2 = this.g.b(cacheKey);
        if (b2 != null) {
            return b(cacheKey, b2);
        }
        return b(cacheKey, atomicBoolean);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean e(CacheKey cacheKey) {
        EncodedImage b2 = this.g.b(cacheKey);
        if (b2 != null) {
            b2.close();
            FLog.a(f1594a, "Found image for %s in staging area", cacheKey.a());
            this.h.c(cacheKey);
            return true;
        }
        FLog.a(f1594a, "Did not find image for %s in staging area", cacheKey.a());
        this.h.e();
        try {
            return this.b.d(cacheKey);
        } catch (Exception unused) {
            return false;
        }
    }

    private Task<EncodedImage> b(final CacheKey cacheKey, final AtomicBoolean atomicBoolean) {
        try {
            return Task.a(new Callable<EncodedImage>() {
                /* class com.facebook.imagepipeline.cache.BufferedDiskCache.AnonymousClass2 */

                /* JADX INFO: finally extract failed */
                /* renamed from: a */
                public EncodedImage call() throws Exception {
                    if (!atomicBoolean.get()) {
                        EncodedImage b2 = BufferedDiskCache.this.g.b(cacheKey);
                        if (b2 != null) {
                            FLog.a(BufferedDiskCache.f1594a, "Found image for %s in staging area", cacheKey.a());
                            BufferedDiskCache.this.h.c(cacheKey);
                            b2.a(cacheKey);
                        } else {
                            FLog.a(BufferedDiskCache.f1594a, "Did not find image for %s in staging area", cacheKey.a());
                            BufferedDiskCache.this.h.e();
                            try {
                                CloseableReference a2 = CloseableReference.a(BufferedDiskCache.this.f(cacheKey));
                                try {
                                    EncodedImage encodedImage = new EncodedImage(a2);
                                    encodedImage.a(cacheKey);
                                    CloseableReference.c(a2);
                                    b2 = encodedImage;
                                } catch (Throwable th) {
                                    CloseableReference.c(a2);
                                    throw th;
                                }
                            } catch (Exception unused) {
                                return null;
                            }
                        }
                        if (!Thread.interrupted()) {
                            return b2;
                        }
                        FLog.a(BufferedDiskCache.f1594a, "Host thread was interrupted, decreasing reference count");
                        if (b2 != null) {
                            b2.close();
                        }
                        throw new InterruptedException();
                    }
                    throw new CancellationException();
                }
            }, this.e);
        } catch (Exception e2) {
            FLog.a(f1594a, e2, "Failed to schedule disk-cache read for %s", cacheKey.a());
            return Task.a(e2);
        }
    }

    public void a(final CacheKey cacheKey, EncodedImage encodedImage) {
        Preconditions.a(cacheKey);
        Preconditions.a(EncodedImage.e(encodedImage));
        this.g.a(cacheKey, encodedImage);
        encodedImage.a(cacheKey);
        final EncodedImage a2 = EncodedImage.a(encodedImage);
        try {
            this.f.execute(new Runnable() {
                /* class com.facebook.imagepipeline.cache.BufferedDiskCache.AnonymousClass3 */

                public void run() {
                    try {
                        BufferedDiskCache.this.c(cacheKey, a2);
                    } finally {
                        BufferedDiskCache.this.g.b(cacheKey, a2);
                        EncodedImage.d(a2);
                    }
                }
            });
        } catch (Exception e2) {
            FLog.a(f1594a, e2, "Failed to schedule disk-cache write for %s", cacheKey.a());
            this.g.b(cacheKey, encodedImage);
            EncodedImage.d(a2);
        }
    }

    /* renamed from: com.facebook.imagepipeline.cache.BufferedDiskCache$4  reason: invalid class name */
    class AnonymousClass4 implements Callable<Void> {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ CacheKey f1598a;
        final /* synthetic */ BufferedDiskCache b;

        /* renamed from: a */
        public Void call() throws Exception {
            this.b.g.a(this.f1598a);
            this.b.b.b(this.f1598a);
            return null;
        }
    }

    public Task<Void> a() {
        this.g.b();
        try {
            return Task.a(new Callable<Void>() {
                /* class com.facebook.imagepipeline.cache.BufferedDiskCache.AnonymousClass5 */

                /* renamed from: a */
                public Void call() throws Exception {
                    BufferedDiskCache.this.g.b();
                    BufferedDiskCache.this.b.a();
                    return null;
                }
            }, this.f);
        } catch (Exception e2) {
            FLog.a(f1594a, e2, "Failed to schedule disk-cache clear", new Object[0]);
            return Task.a(e2);
        }
    }

    private Task<EncodedImage> b(CacheKey cacheKey, EncodedImage encodedImage) {
        FLog.a(f1594a, "Found image for %s in staging area", cacheKey.a());
        this.h.c(cacheKey);
        return Task.a(encodedImage);
    }

    /* JADX INFO: finally extract failed */
    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private PooledByteBuffer f(CacheKey cacheKey) throws IOException {
        try {
            FLog.a(f1594a, "Disk cache read for %s", cacheKey.a());
            BinaryResource a2 = this.b.a(cacheKey);
            if (a2 == null) {
                FLog.a(f1594a, "Disk cache miss for %s", cacheKey.a());
                this.h.g();
                return null;
            }
            FLog.a(f1594a, "Found entry in disk cache for %s", cacheKey.a());
            this.h.f();
            InputStream a3 = a2.a();
            try {
                PooledByteBuffer a4 = this.c.a(a3, (int) a2.b());
                a3.close();
                FLog.a(f1594a, "Successful read from disk cache for %s", cacheKey.a());
                return a4;
            } catch (Throwable th) {
                a3.close();
                throw th;
            }
        } catch (IOException e2) {
            FLog.a(f1594a, e2, "Exception reading from cache for %s", cacheKey.a());
            this.h.h();
            throw e2;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void c(CacheKey cacheKey, final EncodedImage encodedImage) {
        FLog.a(f1594a, "About to write to disk-cache for key %s", cacheKey.a());
        try {
            this.b.a(cacheKey, new WriterCallback() {
                /* class com.facebook.imagepipeline.cache.BufferedDiskCache.AnonymousClass6 */

                @Override // com.facebook.cache.common.WriterCallback
                public void a(OutputStream outputStream) throws IOException {
                    BufferedDiskCache.this.d.a(encodedImage.d(), outputStream);
                }
            });
            FLog.a(f1594a, "Successful disk-cache write for key %s", cacheKey.a());
        } catch (IOException e2) {
            FLog.a(f1594a, e2, "Failed to write to disk-cache for key %s", cacheKey.a());
        }
    }
}
