package com.facebook.imagepipeline.cache;

import android.graphics.Bitmap;
import android.os.SystemClock;
import com.android.internal.util.Predicate;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.internal.Supplier;
import com.facebook.common.internal.VisibleForTesting;
import com.facebook.common.memory.MemoryTrimmable;
import com.facebook.common.references.CloseableReference;
import com.facebook.common.references.ResourceReleaser;
import com.facebook.imagepipeline.bitmaps.PlatformBitmapFactory;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Map;
import java.util.WeakHashMap;
import java.util.concurrent.TimeUnit;
import javax.annotation.Nullable;
import javax.annotation.concurrent.GuardedBy;
import javax.annotation.concurrent.ThreadSafe;

@ThreadSafe
public class CountingMemoryCache<K, V> implements MemoryTrimmable, MemoryCache<K, V> {
    @VisibleForTesting

    /* renamed from: a  reason: collision with root package name */
    static final long f1602a = TimeUnit.MINUTES.toMillis(5);
    @VisibleForTesting
    @GuardedBy
    final CountingLruMap<K, Entry<K, V>> b;
    @VisibleForTesting
    @GuardedBy
    final CountingLruMap<K, Entry<K, V>> c;
    @VisibleForTesting
    @GuardedBy
    final Map<Bitmap, Object> d = new WeakHashMap();
    @GuardedBy
    protected MemoryCacheParams e;
    private final ValueDescriptor<V> f;
    private final CacheTrimStrategy g;
    private final Supplier<MemoryCacheParams> h;
    @GuardedBy
    private long i;

    public interface CacheTrimStrategy {
    }

    public interface EntryStateObserver<K> {
        void a(K k, boolean z);
    }

    /* access modifiers changed from: package-private */
    @VisibleForTesting
    public static class Entry<K, V> {

        /* renamed from: a  reason: collision with root package name */
        public final K f1606a;
        public final CloseableReference<V> b;
        public int c = 0;
        public boolean d = false;
        @Nullable
        public final EntryStateObserver<K> e;

        private Entry(K k, CloseableReference<V> closeableReference, @Nullable EntryStateObserver<K> entryStateObserver) {
            this.f1606a = (K) Preconditions.a(k);
            this.b = (CloseableReference) Preconditions.a(CloseableReference.b(closeableReference));
            this.e = entryStateObserver;
        }

        @VisibleForTesting
        static <K, V> Entry<K, V> a(K k, CloseableReference<V> closeableReference, @Nullable EntryStateObserver<K> entryStateObserver) {
            return new Entry<>(k, closeableReference, entryStateObserver);
        }
    }

    public CountingMemoryCache(ValueDescriptor<V> valueDescriptor, CacheTrimStrategy cacheTrimStrategy, Supplier<MemoryCacheParams> supplier, PlatformBitmapFactory platformBitmapFactory, boolean z) {
        this.f = valueDescriptor;
        this.b = new CountingLruMap<>(a((ValueDescriptor) valueDescriptor));
        this.c = new CountingLruMap<>(a((ValueDescriptor) valueDescriptor));
        this.g = cacheTrimStrategy;
        this.h = supplier;
        this.e = this.h.b();
        this.i = SystemClock.uptimeMillis();
        if (z) {
            platformBitmapFactory.a(new PlatformBitmapFactory.BitmapCreationObserver() {
                /* class com.facebook.imagepipeline.cache.CountingMemoryCache.AnonymousClass1 */
            });
        }
    }

    private ValueDescriptor<Entry<K, V>> a(final ValueDescriptor<V> valueDescriptor) {
        return new ValueDescriptor<Entry<K, V>>() {
            /* class com.facebook.imagepipeline.cache.CountingMemoryCache.AnonymousClass2 */

            @Override // com.facebook.imagepipeline.cache.ValueDescriptor
            public /* bridge */ /* synthetic */ int a(Object obj) {
                return a((Entry) ((Entry) obj));
            }

            public int a(Entry<K, V> entry) {
                return valueDescriptor.a(entry.b.a());
            }
        };
    }

    @Override // com.facebook.imagepipeline.cache.MemoryCache
    public CloseableReference<V> a(K k, CloseableReference<V> closeableReference) {
        return a(k, closeableReference, null);
    }

    public CloseableReference<V> a(K k, CloseableReference<V> closeableReference, EntryStateObserver<K> entryStateObserver) {
        Entry<K, V> b2;
        CloseableReference<V> closeableReference2;
        CloseableReference<V> closeableReference3;
        Preconditions.a(k);
        Preconditions.a(closeableReference);
        c();
        synchronized (this) {
            b2 = this.b.b((Object) k);
            Entry<K, V> b3 = this.c.b((Object) k);
            closeableReference2 = null;
            if (b3 != null) {
                f(b3);
                closeableReference3 = i(b3);
            } else {
                closeableReference3 = null;
            }
            if (b((Object) closeableReference.a())) {
                Entry<K, V> a2 = Entry.a(k, closeableReference, entryStateObserver);
                this.c.a(k, a2);
                closeableReference2 = a((Entry) a2);
            }
        }
        CloseableReference.c(closeableReference3);
        d(b2);
        d();
        return closeableReference2;
    }

    private synchronized boolean b(V v) {
        boolean z;
        int a2 = this.f.a(v);
        z = true;
        if (a2 > this.e.e || a() > this.e.b - 1 || b() > this.e.f1615a - a2) {
            z = false;
        }
        return z;
    }

    @Override // com.facebook.imagepipeline.cache.MemoryCache
    @Nullable
    public CloseableReference<V> a(K k) {
        Entry<K, V> b2;
        CloseableReference<V> a2;
        Preconditions.a(k);
        synchronized (this) {
            b2 = this.b.b((Object) k);
            Entry<K, V> a3 = this.c.a((Object) k);
            a2 = a3 != null ? a((Entry) a3) : null;
        }
        d(b2);
        c();
        d();
        return a2;
    }

    private synchronized CloseableReference<V> a(final Entry<K, V> entry) {
        g(entry);
        return CloseableReference.a(entry.b.a(), new ResourceReleaser<V>() {
            /* class com.facebook.imagepipeline.cache.CountingMemoryCache.AnonymousClass3 */

            @Override // com.facebook.common.references.ResourceReleaser
            public void a(V v) {
                CountingMemoryCache.this.b((CountingMemoryCache) entry);
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void b(Entry<K, V> entry) {
        boolean c2;
        CloseableReference<V> i2;
        Preconditions.a(entry);
        synchronized (this) {
            h(entry);
            c2 = c(entry);
            i2 = i(entry);
        }
        CloseableReference.c(i2);
        if (!c2) {
            entry = null;
        }
        e(entry);
        c();
        d();
    }

    private synchronized boolean c(Entry<K, V> entry) {
        if (entry.d || entry.c != 0) {
            return false;
        }
        this.b.a(entry.f1606a, entry);
        return true;
    }

    @Override // com.facebook.imagepipeline.cache.MemoryCache
    public int a(Predicate<K> predicate) {
        ArrayList<Entry<K, V>> b2;
        ArrayList<Entry<K, V>> b3;
        synchronized (this) {
            b2 = this.b.b((Predicate) predicate);
            b3 = this.c.b((Predicate) predicate);
            c(b3);
        }
        a((ArrayList) b3);
        b((ArrayList) b2);
        c();
        d();
        return b3.size();
    }

    @Override // com.facebook.imagepipeline.cache.MemoryCache
    public synchronized boolean b(Predicate<K> predicate) {
        return !this.c.a((Predicate) predicate).isEmpty();
    }

    private synchronized void c() {
        if (this.i + f1602a <= SystemClock.uptimeMillis()) {
            this.i = SystemClock.uptimeMillis();
            this.e = this.h.b();
        }
    }

    private void d() {
        ArrayList<Entry<K, V>> a2;
        synchronized (this) {
            a2 = a(Math.min(this.e.d, this.e.b - a()), Math.min(this.e.c, this.e.f1615a - b()));
            c(a2);
        }
        a((ArrayList) a2);
        b((ArrayList) a2);
    }

    @Nullable
    private synchronized ArrayList<Entry<K, V>> a(int i2, int i3) {
        int max = Math.max(i2, 0);
        int max2 = Math.max(i3, 0);
        if (this.b.a() <= max && this.b.b() <= max2) {
            return null;
        }
        ArrayList<Entry<K, V>> arrayList = new ArrayList<>();
        while (true) {
            if (this.b.a() <= max && this.b.b() <= max2) {
                return arrayList;
            }
            K c2 = this.b.c();
            this.b.b((Object) c2);
            arrayList.add(this.c.b((Object) c2));
        }
    }

    private void a(@Nullable ArrayList<Entry<K, V>> arrayList) {
        if (arrayList != null) {
            Iterator<Entry<K, V>> it = arrayList.iterator();
            while (it.hasNext()) {
                CloseableReference.c(i(it.next()));
            }
        }
    }

    private void b(@Nullable ArrayList<Entry<K, V>> arrayList) {
        if (arrayList != null) {
            Iterator<Entry<K, V>> it = arrayList.iterator();
            while (it.hasNext()) {
                d(it.next());
            }
        }
    }

    private static <K, V> void d(@Nullable Entry<K, V> entry) {
        if (entry != null && entry.e != null) {
            entry.e.a(entry.f1606a, false);
        }
    }

    private static <K, V> void e(@Nullable Entry<K, V> entry) {
        if (entry != null && entry.e != null) {
            entry.e.a(entry.f1606a, true);
        }
    }

    private synchronized void c(@Nullable ArrayList<Entry<K, V>> arrayList) {
        if (arrayList != null) {
            Iterator<Entry<K, V>> it = arrayList.iterator();
            while (it.hasNext()) {
                f(it.next());
            }
        }
    }

    private synchronized void f(Entry<K, V> entry) {
        Preconditions.a(entry);
        Preconditions.b(!entry.d);
        entry.d = true;
    }

    private synchronized void g(Entry<K, V> entry) {
        Preconditions.a(entry);
        Preconditions.b(!entry.d);
        entry.c++;
    }

    private synchronized void h(Entry<K, V> entry) {
        Preconditions.a(entry);
        Preconditions.b(entry.c > 0);
        entry.c--;
    }

    @Nullable
    private synchronized CloseableReference<V> i(Entry<K, V> entry) {
        Preconditions.a(entry);
        return (!entry.d || entry.c != 0) ? null : entry.b;
    }

    public synchronized int a() {
        return this.c.a() - this.b.a();
    }

    public synchronized int b() {
        return this.c.b() - this.b.b();
    }
}
