package com.facebook.imagepipeline.cache;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.net.Uri;
import android.provider.BaseColumns;
import android.text.TextUtils;
import bolts.Task;
import com.facebook.cache.common.CacheKey;
import com.facebook.cache.common.CacheKeyUtil;
import com.facebook.common.internal.VisibleForTesting;
import com.facebook.common.logging.FLog;
import com.facebook.imagepipeline.image.EncodedImage;
import com.facebook.imagepipeline.request.ImageRequest;
import com.facebook.imagepipeline.request.MediaVariations;
import java.util.concurrent.Callable;
import java.util.concurrent.Executor;
import javax.annotation.Nullable;
import javax.annotation.concurrent.GuardedBy;

public class MediaVariationsIndexDatabase implements MediaVariationsIndex {

    /* renamed from: a  reason: collision with root package name */
    private static final String f1611a = "MediaVariationsIndexDatabase";
    private static final String[] b = {"cache_choice", "cache_key", "width", "height"};
    @GuardedBy
    private final LazyIndexDbOpenHelper c;
    private final Executor d;
    private final Executor e;

    public MediaVariationsIndexDatabase(Context context, Executor executor, Executor executor2) {
        this.c = new LazyIndexDbOpenHelper(context);
        this.d = executor;
        this.e = executor2;
    }

    @Override // com.facebook.imagepipeline.cache.MediaVariationsIndex
    public Task<MediaVariations> a(final String str, final MediaVariations.Builder builder) {
        try {
            return Task.a(new Callable<MediaVariations>() {
                /* class com.facebook.imagepipeline.cache.MediaVariationsIndexDatabase.AnonymousClass1 */

                /* renamed from: a */
                public MediaVariations call() throws Exception {
                    return MediaVariationsIndexDatabase.this.b(str, builder);
                }
            }, this.d);
        } catch (Exception e2) {
            FLog.a(f1611a, e2, "Failed to schedule query task for %s", str);
            return Task.a(e2);
        }
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x009a  */
    @VisibleForTesting
    public MediaVariations b(String str, MediaVariations.Builder builder) {
        Throwable th;
        SQLException e2;
        ImageRequest.CacheChoice cacheChoice;
        MediaVariations.Builder builder2;
        synchronized (MediaVariationsIndexDatabase.class) {
            Cursor cursor = null;
            try {
                Cursor cursor2 = this.c.a().query("media_variations_index", b, "media_id = ?", new String[]{str}, null, null, null);
                try {
                    if (cursor2.getCount() == 0) {
                        MediaVariations a2 = builder.a();
                        if (cursor2 != null) {
                            cursor2.close();
                        }
                        return a2;
                    }
                    int columnIndexOrThrow = cursor2.getColumnIndexOrThrow("cache_key");
                    int columnIndexOrThrow2 = cursor2.getColumnIndexOrThrow("width");
                    int columnIndexOrThrow3 = cursor2.getColumnIndexOrThrow("height");
                    int columnIndexOrThrow4 = cursor2.getColumnIndexOrThrow("cache_choice");
                    while (cursor2.moveToNext()) {
                        String string = cursor2.getString(columnIndexOrThrow4);
                        Uri parse = Uri.parse(cursor2.getString(columnIndexOrThrow));
                        int i = cursor2.getInt(columnIndexOrThrow2);
                        int i2 = cursor2.getInt(columnIndexOrThrow3);
                        if (TextUtils.isEmpty(string)) {
                            builder2 = builder;
                            cacheChoice = null;
                        } else {
                            cacheChoice = ImageRequest.CacheChoice.valueOf(string);
                            builder2 = builder;
                        }
                        builder2.a(parse, i, i2, cacheChoice);
                    }
                    MediaVariations a3 = builder.a();
                    if (cursor2 != null) {
                        cursor2.close();
                    }
                    return a3;
                } catch (SQLException e3) {
                    e2 = e3;
                    cursor = cursor2;
                    try {
                        FLog.b(f1611a, e2, "Error reading for %s", str);
                        throw e2;
                    } catch (Throwable th2) {
                        th = th2;
                        cursor2 = cursor;
                        if (cursor2 != null) {
                        }
                        throw th;
                    }
                } catch (Throwable th3) {
                    th = th3;
                    if (cursor2 != null) {
                        cursor2.close();
                    }
                    throw th;
                }
            } catch (SQLException e4) {
                e2 = e4;
                FLog.b(f1611a, e2, "Error reading for %s", str);
                throw e2;
            }
        }
    }

    @Override // com.facebook.imagepipeline.cache.MediaVariationsIndex
    public void a(final String str, final ImageRequest.CacheChoice cacheChoice, final CacheKey cacheKey, final EncodedImage encodedImage) {
        this.e.execute(new Runnable() {
            /* class com.facebook.imagepipeline.cache.MediaVariationsIndexDatabase.AnonymousClass2 */

            public void run() {
                MediaVariationsIndexDatabase.this.b(str, cacheChoice, cacheKey, encodedImage);
            }
        });
    }

    /* access modifiers changed from: protected */
    public void b(String str, ImageRequest.CacheChoice cacheChoice, CacheKey cacheKey, EncodedImage encodedImage) {
        synchronized (MediaVariationsIndexDatabase.class) {
            SQLiteDatabase a2 = this.c.a();
            try {
                a2.beginTransaction();
                ContentValues contentValues = new ContentValues();
                contentValues.put("media_id", str);
                contentValues.put("width", Integer.valueOf(encodedImage.g()));
                contentValues.put("height", Integer.valueOf(encodedImage.h()));
                contentValues.put("cache_choice", cacheChoice.name());
                contentValues.put("cache_key", cacheKey.a());
                contentValues.put("resource_id", CacheKeyUtil.b(cacheKey));
                a2.replaceOrThrow("media_variations_index", null, contentValues);
                a2.setTransactionSuccessful();
            } catch (Exception e2) {
                FLog.b(f1611a, e2, "Error writing for %s", str);
            } catch (Throwable th) {
                a2.endTransaction();
                throw th;
            }
            a2.endTransaction();
        }
    }

    private static final class IndexEntry implements BaseColumns {
        private IndexEntry() {
        }
    }

    /* access modifiers changed from: private */
    public static class LazyIndexDbOpenHelper {

        /* renamed from: a  reason: collision with root package name */
        private final Context f1614a;
        @Nullable
        private IndexDbOpenHelper b;

        private LazyIndexDbOpenHelper(Context context) {
            this.f1614a = context;
        }

        public synchronized SQLiteDatabase a() {
            if (this.b == null) {
                this.b = new IndexDbOpenHelper(this.f1614a);
            }
            return this.b.getWritableDatabase();
        }
    }

    /* access modifiers changed from: private */
    public static class IndexDbOpenHelper extends SQLiteOpenHelper {
        public IndexDbOpenHelper(Context context) {
            super(context, "FrescoMediaVariationsIndex.db", (SQLiteDatabase.CursorFactory) null, 2);
        }

        public void onCreate(SQLiteDatabase sQLiteDatabase) {
            sQLiteDatabase.beginTransaction();
            try {
                sQLiteDatabase.execSQL("CREATE TABLE media_variations_index (_id INTEGER PRIMARY KEY,media_id TEXT,width INTEGER,height INTEGER,cache_choice TEXT,cache_key TEXT,resource_id TEXT UNIQUE )");
                sQLiteDatabase.execSQL("CREATE INDEX index_media_id ON media_variations_index (media_id)");
                sQLiteDatabase.setTransactionSuccessful();
            } finally {
                sQLiteDatabase.endTransaction();
            }
        }

        /* JADX INFO: finally extract failed */
        public void onUpgrade(SQLiteDatabase sQLiteDatabase, int i, int i2) {
            sQLiteDatabase.beginTransaction();
            try {
                sQLiteDatabase.execSQL("DROP TABLE IF EXISTS media_variations_index");
                sQLiteDatabase.setTransactionSuccessful();
                sQLiteDatabase.endTransaction();
                onCreate(sQLiteDatabase);
            } catch (Throwable th) {
                sQLiteDatabase.endTransaction();
                throw th;
            }
        }

        public void onDowngrade(SQLiteDatabase sQLiteDatabase, int i, int i2) {
            onUpgrade(sQLiteDatabase, i, i2);
        }
    }
}
