package com.facebook.imagepipeline.core;

import android.net.Uri;
import bolts.Continuation;
import bolts.Task;
import com.android.internal.util.Predicate;
import com.facebook.cache.common.CacheKey;
import com.facebook.common.internal.Objects;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.internal.Supplier;
import com.facebook.common.memory.PooledByteBuffer;
import com.facebook.common.references.CloseableReference;
import com.facebook.common.util.UriUtil;
import com.facebook.datasource.DataSource;
import com.facebook.datasource.DataSources;
import com.facebook.datasource.SimpleDataSource;
import com.facebook.imagepipeline.cache.BufferedDiskCache;
import com.facebook.imagepipeline.cache.CacheKeyFactory;
import com.facebook.imagepipeline.cache.MemoryCache;
import com.facebook.imagepipeline.common.Priority;
import com.facebook.imagepipeline.common.ResizeOptions;
import com.facebook.imagepipeline.datasource.CloseableProducerToDataSourceAdapter;
import com.facebook.imagepipeline.datasource.ProducerToDataSourceAdapter;
import com.facebook.imagepipeline.image.CloseableImage;
import com.facebook.imagepipeline.listener.ForwardingRequestListener;
import com.facebook.imagepipeline.listener.RequestListener;
import com.facebook.imagepipeline.producers.Producer;
import com.facebook.imagepipeline.producers.SettableProducerContext;
import com.facebook.imagepipeline.producers.ThreadHandoffProducerQueue;
import com.facebook.imagepipeline.request.ImageRequest;
import com.facebook.imagepipeline.request.ImageRequestBuilder;
import java.util.Set;
import java.util.concurrent.CancellationException;
import java.util.concurrent.atomic.AtomicLong;
import javax.annotation.concurrent.ThreadSafe;

@ThreadSafe
public class ImagePipeline {

    /* renamed from: a  reason: collision with root package name */
    private static final CancellationException f1630a = new CancellationException("Prefetching is not enabled");
    private final ProducerSequenceFactory b;
    private final RequestListener c;
    private final Supplier<Boolean> d;
    private final MemoryCache<CacheKey, CloseableImage> e;
    private final MemoryCache<CacheKey, PooledByteBuffer> f;
    private final BufferedDiskCache g;
    private final BufferedDiskCache h;
    private final CacheKeyFactory i;
    private final ThreadHandoffProducerQueue j;
    private final Supplier<Boolean> k;
    private AtomicLong l = new AtomicLong();

    public ImagePipeline(ProducerSequenceFactory producerSequenceFactory, Set<RequestListener> set, Supplier<Boolean> supplier, MemoryCache<CacheKey, CloseableImage> memoryCache, MemoryCache<CacheKey, PooledByteBuffer> memoryCache2, BufferedDiskCache bufferedDiskCache, BufferedDiskCache bufferedDiskCache2, CacheKeyFactory cacheKeyFactory, ThreadHandoffProducerQueue threadHandoffProducerQueue, Supplier<Boolean> supplier2) {
        this.b = producerSequenceFactory;
        this.c = new ForwardingRequestListener(set);
        this.d = supplier;
        this.e = memoryCache;
        this.f = memoryCache2;
        this.g = bufferedDiskCache;
        this.h = bufferedDiskCache2;
        this.i = cacheKeyFactory;
        this.j = threadHandoffProducerQueue;
        this.k = supplier2;
    }

    private String f() {
        return String.valueOf(this.l.getAndIncrement());
    }

    /* renamed from: com.facebook.imagepipeline.core.ImagePipeline$1  reason: invalid class name */
    class AnonymousClass1 implements Supplier<DataSource<CloseableReference<CloseableImage>>> {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ ImageRequest f1631a;
        final /* synthetic */ Object b;
        final /* synthetic */ ImageRequest.RequestLevel c;
        final /* synthetic */ ImagePipeline d;

        /* renamed from: a */
        public DataSource<CloseableReference<CloseableImage>> b() {
            return this.d.a(this.f1631a, this.b, this.c);
        }

        public String toString() {
            return Objects.a(this).a("uri", this.f1631a.b()).toString();
        }
    }

    /* renamed from: com.facebook.imagepipeline.core.ImagePipeline$2  reason: invalid class name */
    class AnonymousClass2 implements Supplier<DataSource<CloseableReference<PooledByteBuffer>>> {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ ImageRequest f1632a;
        final /* synthetic */ Object b;
        final /* synthetic */ ImagePipeline c;

        /* renamed from: a */
        public DataSource<CloseableReference<PooledByteBuffer>> b() {
            return this.c.b(this.f1632a, this.b);
        }

        public String toString() {
            return Objects.a(this).a("uri", this.f1632a.b()).toString();
        }
    }

    public DataSource<CloseableReference<CloseableImage>> a(ImageRequest imageRequest, Object obj) {
        return a(imageRequest, obj, ImageRequest.RequestLevel.FULL_FETCH);
    }

    public DataSource<CloseableReference<CloseableImage>> a(ImageRequest imageRequest, Object obj, ImageRequest.RequestLevel requestLevel) {
        try {
            return a(this.b.c(imageRequest), imageRequest, requestLevel, obj);
        } catch (Exception e2) {
            return DataSources.a(e2);
        }
    }

    public DataSource<CloseableReference<PooledByteBuffer>> b(ImageRequest imageRequest, Object obj) {
        Preconditions.a(imageRequest.b());
        try {
            Producer<CloseableReference<PooledByteBuffer>> a2 = this.b.a(imageRequest);
            if (imageRequest.g() != null) {
                imageRequest = ImageRequestBuilder.a(imageRequest).a((ResizeOptions) null).n();
            }
            return a(a2, imageRequest, ImageRequest.RequestLevel.FULL_FETCH, obj);
        } catch (Exception e2) {
            return DataSources.a(e2);
        }
    }

    public DataSource<Void> c(ImageRequest imageRequest, Object obj) {
        return a(imageRequest, obj, Priority.MEDIUM);
    }

    public DataSource<Void> a(ImageRequest imageRequest, Object obj, Priority priority) {
        if (!this.d.b().booleanValue()) {
            return DataSources.a(f1630a);
        }
        try {
            return a(this.b.b(imageRequest), imageRequest, ImageRequest.RequestLevel.FULL_FETCH, obj, priority);
        } catch (Exception e2) {
            return DataSources.a(e2);
        }
    }

    public void a() {
        Predicate<CacheKey> r0 = new Predicate<CacheKey>() {
            /* class com.facebook.imagepipeline.core.ImagePipeline.AnonymousClass3 */

            /* renamed from: a */
            public boolean apply(CacheKey cacheKey) {
                return true;
            }
        };
        this.e.a(r0);
        this.f.a(r0);
    }

    public void b() {
        this.g.a();
        this.h.a();
    }

    public void c() {
        a();
        b();
    }

    public boolean a(Uri uri) {
        if (uri == null) {
            return false;
        }
        return this.e.b(c(uri));
    }

    public MemoryCache<CacheKey, CloseableImage> d() {
        return this.e;
    }

    public boolean b(Uri uri) {
        return a(uri, ImageRequest.CacheChoice.SMALL) || a(uri, ImageRequest.CacheChoice.DEFAULT);
    }

    public boolean a(Uri uri, ImageRequest.CacheChoice cacheChoice) {
        return a(ImageRequestBuilder.a(uri).a(cacheChoice).n());
    }

    public boolean a(ImageRequest imageRequest) {
        CacheKey c2 = this.i.c(imageRequest, null);
        switch (imageRequest.a()) {
            case DEFAULT:
                return this.g.c(c2);
            case SMALL:
                return this.h.c(c2);
            default:
                return false;
        }
    }

    /* renamed from: com.facebook.imagepipeline.core.ImagePipeline$5  reason: invalid class name */
    class AnonymousClass5 implements Continuation<Boolean, Task<Boolean>> {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ CacheKey f1635a;
        final /* synthetic */ ImagePipeline b;

        /* renamed from: b */
        public Task<Boolean> a(Task<Boolean> task) throws Exception {
            if (task.c() || task.d() || !task.e().booleanValue()) {
                return this.b.h.b(this.f1635a);
            }
            return Task.a((Object) true);
        }
    }

    /* renamed from: com.facebook.imagepipeline.core.ImagePipeline$4  reason: invalid class name */
    class AnonymousClass4 implements Continuation<Boolean, Void> {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ SimpleDataSource f1634a;

        /* renamed from: b */
        public Void a(Task<Boolean> task) throws Exception {
            this.f1634a.b(Boolean.valueOf(!task.c() && !task.d() && task.e().booleanValue()));
            return null;
        }
    }

    private <T> DataSource<CloseableReference<T>> a(Producer<CloseableReference<T>> producer, ImageRequest imageRequest, ImageRequest.RequestLevel requestLevel, Object obj) {
        boolean z;
        RequestListener b2 = b(imageRequest);
        try {
            ImageRequest.RequestLevel a2 = ImageRequest.RequestLevel.a(imageRequest.m(), requestLevel);
            String f2 = f();
            if (!imageRequest.j() && imageRequest.d() == null) {
                if (UriUtil.a(imageRequest.b())) {
                    z = false;
                    return CloseableProducerToDataSourceAdapter.a(producer, new SettableProducerContext(imageRequest, f2, b2, obj, a2, false, z, imageRequest.l()), b2);
                }
            }
            z = true;
            return CloseableProducerToDataSourceAdapter.a(producer, new SettableProducerContext(imageRequest, f2, b2, obj, a2, false, z, imageRequest.l()), b2);
        } catch (Exception e2) {
            return DataSources.a(e2);
        }
    }

    private DataSource<Void> a(Producer<Void> producer, ImageRequest imageRequest, ImageRequest.RequestLevel requestLevel, Object obj, Priority priority) {
        RequestListener b2 = b(imageRequest);
        try {
            return ProducerToDataSourceAdapter.a(producer, new SettableProducerContext(imageRequest, f(), b2, obj, ImageRequest.RequestLevel.a(imageRequest.m(), requestLevel), true, false, priority), b2);
        } catch (Exception e2) {
            return DataSources.a(e2);
        }
    }

    private RequestListener b(ImageRequest imageRequest) {
        if (imageRequest.q() == null) {
            return this.c;
        }
        return new ForwardingRequestListener(this.c, imageRequest.q());
    }

    private Predicate<CacheKey> c(final Uri uri) {
        return new Predicate<CacheKey>() {
            /* class com.facebook.imagepipeline.core.ImagePipeline.AnonymousClass6 */

            /* renamed from: a */
            public boolean apply(CacheKey cacheKey) {
                return cacheKey.a(uri);
            }
        };
    }

    public CacheKeyFactory e() {
        return this.i;
    }
}
