package com.facebook.imagepipeline.core;

import android.app.ActivityManager;
import android.content.Context;
import android.graphics.Bitmap;
import com.facebook.cache.disk.DiskCacheConfig;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.internal.Supplier;
import com.facebook.common.memory.MemoryTrimmableRegistry;
import com.facebook.common.memory.NoOpMemoryTrimmableRegistry;
import com.facebook.common.webp.BitmapCreator;
import com.facebook.common.webp.WebpBitmapFactory;
import com.facebook.common.webp.WebpSupportStatus;
import com.facebook.imagepipeline.animated.factory.AnimatedImageFactory;
import com.facebook.imagepipeline.bitmaps.HoneycombBitmapCreator;
import com.facebook.imagepipeline.bitmaps.PlatformBitmapFactory;
import com.facebook.imagepipeline.cache.CacheKeyFactory;
import com.facebook.imagepipeline.cache.DefaultBitmapMemoryCacheParamsSupplier;
import com.facebook.imagepipeline.cache.DefaultCacheKeyFactory;
import com.facebook.imagepipeline.cache.DefaultEncodedMemoryCacheParamsSupplier;
import com.facebook.imagepipeline.cache.ImageCacheStatsTracker;
import com.facebook.imagepipeline.cache.MemoryCacheParams;
import com.facebook.imagepipeline.cache.NoOpImageCacheStatsTracker;
import com.facebook.imagepipeline.core.ImagePipelineExperiments;
import com.facebook.imagepipeline.decoder.ImageDecoder;
import com.facebook.imagepipeline.decoder.ImageDecoderConfig;
import com.facebook.imagepipeline.decoder.ProgressiveJpegConfig;
import com.facebook.imagepipeline.decoder.SimpleProgressiveJpegConfig;
import com.facebook.imagepipeline.listener.RequestListener;
import com.facebook.imagepipeline.memory.PoolConfig;
import com.facebook.imagepipeline.memory.PoolFactory;
import com.facebook.imagepipeline.producers.HttpUrlConnectionNetworkFetcher;
import com.facebook.imagepipeline.producers.NetworkFetcher;
import java.util.Collections;
import java.util.HashSet;
import java.util.Set;
import javax.annotation.Nullable;

public class ImagePipelineConfig {
    private static DefaultImageRequestConfig x = new DefaultImageRequestConfig();
    @Nullable

    /* renamed from: a  reason: collision with root package name */
    private final AnimatedImageFactory f1638a;
    private final Bitmap.Config b;
    private final Supplier<MemoryCacheParams> c;
    private final CacheKeyFactory d;
    private final Context e;
    private final boolean f;
    private final FileCacheFactory g;
    private final Supplier<MemoryCacheParams> h;
    private final ExecutorSupplier i;
    private final ImageCacheStatsTracker j;
    @Nullable
    private final ImageDecoder k;
    private final Supplier<Boolean> l;
    private final DiskCacheConfig m;
    private final MemoryTrimmableRegistry n;
    private final NetworkFetcher o;
    @Nullable
    private final PlatformBitmapFactory p;
    private final PoolFactory q;
    private final ProgressiveJpegConfig r;
    private final Set<RequestListener> s;
    private final boolean t;
    private final DiskCacheConfig u;
    @Nullable
    private final ImageDecoderConfig v;
    private final ImagePipelineExperiments w;

    private ImagePipelineConfig(Builder builder) {
        Supplier<MemoryCacheParams> supplier;
        Bitmap.Config config;
        CacheKeyFactory cacheKeyFactory;
        FileCacheFactory fileCacheFactory;
        Supplier<MemoryCacheParams> supplier2;
        ImageCacheStatsTracker imageCacheStatsTracker;
        Supplier<Boolean> supplier3;
        DiskCacheConfig diskCacheConfig;
        MemoryTrimmableRegistry memoryTrimmableRegistry;
        NetworkFetcher networkFetcher;
        PoolFactory poolFactory;
        ProgressiveJpegConfig progressiveJpegConfig;
        Set<RequestListener> set;
        DiskCacheConfig diskCacheConfig2;
        ExecutorSupplier executorSupplier;
        WebpBitmapFactory a2;
        this.w = builder.w.a();
        this.f1638a = builder.f1640a;
        if (builder.c == null) {
            supplier = new DefaultBitmapMemoryCacheParamsSupplier((ActivityManager) builder.e.getSystemService("activity"));
        } else {
            supplier = builder.c;
        }
        this.c = supplier;
        if (builder.b == null) {
            config = Bitmap.Config.ARGB_8888;
        } else {
            config = builder.b;
        }
        this.b = config;
        if (builder.d == null) {
            cacheKeyFactory = DefaultCacheKeyFactory.a();
        } else {
            cacheKeyFactory = builder.d;
        }
        this.d = cacheKeyFactory;
        this.e = (Context) Preconditions.a(builder.e);
        if (builder.u == null) {
            fileCacheFactory = new DiskStorageCacheFactory(new DynamicDefaultDiskStorageFactory());
        } else {
            fileCacheFactory = builder.u;
        }
        this.g = fileCacheFactory;
        this.f = builder.f;
        if (builder.g == null) {
            supplier2 = new DefaultEncodedMemoryCacheParamsSupplier();
        } else {
            supplier2 = builder.g;
        }
        this.h = supplier2;
        if (builder.i == null) {
            imageCacheStatsTracker = NoOpImageCacheStatsTracker.i();
        } else {
            imageCacheStatsTracker = builder.i;
        }
        this.j = imageCacheStatsTracker;
        this.k = builder.j;
        if (builder.k == null) {
            supplier3 = new Supplier<Boolean>() {
                /* class com.facebook.imagepipeline.core.ImagePipelineConfig.AnonymousClass1 */

                /* renamed from: a */
                public Boolean b() {
                    return true;
                }
            };
        } else {
            supplier3 = builder.k;
        }
        this.l = supplier3;
        if (builder.l == null) {
            diskCacheConfig = b(builder.e);
        } else {
            diskCacheConfig = builder.l;
        }
        this.m = diskCacheConfig;
        if (builder.m == null) {
            memoryTrimmableRegistry = NoOpMemoryTrimmableRegistry.a();
        } else {
            memoryTrimmableRegistry = builder.m;
        }
        this.n = memoryTrimmableRegistry;
        if (builder.n == null) {
            networkFetcher = new HttpUrlConnectionNetworkFetcher();
        } else {
            networkFetcher = builder.n;
        }
        this.o = networkFetcher;
        this.p = builder.o;
        if (builder.p == null) {
            poolFactory = new PoolFactory(PoolConfig.i().a());
        } else {
            poolFactory = builder.p;
        }
        this.q = poolFactory;
        if (builder.q == null) {
            progressiveJpegConfig = new SimpleProgressiveJpegConfig();
        } else {
            progressiveJpegConfig = builder.q;
        }
        this.r = progressiveJpegConfig;
        if (builder.r == null) {
            set = new HashSet<>();
        } else {
            set = builder.r;
        }
        this.s = set;
        this.t = builder.s;
        if (builder.t == null) {
            diskCacheConfig2 = this.m;
        } else {
            diskCacheConfig2 = builder.t;
        }
        this.u = diskCacheConfig2;
        this.v = builder.v;
        int c2 = this.q.c();
        if (builder.h == null) {
            executorSupplier = new DefaultExecutorSupplier(c2);
        } else {
            executorSupplier = builder.h;
        }
        this.i = executorSupplier;
        WebpBitmapFactory i2 = this.w.i();
        if (i2 != null) {
            a(i2, this.w, new HoneycombBitmapCreator(p()));
        } else if (this.w.f() && WebpSupportStatus.f1501a && (a2 = WebpSupportStatus.a()) != null) {
            a(a2, this.w, new HoneycombBitmapCreator(p()));
        }
    }

    private static void a(WebpBitmapFactory webpBitmapFactory, ImagePipelineExperiments imagePipelineExperiments, BitmapCreator bitmapCreator) {
        WebpSupportStatus.d = webpBitmapFactory;
        WebpBitmapFactory.WebpErrorLogger h2 = imagePipelineExperiments.h();
        if (h2 != null) {
            webpBitmapFactory.a(h2);
        }
        if (bitmapCreator != null) {
            webpBitmapFactory.a(bitmapCreator);
        }
    }

    private static DiskCacheConfig b(Context context) {
        return DiskCacheConfig.a(context).a();
    }

    public Bitmap.Config a() {
        return this.b;
    }

    public Supplier<MemoryCacheParams> b() {
        return this.c;
    }

    public CacheKeyFactory c() {
        return this.d;
    }

    public Context d() {
        return this.e;
    }

    public static DefaultImageRequestConfig e() {
        return x;
    }

    public FileCacheFactory f() {
        return this.g;
    }

    public boolean g() {
        return this.f;
    }

    public Supplier<MemoryCacheParams> h() {
        return this.h;
    }

    public ExecutorSupplier i() {
        return this.i;
    }

    public ImageCacheStatsTracker j() {
        return this.j;
    }

    @Nullable
    public ImageDecoder k() {
        return this.k;
    }

    public Supplier<Boolean> l() {
        return this.l;
    }

    public DiskCacheConfig m() {
        return this.m;
    }

    public MemoryTrimmableRegistry n() {
        return this.n;
    }

    public NetworkFetcher o() {
        return this.o;
    }

    public PoolFactory p() {
        return this.q;
    }

    public ProgressiveJpegConfig q() {
        return this.r;
    }

    public Set<RequestListener> r() {
        return Collections.unmodifiableSet(this.s);
    }

    public boolean s() {
        return this.t;
    }

    public DiskCacheConfig t() {
        return this.u;
    }

    @Nullable
    public ImageDecoderConfig u() {
        return this.v;
    }

    public ImagePipelineExperiments v() {
        return this.w;
    }

    public static Builder a(Context context) {
        return new Builder(context);
    }

    public static class DefaultImageRequestConfig {

        /* renamed from: a  reason: collision with root package name */
        private boolean f1641a;

        private DefaultImageRequestConfig() {
            this.f1641a = false;
        }

        public boolean a() {
            return this.f1641a;
        }
    }

    public static class Builder {

        /* renamed from: a  reason: collision with root package name */
        private AnimatedImageFactory f1640a;
        private Bitmap.Config b;
        private Supplier<MemoryCacheParams> c;
        private CacheKeyFactory d;
        private final Context e;
        private boolean f;
        private Supplier<MemoryCacheParams> g;
        private ExecutorSupplier h;
        private ImageCacheStatsTracker i;
        private ImageDecoder j;
        private Supplier<Boolean> k;
        private DiskCacheConfig l;
        private MemoryTrimmableRegistry m;
        private NetworkFetcher n;
        private PlatformBitmapFactory o;
        private PoolFactory p;
        private ProgressiveJpegConfig q;
        private Set<RequestListener> r;
        private boolean s;
        private DiskCacheConfig t;
        private FileCacheFactory u;
        private ImageDecoderConfig v;
        private final ImagePipelineExperiments.Builder w;

        private Builder(Context context) {
            this.f = false;
            this.s = true;
            this.w = new ImagePipelineExperiments.Builder(this);
            this.e = (Context) Preconditions.a(context);
        }

        public Builder a(boolean z) {
            this.f = z;
            return this;
        }

        public Builder a(NetworkFetcher networkFetcher) {
            this.n = networkFetcher;
            return this;
        }

        public Builder a(Set<RequestListener> set) {
            this.r = set;
            return this;
        }

        public ImagePipelineConfig a() {
            return new ImagePipelineConfig(this);
        }
    }
}
