package com.facebook.imagepipeline.core;

import android.content.Context;
import android.os.Build;
import android.support.v4.util.Pools;
import com.facebook.cache.common.CacheKey;
import com.facebook.cache.disk.FileCache;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.internal.Suppliers;
import com.facebook.common.memory.PooledByteBuffer;
import com.facebook.imageformat.ImageFormatChecker;
import com.facebook.imagepipeline.animated.factory.AnimatedFactory;
import com.facebook.imagepipeline.animated.factory.AnimatedFactoryProvider;
import com.facebook.imagepipeline.animated.factory.AnimatedImageFactory;
import com.facebook.imagepipeline.bitmaps.ArtBitmapFactory;
import com.facebook.imagepipeline.bitmaps.EmptyJpegGenerator;
import com.facebook.imagepipeline.bitmaps.GingerbreadBitmapFactory;
import com.facebook.imagepipeline.bitmaps.HoneycombBitmapFactory;
import com.facebook.imagepipeline.bitmaps.PlatformBitmapFactory;
import com.facebook.imagepipeline.cache.BitmapCountingMemoryCacheFactory;
import com.facebook.imagepipeline.cache.BitmapMemoryCacheFactory;
import com.facebook.imagepipeline.cache.BufferedDiskCache;
import com.facebook.imagepipeline.cache.CountingMemoryCache;
import com.facebook.imagepipeline.cache.EncodedCountingMemoryCacheFactory;
import com.facebook.imagepipeline.cache.EncodedMemoryCacheFactory;
import com.facebook.imagepipeline.cache.MediaVariationsIndex;
import com.facebook.imagepipeline.cache.MediaVariationsIndexDatabase;
import com.facebook.imagepipeline.cache.MemoryCache;
import com.facebook.imagepipeline.cache.NoOpMediaVariationsIndex;
import com.facebook.imagepipeline.decoder.DefaultImageDecoder;
import com.facebook.imagepipeline.decoder.ImageDecoder;
import com.facebook.imagepipeline.image.CloseableImage;
import com.facebook.imagepipeline.memory.PoolFactory;
import com.facebook.imagepipeline.platform.ArtDecoder;
import com.facebook.imagepipeline.platform.GingerbreadPurgeableDecoder;
import com.facebook.imagepipeline.platform.KitKatPurgeableDecoder;
import com.facebook.imagepipeline.platform.PlatformDecoder;
import com.facebook.imagepipeline.producers.ThreadHandoffProducerQueue;
import javax.annotation.concurrent.NotThreadSafe;

@NotThreadSafe
public class ImagePipelineFactory {

    /* renamed from: a  reason: collision with root package name */
    private static ImagePipelineFactory f1645a;
    private final ThreadHandoffProducerQueue b;
    private final ImagePipelineConfig c;
    private CountingMemoryCache<CacheKey, CloseableImage> d;
    private MemoryCache<CacheKey, CloseableImage> e;
    private CountingMemoryCache<CacheKey, PooledByteBuffer> f;
    private MemoryCache<CacheKey, PooledByteBuffer> g;
    private BufferedDiskCache h;
    private FileCache i;
    private ImageDecoder j;
    private ImagePipeline k;
    private ProducerFactory l;
    private ProducerSequenceFactory m;
    private BufferedDiskCache n;
    private FileCache o;
    private MediaVariationsIndex p;
    private PlatformBitmapFactory q;
    private PlatformDecoder r;
    private AnimatedFactory s;

    public static ImagePipelineFactory a() {
        return (ImagePipelineFactory) Preconditions.a(f1645a, "ImagePipelineFactory was not initialized!");
    }

    public static void a(Context context) {
        a(ImagePipelineConfig.a(context).a());
    }

    public static void a(ImagePipelineConfig imagePipelineConfig) {
        f1645a = new ImagePipelineFactory(imagePipelineConfig);
    }

    public ImagePipelineFactory(ImagePipelineConfig imagePipelineConfig) {
        this.c = (ImagePipelineConfig) Preconditions.a(imagePipelineConfig);
        this.b = new ThreadHandoffProducerQueue(imagePipelineConfig.i().e());
    }

    public AnimatedFactory b() {
        if (this.s == null) {
            this.s = AnimatedFactoryProvider.a(j(), this.c.i());
        }
        return this.s;
    }

    public CountingMemoryCache<CacheKey, CloseableImage> c() {
        if (this.d == null) {
            this.d = BitmapCountingMemoryCacheFactory.a(this.c.b(), this.c.n(), j(), this.c.v().a());
        }
        return this.d;
    }

    public MemoryCache<CacheKey, CloseableImage> d() {
        if (this.e == null) {
            this.e = BitmapMemoryCacheFactory.a(c(), this.c.j());
        }
        return this.e;
    }

    public CountingMemoryCache<CacheKey, PooledByteBuffer> e() {
        if (this.f == null) {
            this.f = EncodedCountingMemoryCacheFactory.a(this.c.h(), this.c.n(), j());
        }
        return this.f;
    }

    public MemoryCache<CacheKey, PooledByteBuffer> f() {
        if (this.g == null) {
            this.g = EncodedMemoryCacheFactory.a(e(), this.c.j());
        }
        return this.g;
    }

    private ImageDecoder n() {
        if (this.j == null) {
            if (this.c.k() != null) {
                this.j = this.c.k();
            } else {
                AnimatedImageFactory a2 = b() != null ? b().a() : null;
                if (this.c.u() == null) {
                    this.j = new DefaultImageDecoder(a2, k(), this.c.a());
                } else {
                    this.j = new DefaultImageDecoder(a2, k(), this.c.a(), this.c.u().a());
                    ImageFormatChecker.a().a(this.c.u().b());
                }
            }
        }
        return this.j;
    }

    public BufferedDiskCache g() {
        if (this.h == null) {
            this.h = new BufferedDiskCache(h(), this.c.p().e(), this.c.p().f(), this.c.i().a(), this.c.i().b(), this.c.j());
        }
        return this.h;
    }

    public FileCache h() {
        if (this.i == null) {
            this.i = this.c.f().a(this.c.m());
        }
        return this.i;
    }

    public ImagePipeline i() {
        if (this.k == null) {
            this.k = new ImagePipeline(p(), this.c.r(), this.c.l(), d(), f(), g(), q(), this.c.c(), this.b, Suppliers.a(false));
        }
        return this.k;
    }

    public static PlatformBitmapFactory a(PoolFactory poolFactory, PlatformDecoder platformDecoder) {
        if (Build.VERSION.SDK_INT >= 21) {
            return new ArtBitmapFactory(poolFactory.a());
        }
        if (Build.VERSION.SDK_INT >= 11) {
            return new HoneycombBitmapFactory(new EmptyJpegGenerator(poolFactory.e()), platformDecoder);
        }
        return new GingerbreadBitmapFactory();
    }

    public PlatformBitmapFactory j() {
        if (this.q == null) {
            this.q = a(this.c.p(), k());
        }
        return this.q;
    }

    public static PlatformDecoder a(PoolFactory poolFactory, boolean z) {
        if (Build.VERSION.SDK_INT >= 21) {
            int c2 = poolFactory.c();
            return new ArtDecoder(poolFactory.a(), c2, new Pools.SynchronizedPool(c2));
        } else if (!z || Build.VERSION.SDK_INT >= 19) {
            return new KitKatPurgeableDecoder(poolFactory.b());
        } else {
            return new GingerbreadPurgeableDecoder();
        }
    }

    public PlatformDecoder k() {
        if (this.r == null) {
            this.r = a(this.c.p(), this.c.v().f());
        }
        return this.r;
    }

    private ProducerFactory o() {
        if (this.l == null) {
            this.l = new ProducerFactory(this.c.d(), this.c.p().g(), n(), this.c.q(), this.c.g(), this.c.s(), this.c.v().g(), this.c.i(), this.c.p().e(), d(), f(), g(), q(), m(), this.c.v().d(), this.c.c(), j(), this.c.v().b());
        }
        return this.l;
    }

    private ProducerSequenceFactory p() {
        if (this.m == null) {
            this.m = new ProducerSequenceFactory(o(), this.c.o(), this.c.s(), this.c.v().f(), this.b, this.c.v().e());
        }
        return this.m;
    }

    public FileCache l() {
        if (this.o == null) {
            this.o = this.c.f().a(this.c.t());
        }
        return this.o;
    }

    private BufferedDiskCache q() {
        if (this.n == null) {
            this.n = new BufferedDiskCache(l(), this.c.p().e(), this.c.p().f(), this.c.i().a(), this.c.i().b(), this.c.j());
        }
        return this.n;
    }

    public MediaVariationsIndex m() {
        if (this.p == null) {
            this.p = this.c.v().c() ? new MediaVariationsIndexDatabase(this.c.d(), this.c.i().a(), this.c.i().b()) : new NoOpMediaVariationsIndex();
        }
        return this.p;
    }
}
