package com.facebook.imagepipeline.core;

import android.net.Uri;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.internal.VisibleForTesting;
import com.facebook.common.memory.PooledByteBuffer;
import com.facebook.common.references.CloseableReference;
import com.facebook.common.webp.WebpSupportStatus;
import com.facebook.imagepipeline.image.CloseableImage;
import com.facebook.imagepipeline.image.EncodedImage;
import com.facebook.imagepipeline.producers.NetworkFetcher;
import com.facebook.imagepipeline.producers.Producer;
import com.facebook.imagepipeline.producers.RemoveImageTransformMetaDataProducer;
import com.facebook.imagepipeline.producers.ThreadHandoffProducerQueue;
import com.facebook.imagepipeline.producers.ThrottlingProducer;
import com.facebook.imagepipeline.producers.ThumbnailProducer;
import com.facebook.imagepipeline.request.ImageRequest;
import java.util.HashMap;
import java.util.Map;

public class ProducerSequenceFactory {
    @VisibleForTesting

    /* renamed from: a  reason: collision with root package name */
    Producer<CloseableReference<CloseableImage>> f1649a;
    @VisibleForTesting
    Producer<EncodedImage> b;
    @VisibleForTesting
    Producer<EncodedImage> c;
    @VisibleForTesting
    Producer<CloseableReference<PooledByteBuffer>> d;
    @VisibleForTesting
    Producer<CloseableReference<PooledByteBuffer>> e;
    @VisibleForTesting
    Producer<Void> f;
    @VisibleForTesting
    Producer<Void> g;
    @VisibleForTesting
    Producer<CloseableReference<CloseableImage>> h;
    @VisibleForTesting
    Producer<CloseableReference<CloseableImage>> i;
    @VisibleForTesting
    Producer<CloseableReference<CloseableImage>> j;
    @VisibleForTesting
    Producer<CloseableReference<CloseableImage>> k;
    @VisibleForTesting
    Producer<CloseableReference<CloseableImage>> l;
    @VisibleForTesting
    Producer<CloseableReference<CloseableImage>> m;
    @VisibleForTesting
    Producer<CloseableReference<CloseableImage>> n;
    @VisibleForTesting
    Map<Producer<CloseableReference<CloseableImage>>, Producer<CloseableReference<CloseableImage>>> o = new HashMap();
    @VisibleForTesting
    Map<Producer<CloseableReference<CloseableImage>>, Producer<Void>> p = new HashMap();
    private final ProducerFactory q;
    private final NetworkFetcher r;
    private final boolean s;
    private final boolean t;
    private final ThreadHandoffProducerQueue u;
    private final boolean v;
    private Producer<EncodedImage> w;

    public ProducerSequenceFactory(ProducerFactory producerFactory, NetworkFetcher networkFetcher, boolean z, boolean z2, ThreadHandoffProducerQueue threadHandoffProducerQueue, boolean z3) {
        this.q = producerFactory;
        this.r = networkFetcher;
        this.s = z;
        this.t = z2;
        this.u = threadHandoffProducerQueue;
        this.v = z3;
    }

    public Producer<CloseableReference<PooledByteBuffer>> a(ImageRequest imageRequest) {
        d(imageRequest);
        Uri b2 = imageRequest.b();
        int c2 = imageRequest.c();
        if (c2 == 0) {
            return a();
        }
        switch (c2) {
            case 2:
            case 3:
                return b();
            default:
                throw new IllegalArgumentException("Unsupported uri scheme for encoded image fetch! Uri is: " + a(b2));
        }
    }

    public Producer<CloseableReference<PooledByteBuffer>> a() {
        synchronized (this) {
            if (this.e == null) {
                this.e = new RemoveImageTransformMetaDataProducer(d());
            }
        }
        return this.e;
    }

    public Producer<CloseableReference<PooledByteBuffer>> b() {
        synchronized (this) {
            if (this.d == null) {
                this.d = new RemoveImageTransformMetaDataProducer(h());
            }
        }
        return this.d;
    }

    public Producer<Void> b(ImageRequest imageRequest) {
        d(imageRequest);
        int c2 = imageRequest.c();
        if (c2 == 0) {
            return e();
        }
        switch (c2) {
            case 2:
            case 3:
                return g();
            default:
                Uri b2 = imageRequest.b();
                throw new IllegalArgumentException("Unsupported uri scheme for encoded image fetch! Uri is: " + a(b2));
        }
    }

    private static void d(ImageRequest imageRequest) {
        Preconditions.a(imageRequest);
        Preconditions.a(imageRequest.m().a() <= ImageRequest.RequestLevel.ENCODED_MEMORY_CACHE.a());
    }

    public Producer<CloseableReference<CloseableImage>> c(ImageRequest imageRequest) {
        Producer<CloseableReference<CloseableImage>> e2 = e(imageRequest);
        return imageRequest.p() != null ? f(e2) : e2;
    }

    private Producer<CloseableReference<CloseableImage>> e(ImageRequest imageRequest) {
        Preconditions.a(imageRequest);
        Uri b2 = imageRequest.b();
        Preconditions.a(b2, "Uri is null.");
        int c2 = imageRequest.c();
        if (c2 == 0) {
            return c();
        }
        switch (c2) {
            case 2:
                return j();
            case 3:
                return i();
            case 4:
                return k();
            case 5:
                return n();
            case 6:
                return m();
            case 7:
                return o();
            case 8:
                return l();
            default:
                throw new IllegalArgumentException("Unsupported uri scheme! Uri is: " + a(b2));
        }
    }

    private synchronized Producer<CloseableReference<CloseableImage>> c() {
        if (this.f1649a == null) {
            this.f1649a = b(f());
        }
        return this.f1649a;
    }

    private synchronized Producer<EncodedImage> d() {
        if (this.c == null) {
            this.c = this.q.a(f(), this.u);
        }
        return this.c;
    }

    private synchronized Producer<Void> e() {
        if (this.g == null) {
            this.g = ProducerFactory.m(d());
        }
        return this.g;
    }

    private synchronized Producer<EncodedImage> f() {
        if (this.w == null) {
            this.w = ProducerFactory.a(c(this.q.a(this.r)));
            this.w = this.q.a(this.w, this.s, this.v);
        }
        return this.w;
    }

    private synchronized Producer<Void> g() {
        if (this.f == null) {
            this.f = ProducerFactory.m(h());
        }
        return this.f;
    }

    private synchronized Producer<EncodedImage> h() {
        if (this.b == null) {
            this.b = this.q.a(c(this.q.f()), this.u);
        }
        return this.b;
    }

    private synchronized Producer<CloseableReference<CloseableImage>> i() {
        if (this.h == null) {
            this.h = a(this.q.f());
        }
        return this.h;
    }

    private synchronized Producer<CloseableReference<CloseableImage>> j() {
        if (this.i == null) {
            this.i = e(this.q.i());
        }
        return this.i;
    }

    private synchronized Producer<CloseableReference<CloseableImage>> k() {
        if (this.j == null) {
            this.j = a(this.q.c(), new ThumbnailProducer[]{this.q.d(), this.q.e()});
        }
        return this.j;
    }

    private synchronized Producer<CloseableReference<CloseableImage>> l() {
        if (this.n == null) {
            this.n = a(this.q.g());
        }
        return this.n;
    }

    private synchronized Producer<CloseableReference<CloseableImage>> m() {
        if (this.k == null) {
            this.k = a(this.q.h());
        }
        return this.k;
    }

    private synchronized Producer<CloseableReference<CloseableImage>> n() {
        if (this.l == null) {
            this.l = a(this.q.b());
        }
        return this.l;
    }

    private synchronized Producer<CloseableReference<CloseableImage>> o() {
        if (this.m == null) {
            Producer<EncodedImage> a2 = this.q.a();
            if (WebpSupportStatus.f1501a && (!this.t || WebpSupportStatus.d == null)) {
                a2 = this.q.o(a2);
            }
            ProducerFactory producerFactory = this.q;
            this.m = b(this.q.a(ProducerFactory.a(a2), true, this.v));
        }
        return this.m;
    }

    private Producer<CloseableReference<CloseableImage>> a(Producer<EncodedImage> producer) {
        return a(producer, new ThumbnailProducer[]{this.q.e()});
    }

    private Producer<CloseableReference<CloseableImage>> a(Producer<EncodedImage> producer, ThumbnailProducer<EncodedImage>[] thumbnailProducerArr) {
        return b(b(c(producer), thumbnailProducerArr));
    }

    private Producer<CloseableReference<CloseableImage>> b(Producer<EncodedImage> producer) {
        return e(this.q.e(producer));
    }

    private Producer<EncodedImage> c(Producer<EncodedImage> producer) {
        if (WebpSupportStatus.f1501a && (!this.t || WebpSupportStatus.d == null)) {
            producer = this.q.o(producer);
        }
        return this.q.i(this.q.j(d(producer)));
    }

    private Producer<EncodedImage> d(Producer<EncodedImage> producer) {
        return this.q.f(this.q.h(this.q.g(producer)));
    }

    private Producer<CloseableReference<CloseableImage>> e(Producer<CloseableReference<CloseableImage>> producer) {
        return this.q.b(this.q.a(this.q.c(this.q.d(producer)), this.u));
    }

    private Producer<EncodedImage> b(Producer<EncodedImage> producer, ThumbnailProducer<EncodedImage>[] thumbnailProducerArr) {
        ThrottlingProducer n2 = this.q.n(this.q.a(ProducerFactory.a(producer), true, this.v));
        ProducerFactory producerFactory = this.q;
        return ProducerFactory.a(a(thumbnailProducerArr), n2);
    }

    private Producer<EncodedImage> a(ThumbnailProducer<EncodedImage>[] thumbnailProducerArr) {
        return this.q.a(this.q.a(thumbnailProducerArr), true, this.v);
    }

    private synchronized Producer<CloseableReference<CloseableImage>> f(Producer<CloseableReference<CloseableImage>> producer) {
        if (!this.o.containsKey(producer)) {
            this.o.put(producer, this.q.k(this.q.l(producer)));
        }
        return this.o.get(producer);
    }

    private static String a(Uri uri) {
        String valueOf = String.valueOf(uri);
        if (valueOf.length() <= 30) {
            return valueOf;
        }
        return valueOf.substring(0, 30) + "...";
    }
}
