package com.facebook.imagepipeline.platform;

import android.annotation.TargetApi;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.support.v4.util.Pools;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.internal.VisibleForTesting;
import com.facebook.common.references.CloseableReference;
import com.facebook.common.streams.LimitedInputStream;
import com.facebook.common.streams.TailAppendingInputStream;
import com.facebook.imagepipeline.image.EncodedImage;
import com.facebook.imagepipeline.memory.BitmapPool;
import com.facebook.imageutils.BitmapUtil;
import java.io.InputStream;
import java.nio.ByteBuffer;
import javax.annotation.concurrent.ThreadSafe;

@ThreadSafe
@TargetApi(21)
public class ArtDecoder implements PlatformDecoder {
    private static final byte[] c = {-1, -39};
    @VisibleForTesting

    /* renamed from: a  reason: collision with root package name */
    final Pools.SynchronizedPool<ByteBuffer> f1687a;
    private final BitmapPool b;

    public ArtDecoder(BitmapPool bitmapPool, int i, Pools.SynchronizedPool synchronizedPool) {
        this.b = bitmapPool;
        this.f1687a = synchronizedPool;
        for (int i2 = 0; i2 < i; i2++) {
            this.f1687a.a(ByteBuffer.allocate(16384));
        }
    }

    @Override // com.facebook.imagepipeline.platform.PlatformDecoder
    public CloseableReference<Bitmap> a(EncodedImage encodedImage, Bitmap.Config config) {
        BitmapFactory.Options b2 = b(encodedImage, config);
        boolean z = b2.inPreferredConfig != Bitmap.Config.ARGB_8888;
        try {
            return a(encodedImage.d(), b2);
        } catch (RuntimeException e) {
            if (z) {
                return a(encodedImage, Bitmap.Config.ARGB_8888);
            }
            throw e;
        }
    }

    @Override // com.facebook.imagepipeline.platform.PlatformDecoder
    public CloseableReference<Bitmap> a(EncodedImage encodedImage, Bitmap.Config config, int i) {
        boolean e = encodedImage.e(i);
        BitmapFactory.Options b2 = b(encodedImage, config);
        InputStream d = encodedImage.d();
        Preconditions.a(d);
        if (encodedImage.k() > i) {
            d = new LimitedInputStream(d, i);
        }
        InputStream tailAppendingInputStream = !e ? new TailAppendingInputStream(d, c) : d;
        boolean z = b2.inPreferredConfig != Bitmap.Config.ARGB_8888;
        try {
            return a(tailAppendingInputStream, b2);
        } catch (RuntimeException e2) {
            if (z) {
                return a(encodedImage, Bitmap.Config.ARGB_8888);
            }
            throw e2;
        }
    }

    /* access modifiers changed from: protected */
    public CloseableReference<Bitmap> a(InputStream inputStream, BitmapFactory.Options options) {
        Preconditions.a(inputStream);
        Bitmap bitmap = (Bitmap) this.b.a(BitmapUtil.a(options.outWidth, options.outHeight, options.inPreferredConfig));
        if (bitmap != null) {
            options.inBitmap = bitmap;
            ByteBuffer a2 = this.f1687a.a();
            if (a2 == null) {
                a2 = ByteBuffer.allocate(16384);
            }
            try {
                options.inTempStorage = a2.array();
                Bitmap decodeStream = BitmapFactory.decodeStream(inputStream, null, options);
                this.f1687a.a(a2);
                if (bitmap == decodeStream) {
                    return CloseableReference.a(decodeStream, this.b);
                }
                this.b.a((Object) bitmap);
                decodeStream.recycle();
                throw new IllegalStateException();
            } catch (RuntimeException e) {
                this.b.a((Object) bitmap);
                throw e;
            } catch (Throwable th) {
                this.f1687a.a(a2);
                throw th;
            }
        } else {
            throw new NullPointerException("BitmapPool.get returned null");
        }
    }

    private static BitmapFactory.Options b(EncodedImage encodedImage, Bitmap.Config config) {
        BitmapFactory.Options options = new BitmapFactory.Options();
        options.inSampleSize = encodedImage.i();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeStream(encodedImage.d(), null, options);
        if (options.outWidth == -1 || options.outHeight == -1) {
            throw new IllegalArgumentException();
        }
        options.inJustDecodeBounds = false;
        options.inDither = true;
        options.inPreferredConfig = config;
        options.inMutable = true;
        return options;
    }
}
