package com.facebook.imagepipeline.producers;

import android.graphics.Bitmap;
import com.facebook.common.internal.ImmutableMap;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.memory.ByteArrayPool;
import com.facebook.common.references.CloseableReference;
import com.facebook.common.util.ExceptionWithNoStacktrace;
import com.facebook.common.util.UriUtil;
import com.facebook.imageformat.DefaultImageFormats;
import com.facebook.imageformat.ImageFormat;
import com.facebook.imagepipeline.common.ImageDecodeOptions;
import com.facebook.imagepipeline.common.ResizeOptions;
import com.facebook.imagepipeline.decoder.ImageDecoder;
import com.facebook.imagepipeline.decoder.ProgressiveJpegConfig;
import com.facebook.imagepipeline.decoder.ProgressiveJpegParser;
import com.facebook.imagepipeline.image.CloseableImage;
import com.facebook.imagepipeline.image.CloseableStaticBitmap;
import com.facebook.imagepipeline.image.EncodedImage;
import com.facebook.imagepipeline.image.ImmutableQualityInfo;
import com.facebook.imagepipeline.image.QualityInfo;
import com.facebook.imagepipeline.producers.JobScheduler;
import com.facebook.imagepipeline.request.ImageRequest;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.Executor;
import javax.annotation.Nullable;
import javax.annotation.concurrent.GuardedBy;

public class DecodeProducer implements Producer<CloseableReference<CloseableImage>> {

    /* renamed from: a  reason: collision with root package name */
    private final ByteArrayPool f1696a;
    private final Executor b;
    private final ImageDecoder c;
    private final ProgressiveJpegConfig d;
    private final Producer<EncodedImage> e;
    private final boolean f;
    private final boolean g;
    private final boolean h;

    public DecodeProducer(ByteArrayPool byteArrayPool, Executor executor, ImageDecoder imageDecoder, ProgressiveJpegConfig progressiveJpegConfig, boolean z, boolean z2, boolean z3, Producer<EncodedImage> producer) {
        this.f1696a = (ByteArrayPool) Preconditions.a(byteArrayPool);
        this.b = (Executor) Preconditions.a(executor);
        this.c = (ImageDecoder) Preconditions.a(imageDecoder);
        this.d = (ProgressiveJpegConfig) Preconditions.a(progressiveJpegConfig);
        this.f = z;
        this.g = z2;
        this.e = (Producer) Preconditions.a(producer);
        this.h = z3;
    }

    @Override // com.facebook.imagepipeline.producers.Producer
    public void a(Consumer<CloseableReference<CloseableImage>> consumer, ProducerContext producerContext) {
        Consumer<EncodedImage> consumer2;
        if (!UriUtil.a(producerContext.a().b())) {
            consumer2 = new LocalImagesProgressiveDecoder(consumer, producerContext, this.h);
        } else {
            consumer2 = new NetworkImagesProgressiveDecoder(consumer, producerContext, new ProgressiveJpegParser(this.f1696a), this.d, this.h);
        }
        this.e.a(consumer2, producerContext);
    }

    private abstract class ProgressiveDecoder extends DelegatingConsumer<EncodedImage, CloseableReference<CloseableImage>> {

        /* renamed from: a  reason: collision with root package name */
        private final ProducerContext f1699a;
        private final ProducerListener c;
        private final ImageDecodeOptions d;
        @GuardedBy
        private boolean e = false;
        private final JobScheduler f;

        /* access modifiers changed from: protected */
        public abstract int a(EncodedImage encodedImage);

        /* access modifiers changed from: protected */
        public abstract QualityInfo c();

        public ProgressiveDecoder(Consumer<CloseableReference<CloseableImage>> consumer, final ProducerContext producerContext, final boolean z) {
            super(consumer);
            this.f1699a = producerContext;
            this.c = producerContext.c();
            this.d = producerContext.a().i();
            this.f = new JobScheduler(DecodeProducer.this.b, new JobScheduler.JobRunnable(DecodeProducer.this) {
                /* class com.facebook.imagepipeline.producers.DecodeProducer.ProgressiveDecoder.AnonymousClass1 */

                @Override // com.facebook.imagepipeline.producers.JobScheduler.JobRunnable
                public void a(EncodedImage encodedImage, boolean z) {
                    if (encodedImage != null) {
                        if (DecodeProducer.this.f) {
                            ImageRequest a2 = producerContext.a();
                            if (DecodeProducer.this.g || !UriUtil.a(a2.b())) {
                                encodedImage.d(DownsampleUtil.a(a2, encodedImage));
                            }
                        }
                        ProgressiveDecoder.this.c(encodedImage, z);
                    }
                }
            }, this.d.f1623a);
            this.f1699a.a(new BaseProducerContextCallbacks(DecodeProducer.this) {
                /* class com.facebook.imagepipeline.producers.DecodeProducer.ProgressiveDecoder.AnonymousClass2 */

                @Override // com.facebook.imagepipeline.producers.BaseProducerContextCallbacks, com.facebook.imagepipeline.producers.ProducerContextCallbacks
                public void c() {
                    if (ProgressiveDecoder.this.f1699a.h()) {
                        ProgressiveDecoder.this.f.b();
                    }
                }

                @Override // com.facebook.imagepipeline.producers.BaseProducerContextCallbacks, com.facebook.imagepipeline.producers.ProducerContextCallbacks
                public void a() {
                    if (z) {
                        ProgressiveDecoder.this.f();
                    }
                }
            });
        }

        /* renamed from: b */
        public void a(EncodedImage encodedImage, boolean z) {
            if (z && !EncodedImage.e(encodedImage)) {
                c(new ExceptionWithNoStacktrace("Encoded image is not valid."));
            } else if (a(encodedImage, z)) {
                if (z || this.f1699a.h()) {
                    this.f.b();
                }
            }
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.imagepipeline.producers.BaseConsumer, com.facebook.imagepipeline.producers.DelegatingConsumer
        public void a(float f2) {
            super.a(f2 * 0.99f);
        }

        @Override // com.facebook.imagepipeline.producers.BaseConsumer, com.facebook.imagepipeline.producers.DelegatingConsumer
        public void a(Throwable th) {
            c(th);
        }

        @Override // com.facebook.imagepipeline.producers.BaseConsumer, com.facebook.imagepipeline.producers.DelegatingConsumer
        public void a() {
            f();
        }

        /* access modifiers changed from: protected */
        public boolean a(EncodedImage encodedImage, boolean z) {
            return this.f.a(encodedImage, z);
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void c(EncodedImage encodedImage, boolean z) {
            String str;
            String str2;
            String str3;
            if (!e() && EncodedImage.e(encodedImage)) {
                ImageFormat e2 = encodedImage.e();
                String a2 = e2 != null ? e2.a() : "unknown";
                if (encodedImage != null) {
                    str = encodedImage.g() + "x" + encodedImage.h();
                    str2 = String.valueOf(encodedImage.i());
                } else {
                    str = "unknown";
                    str2 = "unknown";
                }
                ResizeOptions g = this.f1699a.a().g();
                if (g != null) {
                    str3 = g.f1626a + "x" + g.b;
                } else {
                    str3 = "unknown";
                }
                try {
                    long c2 = this.f.c();
                    int k = z ? encodedImage.k() : a(encodedImage);
                    QualityInfo c3 = z ? ImmutableQualityInfo.f1661a : c();
                    this.c.a(this.f1699a.b(), "DecodeProducer");
                    try {
                        CloseableImage a3 = DecodeProducer.this.c.a(encodedImage, k, c3, this.d);
                        this.c.a(this.f1699a.b(), "DecodeProducer", a(a3, c2, c3, z, a2, str, str3, str2));
                        a(a3, z);
                    } catch (Exception e3) {
                        this.c.a(this.f1699a.b(), "DecodeProducer", e3, a(null, c2, c3, z, a2, str, str3, str2));
                        c(e3);
                        EncodedImage.d(encodedImage);
                    }
                } finally {
                    EncodedImage.d(encodedImage);
                }
            }
        }

        private Map<String, String> a(@Nullable CloseableImage closeableImage, long j, QualityInfo qualityInfo, boolean z, String str, String str2, String str3, String str4) {
            if (!this.c.b(this.f1699a.b())) {
                return null;
            }
            String valueOf = String.valueOf(j);
            String valueOf2 = String.valueOf(qualityInfo.b());
            String valueOf3 = String.valueOf(z);
            if (closeableImage instanceof CloseableStaticBitmap) {
                Bitmap a2 = ((CloseableStaticBitmap) closeableImage).a();
                HashMap hashMap = new HashMap(8);
                hashMap.put("bitmapSize", a2.getWidth() + "x" + a2.getHeight());
                hashMap.put("queueTime", valueOf);
                hashMap.put("hasGoodQuality", valueOf2);
                hashMap.put("isFinal", valueOf3);
                hashMap.put("encodedImageSize", str2);
                hashMap.put("imageFormat", str);
                hashMap.put("requestedImageSize", str3);
                hashMap.put("sampleSize", str4);
                return ImmutableMap.a(hashMap);
            }
            HashMap hashMap2 = new HashMap(7);
            hashMap2.put("queueTime", valueOf);
            hashMap2.put("hasGoodQuality", valueOf2);
            hashMap2.put("isFinal", valueOf3);
            hashMap2.put("encodedImageSize", str2);
            hashMap2.put("imageFormat", str);
            hashMap2.put("requestedImageSize", str3);
            hashMap2.put("sampleSize", str4);
            return ImmutableMap.a(hashMap2);
        }

        private synchronized boolean e() {
            return this.e;
        }

        private void a(boolean z) {
            synchronized (this) {
                if (z) {
                    if (!this.e) {
                        d().b(1.0f);
                        this.e = true;
                        this.f.a();
                    }
                }
            }
        }

        private void a(CloseableImage closeableImage, boolean z) {
            CloseableReference a2 = CloseableReference.a(closeableImage);
            try {
                a(z);
                d().b(a2, z);
            } finally {
                CloseableReference.c(a2);
            }
        }

        private void c(Throwable th) {
            a(true);
            d().b(th);
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void f() {
            a(true);
            d().b();
        }
    }

    private class LocalImagesProgressiveDecoder extends ProgressiveDecoder {
        public LocalImagesProgressiveDecoder(Consumer<CloseableReference<CloseableImage>> consumer, ProducerContext producerContext, boolean z) {
            super(consumer, producerContext, z);
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.imagepipeline.producers.DecodeProducer.ProgressiveDecoder
        public synchronized boolean a(EncodedImage encodedImage, boolean z) {
            if (!z) {
                return false;
            }
            return super.a(encodedImage, z);
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.imagepipeline.producers.DecodeProducer.ProgressiveDecoder
        public int a(EncodedImage encodedImage) {
            return encodedImage.k();
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.imagepipeline.producers.DecodeProducer.ProgressiveDecoder
        public QualityInfo c() {
            return ImmutableQualityInfo.a(0, false, false);
        }
    }

    private class NetworkImagesProgressiveDecoder extends ProgressiveDecoder {
        private final ProgressiveJpegParser c;
        private final ProgressiveJpegConfig d;
        private int e = 0;

        public NetworkImagesProgressiveDecoder(Consumer<CloseableReference<CloseableImage>> consumer, ProducerContext producerContext, ProgressiveJpegParser progressiveJpegParser, ProgressiveJpegConfig progressiveJpegConfig, boolean z) {
            super(consumer, producerContext, z);
            this.c = (ProgressiveJpegParser) Preconditions.a(progressiveJpegParser);
            this.d = (ProgressiveJpegConfig) Preconditions.a(progressiveJpegConfig);
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.imagepipeline.producers.DecodeProducer.ProgressiveDecoder
        public synchronized boolean a(EncodedImage encodedImage, boolean z) {
            boolean a2 = super.a(encodedImage, z);
            if (!z && EncodedImage.e(encodedImage) && encodedImage.e() == DefaultImageFormats.f1575a) {
                if (!this.c.a(encodedImage)) {
                    return false;
                }
                int b = this.c.b();
                if (b <= this.e) {
                    return false;
                }
                if (b < this.d.a(this.e) && !this.c.c()) {
                    return false;
                }
                this.e = b;
            }
            return a2;
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.imagepipeline.producers.DecodeProducer.ProgressiveDecoder
        public int a(EncodedImage encodedImage) {
            return this.c.a();
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.imagepipeline.producers.DecodeProducer.ProgressiveDecoder
        public QualityInfo c() {
            return this.d.b(this.c.b());
        }
    }
}
