package com.facebook.imagepipeline.producers;

import android.content.ContentResolver;
import android.database.Cursor;
import android.graphics.Rect;
import android.media.ExifInterface;
import android.net.Uri;
import android.provider.MediaStore;
import com.facebook.common.logging.FLog;
import com.facebook.common.memory.PooledByteBufferFactory;
import com.facebook.common.util.UriUtil;
import com.facebook.imagepipeline.common.ResizeOptions;
import com.facebook.imagepipeline.image.EncodedImage;
import com.facebook.imagepipeline.request.ImageRequest;
import com.facebook.imageutils.JfifUtil;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.concurrent.Executor;
import javax.annotation.Nullable;

public class LocalContentUriThumbnailFetchProducer extends LocalFetchProducer implements ThumbnailProducer<EncodedImage> {

    /* renamed from: a  reason: collision with root package name */
    private static final Class<?> f1722a = LocalContentUriThumbnailFetchProducer.class;
    private static final String[] b = {"_id", "_data"};
    private static final String[] c = {"_data"};
    private static final Rect d = new Rect(0, 0, 512, 384);
    private static final Rect e = new Rect(0, 0, 96, 96);
    private final ContentResolver f;

    /* access modifiers changed from: protected */
    @Override // com.facebook.imagepipeline.producers.LocalFetchProducer
    public String a() {
        return "LocalContentUriThumbnailFetchProducer";
    }

    public LocalContentUriThumbnailFetchProducer(Executor executor, PooledByteBufferFactory pooledByteBufferFactory, ContentResolver contentResolver) {
        super(executor, pooledByteBufferFactory);
        this.f = contentResolver;
    }

    @Override // com.facebook.imagepipeline.producers.ThumbnailProducer
    public boolean a(ResizeOptions resizeOptions) {
        return ThumbnailSizeChecker.a(d.width(), d.height(), resizeOptions);
    }

    /* access modifiers changed from: protected */
    @Override // com.facebook.imagepipeline.producers.LocalFetchProducer
    public EncodedImage a(ImageRequest imageRequest) throws IOException {
        EncodedImage a2;
        Uri b2 = imageRequest.b();
        if (!UriUtil.e(b2) || (a2 = a(b2, imageRequest.g())) == null) {
            return null;
        }
        return a2;
    }

    @Nullable
    private EncodedImage a(Uri uri, ResizeOptions resizeOptions) throws IOException {
        EncodedImage a2;
        Cursor query = this.f.query(uri, b, null, null, null);
        if (query == null) {
            return null;
        }
        try {
            if (query.getCount() == 0) {
                return null;
            }
            query.moveToFirst();
            String string = query.getString(query.getColumnIndex("_data"));
            if (resizeOptions == null || (a2 = a(resizeOptions, query.getInt(query.getColumnIndex("_id")))) == null) {
                query.close();
                return null;
            }
            a2.c(b(string));
            query.close();
            return a2;
        } finally {
            query.close();
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:25:0x0056  */
    private EncodedImage a(ResizeOptions resizeOptions, int i) throws IOException {
        Throwable th;
        Cursor cursor;
        int b2 = b(resizeOptions);
        if (b2 == 0) {
            return null;
        }
        try {
            cursor = MediaStore.Images.Thumbnails.queryMiniThumbnail(this.f, (long) i, b2, c);
            if (cursor == null) {
                if (cursor != null) {
                    cursor.close();
                }
                return null;
            }
            try {
                cursor.moveToFirst();
                if (cursor.getCount() > 0) {
                    String string = cursor.getString(cursor.getColumnIndex("_data"));
                    if (new File(string).exists()) {
                        EncodedImage b3 = b(new FileInputStream(string), a(string));
                        if (cursor != null) {
                            cursor.close();
                        }
                        return b3;
                    }
                }
                if (cursor != null) {
                    cursor.close();
                }
                return null;
            } catch (Throwable th2) {
                th = th2;
                if (cursor != null) {
                    cursor.close();
                }
                throw th;
            }
        } catch (Throwable th3) {
            th = th3;
            cursor = null;
            if (cursor != null) {
            }
            throw th;
        }
    }

    private static int b(ResizeOptions resizeOptions) {
        if (ThumbnailSizeChecker.a(e.width(), e.height(), resizeOptions)) {
            return 3;
        }
        return ThumbnailSizeChecker.a(d.width(), d.height(), resizeOptions) ? 1 : 0;
    }

    private static int a(String str) {
        if (str == null) {
            return -1;
        }
        return (int) new File(str).length();
    }

    private static int b(String str) {
        if (str != null) {
            try {
                return JfifUtil.a(new ExifInterface(str).getAttributeInt("Orientation", 1));
            } catch (IOException e2) {
                FLog.b(f1722a, e2, "Unable to retrieve thumbnail rotation for %s", str);
            }
        }
        return 0;
    }
}
