package com.facebook.imagepipeline.producers;

import android.content.ContentResolver;
import android.media.ExifInterface;
import android.net.Uri;
import android.util.Pair;
import com.facebook.common.internal.ImmutableMap;
import com.facebook.common.internal.VisibleForTesting;
import com.facebook.common.memory.PooledByteBuffer;
import com.facebook.common.memory.PooledByteBufferFactory;
import com.facebook.common.memory.PooledByteBufferInputStream;
import com.facebook.common.references.CloseableReference;
import com.facebook.common.util.UriUtil;
import com.facebook.imageformat.DefaultImageFormats;
import com.facebook.imagepipeline.common.ResizeOptions;
import com.facebook.imagepipeline.image.EncodedImage;
import com.facebook.imagepipeline.request.ImageRequest;
import com.facebook.imageutils.BitmapUtil;
import com.facebook.imageutils.JfifUtil;
import java.io.File;
import java.io.IOException;
import java.util.Map;
import java.util.concurrent.Executor;

public class LocalExifThumbnailProducer implements ThumbnailProducer<EncodedImage> {

    /* renamed from: a  reason: collision with root package name */
    private final Executor f1723a;
    private final PooledByteBufferFactory b;
    private final ContentResolver c;

    public LocalExifThumbnailProducer(Executor executor, PooledByteBufferFactory pooledByteBufferFactory, ContentResolver contentResolver) {
        this.f1723a = executor;
        this.b = pooledByteBufferFactory;
        this.c = contentResolver;
    }

    @Override // com.facebook.imagepipeline.producers.ThumbnailProducer
    public boolean a(ResizeOptions resizeOptions) {
        return ThumbnailSizeChecker.a(512, 512, resizeOptions);
    }

    @Override // com.facebook.imagepipeline.producers.Producer
    public void a(Consumer<EncodedImage> consumer, ProducerContext producerContext) {
        ProducerListener c2 = producerContext.c();
        String b2 = producerContext.b();
        final ImageRequest a2 = producerContext.a();
        final AnonymousClass1 r7 = new StatefulProducerRunnable<EncodedImage>(consumer, c2, "LocalExifThumbnailProducer", b2) {
            /* class com.facebook.imagepipeline.producers.LocalExifThumbnailProducer.AnonymousClass1 */

            /* access modifiers changed from: protected */
            /* renamed from: d */
            public EncodedImage c() throws Exception {
                ExifInterface a2 = LocalExifThumbnailProducer.this.a(a2.b());
                if (a2 == null || !a2.hasThumbnail()) {
                    return null;
                }
                return LocalExifThumbnailProducer.this.a((LocalExifThumbnailProducer) LocalExifThumbnailProducer.this.b.a(a2.getThumbnail()), (PooledByteBuffer) a2);
            }

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public void b(EncodedImage encodedImage) {
                EncodedImage.d(encodedImage);
            }

            /* access modifiers changed from: protected */
            /* renamed from: b */
            public Map<String, String> c(EncodedImage encodedImage) {
                return ImmutableMap.a("createdThumbnail", Boolean.toString(encodedImage != null));
            }
        };
        producerContext.a(new BaseProducerContextCallbacks() {
            /* class com.facebook.imagepipeline.producers.LocalExifThumbnailProducer.AnonymousClass2 */

            @Override // com.facebook.imagepipeline.producers.BaseProducerContextCallbacks, com.facebook.imagepipeline.producers.ProducerContextCallbacks
            public void a() {
                r7.a();
            }
        });
        this.f1723a.execute(r7);
    }

    /* access modifiers changed from: package-private */
    @VisibleForTesting
    public ExifInterface a(Uri uri) throws IOException {
        String a2 = UriUtil.a(this.c, uri);
        if (a(a2)) {
            return new ExifInterface(a2);
        }
        return null;
    }

    /* JADX INFO: finally extract failed */
    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private EncodedImage a(PooledByteBuffer pooledByteBuffer, ExifInterface exifInterface) {
        Pair<Integer, Integer> a2 = BitmapUtil.a(new PooledByteBufferInputStream(pooledByteBuffer));
        int a3 = a(exifInterface);
        int i = -1;
        int intValue = a2 != null ? ((Integer) a2.first).intValue() : -1;
        if (a2 != null) {
            i = ((Integer) a2.second).intValue();
        }
        CloseableReference a4 = CloseableReference.a(pooledByteBuffer);
        try {
            EncodedImage encodedImage = new EncodedImage(a4);
            CloseableReference.c(a4);
            encodedImage.a(DefaultImageFormats.f1575a);
            encodedImage.c(a3);
            encodedImage.b(intValue);
            encodedImage.a(i);
            return encodedImage;
        } catch (Throwable th) {
            CloseableReference.c(a4);
            throw th;
        }
    }

    private int a(ExifInterface exifInterface) {
        return JfifUtil.a(Integer.parseInt(exifInterface.getAttribute("Orientation")));
    }

    /* access modifiers changed from: package-private */
    @VisibleForTesting
    public boolean a(String str) throws IOException {
        if (str == null) {
            return false;
        }
        File file = new File(str);
        if (!file.exists() || !file.canRead()) {
            return false;
        }
        return true;
    }
}
