package com.facebook.imagepipeline.producers;

import com.facebook.common.internal.Preconditions;
import com.facebook.common.memory.PooledByteBufferFactory;
import com.facebook.common.memory.PooledByteBufferOutputStream;
import com.facebook.common.references.CloseableReference;
import com.facebook.common.util.TriState;
import com.facebook.imageformat.DefaultImageFormats;
import com.facebook.imageformat.ImageFormat;
import com.facebook.imageformat.ImageFormatChecker;
import com.facebook.imagepipeline.image.EncodedImage;
import com.facebook.imagepipeline.nativecode.WebpTranscoder;
import com.facebook.imagepipeline.nativecode.WebpTranscoderFactory;
import java.io.InputStream;
import java.util.concurrent.Executor;
import javax.annotation.Nullable;

public class WebpTranscodeProducer implements Producer<EncodedImage> {

    /* renamed from: a  reason: collision with root package name */
    private final Executor f1768a;
    private final PooledByteBufferFactory b;
    private final Producer<EncodedImage> c;

    public WebpTranscodeProducer(Executor executor, PooledByteBufferFactory pooledByteBufferFactory, Producer<EncodedImage> producer) {
        this.f1768a = (Executor) Preconditions.a(executor);
        this.b = (PooledByteBufferFactory) Preconditions.a(pooledByteBufferFactory);
        this.c = (Producer) Preconditions.a(producer);
    }

    @Override // com.facebook.imagepipeline.producers.Producer
    public void a(Consumer<EncodedImage> consumer, ProducerContext producerContext) {
        this.c.a(new WebpTranscodeConsumer(consumer, producerContext), producerContext);
    }

    private class WebpTranscodeConsumer extends DelegatingConsumer<EncodedImage, EncodedImage> {
        private final ProducerContext b;
        private TriState c = TriState.UNSET;

        public WebpTranscodeConsumer(Consumer<EncodedImage> consumer, ProducerContext producerContext) {
            super(consumer);
            this.b = producerContext;
        }

        /* access modifiers changed from: protected */
        public void a(@Nullable EncodedImage encodedImage, boolean z) {
            if (this.c == TriState.UNSET && encodedImage != null) {
                this.c = WebpTranscodeProducer.b(encodedImage);
            }
            if (this.c == TriState.NO) {
                d().b(encodedImage, z);
            } else if (!z) {
            } else {
                if (this.c != TriState.YES || encodedImage == null) {
                    d().b(encodedImage, z);
                } else {
                    WebpTranscodeProducer.this.a(encodedImage, d(), this.b);
                }
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void a(EncodedImage encodedImage, Consumer<EncodedImage> consumer, ProducerContext producerContext) {
        Preconditions.a(encodedImage);
        final EncodedImage a2 = EncodedImage.a(encodedImage);
        this.f1768a.execute(new StatefulProducerRunnable<EncodedImage>(consumer, producerContext.c(), "WebpTranscodeProducer", producerContext.b()) {
            /* class com.facebook.imagepipeline.producers.WebpTranscodeProducer.AnonymousClass1 */

            /* JADX INFO: finally extract failed */
            /* access modifiers changed from: protected */
            /* renamed from: d */
            public EncodedImage c() throws Exception {
                PooledByteBufferOutputStream a2 = WebpTranscodeProducer.this.b.a();
                try {
                    WebpTranscodeProducer.b(a2, a2);
                    CloseableReference a3 = CloseableReference.a(a2.a());
                    try {
                        EncodedImage encodedImage = new EncodedImage(a3);
                        encodedImage.b(a2);
                        CloseableReference.c(a3);
                        return encodedImage;
                    } catch (Throwable th) {
                        CloseableReference.c(a3);
                        throw th;
                    }
                } finally {
                    a2.close();
                }
            }

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public void b(EncodedImage encodedImage) {
                EncodedImage.d(encodedImage);
            }

            /* access modifiers changed from: protected */
            /* renamed from: b */
            public void a(EncodedImage encodedImage) {
                EncodedImage.d(a2);
                super.a((Object) encodedImage);
            }

            /* access modifiers changed from: protected */
            @Override // com.facebook.imagepipeline.producers.StatefulProducerRunnable, com.facebook.common.executors.StatefulRunnable
            public void a(Exception exc) {
                EncodedImage.d(a2);
                super.a(exc);
            }

            /* access modifiers changed from: protected */
            @Override // com.facebook.imagepipeline.producers.StatefulProducerRunnable, com.facebook.common.executors.StatefulRunnable
            public void b() {
                EncodedImage.d(a2);
                super.b();
            }
        });
    }

    /* access modifiers changed from: private */
    public static TriState b(EncodedImage encodedImage) {
        Preconditions.a(encodedImage);
        ImageFormat c2 = ImageFormatChecker.c(encodedImage.d());
        if (DefaultImageFormats.b(c2)) {
            WebpTranscoder a2 = WebpTranscoderFactory.a();
            if (a2 == null) {
                return TriState.NO;
            }
            return TriState.a(!a2.a(c2));
        } else if (c2 == ImageFormat.f1576a) {
            return TriState.UNSET;
        } else {
            return TriState.NO;
        }
    }

    /* access modifiers changed from: private */
    public static void b(EncodedImage encodedImage, PooledByteBufferOutputStream pooledByteBufferOutputStream) throws Exception {
        InputStream d = encodedImage.d();
        ImageFormat c2 = ImageFormatChecker.c(d);
        if (c2 == DefaultImageFormats.e || c2 == DefaultImageFormats.g) {
            WebpTranscoderFactory.a().a(d, pooledByteBufferOutputStream, 80);
            encodedImage.a(DefaultImageFormats.f1575a);
        } else if (c2 == DefaultImageFormats.f || c2 == DefaultImageFormats.h) {
            WebpTranscoderFactory.a().a(d, pooledByteBufferOutputStream);
            encodedImage.a(DefaultImageFormats.b);
        } else {
            throw new IllegalArgumentException("Wrong image format");
        }
    }
}
