package com.facebook.react;

import com.facebook.common.logging.FLog;
import com.facebook.react.bridge.BaseJavaModule;
import com.facebook.react.bridge.ModuleHolder;
import com.facebook.react.bridge.ModuleSpec;
import com.facebook.react.bridge.NativeModule;
import com.facebook.react.bridge.NativeModuleRegistry;
import com.facebook.react.bridge.OnBatchCompleteListener;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactMarker;
import com.facebook.react.bridge.ReactMarkerConstants;
import com.facebook.react.module.model.ReactModuleInfo;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class NativeModuleRegistryBuilder {

    /* renamed from: a  reason: collision with root package name */
    private final ReactApplicationContext f1807a;
    private final ReactInstanceManager b;
    private final boolean c;
    private final Map<Class<? extends NativeModule>, ModuleHolder> d = new HashMap();
    private final Map<String, Class<? extends NativeModule>> e = new HashMap();

    public NativeModuleRegistryBuilder(ReactApplicationContext reactApplicationContext, ReactInstanceManager reactInstanceManager, boolean z) {
        this.f1807a = reactApplicationContext;
        this.b = reactInstanceManager;
        this.c = z;
    }

    /* JADX INFO: finally extract failed */
    public void a(ReactPackage reactPackage) {
        List<NativeModule> list;
        ModuleHolder moduleHolder;
        if (!this.c) {
            FLog.a("ReactNative", reactPackage.getClass().getSimpleName() + " is not a LazyReactPackage, falling back to old version.");
            if (reactPackage instanceof ReactInstancePackage) {
                list = ((ReactInstancePackage) reactPackage).a(this.f1807a, this.b);
            } else {
                list = reactPackage.a(this.f1807a);
            }
            for (NativeModule nativeModule : list) {
                a(nativeModule);
            }
        } else if (reactPackage instanceof LazyReactPackage) {
            LazyReactPackage lazyReactPackage = (LazyReactPackage) reactPackage;
            List<ModuleSpec> c2 = lazyReactPackage.c(this.f1807a);
            Map<Class, ReactModuleInfo> a2 = lazyReactPackage.a().a();
            for (ModuleSpec moduleSpec : c2) {
                Class<? extends NativeModule> a3 = moduleSpec.a();
                ReactModuleInfo reactModuleInfo = a2.get(a3);
                if (reactModuleInfo != null) {
                    moduleHolder = new ModuleHolder(reactModuleInfo, moduleSpec.b());
                } else if (!BaseJavaModule.class.isAssignableFrom(a3)) {
                    ReactMarker.logMarker(ReactMarkerConstants.CREATE_MODULE_START, moduleSpec.a().getName());
                    try {
                        NativeModule nativeModule2 = (NativeModule) moduleSpec.b().b();
                        ReactMarker.logMarker(ReactMarkerConstants.CREATE_MODULE_END);
                        moduleHolder = new ModuleHolder(nativeModule2);
                    } catch (Throwable th) {
                        ReactMarker.logMarker(ReactMarkerConstants.CREATE_MODULE_END);
                        throw th;
                    }
                } else {
                    throw new IllegalStateException("Native Java module " + a3.getSimpleName() + " should be annotated with @ReactModule and added to a @ReactModuleList.");
                }
                String name = moduleHolder.getName();
                if (this.e.containsKey(name)) {
                    Class<? extends NativeModule> cls = this.e.get(name);
                    if (moduleHolder.d()) {
                        this.d.remove(cls);
                    } else {
                        throw new IllegalStateException("Native module " + a3.getSimpleName() + " tried to override " + cls.getSimpleName() + " for module name " + name + ". If this was your intention, set canOverrideExistingModule=true");
                    }
                }
                this.e.put(name, a3);
                this.d.put(a3, moduleHolder);
            }
        } else {
            throw new IllegalStateException("Lazy native modules requires all ReactPackage to inherit from LazyReactPackage");
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r2v2, resolved type: java.util.Map<java.lang.String, java.lang.Class<? extends com.facebook.react.bridge.NativeModule>> */
    /* JADX DEBUG: Multi-variable search result rejected for r6v1, resolved type: java.util.Map<java.lang.Class<? extends com.facebook.react.bridge.NativeModule>, com.facebook.react.bridge.ModuleHolder> */
    /* JADX WARN: Multi-variable type inference failed */
    public void a(NativeModule nativeModule) {
        String name = nativeModule.getName();
        Class<?> cls = nativeModule.getClass();
        if (this.e.containsKey(name)) {
            Class<? extends NativeModule> cls2 = this.e.get(name);
            if (nativeModule.canOverrideExistingModule()) {
                this.d.remove(cls2);
            } else {
                throw new IllegalStateException("Native module " + cls.getSimpleName() + " tried to override " + cls2.getSimpleName() + " for module name " + name + ". If this was your intention, set canOverrideExistingModule=true");
            }
        }
        this.e.put(name, cls);
        this.d.put(cls, new ModuleHolder(nativeModule));
    }

    public NativeModuleRegistry a() {
        ArrayList arrayList = new ArrayList();
        for (Map.Entry<Class<? extends NativeModule>, ModuleHolder> entry : this.d.entrySet()) {
            if (OnBatchCompleteListener.class.isAssignableFrom(entry.getKey())) {
                arrayList.add(entry.getValue());
            }
        }
        return new NativeModuleRegistry(this.f1807a, this.d, arrayList);
    }
}
