package com.facebook.react;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Process;
import android.support.v4.view.ViewCompat;
import android.util.Log;
import android.view.View;
import com.facebook.common.logging.FLog;
import com.facebook.debug.holder.PrinterHolder;
import com.facebook.debug.tags.ReactDebugOverlayTags;
import com.facebook.infer.annotation.Assertions;
import com.facebook.infer.annotation.ThreadConfined;
import com.facebook.infer.annotation.ThreadSafe;
import com.facebook.react.bridge.CatalystInstance;
import com.facebook.react.bridge.CatalystInstanceImpl;
import com.facebook.react.bridge.JSBundleLoader;
import com.facebook.react.bridge.JSIModulesProvider;
import com.facebook.react.bridge.JavaJSExecutor;
import com.facebook.react.bridge.JavaScriptExecutor;
import com.facebook.react.bridge.JavaScriptExecutorFactory;
import com.facebook.react.bridge.NativeModuleCallExceptionHandler;
import com.facebook.react.bridge.NativeModuleRegistry;
import com.facebook.react.bridge.NotThreadSafeBridgeIdleDebugListener;
import com.facebook.react.bridge.ProxyJavaScriptExecutor;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReactMarker;
import com.facebook.react.bridge.ReactMarkerConstants;
import com.facebook.react.bridge.UIManager;
import com.facebook.react.bridge.UiThreadUtil;
import com.facebook.react.bridge.queue.ReactQueueConfigurationSpec;
import com.facebook.react.common.LifecycleState;
import com.facebook.react.common.annotations.VisibleForTesting;
import com.facebook.react.devsupport.DevSupportManagerFactory;
import com.facebook.react.devsupport.ReactInstanceManagerDevHelper;
import com.facebook.react.devsupport.RedBoxHandler;
import com.facebook.react.devsupport.interfaces.DevBundleDownloadListener;
import com.facebook.react.devsupport.interfaces.DevSupportManager;
import com.facebook.react.devsupport.interfaces.PackagerStatusCallback;
import com.facebook.react.modules.appregistry.AppRegistry;
import com.facebook.react.modules.core.DefaultHardwareBackBtnHandler;
import com.facebook.react.modules.core.DeviceEventManagerModule;
import com.facebook.react.modules.core.ReactChoreographer;
import com.facebook.react.modules.debug.interfaces.DeveloperSettings;
import com.facebook.react.modules.fabric.ReactFabric;
import com.facebook.react.uimanager.DisplayMetricsHolder;
import com.facebook.react.uimanager.UIImplementationProvider;
import com.facebook.react.uimanager.UIManagerModule;
import com.facebook.react.uimanager.ViewManager;
import com.facebook.react.views.imagehelper.ResourceDrawableIdHelper;
import com.facebook.soloader.SoLoader;
import com.facebook.systrace.Systrace;
import com.facebook.systrace.SystraceMessage;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashSet;
import java.util.List;
import javax.annotation.Nullable;

@ThreadSafe
public class ReactInstanceManager {

    /* renamed from: a  reason: collision with root package name */
    private static final String f1812a = "ReactInstanceManager";
    private final List<ReactRootView> b = Collections.synchronizedList(new ArrayList());
    private volatile LifecycleState c;
    @ThreadConfined
    @Nullable
    private ReactContextInitParams d;
    @Nullable
    private volatile Thread e;
    private final JavaScriptExecutorFactory f;
    @Nullable
    private final JSBundleLoader g;
    @Nullable
    private final String h;
    private final List<ReactPackage> i;
    private final DevSupportManager j;
    private final boolean k;
    @Nullable
    private final NotThreadSafeBridgeIdleDebugListener l;
    private final Object m = new Object();
    @Nullable
    private volatile ReactContext n;
    private final Context o;
    @ThreadConfined
    @Nullable
    private DefaultHardwareBackBtnHandler p;
    @Nullable
    private Activity q;
    private final Collection<ReactInstanceEventListener> r = Collections.synchronizedSet(new HashSet());
    private volatile boolean s = false;
    private volatile Boolean t = false;
    private final MemoryPressureRouter u;
    @Nullable
    private final NativeModuleCallExceptionHandler v;
    private final boolean w;
    private final boolean x;
    @Nullable
    private final JSIModulesProvider y;
    private List<ViewManager> z;

    public interface ReactInstanceEventListener {
        void a(ReactContext reactContext);
    }

    /* access modifiers changed from: private */
    public class ReactContextInitParams {
        private final JavaScriptExecutorFactory b;
        private final JSBundleLoader c;

        public ReactContextInitParams(JavaScriptExecutorFactory javaScriptExecutorFactory, JSBundleLoader jSBundleLoader) {
            this.b = (JavaScriptExecutorFactory) Assertions.b(javaScriptExecutorFactory);
            this.c = (JSBundleLoader) Assertions.b(jSBundleLoader);
        }

        public JavaScriptExecutorFactory a() {
            return this.b;
        }

        public JSBundleLoader b() {
            return this.c;
        }
    }

    public static ReactInstanceManagerBuilder a() {
        return new ReactInstanceManagerBuilder();
    }

    ReactInstanceManager(Context context, @Nullable Activity activity, @Nullable DefaultHardwareBackBtnHandler defaultHardwareBackBtnHandler, JavaScriptExecutorFactory javaScriptExecutorFactory, @Nullable JSBundleLoader jSBundleLoader, @Nullable String str, List<ReactPackage> list, boolean z2, @Nullable NotThreadSafeBridgeIdleDebugListener notThreadSafeBridgeIdleDebugListener, LifecycleState lifecycleState, UIImplementationProvider uIImplementationProvider, NativeModuleCallExceptionHandler nativeModuleCallExceptionHandler, @Nullable RedBoxHandler redBoxHandler, boolean z3, boolean z4, boolean z5, @Nullable DevBundleDownloadListener devBundleDownloadListener, int i2, int i3, @Nullable JSIModulesProvider jSIModulesProvider) {
        Log.d("ReactNative", "ReactInstanceManager.ctor()");
        a(context);
        DisplayMetricsHolder.a(context);
        this.o = context;
        this.q = activity;
        this.p = defaultHardwareBackBtnHandler;
        this.f = javaScriptExecutorFactory;
        this.g = jSBundleLoader;
        this.h = str;
        this.i = new ArrayList();
        this.k = z2;
        this.j = DevSupportManagerFactory.a(context, m(), this.h, z2, redBoxHandler, devBundleDownloadListener, i2);
        this.l = notThreadSafeBridgeIdleDebugListener;
        this.c = lifecycleState;
        this.u = new MemoryPressureRouter(context);
        this.v = nativeModuleCallExceptionHandler;
        this.w = z3;
        this.x = z5;
        synchronized (this.i) {
            PrinterHolder.a().a(ReactDebugOverlayTags.c, "RNCore: Use Split Packages");
            this.i.add(new CoreModulesPackage(this, new DefaultHardwareBackBtnHandler() {
                /* class com.facebook.react.ReactInstanceManager.AnonymousClass1 */

                @Override // com.facebook.react.modules.core.DefaultHardwareBackBtnHandler
                public void invokeDefaultOnBackPressed() {
                    ReactInstanceManager.this.p();
                }
            }, uIImplementationProvider, z4, i3));
            if (this.k) {
                this.i.add(new DebugCorePackage());
            }
            this.i.addAll(list);
        }
        this.y = jSIModulesProvider;
        ReactChoreographer.a();
        if (this.k) {
            this.j.r();
        }
    }

    private ReactInstanceManagerDevHelper m() {
        return new ReactInstanceManagerDevHelper() {
            /* class com.facebook.react.ReactInstanceManager.AnonymousClass2 */

            @Override // com.facebook.react.devsupport.ReactInstanceManagerDevHelper
            public void a(JavaJSExecutor.Factory factory) {
                ReactInstanceManager.this.a((ReactInstanceManager) factory);
            }

            @Override // com.facebook.react.devsupport.ReactInstanceManagerDevHelper
            public void a() {
                ReactInstanceManager.this.u();
            }

            @Override // com.facebook.react.devsupport.ReactInstanceManagerDevHelper
            public void b() {
                ReactInstanceManager.this.q();
            }

            @Override // com.facebook.react.devsupport.ReactInstanceManagerDevHelper
            @Nullable
            public Activity c() {
                return ReactInstanceManager.this.q;
            }
        };
    }

    public DevSupportManager b() {
        return this.j;
    }

    private static void a(Context context) {
        SoLoader.init(context, false);
    }

    @ThreadConfined
    public void c() {
        Log.d("ReactNative", "ReactInstanceManager.createReactContextInBackground()");
        Assertions.a(!this.s, "createReactContextInBackground should only be called when creating the react application for the first time. When reloading JS, e.g. from a new file, explicitlyuse recreateReactContextInBackground");
        this.s = true;
        n();
    }

    @ThreadConfined
    public void d() {
        Assertions.a(this.s, "recreateReactContextInBackground should only be called after the initial createReactContextInBackground call.");
        n();
    }

    @ThreadConfined
    private void n() {
        Log.d("ReactNative", "ReactInstanceManager.recreateReactContextInBackgroundInner()");
        PrinterHolder.a().a(ReactDebugOverlayTags.c, "RNCore: recreateReactContextInBackground");
        UiThreadUtil.b();
        if (!this.k || this.h == null || Systrace.a(0)) {
            o();
            return;
        }
        final DeveloperSettings i2 = this.j.i();
        if (this.j.m() && !i2.k()) {
            u();
        } else if (this.g == null) {
            this.j.o();
        } else {
            this.j.a(new PackagerStatusCallback() {
                /* class com.facebook.react.ReactInstanceManager.AnonymousClass3 */

                @Override // com.facebook.react.devsupport.interfaces.PackagerStatusCallback
                public void a(final boolean z) {
                    UiThreadUtil.a(new Runnable() {
                        /* class com.facebook.react.ReactInstanceManager.AnonymousClass3.AnonymousClass1 */

                        public void run() {
                            if (z) {
                                ReactInstanceManager.this.j.o();
                                return;
                            }
                            i2.e(false);
                            ReactInstanceManager.this.o();
                        }
                    });
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    @ThreadConfined
    private void o() {
        Log.d("ReactNative", "ReactInstanceManager.recreateReactContextInBackgroundFromBundleLoader()");
        PrinterHolder.a().a(ReactDebugOverlayTags.c, "RNCore: load from BundleLoader");
        a(this.f, this.g);
    }

    public boolean e() {
        return this.s;
    }

    public void f() {
        UiThreadUtil.b();
        ReactContext reactContext = this.n;
        if (reactContext == null) {
            FLog.c("ReactNative", "Instance detached from instance manager");
            p();
            return;
        }
        ((DeviceEventManagerModule) reactContext.b(DeviceEventManagerModule.class)).emitHardwareBackPressed();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void p() {
        UiThreadUtil.b();
        if (this.p != null) {
            this.p.invokeDefaultOnBackPressed();
        }
    }

    @ThreadConfined
    public void a(Intent intent) {
        UiThreadUtil.b();
        ReactContext l2 = l();
        if (l2 == null) {
            FLog.c("ReactNative", "Instance detached from instance manager");
            return;
        }
        String action = intent.getAction();
        Uri data = intent.getData();
        if ("android.intent.action.VIEW".equals(action) && data != null) {
            ((DeviceEventManagerModule) l2.b(DeviceEventManagerModule.class)).emitNewIntentReceived(data);
        }
        l2.a(this.q, intent);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void q() {
        ReactContext l2 = l();
        if (l2 != null) {
            ((DeviceEventManagerModule.RCTDeviceEventEmitter) l2.a(DeviceEventManagerModule.RCTDeviceEventEmitter.class)).emit("toggleElementInspector", null);
        }
    }

    @ThreadConfined
    public void g() {
        UiThreadUtil.b();
        this.p = null;
        if (this.k) {
            this.j.a(false);
        }
        r();
    }

    @ThreadConfined
    public void a(Activity activity) {
        Assertions.b(this.q);
        boolean z2 = activity == this.q;
        Assertions.a(z2, "Pausing an activity that is not the current activity, this is incorrect! Current activity: " + this.q.getClass().getSimpleName() + " Paused activity: " + activity.getClass().getSimpleName());
        g();
    }

    @ThreadConfined
    public void a(Activity activity, DefaultHardwareBackBtnHandler defaultHardwareBackBtnHandler) {
        UiThreadUtil.b();
        this.p = defaultHardwareBackBtnHandler;
        b(activity);
    }

    @ThreadConfined
    public void b(Activity activity) {
        UiThreadUtil.b();
        this.q = activity;
        if (this.k) {
            final View decorView = this.q.getWindow().getDecorView();
            if (!ViewCompat.z(decorView)) {
                decorView.addOnAttachStateChangeListener(new View.OnAttachStateChangeListener() {
                    /* class com.facebook.react.ReactInstanceManager.AnonymousClass4 */

                    public void onViewDetachedFromWindow(View view) {
                    }

                    public void onViewAttachedToWindow(View view) {
                        decorView.removeOnAttachStateChangeListener(this);
                        ReactInstanceManager.this.j.a(true);
                    }
                });
            } else {
                this.j.a(true);
            }
        }
        a(false);
    }

    @ThreadConfined
    public void h() {
        UiThreadUtil.b();
        if (this.k) {
            this.j.a(false);
        }
        s();
        this.q = null;
    }

    @ThreadConfined
    public void c(Activity activity) {
        if (activity == this.q) {
            h();
        }
    }

    @ThreadConfined
    public void i() {
        UiThreadUtil.b();
        PrinterHolder.a().a(ReactDebugOverlayTags.c, "RNCore: Destroy");
        this.t = true;
        if (this.k) {
            this.j.a(false);
            this.j.s();
        }
        s();
        if (this.e != null) {
            this.e = null;
        }
        this.u.a(this.o);
        synchronized (this.m) {
            if (this.n != null) {
                this.n.f();
                this.n = null;
            }
        }
        this.s = false;
        this.q = null;
        ResourceDrawableIdHelper.a().b();
        this.t = false;
        synchronized (this.t) {
            this.t.notifyAll();
        }
    }

    private synchronized void a(boolean z2) {
        ReactContext l2 = l();
        if (l2 != null && (z2 || this.c == LifecycleState.BEFORE_RESUME || this.c == LifecycleState.BEFORE_CREATE)) {
            l2.a(this.q);
        }
        this.c = LifecycleState.RESUMED;
    }

    private synchronized void r() {
        ReactContext l2 = l();
        if (l2 != null) {
            if (this.c == LifecycleState.BEFORE_CREATE) {
                l2.a(this.q);
                l2.d();
            } else if (this.c == LifecycleState.RESUMED) {
                l2.d();
            }
        }
        this.c = LifecycleState.BEFORE_RESUME;
    }

    private synchronized void s() {
        ReactContext l2 = l();
        if (l2 != null) {
            if (this.c == LifecycleState.RESUMED) {
                l2.d();
                this.c = LifecycleState.BEFORE_RESUME;
            }
            if (this.c == LifecycleState.BEFORE_RESUME) {
                l2.e();
            }
        }
        this.c = LifecycleState.BEFORE_CREATE;
    }

    private synchronized void t() {
        if (this.c == LifecycleState.RESUMED) {
            a(true);
        }
    }

    @ThreadConfined
    public void a(Activity activity, int i2, int i3, Intent intent) {
        ReactContext l2 = l();
        if (l2 != null) {
            l2.a(activity, i2, i3, intent);
        }
    }

    @ThreadConfined
    public void j() {
        UiThreadUtil.b();
        this.j.g();
    }

    @ThreadConfined
    public void a(ReactRootView reactRootView) {
        UiThreadUtil.b();
        this.b.add(reactRootView);
        reactRootView.removeAllViews();
        reactRootView.setId(-1);
        ReactContext l2 = l();
        if (this.e == null && l2 != null) {
            a(reactRootView, l2.a());
        }
    }

    @ThreadConfined
    public void b(ReactRootView reactRootView) {
        ReactContext l2;
        UiThreadUtil.b();
        if (this.b.remove(reactRootView) && (l2 = l()) != null && l2.b()) {
            b(reactRootView, l2.a());
        }
    }

    public List<ViewManager> a(ReactApplicationContext reactApplicationContext) {
        ReactMarker.logMarker(ReactMarkerConstants.CREATE_VIEW_MANAGERS_START);
        Systrace.a(0, "createAllViewManagers");
        try {
            if (this.z == null) {
                synchronized (this.i) {
                    if (this.z == null) {
                        this.z = new ArrayList();
                        for (ReactPackage reactPackage : this.i) {
                            this.z.addAll(reactPackage.b(reactApplicationContext));
                        }
                        return this.z;
                    }
                }
            }
            List<ViewManager> list = this.z;
            Systrace.b(0);
            ReactMarker.logMarker(ReactMarkerConstants.CREATE_VIEW_MANAGERS_END);
            return list;
        } finally {
            Systrace.b(0);
            ReactMarker.logMarker(ReactMarkerConstants.CREATE_VIEW_MANAGERS_END);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:10:0x0016, code lost:
        monitor-enter(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:12:?, code lost:
        r0 = r6.i.iterator();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0021, code lost:
        if (r0.hasNext() == false) goto L_0x003b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0023, code lost:
        r4 = r0.next();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x002b, code lost:
        if ((r4 instanceof com.facebook.react.ViewManagerOnDemandReactPackage) == false) goto L_0x001d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x002d, code lost:
        r4 = ((com.facebook.react.ViewManagerOnDemandReactPackage) r4).a(r1, r7, !r6.x);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0037, code lost:
        if (r4 == null) goto L_0x001d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0039, code lost:
        monitor-exit(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x003a, code lost:
        return r4;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x003b, code lost:
        monitor-exit(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x003c, code lost:
        return null;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:9:0x0014, code lost:
        r3 = r6.i;
     */
    @Nullable
    public ViewManager a(String str) {
        synchronized (this.m) {
            ReactApplicationContext reactApplicationContext = (ReactApplicationContext) l();
            if (reactApplicationContext != null) {
                if (!reactApplicationContext.b()) {
                }
            }
            return null;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:10:0x0015, code lost:
        monitor-enter(r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:12:?, code lost:
        r0 = new java.util.HashSet();
        r3 = r6.i.iterator();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0025, code lost:
        if (r3.hasNext() == false) goto L_0x0041;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0027, code lost:
        r4 = r3.next();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x002f, code lost:
        if ((r4 instanceof com.facebook.react.ViewManagerOnDemandReactPackage) == false) goto L_0x0021;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0031, code lost:
        r4 = ((com.facebook.react.ViewManagerOnDemandReactPackage) r4).a(r1, !r6.x);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x003b, code lost:
        if (r4 == null) goto L_0x0021;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x003d, code lost:
        r0.addAll(r4);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0041, code lost:
        r1 = new java.util.ArrayList(r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x0046, code lost:
        monitor-exit(r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0047, code lost:
        return r1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:9:0x0013, code lost:
        r2 = r6.i;
     */
    @Nullable
    public List<String> k() {
        synchronized (this.m) {
            ReactApplicationContext reactApplicationContext = (ReactApplicationContext) l();
            if (reactApplicationContext != null) {
                if (!reactApplicationContext.b()) {
                }
            }
            return null;
        }
    }

    public void a(ReactInstanceEventListener reactInstanceEventListener) {
        this.r.remove(reactInstanceEventListener);
    }

    @Nullable
    @VisibleForTesting
    public ReactContext l() {
        ReactContext reactContext;
        synchronized (this.m) {
            reactContext = this.n;
        }
        return reactContext;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    @ThreadConfined
    private void a(JavaJSExecutor.Factory factory) {
        Log.d("ReactNative", "ReactInstanceManager.onReloadWithJSDebugger()");
        a(new ProxyJavaScriptExecutor.Factory(factory), JSBundleLoader.b(this.j.k(), this.j.j()));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    @ThreadConfined
    private void u() {
        Log.d("ReactNative", "ReactInstanceManager.onJSBundleLoadedFromServer()");
        a(this.f, JSBundleLoader.a(this.j.j(), this.j.l()));
    }

    @ThreadConfined
    private void a(JavaScriptExecutorFactory javaScriptExecutorFactory, JSBundleLoader jSBundleLoader) {
        Log.d("ReactNative", "ReactInstanceManager.recreateReactContextInBackground()");
        UiThreadUtil.b();
        ReactContextInitParams reactContextInitParams = new ReactContextInitParams(javaScriptExecutorFactory, jSBundleLoader);
        if (this.e == null) {
            a(reactContextInitParams);
        } else {
            this.d = reactContextInitParams;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    @ThreadConfined
    private void a(final ReactContextInitParams reactContextInitParams) {
        Log.d("ReactNative", "ReactInstanceManager.runCreateReactContextOnNewThread()");
        UiThreadUtil.b();
        synchronized (this.m) {
            if (this.n != null) {
                a(this.n);
                this.n = null;
            }
        }
        this.e = new Thread(new Runnable() {
            /* class com.facebook.react.ReactInstanceManager.AnonymousClass5 */

            /* JADX WARNING: Exception block dominator not found, dom blocks: [] */
            /* JADX WARNING: Missing exception handler attribute for start block: B:2:0x000c */
            /* JADX WARNING: Removed duplicated region for block: B:2:0x000c A[LOOP:0: B:2:0x000c->B:16:0x000c, LOOP_START, SYNTHETIC] */
            public void run() {
                ReactMarker.logMarker(ReactMarkerConstants.REACT_CONTEXT_THREAD_END);
                synchronized (ReactInstanceManager.this.t) {
                    while (ReactInstanceManager.this.t.booleanValue()) {
                        ReactInstanceManager.this.t.wait();
                    }
                }
                ReactInstanceManager.this.s = true;
                try {
                    Process.setThreadPriority(-4);
                    final ReactApplicationContext a2 = ReactInstanceManager.this.a((ReactInstanceManager) reactContextInitParams.a().a(), (JavaScriptExecutor) reactContextInitParams.b());
                    ReactInstanceManager.this.e = null;
                    ReactMarker.logMarker(ReactMarkerConstants.PRE_SETUP_REACT_CONTEXT_START);
                    AnonymousClass1 r1 = new Runnable() {
                        /* class com.facebook.react.ReactInstanceManager.AnonymousClass5.AnonymousClass1 */

                        public void run() {
                            if (ReactInstanceManager.this.d != null) {
                                ReactInstanceManager.this.a((ReactInstanceManager) ReactInstanceManager.this.d);
                                ReactInstanceManager.this.d = null;
                            }
                        }
                    };
                    a2.b(new Runnable() {
                        /* class com.facebook.react.ReactInstanceManager.AnonymousClass5.AnonymousClass2 */

                        public void run() {
                            try {
                                ReactInstanceManager.this.b((ReactInstanceManager) a2);
                            } catch (Exception e) {
                                ReactInstanceManager.this.j.a(e);
                            }
                        }
                    });
                    UiThreadUtil.a(r1);
                } catch (Exception e) {
                    ReactInstanceManager.this.j.a(e);
                }
            }
        });
        ReactMarker.logMarker(ReactMarkerConstants.REACT_CONTEXT_THREAD_START);
        this.e.start();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void b(final ReactApplicationContext reactApplicationContext) {
        Log.d("ReactNative", "ReactInstanceManager.setupReactContext()");
        ReactMarker.logMarker(ReactMarkerConstants.PRE_SETUP_REACT_CONTEXT_END);
        ReactMarker.logMarker(ReactMarkerConstants.SETUP_REACT_CONTEXT_START);
        Systrace.a(0, "setupReactContext");
        synchronized (this.m) {
            this.n = (ReactContext) Assertions.b(reactApplicationContext);
        }
        CatalystInstance catalystInstance = (CatalystInstance) Assertions.b(reactApplicationContext.a());
        catalystInstance.initialize();
        this.j.a(reactApplicationContext);
        this.u.a(catalystInstance);
        t();
        ReactMarker.logMarker(ReactMarkerConstants.ATTACH_MEASURED_ROOT_VIEWS_START);
        synchronized (this.b) {
            for (ReactRootView reactRootView : this.b) {
                a(reactRootView, catalystInstance);
            }
        }
        ReactMarker.logMarker(ReactMarkerConstants.ATTACH_MEASURED_ROOT_VIEWS_END);
        final ReactInstanceEventListener[] reactInstanceEventListenerArr = (ReactInstanceEventListener[]) this.r.toArray(new ReactInstanceEventListener[this.r.size()]);
        UiThreadUtil.a(new Runnable() {
            /* class com.facebook.react.ReactInstanceManager.AnonymousClass6 */

            public void run() {
                for (ReactInstanceEventListener reactInstanceEventListener : reactInstanceEventListenerArr) {
                    reactInstanceEventListener.a(reactApplicationContext);
                }
            }
        });
        Systrace.b(0);
        ReactMarker.logMarker(ReactMarkerConstants.SETUP_REACT_CONTEXT_END);
        reactApplicationContext.c(new Runnable() {
            /* class com.facebook.react.ReactInstanceManager.AnonymousClass7 */

            public void run() {
                Process.setThreadPriority(0);
            }
        });
        reactApplicationContext.b(new Runnable() {
            /* class com.facebook.react.ReactInstanceManager.AnonymousClass8 */

            public void run() {
                Process.setThreadPriority(0);
            }
        });
    }

    private void a(final ReactRootView reactRootView, CatalystInstance catalystInstance) {
        Log.d("ReactNative", "ReactInstanceManager.attachRootViewToInstance()");
        Systrace.a(0, "attachRootViewToInstance");
        final int addRootView = ((UIManager) (reactRootView.d() ? catalystInstance.getJSIModule(UIManager.class) : catalystInstance.getNativeModule(UIManagerModule.class))).addRootView(reactRootView);
        reactRootView.setRootViewTag(addRootView);
        reactRootView.c();
        Systrace.a(0, "pre_rootView.onAttachedToReactInstance", addRootView);
        UiThreadUtil.a(new Runnable() {
            /* class com.facebook.react.ReactInstanceManager.AnonymousClass9 */

            public void run() {
                Systrace.b(0, "pre_rootView.onAttachedToReactInstance", addRootView);
                reactRootView.b();
            }
        });
        Systrace.b(0);
    }

    private void b(ReactRootView reactRootView, CatalystInstance catalystInstance) {
        Log.d("ReactNative", "ReactInstanceManager.detachViewFromInstance()");
        UiThreadUtil.b();
        if (reactRootView.d()) {
            ((ReactFabric) catalystInstance.getJSModule(ReactFabric.class)).unmountComponentAtNodeAndRemoveContainer(reactRootView.getId());
        } else {
            ((AppRegistry) catalystInstance.getJSModule(AppRegistry.class)).unmountApplicationComponentAtRootTag(reactRootView.getId());
        }
    }

    private void a(ReactContext reactContext) {
        Log.d("ReactNative", "ReactInstanceManager.tearDownReactContext()");
        UiThreadUtil.b();
        if (this.c == LifecycleState.RESUMED) {
            reactContext.d();
        }
        synchronized (this.b) {
            for (ReactRootView reactRootView : this.b) {
                reactRootView.removeAllViews();
                reactRootView.setId(-1);
            }
        }
        reactContext.f();
        this.j.b(reactContext);
        this.u.b(reactContext.a());
    }

    /* JADX INFO: finally extract failed */
    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private ReactApplicationContext a(JavaScriptExecutor javaScriptExecutor, JSBundleLoader jSBundleLoader) {
        Log.d("ReactNative", "ReactInstanceManager.createReactContext()");
        ReactMarker.logMarker(ReactMarkerConstants.CREATE_REACT_CONTEXT_START);
        ReactApplicationContext reactApplicationContext = new ReactApplicationContext(this.o);
        if (this.k) {
            reactApplicationContext.a(this.j);
        }
        CatalystInstanceImpl.Builder a2 = new CatalystInstanceImpl.Builder().a(ReactQueueConfigurationSpec.d()).a(javaScriptExecutor).a(a(reactApplicationContext, this.i, false)).a(jSBundleLoader).a(this.v != null ? this.v : this.j);
        ReactMarker.logMarker(ReactMarkerConstants.CREATE_CATALYST_INSTANCE_START);
        Systrace.a(0, "createCatalystInstance");
        try {
            CatalystInstanceImpl a3 = a2.a();
            Systrace.b(0);
            ReactMarker.logMarker(ReactMarkerConstants.CREATE_CATALYST_INSTANCE_END);
            if (this.y != null) {
                a3.addJSIModules(this.y.a(reactApplicationContext, a3.getJavaScriptContextHolder()));
            }
            if (this.l != null) {
                a3.addBridgeIdleDebugListener(this.l);
            }
            if (Systrace.a(0)) {
                a3.setGlobalVariable("__RCTProfileIsProfiling", "true");
            }
            ReactMarker.logMarker(ReactMarkerConstants.PRE_RUN_JS_BUNDLE_START);
            a3.runJSBundle();
            reactApplicationContext.a(a3);
            return reactApplicationContext;
        } catch (Throwable th) {
            Systrace.b(0);
            ReactMarker.logMarker(ReactMarkerConstants.CREATE_CATALYST_INSTANCE_END);
            throw th;
        }
    }

    private NativeModuleRegistry a(ReactApplicationContext reactApplicationContext, List<ReactPackage> list, boolean z2) {
        NativeModuleRegistryBuilder nativeModuleRegistryBuilder = new NativeModuleRegistryBuilder(reactApplicationContext, this, this.w);
        ReactMarker.logMarker(ReactMarkerConstants.PROCESS_PACKAGES_START);
        synchronized (this.i) {
            for (ReactPackage reactPackage : list) {
                if (!z2 || !this.i.contains(reactPackage)) {
                    Systrace.a(0, "createAndProcessCustomReactPackage");
                    if (z2) {
                        try {
                            this.i.add(reactPackage);
                        } catch (Throwable th) {
                            Systrace.b(0);
                            throw th;
                        }
                    }
                    a(reactPackage, nativeModuleRegistryBuilder);
                    Systrace.b(0);
                }
            }
        }
        ReactMarker.logMarker(ReactMarkerConstants.PROCESS_PACKAGES_END);
        ReactMarker.logMarker(ReactMarkerConstants.BUILD_NATIVE_MODULE_REGISTRY_START);
        Systrace.a(0, "buildNativeModuleRegistry");
        try {
            return nativeModuleRegistryBuilder.a();
        } finally {
            Systrace.b(0);
            ReactMarker.logMarker(ReactMarkerConstants.BUILD_NATIVE_MODULE_REGISTRY_END);
        }
    }

    private void a(ReactPackage reactPackage, NativeModuleRegistryBuilder nativeModuleRegistryBuilder) {
        SystraceMessage.a(0, "processPackage").a("className", reactPackage.getClass().getSimpleName()).a();
        boolean z2 = reactPackage instanceof ReactPackageLogger;
        if (z2) {
            ((ReactPackageLogger) reactPackage).b();
        }
        nativeModuleRegistryBuilder.a(reactPackage);
        if (z2) {
            ((ReactPackageLogger) reactPackage).c();
        }
        SystraceMessage.a(0).a();
    }
}
