package com.facebook.react.animated;

import android.util.SparseArray;
import com.facebook.common.logging.FLog;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.JSApplicationIllegalArgumentException;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.UiThreadUtil;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.uimanager.IllegalViewOperationException;
import com.facebook.react.uimanager.UIImplementation;
import com.facebook.react.uimanager.UIManagerModule;
import com.facebook.react.uimanager.events.Event;
import com.facebook.react.uimanager.events.EventDispatcherListener;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.ListIterator;
import java.util.Map;
import javax.annotation.Nullable;

/* access modifiers changed from: package-private */
public class NativeAnimatedNodesManager implements EventDispatcherListener {

    /* renamed from: a  reason: collision with root package name */
    private final SparseArray<AnimatedNode> f1854a = new SparseArray<>();
    private final SparseArray<AnimationDriver> b = new SparseArray<>();
    private final SparseArray<AnimatedNode> c = new SparseArray<>();
    private final Map<String, List<EventAnimationDriver>> d = new HashMap();
    private final UIManagerModule.CustomEventNamesResolver e;
    private final UIImplementation f;
    private int g = 0;
    private final List<AnimatedNode> h = new LinkedList();

    public NativeAnimatedNodesManager(UIManagerModule uIManagerModule) {
        this.f = uIManagerModule.getUIImplementation();
        uIManagerModule.getEventDispatcher().a(this);
        this.e = uIManagerModule.getDirectEventNamesResolver();
    }

    /* access modifiers changed from: package-private */
    @Nullable
    public AnimatedNode a(int i) {
        return this.f1854a.get(i);
    }

    public boolean a() {
        return this.b.size() > 0 || this.c.size() > 0;
    }

    public void a(int i, ReadableMap readableMap) {
        AnimatedNode animatedNode;
        if (this.f1854a.get(i) == null) {
            String f2 = readableMap.f("type");
            if ("style".equals(f2)) {
                animatedNode = new StyleAnimatedNode(readableMap, this);
            } else if ("value".equals(f2)) {
                animatedNode = new ValueAnimatedNode(readableMap);
            } else if ("props".equals(f2)) {
                animatedNode = new PropsAnimatedNode(readableMap, this, this.f);
            } else if ("interpolation".equals(f2)) {
                animatedNode = new InterpolationAnimatedNode(readableMap);
            } else if ("addition".equals(f2)) {
                animatedNode = new AdditionAnimatedNode(readableMap, this);
            } else if ("division".equals(f2)) {
                animatedNode = new DivisionAnimatedNode(readableMap, this);
            } else if ("multiplication".equals(f2)) {
                animatedNode = new MultiplicationAnimatedNode(readableMap, this);
            } else if ("modulus".equals(f2)) {
                animatedNode = new ModulusAnimatedNode(readableMap, this);
            } else if ("diffclamp".equals(f2)) {
                animatedNode = new DiffClampAnimatedNode(readableMap, this);
            } else if ("transform".equals(f2)) {
                animatedNode = new TransformAnimatedNode(readableMap, this);
            } else if ("tracking".equals(f2)) {
                animatedNode = new TrackingAnimatedNode(readableMap, this);
            } else {
                throw new JSApplicationIllegalArgumentException("Unsupported node type: " + f2);
            }
            animatedNode.d = i;
            this.f1854a.put(i, animatedNode);
            this.c.put(i, animatedNode);
            return;
        }
        throw new JSApplicationIllegalArgumentException("Animated node with tag " + i + " already exists");
    }

    public void b(int i) {
        this.f1854a.remove(i);
        this.c.remove(i);
    }

    public void a(int i, AnimatedNodeValueListener animatedNodeValueListener) {
        AnimatedNode animatedNode = this.f1854a.get(i);
        if (animatedNode == null || !(animatedNode instanceof ValueAnimatedNode)) {
            throw new JSApplicationIllegalArgumentException("Animated node with tag " + i + " does not exists or is not a 'value' node");
        }
        ((ValueAnimatedNode) animatedNode).a(animatedNodeValueListener);
    }

    public void c(int i) {
        AnimatedNode animatedNode = this.f1854a.get(i);
        if (animatedNode == null || !(animatedNode instanceof ValueAnimatedNode)) {
            throw new JSApplicationIllegalArgumentException("Animated node with tag " + i + " does not exists or is not a 'value' node");
        }
        ((ValueAnimatedNode) animatedNode).a((AnimatedNodeValueListener) null);
    }

    public void a(int i, double d2) {
        AnimatedNode animatedNode = this.f1854a.get(i);
        if (animatedNode == null || !(animatedNode instanceof ValueAnimatedNode)) {
            throw new JSApplicationIllegalArgumentException("Animated node with tag " + i + " does not exists or is not a 'value' node");
        }
        a(animatedNode);
        ((ValueAnimatedNode) animatedNode).e = d2;
        this.c.put(i, animatedNode);
    }

    public void b(int i, double d2) {
        AnimatedNode animatedNode = this.f1854a.get(i);
        if (animatedNode == null || !(animatedNode instanceof ValueAnimatedNode)) {
            throw new JSApplicationIllegalArgumentException("Animated node with tag " + i + " does not exists or is not a 'value' node");
        }
        ((ValueAnimatedNode) animatedNode).f = d2;
        this.c.put(i, animatedNode);
    }

    public void d(int i) {
        AnimatedNode animatedNode = this.f1854a.get(i);
        if (animatedNode == null || !(animatedNode instanceof ValueAnimatedNode)) {
            throw new JSApplicationIllegalArgumentException("Animated node with tag " + i + " does not exists or is not a 'value' node");
        }
        ((ValueAnimatedNode) animatedNode).c();
    }

    public void e(int i) {
        AnimatedNode animatedNode = this.f1854a.get(i);
        if (animatedNode == null || !(animatedNode instanceof ValueAnimatedNode)) {
            throw new JSApplicationIllegalArgumentException("Animated node with tag " + i + " does not exists or is not a 'value' node");
        }
        ((ValueAnimatedNode) animatedNode).d();
    }

    public void a(int i, int i2, ReadableMap readableMap, Callback callback) {
        AnimationDriver animationDriver;
        AnimatedNode animatedNode = this.f1854a.get(i2);
        if (animatedNode == null) {
            throw new JSApplicationIllegalArgumentException("Animated node with tag " + i2 + " does not exists");
        } else if (animatedNode instanceof ValueAnimatedNode) {
            AnimationDriver animationDriver2 = this.b.get(i);
            if (animationDriver2 != null) {
                animationDriver2.a(readableMap);
                return;
            }
            String f2 = readableMap.f("type");
            if ("frames".equals(f2)) {
                animationDriver = new FrameBasedAnimationDriver(readableMap);
            } else if ("spring".equals(f2)) {
                animationDriver = new SpringAnimation(readableMap);
            } else if ("decay".equals(f2)) {
                animationDriver = new DecayAnimation(readableMap);
            } else {
                throw new JSApplicationIllegalArgumentException("Unsupported animation type: " + f2);
            }
            animationDriver.d = i;
            animationDriver.c = callback;
            animationDriver.b = (ValueAnimatedNode) animatedNode;
            this.b.put(i, animationDriver);
        } else {
            throw new JSApplicationIllegalArgumentException("Animated node should be of type " + ValueAnimatedNode.class.getName());
        }
    }

    private void a(AnimatedNode animatedNode) {
        int i = 0;
        while (i < this.b.size()) {
            AnimationDriver valueAt = this.b.valueAt(i);
            if (animatedNode.equals(valueAt.b)) {
                if (valueAt.c != null) {
                    WritableMap b2 = Arguments.b();
                    b2.putBoolean("finished", false);
                    valueAt.c.a(b2);
                }
                this.b.removeAt(i);
                i--;
            }
            i++;
        }
    }

    public void f(int i) {
        for (int i2 = 0; i2 < this.b.size(); i2++) {
            AnimationDriver valueAt = this.b.valueAt(i2);
            if (valueAt.d == i) {
                if (valueAt.c != null) {
                    WritableMap b2 = Arguments.b();
                    b2.putBoolean("finished", false);
                    valueAt.c.a(b2);
                }
                this.b.removeAt(i2);
                return;
            }
        }
    }

    public void a(int i, int i2) {
        AnimatedNode animatedNode = this.f1854a.get(i);
        if (animatedNode != null) {
            AnimatedNode animatedNode2 = this.f1854a.get(i2);
            if (animatedNode2 != null) {
                animatedNode.a(animatedNode2);
                this.c.put(i2, animatedNode2);
                return;
            }
            throw new JSApplicationIllegalArgumentException("Animated node with tag " + i2 + " does not exists");
        }
        throw new JSApplicationIllegalArgumentException("Animated node with tag " + i + " does not exists");
    }

    public void b(int i, int i2) {
        AnimatedNode animatedNode = this.f1854a.get(i);
        if (animatedNode != null) {
            AnimatedNode animatedNode2 = this.f1854a.get(i2);
            if (animatedNode2 != null) {
                animatedNode.b(animatedNode2);
                this.c.put(i2, animatedNode2);
                return;
            }
            throw new JSApplicationIllegalArgumentException("Animated node with tag " + i2 + " does not exists");
        }
        throw new JSApplicationIllegalArgumentException("Animated node with tag " + i + " does not exists");
    }

    public void c(int i, int i2) {
        AnimatedNode animatedNode = this.f1854a.get(i);
        if (animatedNode == null) {
            throw new JSApplicationIllegalArgumentException("Animated node with tag " + i + " does not exists");
        } else if (animatedNode instanceof PropsAnimatedNode) {
            ((PropsAnimatedNode) animatedNode).a(i2);
            this.c.put(i, animatedNode);
        } else {
            throw new JSApplicationIllegalArgumentException("Animated node connected to view should beof type " + PropsAnimatedNode.class.getName());
        }
    }

    public void d(int i, int i2) {
        AnimatedNode animatedNode = this.f1854a.get(i);
        if (animatedNode == null) {
            throw new JSApplicationIllegalArgumentException("Animated node with tag " + i + " does not exists");
        } else if (animatedNode instanceof PropsAnimatedNode) {
            ((PropsAnimatedNode) animatedNode).b(i2);
        } else {
            throw new JSApplicationIllegalArgumentException("Animated node connected to view should beof type " + PropsAnimatedNode.class.getName());
        }
    }

    public void e(int i, int i2) {
        AnimatedNode animatedNode = this.f1854a.get(i);
        if (animatedNode != null) {
            if (animatedNode instanceof PropsAnimatedNode) {
                ((PropsAnimatedNode) animatedNode).b();
                return;
            }
            throw new JSApplicationIllegalArgumentException("Animated node connected to view should beof type " + PropsAnimatedNode.class.getName());
        }
    }

    public void a(int i, String str, ReadableMap readableMap) {
        int e2 = readableMap.e("animatedValueTag");
        AnimatedNode animatedNode = this.f1854a.get(e2);
        if (animatedNode == null) {
            throw new JSApplicationIllegalArgumentException("Animated node with tag " + e2 + " does not exists");
        } else if (animatedNode instanceof ValueAnimatedNode) {
            ReadableArray k = readableMap.k("nativeEventPath");
            ArrayList arrayList = new ArrayList(k.a());
            for (int i2 = 0; i2 < k.a(); i2++) {
                arrayList.add(k.d(i2));
            }
            EventAnimationDriver eventAnimationDriver = new EventAnimationDriver(arrayList, (ValueAnimatedNode) animatedNode);
            String str2 = i + str;
            if (this.d.containsKey(str2)) {
                this.d.get(str2).add(eventAnimationDriver);
                return;
            }
            ArrayList arrayList2 = new ArrayList(1);
            arrayList2.add(eventAnimationDriver);
            this.d.put(str2, arrayList2);
        } else {
            throw new JSApplicationIllegalArgumentException("Animated node connected to event should beof type " + ValueAnimatedNode.class.getName());
        }
    }

    public void a(int i, String str, int i2) {
        String str2 = i + str;
        if (this.d.containsKey(str2)) {
            List<EventAnimationDriver> list = this.d.get(str2);
            if (list.size() == 1) {
                this.d.remove(i + str);
                return;
            }
            ListIterator<EventAnimationDriver> listIterator = list.listIterator();
            while (listIterator.hasNext()) {
                if (listIterator.next().mValueNode.d == i2) {
                    listIterator.remove();
                    return;
                }
            }
        }
    }

    @Override // com.facebook.react.uimanager.events.EventDispatcherListener
    public void a(final Event event) {
        if (UiThreadUtil.a()) {
            b(event);
        } else {
            UiThreadUtil.a(new Runnable() {
                /* class com.facebook.react.animated.NativeAnimatedNodesManager.AnonymousClass1 */

                public void run() {
                    NativeAnimatedNodesManager.this.b((NativeAnimatedNodesManager) event);
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void b(Event event) {
        if (!this.d.isEmpty()) {
            String a2 = this.e.a(event.b());
            Map<String, List<EventAnimationDriver>> map = this.d;
            List<EventAnimationDriver> list = map.get(event.c() + a2);
            if (list != null) {
                for (EventAnimationDriver eventAnimationDriver : list) {
                    a(eventAnimationDriver.mValueNode);
                    event.a(eventAnimationDriver);
                    this.h.add(eventAnimationDriver.mValueNode);
                }
                a(this.h);
                this.h.clear();
            }
        }
    }

    public void a(long j) {
        UiThreadUtil.b();
        for (int i = 0; i < this.c.size(); i++) {
            this.h.add(this.c.valueAt(i));
        }
        this.c.clear();
        boolean z = false;
        for (int i2 = 0; i2 < this.b.size(); i2++) {
            AnimationDriver valueAt = this.b.valueAt(i2);
            valueAt.a(j);
            this.h.add(valueAt.b);
            if (valueAt.f1832a) {
                z = true;
            }
        }
        a(this.h);
        this.h.clear();
        if (z) {
            for (int size = this.b.size() - 1; size >= 0; size--) {
                AnimationDriver valueAt2 = this.b.valueAt(size);
                if (valueAt2.f1832a) {
                    if (valueAt2.c != null) {
                        WritableMap b2 = Arguments.b();
                        b2.putBoolean("finished", true);
                        valueAt2.c.a(b2);
                    }
                    this.b.removeAt(size);
                }
            }
        }
    }

    private void a(List<AnimatedNode> list) {
        this.g++;
        if (this.g == 0) {
            this.g++;
        }
        ArrayDeque arrayDeque = new ArrayDeque();
        int i = 0;
        for (AnimatedNode animatedNode : list) {
            if (animatedNode.c != this.g) {
                animatedNode.c = this.g;
                i++;
                arrayDeque.add(animatedNode);
            }
        }
        while (!arrayDeque.isEmpty()) {
            AnimatedNode animatedNode2 = (AnimatedNode) arrayDeque.poll();
            if (animatedNode2.f1831a != null) {
                int i2 = i;
                for (int i3 = 0; i3 < animatedNode2.f1831a.size(); i3++) {
                    AnimatedNode animatedNode3 = animatedNode2.f1831a.get(i3);
                    animatedNode3.b++;
                    if (animatedNode3.c != this.g) {
                        animatedNode3.c = this.g;
                        i2++;
                        arrayDeque.add(animatedNode3);
                    }
                }
                i = i2;
            }
        }
        this.g++;
        if (this.g == 0) {
            this.g++;
        }
        int i4 = 0;
        for (AnimatedNode animatedNode4 : list) {
            if (animatedNode4.b == 0 && animatedNode4.c != this.g) {
                animatedNode4.c = this.g;
                i4++;
                arrayDeque.add(animatedNode4);
            }
        }
        while (!arrayDeque.isEmpty()) {
            AnimatedNode animatedNode5 = (AnimatedNode) arrayDeque.poll();
            animatedNode5.a();
            if (animatedNode5 instanceof PropsAnimatedNode) {
                try {
                    ((PropsAnimatedNode) animatedNode5).c();
                } catch (IllegalViewOperationException e2) {
                    FLog.c("ReactNative", "Native animation workaround, frame lost as result of race condition", e2);
                }
            }
            if (animatedNode5 instanceof ValueAnimatedNode) {
                ((ValueAnimatedNode) animatedNode5).e();
            }
            if (animatedNode5.f1831a != null) {
                int i5 = i4;
                for (int i6 = 0; i6 < animatedNode5.f1831a.size(); i6++) {
                    AnimatedNode animatedNode6 = animatedNode5.f1831a.get(i6);
                    animatedNode6.b--;
                    if (animatedNode6.c != this.g && animatedNode6.b == 0) {
                        animatedNode6.c = this.g;
                        i5++;
                        arrayDeque.add(animatedNode6);
                    }
                }
                i4 = i5;
            }
        }
        if (i != i4) {
            throw new IllegalStateException("Looks like animated nodes graph has cycles, there are " + i + " but toposort visited only " + i4);
        }
    }
}
