package com.facebook.react.bridge;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

public class JavaOnlyMap implements ReadableMap, WritableMap {

    /* renamed from: a  reason: collision with root package name */
    private final Map f1895a;

    public static JavaOnlyMap a(Object... objArr) {
        return new JavaOnlyMap(objArr);
    }

    public static JavaOnlyMap a(ReadableMap readableMap) {
        JavaOnlyMap javaOnlyMap = new JavaOnlyMap();
        ReadableMapKeySetIterator a2 = readableMap.a();
        while (a2.hasNextKey()) {
            String nextKey = a2.nextKey();
            switch (readableMap.j(nextKey)) {
                case Null:
                    javaOnlyMap.putNull(nextKey);
                    break;
                case Boolean:
                    javaOnlyMap.putBoolean(nextKey, readableMap.c(nextKey));
                    break;
                case Number:
                    javaOnlyMap.putDouble(nextKey, readableMap.d(nextKey));
                    break;
                case String:
                    javaOnlyMap.putString(nextKey, readableMap.f(nextKey));
                    break;
                case Map:
                    javaOnlyMap.a(nextKey, a(readableMap.g(nextKey)));
                    break;
                case Array:
                    javaOnlyMap.a(nextKey, JavaOnlyArray.a(readableMap.k(nextKey)));
                    break;
            }
        }
        return javaOnlyMap;
    }

    private JavaOnlyMap(Object... objArr) {
        if (objArr.length % 2 == 0) {
            this.f1895a = new HashMap();
            for (int i = 0; i < objArr.length; i += 2) {
                this.f1895a.put(objArr[i], objArr[i + 1]);
            }
            return;
        }
        throw new IllegalArgumentException("You must provide the same number of keys and values");
    }

    public JavaOnlyMap() {
        this.f1895a = new HashMap();
    }

    @Override // com.facebook.react.bridge.ReadableMap
    public boolean a(String str) {
        return this.f1895a.containsKey(str);
    }

    @Override // com.facebook.react.bridge.ReadableMap
    public boolean b(String str) {
        return this.f1895a.get(str) == null;
    }

    @Override // com.facebook.react.bridge.ReadableMap
    public boolean c(String str) {
        return ((Boolean) this.f1895a.get(str)).booleanValue();
    }

    @Override // com.facebook.react.bridge.ReadableMap
    public double d(String str) {
        return ((Number) this.f1895a.get(str)).doubleValue();
    }

    @Override // com.facebook.react.bridge.ReadableMap
    public int e(String str) {
        return ((Number) this.f1895a.get(str)).intValue();
    }

    @Override // com.facebook.react.bridge.ReadableMap
    public String f(String str) {
        return (String) this.f1895a.get(str);
    }

    @Override // com.facebook.react.bridge.ReadableMap
    public ReadableMap g(String str) {
        return (ReadableMap) this.f1895a.get(str);
    }

    /* renamed from: h */
    public JavaOnlyArray k(String str) {
        return (JavaOnlyArray) this.f1895a.get(str);
    }

    @Override // com.facebook.react.bridge.ReadableMap
    public Dynamic i(String str) {
        return DynamicFromMap.a(this, str);
    }

    @Override // com.facebook.react.bridge.ReadableMap
    public ReadableType j(String str) {
        Object obj = this.f1895a.get(str);
        if (obj == null) {
            return ReadableType.Null;
        }
        if (obj instanceof Number) {
            return ReadableType.Number;
        }
        if (obj instanceof String) {
            return ReadableType.String;
        }
        if (obj instanceof Boolean) {
            return ReadableType.Boolean;
        }
        if (obj instanceof ReadableMap) {
            return ReadableType.Map;
        }
        if (obj instanceof ReadableArray) {
            return ReadableType.Array;
        }
        if (obj instanceof Dynamic) {
            return ((Dynamic) obj).d();
        }
        throw new IllegalArgumentException("Invalid value " + obj.toString() + " for key " + str + "contained in JavaOnlyMap");
    }

    @Override // com.facebook.react.bridge.ReadableMap
    public ReadableMapKeySetIterator a() {
        return new ReadableMapKeySetIterator() {
            /* class com.facebook.react.bridge.JavaOnlyMap.AnonymousClass1 */

            /* renamed from: a  reason: collision with root package name */
            Iterator<String> f1896a = JavaOnlyMap.this.f1895a.keySet().iterator();

            @Override // com.facebook.react.bridge.ReadableMapKeySetIterator
            public boolean hasNextKey() {
                return this.f1896a.hasNext();
            }

            @Override // com.facebook.react.bridge.ReadableMapKeySetIterator
            public String nextKey() {
                return this.f1896a.next();
            }
        };
    }

    @Override // com.facebook.react.bridge.WritableMap
    public void putBoolean(String str, boolean z) {
        this.f1895a.put(str, Boolean.valueOf(z));
    }

    @Override // com.facebook.react.bridge.WritableMap
    public void putDouble(String str, double d) {
        this.f1895a.put(str, Double.valueOf(d));
    }

    @Override // com.facebook.react.bridge.WritableMap
    public void putInt(String str, int i) {
        this.f1895a.put(str, Integer.valueOf(i));
    }

    @Override // com.facebook.react.bridge.WritableMap
    public void putString(String str, String str2) {
        this.f1895a.put(str, str2);
    }

    @Override // com.facebook.react.bridge.WritableMap
    public void putNull(String str) {
        this.f1895a.put(str, null);
    }

    @Override // com.facebook.react.bridge.WritableMap
    public void a(String str, WritableMap writableMap) {
        this.f1895a.put(str, writableMap);
    }

    @Override // com.facebook.react.bridge.WritableMap
    public void a(String str, WritableArray writableArray) {
        this.f1895a.put(str, writableArray);
    }

    @Override // com.facebook.react.bridge.ReadableMap
    public HashMap<String, Object> b() {
        return new HashMap<>(this.f1895a);
    }

    public String toString() {
        return this.f1895a.toString();
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        JavaOnlyMap javaOnlyMap = (JavaOnlyMap) obj;
        return this.f1895a == null ? javaOnlyMap.f1895a == null : this.f1895a.equals(javaOnlyMap.f1895a);
    }

    public int hashCode() {
        if (this.f1895a != null) {
            return this.f1895a.hashCode();
        }
        return 0;
    }
}
