package com.facebook.react.bridge;

import android.app.Activity;
import android.content.Context;
import android.content.ContextWrapper;
import android.content.Intent;
import android.view.LayoutInflater;
import com.facebook.infer.annotation.Assertions;
import com.facebook.react.bridge.queue.MessageQueueThread;
import com.facebook.react.bridge.queue.ReactQueueConfiguration;
import com.facebook.react.common.LifecycleState;
import java.lang.ref.WeakReference;
import java.util.Iterator;
import java.util.concurrent.CopyOnWriteArraySet;
import javax.annotation.Nullable;

public class ReactContext extends ContextWrapper {

    /* renamed from: a  reason: collision with root package name */
    private final CopyOnWriteArraySet<LifecycleEventListener> f1914a = new CopyOnWriteArraySet<>();
    private final CopyOnWriteArraySet<ActivityEventListener> b = new CopyOnWriteArraySet<>();
    private LifecycleState c = LifecycleState.BEFORE_CREATE;
    @Nullable
    private CatalystInstance d;
    @Nullable
    private LayoutInflater e;
    @Nullable
    private MessageQueueThread f;
    @Nullable
    private MessageQueueThread g;
    @Nullable
    private MessageQueueThread h;
    @Nullable
    private NativeModuleCallExceptionHandler i;
    @Nullable
    private WeakReference<Activity> j;

    public ReactContext(Context context) {
        super(context);
    }

    public void a(CatalystInstance catalystInstance) {
        if (catalystInstance == null) {
            throw new IllegalArgumentException("CatalystInstance cannot be null.");
        } else if (this.d == null) {
            this.d = catalystInstance;
            ReactQueueConfiguration reactQueueConfiguration = catalystInstance.getReactQueueConfiguration();
            this.f = reactQueueConfiguration.a();
            this.g = reactQueueConfiguration.b();
            this.h = reactQueueConfiguration.c();
        } else {
            throw new IllegalStateException("ReactContext has been already initialized");
        }
    }

    public void a(@Nullable NativeModuleCallExceptionHandler nativeModuleCallExceptionHandler) {
        this.i = nativeModuleCallExceptionHandler;
    }

    @Override // android.content.Context, android.content.ContextWrapper
    public Object getSystemService(String str) {
        if (!"layout_inflater".equals(str)) {
            return getBaseContext().getSystemService(str);
        }
        if (this.e == null) {
            this.e = LayoutInflater.from(getBaseContext()).cloneInContext(this);
        }
        return this.e;
    }

    public <T extends JavaScriptModule> T a(Class<T> cls) {
        if (this.d != null) {
            return (T) this.d.getJSModule(cls);
        }
        throw new RuntimeException("Tried to access a JS module before the React instance was fully set up. Calls to ReactContext#getJSModule should only happen once initialize() has been called on your native module.");
    }

    public <T extends NativeModule> T b(Class<T> cls) {
        if (this.d != null) {
            return (T) this.d.getNativeModule(cls);
        }
        throw new RuntimeException("Trying to call native module before CatalystInstance has been set!");
    }

    public CatalystInstance a() {
        return (CatalystInstance) Assertions.b(this.d);
    }

    public boolean b() {
        return this.d != null && !this.d.isDestroyed();
    }

    public LifecycleState c() {
        return this.c;
    }

    public void a(final LifecycleEventListener lifecycleEventListener) {
        this.f1914a.add(lifecycleEventListener);
        if (b()) {
            switch (this.c) {
                case BEFORE_CREATE:
                case BEFORE_RESUME:
                    return;
                case RESUMED:
                    a(new Runnable() {
                        /* class com.facebook.react.bridge.ReactContext.AnonymousClass1 */

                        public void run() {
                            if (ReactContext.this.f1914a.contains(lifecycleEventListener)) {
                                try {
                                    lifecycleEventListener.onHostResume();
                                } catch (RuntimeException e) {
                                    ReactContext.this.a(e);
                                }
                            }
                        }
                    });
                    return;
                default:
                    throw new RuntimeException("Unhandled lifecycle state.");
            }
        }
    }

    public void b(LifecycleEventListener lifecycleEventListener) {
        this.f1914a.remove(lifecycleEventListener);
    }

    public void a(ActivityEventListener activityEventListener) {
        this.b.add(activityEventListener);
    }

    public void a(@Nullable Activity activity) {
        this.c = LifecycleState.RESUMED;
        this.j = new WeakReference<>(activity);
        ReactMarker.logMarker(ReactMarkerConstants.ON_HOST_RESUME_START);
        Iterator<LifecycleEventListener> it = this.f1914a.iterator();
        while (it.hasNext()) {
            try {
                it.next().onHostResume();
            } catch (RuntimeException e2) {
                a(e2);
            }
        }
        ReactMarker.logMarker(ReactMarkerConstants.ON_HOST_RESUME_END);
    }

    public void a(@Nullable Activity activity, Intent intent) {
        UiThreadUtil.b();
        this.j = new WeakReference<>(activity);
        Iterator<ActivityEventListener> it = this.b.iterator();
        while (it.hasNext()) {
            try {
                it.next().onNewIntent(intent);
            } catch (RuntimeException e2) {
                a(e2);
            }
        }
    }

    public void d() {
        this.c = LifecycleState.BEFORE_RESUME;
        ReactMarker.logMarker(ReactMarkerConstants.ON_HOST_PAUSE_START);
        Iterator<LifecycleEventListener> it = this.f1914a.iterator();
        while (it.hasNext()) {
            try {
                it.next().onHostPause();
            } catch (RuntimeException e2) {
                a(e2);
            }
        }
        ReactMarker.logMarker(ReactMarkerConstants.ON_HOST_PAUSE_END);
    }

    public void e() {
        UiThreadUtil.b();
        this.c = LifecycleState.BEFORE_CREATE;
        Iterator<LifecycleEventListener> it = this.f1914a.iterator();
        while (it.hasNext()) {
            try {
                it.next().onHostDestroy();
            } catch (RuntimeException e2) {
                a(e2);
            }
        }
        this.j = null;
    }

    public void f() {
        UiThreadUtil.b();
        if (this.d != null) {
            this.d.destroy();
        }
    }

    public void a(Activity activity, int i2, int i3, Intent intent) {
        Iterator<ActivityEventListener> it = this.b.iterator();
        while (it.hasNext()) {
            try {
                it.next().onActivityResult(activity, i2, i3, intent);
            } catch (RuntimeException e2) {
                a(e2);
            }
        }
    }

    public void g() {
        ((MessageQueueThread) Assertions.b(this.f)).assertIsOnThread();
    }

    public boolean h() {
        return ((MessageQueueThread) Assertions.b(this.f)).isOnThread();
    }

    public void a(Runnable runnable) {
        ((MessageQueueThread) Assertions.b(this.f)).runOnQueue(runnable);
    }

    public void i() {
        ((MessageQueueThread) Assertions.b(this.g)).assertIsOnThread();
    }

    public void a(String str) {
        ((MessageQueueThread) Assertions.b(this.g)).assertIsOnThread(str);
    }

    public void b(Runnable runnable) {
        ((MessageQueueThread) Assertions.b(this.g)).runOnQueue(runnable);
    }

    public void c(Runnable runnable) {
        ((MessageQueueThread) Assertions.b(this.h)).runOnQueue(runnable);
    }

    public void a(Exception exc) {
        if (this.d == null || this.d.isDestroyed() || this.i == null) {
            throw new RuntimeException(exc);
        }
        this.i.a(exc);
    }

    public boolean j() {
        return (this.j == null || this.j.get() == null) ? false : true;
    }

    @Nullable
    public Activity k() {
        if (this.j == null) {
            return null;
        }
        return this.j.get();
    }

    public JavaScriptContextHolder l() {
        return this.d.getJavaScriptContextHolder();
    }
}
