package com.facebook.react.devsupport;

import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.ReadableType;
import com.facebook.react.devsupport.interfaces.StackFrame;
import java.io.File;
import java.util.regex.Pattern;
import javax.annotation.Nullable;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class StackTraceHelper {

    /* renamed from: a  reason: collision with root package name */
    private static final Pattern f2031a = Pattern.compile("^(?:(.*?)@)?(.*?)\\:([0-9]+)\\:([0-9]+)$");

    public static class StackFrameImpl implements StackFrame {

        /* renamed from: a  reason: collision with root package name */
        private final String f2032a;
        private final String b;
        private final int c;
        private final int d;
        private final String e;

        private StackFrameImpl(String str, String str2, int i, int i2) {
            this.f2032a = str;
            this.b = str2;
            this.c = i;
            this.d = i2;
            this.e = str != null ? new File(str).getName() : "";
        }

        private StackFrameImpl(String str, String str2, String str3, int i, int i2) {
            this.f2032a = str;
            this.e = str2;
            this.b = str3;
            this.c = i;
            this.d = i2;
        }

        @Override // com.facebook.react.devsupport.interfaces.StackFrame
        public String a() {
            return this.f2032a;
        }

        @Override // com.facebook.react.devsupport.interfaces.StackFrame
        public String b() {
            return this.b;
        }

        @Override // com.facebook.react.devsupport.interfaces.StackFrame
        public int c() {
            return this.c;
        }

        @Override // com.facebook.react.devsupport.interfaces.StackFrame
        public int d() {
            return this.d;
        }

        @Override // com.facebook.react.devsupport.interfaces.StackFrame
        public String e() {
            return this.e;
        }
    }

    public static StackFrame[] a(@Nullable ReadableArray readableArray) {
        int a2 = readableArray != null ? readableArray.a() : 0;
        StackFrame[] stackFrameArr = new StackFrame[a2];
        for (int i = 0; i < a2; i++) {
            ReadableType h = readableArray.h(i);
            if (h == ReadableType.Map) {
                ReadableMap i2 = readableArray.i(i);
                stackFrameArr[i] = new StackFrameImpl(i2.f("file"), i2.f("methodName"), (!i2.a("lineNumber") || i2.b("lineNumber")) ? -1 : i2.e("lineNumber"), (!i2.a("column") || i2.b("column")) ? -1 : i2.e("column"));
            } else if (h == ReadableType.String) {
                stackFrameArr[i] = new StackFrameImpl((String) null, readableArray.d(i), -1, -1);
            }
        }
        return stackFrameArr;
    }

    public static StackFrame[] a(JSONArray jSONArray) {
        int length = jSONArray != null ? jSONArray.length() : 0;
        StackFrame[] stackFrameArr = new StackFrame[length];
        for (int i = 0; i < length; i++) {
            try {
                JSONObject jSONObject = jSONArray.getJSONObject(i);
                stackFrameArr[i] = new StackFrameImpl(jSONObject.getString("file"), jSONObject.getString("methodName"), (!jSONObject.has("lineNumber") || jSONObject.isNull("lineNumber")) ? -1 : jSONObject.getInt("lineNumber"), (!jSONObject.has("column") || jSONObject.isNull("column")) ? -1 : jSONObject.getInt("column"));
            } catch (JSONException e) {
                throw new RuntimeException(e);
            }
        }
        return stackFrameArr;
    }

    public static StackFrame[] a(Throwable th) {
        StackTraceElement[] stackTrace = th.getStackTrace();
        StackFrame[] stackFrameArr = new StackFrame[stackTrace.length];
        for (int i = 0; i < stackTrace.length; i++) {
            stackFrameArr[i] = new StackFrameImpl(stackTrace[i].getClassName(), stackTrace[i].getFileName(), stackTrace[i].getMethodName(), stackTrace[i].getLineNumber(), -1);
        }
        return stackFrameArr;
    }

    public static String a(StackFrame stackFrame) {
        StringBuilder sb = new StringBuilder();
        sb.append(stackFrame.e());
        int c = stackFrame.c();
        if (c > 0) {
            sb.append(":");
            sb.append(c);
            int d = stackFrame.d();
            if (d > 0) {
                sb.append(":");
                sb.append(d);
            }
        }
        return sb.toString();
    }

    public static String a(String str, StackFrame[] stackFrameArr) {
        StringBuilder sb = new StringBuilder();
        sb.append(str);
        sb.append("\n");
        for (StackFrame stackFrame : stackFrameArr) {
            sb.append(stackFrame.b());
            sb.append("\n");
            sb.append("    ");
            sb.append(a(stackFrame));
            sb.append("\n");
        }
        return sb.toString();
    }
}
