package com.facebook.react.jstasks;

import android.os.Handler;
import android.util.SparseArray;
import com.facebook.infer.annotation.Assertions;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.UiThreadUtil;
import com.facebook.react.common.LifecycleState;
import com.facebook.react.modules.appregistry.AppRegistry;
import java.lang.ref.WeakReference;
import java.util.Set;
import java.util.WeakHashMap;
import java.util.concurrent.CopyOnWriteArraySet;
import java.util.concurrent.atomic.AtomicInteger;

public class HeadlessJsTaskContext {

    /* renamed from: a  reason: collision with root package name */
    private static final WeakHashMap<ReactContext, HeadlessJsTaskContext> f2069a = new WeakHashMap<>();
    private final WeakReference<ReactContext> b;
    private final Set<HeadlessJsTaskEventListener> c = new CopyOnWriteArraySet();
    private final AtomicInteger d = new AtomicInteger(0);
    private final Handler e = new Handler();
    private final Set<Integer> f = new CopyOnWriteArraySet();
    private final SparseArray<Runnable> g = new SparseArray<>();

    public static HeadlessJsTaskContext a(ReactContext reactContext) {
        HeadlessJsTaskContext headlessJsTaskContext = f2069a.get(reactContext);
        if (headlessJsTaskContext != null) {
            return headlessJsTaskContext;
        }
        HeadlessJsTaskContext headlessJsTaskContext2 = new HeadlessJsTaskContext(reactContext);
        f2069a.put(reactContext, headlessJsTaskContext2);
        return headlessJsTaskContext2;
    }

    private HeadlessJsTaskContext(ReactContext reactContext) {
        this.b = new WeakReference<>(reactContext);
    }

    public void a(HeadlessJsTaskEventListener headlessJsTaskEventListener) {
        this.c.add(headlessJsTaskEventListener);
    }

    public void b(HeadlessJsTaskEventListener headlessJsTaskEventListener) {
        this.c.remove(headlessJsTaskEventListener);
    }

    public boolean a() {
        return this.f.size() > 0;
    }

    public synchronized int a(HeadlessJsTaskConfig headlessJsTaskConfig) {
        int incrementAndGet;
        UiThreadUtil.b();
        ReactContext reactContext = (ReactContext) Assertions.a(this.b.get(), "Tried to start a task on a react context that has already been destroyed");
        if (reactContext.c() == LifecycleState.RESUMED) {
            if (!headlessJsTaskConfig.d()) {
                throw new IllegalStateException("Tried to start task " + headlessJsTaskConfig.a() + " while in foreground, but this is not allowed.");
            }
        }
        incrementAndGet = this.d.incrementAndGet();
        this.f.add(Integer.valueOf(incrementAndGet));
        ((AppRegistry) reactContext.a(AppRegistry.class)).startHeadlessTask(incrementAndGet, headlessJsTaskConfig.a(), headlessJsTaskConfig.b());
        if (headlessJsTaskConfig.c() > 0) {
            a(incrementAndGet, headlessJsTaskConfig.c());
        }
        for (HeadlessJsTaskEventListener headlessJsTaskEventListener : this.c) {
            headlessJsTaskEventListener.onHeadlessJsTaskStart(incrementAndGet);
        }
        return incrementAndGet;
    }

    public synchronized void a(final int i) {
        boolean remove = this.f.remove(Integer.valueOf(i));
        Assertions.a(remove, "Tried to finish non-existent task with id " + i + ".");
        Runnable runnable = this.g.get(i);
        if (runnable != null) {
            this.e.removeCallbacks(runnable);
            this.g.remove(i);
        }
        UiThreadUtil.a(new Runnable() {
            /* class com.facebook.react.jstasks.HeadlessJsTaskContext.AnonymousClass1 */

            public void run() {
                for (HeadlessJsTaskEventListener headlessJsTaskEventListener : HeadlessJsTaskContext.this.c) {
                    headlessJsTaskEventListener.onHeadlessJsTaskFinish(i);
                }
            }
        });
    }

    public synchronized boolean b(int i) {
        return this.f.contains(Integer.valueOf(i));
    }

    private void a(final int i, long j) {
        AnonymousClass2 r0 = new Runnable() {
            /* class com.facebook.react.jstasks.HeadlessJsTaskContext.AnonymousClass2 */

            public void run() {
                HeadlessJsTaskContext.this.a(i);
            }
        };
        this.g.append(i, r0);
        this.e.postDelayed(r0, j);
    }
}
