package com.facebook.react.modules.camera;

import android.content.ContentResolver;
import android.content.Context;
import android.content.res.AssetFileDescriptor;
import android.database.Cursor;
import android.graphics.BitmapFactory;
import android.media.MediaMetadataRetriever;
import android.media.MediaScannerConnection;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Build;
import android.os.Environment;
import android.provider.MediaStore;
import android.text.TextUtils;
import com.facebook.common.logging.FLog;
import com.facebook.react.bridge.GuardedAsyncTask;
import com.facebook.react.bridge.JSApplicationIllegalArgumentException;
import com.facebook.react.bridge.Promise;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.bridge.WritableNativeArray;
import com.facebook.react.bridge.WritableNativeMap;
import com.facebook.react.module.annotations.ReactModule;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.channels.FileChannel;
import java.util.ArrayList;
import javax.annotation.Nullable;

@ReactModule
public class CameraRollManager extends ReactContextBaseJavaModule {
    private static final String ERROR_UNABLE_TO_LOAD = "E_UNABLE_TO_LOAD";
    private static final String ERROR_UNABLE_TO_LOAD_PERMISSION = "E_UNABLE_TO_LOAD_PERMISSION";
    private static final String ERROR_UNABLE_TO_SAVE = "E_UNABLE_TO_SAVE";
    public static final boolean IS_JELLY_BEAN_OR_LATER = (Build.VERSION.SDK_INT >= 16);
    protected static final String NAME = "CameraRollManager";
    private static final String[] PROJECTION;
    private static final String SELECTION_BUCKET = "bucket_display_name = ?";
    private static final String SELECTION_DATE_TAKEN = "datetaken < ?";

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return NAME;
    }

    static {
        if (IS_JELLY_BEAN_OR_LATER) {
            PROJECTION = new String[]{"_id", "mime_type", "bucket_display_name", "datetaken", "width", "height", "longitude", "latitude"};
        } else {
            PROJECTION = new String[]{"_id", "mime_type", "bucket_display_name", "datetaken", "longitude", "latitude"};
        }
    }

    public CameraRollManager(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
    }

    @ReactMethod
    public void saveToCameraRoll(String str, String str2, Promise promise) {
        new SaveToCameraRoll(getReactApplicationContext(), Uri.parse(str), promise).executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
    }

    private static class SaveToCameraRoll extends GuardedAsyncTask<Void, Void> {

        /* renamed from: a  reason: collision with root package name */
        private final Context f2079a;
        private final Uri b;
        private final Promise c;

        public SaveToCameraRoll(ReactContext reactContext, Uri uri, Promise promise) {
            super(reactContext);
            this.f2079a = reactContext;
            this.b = uri;
            this.c = promise;
        }

        /* access modifiers changed from: protected */
        /* JADX WARNING: Removed duplicated region for block: B:53:0x0106  */
        /* JADX WARNING: Removed duplicated region for block: B:79:? A[ADDED_TO_REGION, RETURN, SYNTHETIC] */
        /* renamed from: a */
        public void b(Void... voidArr) {
            Throwable th;
            FileChannel fileChannel;
            IOException e;
            String str;
            int i;
            File file = new File(this.b.getPath());
            FileChannel fileChannel2 = null;
            try {
                File externalStoragePublicDirectory = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DCIM);
                externalStoragePublicDirectory.mkdirs();
                if (!externalStoragePublicDirectory.isDirectory()) {
                    this.c.a(CameraRollManager.ERROR_UNABLE_TO_LOAD, "External media storage directory not available");
                    return;
                }
                File file2 = new File(externalStoragePublicDirectory, file.getName());
                String name = file.getName();
                if (name.indexOf(46) >= 0) {
                    String substring = name.substring(0, name.lastIndexOf(46));
                    i = 0;
                    str = name.substring(name.lastIndexOf(46));
                    name = substring;
                } else {
                    str = "";
                    i = 0;
                }
                while (!file2.createNewFile()) {
                    file2 = new File(externalStoragePublicDirectory, name + "_" + i + str);
                    i++;
                }
                FileChannel channel = new FileInputStream(file).getChannel();
                try {
                    fileChannel = new FileOutputStream(file2).getChannel();
                    try {
                        fileChannel.transferFrom(channel, 0, channel.size());
                        channel.close();
                        fileChannel.close();
                        MediaScannerConnection.scanFile(this.f2079a, new String[]{file2.getAbsolutePath()}, null, new MediaScannerConnection.OnScanCompletedListener() {
                            /* class com.facebook.react.modules.camera.CameraRollManager.SaveToCameraRoll.AnonymousClass1 */

                            public void onScanCompleted(String str, Uri uri) {
                                if (uri != null) {
                                    SaveToCameraRoll.this.c.a((Object) uri.toString());
                                } else {
                                    SaveToCameraRoll.this.c.a(CameraRollManager.ERROR_UNABLE_TO_SAVE, "Could not add image to gallery");
                                }
                            }
                        });
                        if (channel != null && channel.isOpen()) {
                            try {
                                channel.close();
                            } catch (IOException e2) {
                                FLog.c("ReactNative", "Could not close input channel", e2);
                            }
                        }
                        if (fileChannel != null && fileChannel.isOpen()) {
                            try {
                                fileChannel.close();
                            } catch (IOException e3) {
                                FLog.c("ReactNative", "Could not close output channel", e3);
                            }
                        }
                    } catch (IOException e4) {
                        fileChannel2 = channel;
                        e = e4;
                        try {
                            this.c.a((Throwable) e);
                            try {
                                fileChannel2.close();
                            } catch (IOException e5) {
                                FLog.c("ReactNative", "Could not close input channel", e5);
                            }
                            if (fileChannel == null) {
                            }
                        } catch (Throwable th2) {
                            th = th2;
                            if (fileChannel2 != null && fileChannel2.isOpen()) {
                                try {
                                    fileChannel2.close();
                                } catch (IOException e6) {
                                    FLog.c("ReactNative", "Could not close input channel", e6);
                                }
                            }
                            if (fileChannel != null && fileChannel.isOpen()) {
                                try {
                                    fileChannel.close();
                                } catch (IOException e7) {
                                    FLog.c("ReactNative", "Could not close output channel", e7);
                                }
                            }
                            throw th;
                        }
                    } catch (Throwable th3) {
                        fileChannel2 = channel;
                        th = th3;
                        fileChannel2.close();
                        fileChannel.close();
                        throw th;
                    }
                } catch (IOException e8) {
                    fileChannel2 = channel;
                    e = e8;
                    fileChannel = null;
                    this.c.a((Throwable) e);
                    if (fileChannel2 != null && fileChannel2.isOpen()) {
                        fileChannel2.close();
                    }
                    if (fileChannel == null && fileChannel.isOpen()) {
                        fileChannel.close();
                    }
                } catch (Throwable th4) {
                    fileChannel2 = channel;
                    th = th4;
                    fileChannel = null;
                    fileChannel2.close();
                    fileChannel.close();
                    throw th;
                }
            } catch (IOException e9) {
                e = e9;
                fileChannel = null;
                this.c.a((Throwable) e);
                fileChannel2.close();
                if (fileChannel == null) {
                }
            } catch (Throwable th5) {
                th = th5;
                fileChannel = null;
                fileChannel2.close();
                fileChannel.close();
                throw th;
            }
        }
    }

    @ReactMethod
    public void getPhotos(ReadableMap readableMap, Promise promise) {
        int e = readableMap.e("first");
        String f = readableMap.a("after") ? readableMap.f("after") : null;
        String f2 = readableMap.a("groupName") ? readableMap.f("groupName") : null;
        String f3 = readableMap.a("assetType") ? readableMap.f("assetType") : null;
        ReadableArray k = readableMap.a("mimeTypes") ? readableMap.k("mimeTypes") : null;
        if (!readableMap.a("groupTypes")) {
            new GetPhotosTask(getReactApplicationContext(), e, f, f2, k, f3, promise).executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
            return;
        }
        throw new JSApplicationIllegalArgumentException("groupTypes is not supported on Android");
    }

    private static class GetPhotosTask extends GuardedAsyncTask<Void, Void> {

        /* renamed from: a  reason: collision with root package name */
        private final Context f2078a;
        private final int b;
        @Nullable
        private final String c;
        @Nullable
        private final String d;
        @Nullable
        private final ReadableArray e;
        private final Promise f;
        @Nullable
        private final String g;

        private GetPhotosTask(ReactContext reactContext, int i, @Nullable String str, @Nullable String str2, @Nullable ReadableArray readableArray, @Nullable String str3, Promise promise) {
            super(reactContext);
            this.f2078a = reactContext;
            this.b = i;
            this.c = str;
            this.d = str2;
            this.e = readableArray;
            this.f = promise;
            this.g = str3;
        }

        /* access modifiers changed from: protected */
        /* renamed from: a */
        public void b(Void... voidArr) {
            StringBuilder sb = new StringBuilder("1");
            ArrayList arrayList = new ArrayList();
            if (!TextUtils.isEmpty(this.c)) {
                sb.append(" AND datetaken < ?");
                arrayList.add(this.c);
            }
            if (!TextUtils.isEmpty(this.d)) {
                sb.append(" AND bucket_display_name = ?");
                arrayList.add(this.d);
            }
            if (this.e != null && this.e.a() > 0) {
                sb.append(" AND mime_type IN (");
                for (int i = 0; i < this.e.a(); i++) {
                    sb.append("?,");
                    arrayList.add(this.e.d(i));
                }
                sb.replace(sb.length() - 1, sb.length(), ")");
            }
            WritableNativeMap writableNativeMap = new WritableNativeMap();
            ContentResolver contentResolver = this.f2078a.getContentResolver();
            try {
                Uri uri = (this.g == null || !this.g.equals("Videos")) ? MediaStore.Images.Media.EXTERNAL_CONTENT_URI : MediaStore.Video.Media.EXTERNAL_CONTENT_URI;
                String[] strArr = CameraRollManager.PROJECTION;
                String sb2 = sb.toString();
                String[] strArr2 = (String[]) arrayList.toArray(new String[arrayList.size()]);
                Cursor query = contentResolver.query(uri, strArr, sb2, strArr2, "datetaken DESC, date_modified DESC LIMIT " + (this.b + 1));
                if (query == null) {
                    this.f.a(CameraRollManager.ERROR_UNABLE_TO_LOAD, "Could not get photos");
                    return;
                }
                try {
                    CameraRollManager.putEdges(contentResolver, query, writableNativeMap, this.b, this.g);
                    CameraRollManager.putPageInfo(query, writableNativeMap, this.b);
                } finally {
                    query.close();
                    this.f.a(writableNativeMap);
                }
            } catch (SecurityException e2) {
                this.f.a(CameraRollManager.ERROR_UNABLE_TO_LOAD_PERMISSION, "Could not get photos: need READ_EXTERNAL_STORAGE permission", e2);
            }
        }
    }

    /* access modifiers changed from: private */
    public static void putPageInfo(Cursor cursor, WritableMap writableMap, int i) {
        WritableNativeMap writableNativeMap = new WritableNativeMap();
        writableNativeMap.putBoolean("has_next_page", i < cursor.getCount());
        if (i < cursor.getCount()) {
            cursor.moveToPosition(i - 1);
            writableNativeMap.putString("end_cursor", cursor.getString(cursor.getColumnIndex("datetaken")));
        }
        writableMap.a("page_info", writableNativeMap);
    }

    /* access modifiers changed from: private */
    public static void putEdges(ContentResolver contentResolver, Cursor cursor, WritableMap writableMap, int i, @Nullable String str) {
        WritableNativeArray writableNativeArray;
        WritableNativeArray writableNativeArray2 = new WritableNativeArray();
        cursor.moveToFirst();
        int columnIndex = cursor.getColumnIndex("_id");
        int columnIndex2 = cursor.getColumnIndex("mime_type");
        int columnIndex3 = cursor.getColumnIndex("bucket_display_name");
        int columnIndex4 = cursor.getColumnIndex("datetaken");
        int columnIndex5 = IS_JELLY_BEAN_OR_LATER ? cursor.getColumnIndex("width") : -1;
        int columnIndex6 = IS_JELLY_BEAN_OR_LATER ? cursor.getColumnIndex("height") : -1;
        int columnIndex7 = cursor.getColumnIndex("longitude");
        int columnIndex8 = cursor.getColumnIndex("latitude");
        int i2 = i;
        int i3 = 0;
        while (i3 < i2 && !cursor.isAfterLast()) {
            WritableNativeMap writableNativeMap = new WritableNativeMap();
            WritableNativeMap writableNativeMap2 = new WritableNativeMap();
            int i4 = i3;
            if (putImageInfo(contentResolver, cursor, writableNativeMap2, columnIndex, columnIndex5, columnIndex6, str)) {
                putBasicNodeInfo(cursor, writableNativeMap2, columnIndex2, columnIndex3, columnIndex4);
                putLocationInfo(cursor, writableNativeMap2, columnIndex7, columnIndex8);
                writableNativeMap.a("node", writableNativeMap2);
                writableNativeArray = writableNativeArray2;
                writableNativeArray.a(writableNativeMap);
            } else {
                writableNativeArray = writableNativeArray2;
                i4--;
            }
            cursor.moveToNext();
            i3 = i4 + 1;
            i2 = i;
            writableNativeArray2 = writableNativeArray;
            columnIndex8 = columnIndex8;
            columnIndex = columnIndex;
        }
        writableMap.a("edges", writableNativeArray2);
    }

    private static void putBasicNodeInfo(Cursor cursor, WritableMap writableMap, int i, int i2, int i3) {
        writableMap.putString("type", cursor.getString(i));
        writableMap.putString("group_name", cursor.getString(i2));
        writableMap.putDouble("timestamp", ((double) cursor.getLong(i3)) / 1000.0d);
    }

    private static boolean putImageInfo(ContentResolver contentResolver, Cursor cursor, WritableMap writableMap, int i, int i2, int i3, @Nullable String str) {
        Uri uri;
        float f;
        WritableNativeMap writableNativeMap = new WritableNativeMap();
        if (str == null || !str.equals("Videos")) {
            uri = Uri.withAppendedPath(MediaStore.Images.Media.EXTERNAL_CONTENT_URI, cursor.getString(i));
        } else {
            uri = Uri.withAppendedPath(MediaStore.Video.Media.EXTERNAL_CONTENT_URI, cursor.getString(i));
        }
        writableNativeMap.putString("uri", uri.toString());
        float f2 = -1.0f;
        if (IS_JELLY_BEAN_OR_LATER) {
            f2 = (float) cursor.getInt(i2);
            f = (float) cursor.getInt(i3);
        } else {
            f = -1.0f;
        }
        if (str != null && str.equals("Videos") && Build.VERSION.SDK_INT >= 10) {
            try {
                AssetFileDescriptor openAssetFileDescriptor = contentResolver.openAssetFileDescriptor(uri, "r");
                MediaMetadataRetriever mediaMetadataRetriever = new MediaMetadataRetriever();
                mediaMetadataRetriever.setDataSource(openAssetFileDescriptor.getFileDescriptor());
                if (f2 <= 0.0f || f <= 0.0f) {
                    try {
                        float parseInt = (float) Integer.parseInt(mediaMetadataRetriever.extractMetadata(19));
                        f2 = (float) Integer.parseInt(mediaMetadataRetriever.extractMetadata(18));
                        f = parseInt;
                    } catch (NumberFormatException e) {
                        FLog.c("ReactNative", "Number format exception occurred while trying to fetch video metadata for " + uri.toString(), e);
                        mediaMetadataRetriever.release();
                        openAssetFileDescriptor.close();
                        return false;
                    } catch (Throwable th) {
                        mediaMetadataRetriever.release();
                        openAssetFileDescriptor.close();
                        throw th;
                    }
                }
                writableNativeMap.putInt("playableDuration", Integer.parseInt(mediaMetadataRetriever.extractMetadata(9)) / 1000);
                mediaMetadataRetriever.release();
                openAssetFileDescriptor.close();
            } catch (IOException e2) {
                FLog.c("ReactNative", "Could not get video metadata for " + uri.toString(), e2);
                return false;
            }
        }
        if (f2 <= 0.0f || f <= 0.0f) {
            try {
                AssetFileDescriptor openAssetFileDescriptor2 = contentResolver.openAssetFileDescriptor(uri, "r");
                BitmapFactory.Options options = new BitmapFactory.Options();
                options.inJustDecodeBounds = true;
                BitmapFactory.decodeFileDescriptor(openAssetFileDescriptor2.getFileDescriptor(), null, options);
                f2 = (float) options.outWidth;
                f = (float) options.outHeight;
                openAssetFileDescriptor2.close();
            } catch (IOException e3) {
                FLog.c("ReactNative", "Could not get width/height for " + uri.toString(), e3);
                return false;
            }
        }
        writableNativeMap.putDouble("width", (double) f2);
        writableNativeMap.putDouble("height", (double) f);
        writableMap.a("image", writableNativeMap);
        return true;
    }

    private static void putLocationInfo(Cursor cursor, WritableMap writableMap, int i, int i2) {
        double d = cursor.getDouble(i);
        double d2 = cursor.getDouble(i2);
        if (d > 0.0d || d2 > 0.0d) {
            WritableNativeMap writableNativeMap = new WritableNativeMap();
            writableNativeMap.putDouble("longitude", d);
            writableNativeMap.putDouble("latitude", d2);
            writableMap.a("location", writableNativeMap);
        }
    }
}
