package com.facebook.react.modules.camera;

import android.annotation.SuppressLint;
import android.content.Context;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.BitmapRegionDecoder;
import android.graphics.Matrix;
import android.graphics.Rect;
import android.media.ExifInterface;
import android.net.Uri;
import android.os.AsyncTask;
import android.text.TextUtils;
import com.facebook.common.logging.FLog;
import com.facebook.infer.annotation.Assertions;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.GuardedAsyncTask;
import com.facebook.react.bridge.JSApplicationIllegalArgumentException;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.module.annotations.ReactModule;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FilenameFilter;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import javax.annotation.Nullable;

@ReactModule
public class ImageEditingManager extends ReactContextBaseJavaModule {
    private static final int COMPRESS_QUALITY = 90;
    @SuppressLint({"InlinedApi"})
    private static final String[] EXIF_ATTRIBUTES = {"FNumber", "DateTime", "DateTimeDigitized", "ExposureTime", "Flash", "FocalLength", "GPSAltitude", "GPSAltitudeRef", "GPSDateStamp", "GPSLatitude", "GPSLatitudeRef", "GPSLongitude", "GPSLongitudeRef", "GPSProcessingMethod", "GPSTimeStamp", "ImageLength", "ImageWidth", "ISOSpeedRatings", "Make", "Model", "Orientation", "SubSecTime", "SubSecTimeDigitized", "SubSecTimeOriginal", "WhiteBalance"};
    private static final List<String> LOCAL_URI_PREFIXES = Arrays.asList("file://", "content://");
    protected static final String NAME = "ImageEditingManager";
    private static final String TEMP_FILE_PREFIX = "ReactNative_cropped_image_";

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return NAME;
    }

    public ImageEditingManager(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
        new CleanTask(getReactApplicationContext()).executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
    }

    @Override // com.facebook.react.bridge.BaseJavaModule
    public Map<String, Object> getConstants() {
        return Collections.emptyMap();
    }

    @Override // com.facebook.react.bridge.BaseJavaModule, com.facebook.react.bridge.NativeModule
    public void onCatalystInstanceDestroy() {
        new CleanTask(getReactApplicationContext()).executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
    }

    private static class CleanTask extends GuardedAsyncTask<Void, Void> {

        /* renamed from: a  reason: collision with root package name */
        private final Context f2081a;

        private CleanTask(ReactContext reactContext) {
            super(reactContext);
            this.f2081a = reactContext;
        }

        /* access modifiers changed from: protected */
        /* renamed from: a */
        public void b(Void... voidArr) {
            a(this.f2081a.getCacheDir());
            File externalCacheDir = this.f2081a.getExternalCacheDir();
            if (externalCacheDir != null) {
                a(externalCacheDir);
            }
        }

        private void a(File file) {
            File[] listFiles = file.listFiles(new FilenameFilter() {
                /* class com.facebook.react.modules.camera.ImageEditingManager.CleanTask.AnonymousClass1 */

                public boolean accept(File file, String str) {
                    return str.startsWith(ImageEditingManager.TEMP_FILE_PREFIX);
                }
            });
            if (listFiles != null) {
                for (File file2 : listFiles) {
                    file2.delete();
                }
            }
        }
    }

    @ReactMethod
    public void cropImage(String str, ReadableMap readableMap, Callback callback, Callback callback2) {
        ReadableMap readableMap2 = null;
        ReadableMap g = readableMap.a("offset") ? readableMap.g("offset") : null;
        if (readableMap.a("size")) {
            readableMap2 = readableMap.g("size");
        }
        if (g == null || readableMap2 == null || !g.a("x") || !g.a("y") || !readableMap2.a("width") || !readableMap2.a("height")) {
            throw new JSApplicationIllegalArgumentException("Please specify offset and size");
        } else if (str == null || str.isEmpty()) {
            throw new JSApplicationIllegalArgumentException("Please specify a URI");
        } else {
            CropTask cropTask = new CropTask(getReactApplicationContext(), str, (int) g.d("x"), (int) g.d("y"), (int) readableMap2.d("width"), (int) readableMap2.d("height"), callback, callback2);
            if (readableMap.a("displaySize")) {
                ReadableMap g2 = readableMap.g("displaySize");
                cropTask.a((int) g2.d("width"), (int) g2.d("height"));
            }
            cropTask.executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR, new Void[0]);
        }
    }

    private static class CropTask extends GuardedAsyncTask<Void, Void> {

        /* renamed from: a  reason: collision with root package name */
        final Context f2083a;
        final String b;
        final int c;
        final int d;
        final int e;
        final int f;
        int g;
        int h;
        final Callback i;
        final Callback j;

        private CropTask(ReactContext reactContext, String str, int i2, int i3, int i4, int i5, Callback callback, Callback callback2) {
            super(reactContext);
            this.g = 0;
            this.h = 0;
            if (i2 < 0 || i3 < 0 || i4 <= 0 || i5 <= 0) {
                throw new JSApplicationIllegalArgumentException(String.format("Invalid crop rectangle: [%d, %d, %d, %d]", Integer.valueOf(i2), Integer.valueOf(i3), Integer.valueOf(i4), Integer.valueOf(i5)));
            }
            this.f2083a = reactContext;
            this.b = str;
            this.c = i2;
            this.d = i3;
            this.e = i4;
            this.f = i5;
            this.i = callback;
            this.j = callback2;
        }

        public void a(int i2, int i3) {
            if (i2 <= 0 || i3 <= 0) {
                throw new JSApplicationIllegalArgumentException(String.format("Invalid target size: [%d, %d]", Integer.valueOf(i2), Integer.valueOf(i3)));
            }
            this.g = i2;
            this.h = i3;
        }

        private InputStream a() throws IOException {
            InputStream inputStream;
            if (ImageEditingManager.isLocalUri(this.b)) {
                inputStream = this.f2083a.getContentResolver().openInputStream(Uri.parse(this.b));
            } else {
                inputStream = new URL(this.b).openConnection().getInputStream();
            }
            if (inputStream != null) {
                return inputStream;
            }
            throw new IOException("Cannot open bitmap: " + this.b);
        }

        /* access modifiers changed from: protected */
        /* renamed from: a */
        public void b(Void... voidArr) {
            Bitmap bitmap;
            try {
                BitmapFactory.Options options = new BitmapFactory.Options();
                if (this.g > 0 && this.h > 0) {
                    bitmap = a(this.g, this.h, options);
                } else {
                    bitmap = a(options);
                }
                String str = options.outMimeType;
                if (str == null || str.isEmpty()) {
                    throw new IOException("Could not determine MIME type");
                }
                File createTempFile = ImageEditingManager.createTempFile(this.f2083a, str);
                ImageEditingManager.writeCompressedBitmapToFile(bitmap, str, createTempFile);
                if (str.equals("image/jpeg")) {
                    ImageEditingManager.copyExif(this.f2083a, Uri.parse(this.b), createTempFile);
                }
                this.i.a(Uri.fromFile(createTempFile).toString());
            } catch (Exception e2) {
                this.j.a(e2.getMessage());
            }
        }

        private Bitmap a(BitmapFactory.Options options) throws IOException {
            InputStream a2 = a();
            BitmapRegionDecoder newInstance = BitmapRegionDecoder.newInstance(a2, false);
            try {
                return newInstance.decodeRegion(new Rect(this.c, this.d, this.c + this.e, this.d + this.f), options);
            } finally {
                if (a2 != null) {
                    a2.close();
                }
                newInstance.recycle();
            }
        }

        private Bitmap a(int i2, int i3, BitmapFactory.Options options) throws IOException {
            float f2;
            float f3;
            float f4;
            float f5;
            float f6;
            Assertions.b(options);
            BitmapFactory.Options options2 = new BitmapFactory.Options();
            options2.inJustDecodeBounds = true;
            InputStream a2 = a();
            try {
                BitmapFactory.decodeStream(a2, null, options2);
                if (a2 != null) {
                    a2.close();
                }
                float f7 = (float) i2;
                float f8 = (float) i3;
                float f9 = f7 / f8;
                if (((float) this.e) / ((float) this.f) > f9) {
                    f6 = ((float) this.f) * f9;
                    f5 = (float) this.f;
                    f3 = ((float) this.c) + ((((float) this.e) - f6) / 2.0f);
                    f2 = (float) this.d;
                    f4 = f8 / ((float) this.f);
                } else {
                    f6 = (float) this.e;
                    float f10 = ((float) this.e) / f9;
                    f3 = (float) this.c;
                    f2 = ((float) this.d) + ((((float) this.f) - f10) / 2.0f);
                    f4 = f7 / ((float) this.e);
                    f5 = f10;
                }
                options.inSampleSize = ImageEditingManager.getDecodeSampleSize(this.e, this.f, i2, i3);
                options2.inJustDecodeBounds = false;
                a2 = a();
                try {
                    Bitmap decodeStream = BitmapFactory.decodeStream(a2, null, options);
                    if (decodeStream != null) {
                        float f11 = f4 * ((float) options.inSampleSize);
                        Matrix matrix = new Matrix();
                        matrix.setScale(f11, f11);
                        return Bitmap.createBitmap(decodeStream, (int) Math.floor((double) (f3 / ((float) options.inSampleSize))), (int) Math.floor((double) (f2 / ((float) options.inSampleSize))), (int) Math.floor((double) (f6 / ((float) options.inSampleSize))), (int) Math.floor((double) (f5 / ((float) options.inSampleSize))), matrix, true);
                    }
                    throw new IOException("Cannot decode bitmap: " + this.b);
                } finally {
                }
            } finally {
                if (a2 != null) {
                    a2.close();
                }
            }
        }
    }

    /* access modifiers changed from: private */
    public static void copyExif(Context context, Uri uri, File file) throws IOException {
        File fileFromUri = getFileFromUri(context, uri);
        if (fileFromUri == null) {
            FLog.c("ReactNative", "Couldn't get real path for uri: " + uri);
            return;
        }
        ExifInterface exifInterface = new ExifInterface(fileFromUri.getAbsolutePath());
        ExifInterface exifInterface2 = new ExifInterface(file.getAbsolutePath());
        String[] strArr = EXIF_ATTRIBUTES;
        for (String str : strArr) {
            String attribute = exifInterface.getAttribute(str);
            if (attribute != null) {
                exifInterface2.setAttribute(str, attribute);
            }
        }
        exifInterface2.saveAttributes();
    }

    @Nullable
    private static File getFileFromUri(Context context, Uri uri) {
        Cursor query;
        if (uri.getScheme().equals("file")) {
            return new File(uri.getPath());
        }
        if (!uri.getScheme().equals("content") || (query = context.getContentResolver().query(uri, new String[]{"_data"}, null, null, null)) == null) {
            return null;
        }
        try {
            if (query.moveToFirst()) {
                String string = query.getString(0);
                if (!TextUtils.isEmpty(string)) {
                    return new File(string);
                }
            }
            query.close();
            return null;
        } finally {
            query.close();
        }
    }

    /* access modifiers changed from: private */
    public static boolean isLocalUri(String str) {
        for (String str2 : LOCAL_URI_PREFIXES) {
            if (str.startsWith(str2)) {
                return true;
            }
        }
        return false;
    }

    private static String getFileExtensionForType(@Nullable String str) {
        if ("image/png".equals(str)) {
            return ".png";
        }
        return "image/webp".equals(str) ? ".webp" : ".jpg";
    }

    private static Bitmap.CompressFormat getCompressFormatForType(String str) {
        if ("image/png".equals(str)) {
            return Bitmap.CompressFormat.PNG;
        }
        if ("image/webp".equals(str)) {
            return Bitmap.CompressFormat.WEBP;
        }
        return Bitmap.CompressFormat.JPEG;
    }

    /* access modifiers changed from: private */
    public static void writeCompressedBitmapToFile(Bitmap bitmap, String str, File file) throws IOException {
        FileOutputStream fileOutputStream = new FileOutputStream(file);
        try {
            bitmap.compress(getCompressFormatForType(str), 90, fileOutputStream);
        } finally {
            fileOutputStream.close();
        }
    }

    /* access modifiers changed from: private */
    public static File createTempFile(Context context, @Nullable String str) throws IOException {
        File externalCacheDir = context.getExternalCacheDir();
        File cacheDir = context.getCacheDir();
        if (externalCacheDir == null && cacheDir == null) {
            throw new IOException("No cache directory available");
        }
        if (externalCacheDir == null || (cacheDir != null && externalCacheDir.getFreeSpace() <= cacheDir.getFreeSpace())) {
            externalCacheDir = cacheDir;
        }
        return File.createTempFile(TEMP_FILE_PREFIX, getFileExtensionForType(str), externalCacheDir);
    }

    /* access modifiers changed from: private */
    public static int getDecodeSampleSize(int i, int i2, int i3, int i4) {
        int i5 = 1;
        if (i2 > i3 || i > i4) {
            int i6 = i2 / 2;
            int i7 = i / 2;
            while (i7 / i5 >= i3 && i6 / i5 >= i4) {
                i5 *= 2;
            }
        }
        return i5;
    }
}
