package com.facebook.react.modules.location;

import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import com.facebook.common.logging.FLog;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.common.SystemClock;
import com.facebook.react.module.annotations.ReactModule;
import com.facebook.react.modules.core.DeviceEventManagerModule;
import javax.annotation.Nullable;

@ReactModule
public class LocationModule extends ReactContextBaseJavaModule {
    private static final float RCT_DEFAULT_LOCATION_ACCURACY = 100.0f;
    private final LocationListener mLocationListener = new LocationListener() {
        /* class com.facebook.react.modules.location.LocationModule.AnonymousClass1 */

        public void onProviderDisabled(String str) {
        }

        public void onProviderEnabled(String str) {
        }

        public void onLocationChanged(Location location) {
            ((DeviceEventManagerModule.RCTDeviceEventEmitter) LocationModule.this.getReactApplicationContext().a(DeviceEventManagerModule.RCTDeviceEventEmitter.class)).emit("geolocationDidChange", LocationModule.locationToMap(location));
        }

        public void onStatusChanged(String str, int i, Bundle bundle) {
            if (i == 0) {
                LocationModule locationModule = LocationModule.this;
                int i2 = PositionError.b;
                locationModule.emitError(i2, "Provider " + str + " is out of service.");
            } else if (i == 1) {
                LocationModule locationModule2 = LocationModule.this;
                int i3 = PositionError.c;
                locationModule2.emitError(i3, "Provider " + str + " is temporarily unavailable.");
            }
        }
    };
    @Nullable
    private String mWatchedProvider;

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return "LocationObserver";
    }

    public LocationModule(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
    }

    private static class LocationOptions {

        /* renamed from: a  reason: collision with root package name */
        private final long f2118a;
        private final double b;
        private final boolean c;
        private final float d;

        private LocationOptions(long j, double d2, boolean z, float f) {
            this.f2118a = j;
            this.b = d2;
            this.c = z;
            this.d = f;
        }

        /* access modifiers changed from: private */
        public static LocationOptions b(ReadableMap readableMap) {
            return new LocationOptions(readableMap.a("timeout") ? (long) readableMap.d("timeout") : Long.MAX_VALUE, readableMap.a("maximumAge") ? readableMap.d("maximumAge") : Double.POSITIVE_INFINITY, readableMap.a("enableHighAccuracy") && readableMap.c("enableHighAccuracy"), readableMap.a("distanceFilter") ? (float) readableMap.d("distanceFilter") : LocationModule.RCT_DEFAULT_LOCATION_ACCURACY);
        }
    }

    @ReactMethod
    public void getCurrentPosition(ReadableMap readableMap, Callback callback, Callback callback2) {
        LocationOptions b = LocationOptions.b(readableMap);
        try {
            LocationManager locationManager = (LocationManager) getReactApplicationContext().getSystemService("location");
            String validProvider = getValidProvider(locationManager, b.c);
            if (validProvider == null) {
                callback2.a(PositionError.a(PositionError.b, "No location provider available."));
                return;
            }
            Location lastKnownLocation = locationManager.getLastKnownLocation(validProvider);
            if (lastKnownLocation == null || ((double) (SystemClock.a() - lastKnownLocation.getTime())) >= b.b) {
                new SingleUpdateRequest(locationManager, validProvider, b.f2118a, callback, callback2).a(lastKnownLocation);
                return;
            }
            callback.a(locationToMap(lastKnownLocation));
        } catch (SecurityException e) {
            throwLocationPermissionMissing(e);
        }
    }

    @ReactMethod
    public void startObserving(ReadableMap readableMap) {
        if (!"gps".equals(this.mWatchedProvider)) {
            LocationOptions b = LocationOptions.b(readableMap);
            try {
                LocationManager locationManager = (LocationManager) getReactApplicationContext().getSystemService("location");
                String validProvider = getValidProvider(locationManager, b.c);
                if (validProvider == null) {
                    emitError(PositionError.b, "No location provider available.");
                    return;
                }
                if (!validProvider.equals(this.mWatchedProvider)) {
                    locationManager.removeUpdates(this.mLocationListener);
                    locationManager.requestLocationUpdates(validProvider, 1000, b.d, this.mLocationListener);
                }
                this.mWatchedProvider = validProvider;
            } catch (SecurityException e) {
                throwLocationPermissionMissing(e);
            }
        }
    }

    @ReactMethod
    public void stopObserving() {
        ((LocationManager) getReactApplicationContext().getSystemService("location")).removeUpdates(this.mLocationListener);
        this.mWatchedProvider = null;
    }

    @Nullable
    private static String getValidProvider(LocationManager locationManager, boolean z) {
        String str = z ? "gps" : "network";
        if (!locationManager.isProviderEnabled(str)) {
            str = str.equals("gps") ? "network" : "gps";
            if (!locationManager.isProviderEnabled(str)) {
                return null;
            }
        }
        return str;
    }

    /* access modifiers changed from: private */
    public static WritableMap locationToMap(Location location) {
        WritableMap b = Arguments.b();
        WritableMap b2 = Arguments.b();
        b2.putDouble("latitude", location.getLatitude());
        b2.putDouble("longitude", location.getLongitude());
        b2.putDouble("altitude", location.getAltitude());
        b2.putDouble("accuracy", (double) location.getAccuracy());
        b2.putDouble("heading", (double) location.getBearing());
        b2.putDouble("speed", (double) location.getSpeed());
        b.a("coords", b2);
        b.putDouble("timestamp", (double) location.getTime());
        if (Build.VERSION.SDK_INT >= 18) {
            b.putBoolean("mocked", location.isFromMockProvider());
        }
        return b;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void emitError(int i, String str) {
        ((DeviceEventManagerModule.RCTDeviceEventEmitter) getReactApplicationContext().a(DeviceEventManagerModule.RCTDeviceEventEmitter.class)).emit("geolocationError", PositionError.a(i, str));
    }

    private static void throwLocationPermissionMissing(SecurityException securityException) {
        throw new SecurityException("Looks like the app doesn't have the permission to access location.\nAdd the following line to your app's AndroidManifest.xml:\n<uses-permission android:name=\"android.permission.ACCESS_FINE_LOCATION\" />", securityException);
    }

    private static class SingleUpdateRequest {

        /* renamed from: a  reason: collision with root package name */
        private final Callback f2119a;
        private final Callback b;
        private final LocationManager c;
        private final String d;
        private final long e;
        private Location f;
        private final Handler g;
        private final Runnable h;
        private final LocationListener i;
        private boolean j;

        private SingleUpdateRequest(LocationManager locationManager, String str, long j2, Callback callback, Callback callback2) {
            this.g = new Handler();
            this.h = new Runnable() {
                /* class com.facebook.react.modules.location.LocationModule.SingleUpdateRequest.AnonymousClass1 */

                public void run() {
                    synchronized (SingleUpdateRequest.this) {
                        if (!SingleUpdateRequest.this.j) {
                            SingleUpdateRequest.this.b.a(PositionError.a(PositionError.c, "Location request timed out"));
                            SingleUpdateRequest.this.c.removeUpdates(SingleUpdateRequest.this.i);
                            FLog.b("ReactNative", "LocationModule: Location request timed out");
                            SingleUpdateRequest.this.j = true;
                        }
                    }
                }
            };
            this.i = new LocationListener() {
                /* class com.facebook.react.modules.location.LocationModule.SingleUpdateRequest.AnonymousClass2 */

                public void onProviderDisabled(String str) {
                }

                public void onProviderEnabled(String str) {
                }

                public void onStatusChanged(String str, int i, Bundle bundle) {
                }

                public void onLocationChanged(Location location) {
                    synchronized (SingleUpdateRequest.this) {
                        if (!SingleUpdateRequest.this.j && SingleUpdateRequest.this.a((SingleUpdateRequest) location, SingleUpdateRequest.this.f)) {
                            SingleUpdateRequest.this.f2119a.a(LocationModule.locationToMap(location));
                            SingleUpdateRequest.this.g.removeCallbacks(SingleUpdateRequest.this.h);
                            SingleUpdateRequest.this.j = true;
                            SingleUpdateRequest.this.c.removeUpdates(SingleUpdateRequest.this.i);
                        }
                        SingleUpdateRequest.this.f = location;
                    }
                }
            };
            this.c = locationManager;
            this.d = str;
            this.e = j2;
            this.f2119a = callback;
            this.b = callback2;
        }

        public void a(Location location) {
            this.f = location;
            this.c.requestLocationUpdates(this.d, 100, 1.0f, this.i);
            this.g.postDelayed(this.h, this.e);
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private boolean a(Location location, Location location2) {
            if (location2 == null) {
                return true;
            }
            long time = location.getTime() - location2.getTime();
            boolean z = time > 120000;
            boolean z2 = time < -120000;
            boolean z3 = time > 0;
            if (z) {
                return true;
            }
            if (z2) {
                return false;
            }
            int accuracy = (int) (location.getAccuracy() - location2.getAccuracy());
            boolean z4 = accuracy > 0;
            boolean z5 = accuracy < 0;
            boolean z6 = accuracy > 200;
            boolean a2 = a(location.getProvider(), location2.getProvider());
            if (z5) {
                return true;
            }
            if (z3 && !z4) {
                return true;
            }
            if (!z3 || z6 || !a2) {
                return false;
            }
            return true;
        }

        private boolean a(String str, String str2) {
            if (str == null) {
                return str2 == null;
            }
            return str.equals(str2);
        }
    }
}
