package com.facebook.react.modules.network;

import android.annotation.TargetApi;
import android.content.Context;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.text.TextUtils;
import android.webkit.CookieManager;
import android.webkit.CookieSyncManager;
import android.webkit.ValueCallback;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.GuardedAsyncTask;
import com.facebook.react.bridge.GuardedResultAsyncTask;
import com.facebook.react.bridge.ReactContext;
import java.io.IOException;
import java.net.CookieHandler;
import java.net.URI;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import javax.annotation.Nullable;

public class ForwardingCookieHandler extends CookieHandler {

    /* renamed from: a  reason: collision with root package name */
    private static final boolean f2125a = (Build.VERSION.SDK_INT < 21);
    private final CookieSaver b = new CookieSaver();
    private final ReactContext c;
    @Nullable
    private CookieManager d;

    public ForwardingCookieHandler(ReactContext reactContext) {
        this.c = reactContext;
    }

    @Override // java.net.CookieHandler
    public Map<String, List<String>> get(URI uri, Map<String, List<String>> map) throws IOException {
        String cookie = c().getCookie(uri.toString());
        if (TextUtils.isEmpty(cookie)) {
            return Collections.emptyMap();
        }
        return Collections.singletonMap("Cookie", Collections.singletonList(cookie));
    }

    @Override // java.net.CookieHandler
    public void put(URI uri, Map<String, List<String>> map) throws IOException {
        String uri2 = uri.toString();
        for (Map.Entry<String, List<String>> entry : map.entrySet()) {
            String key = entry.getKey();
            if (key != null && a(key)) {
                a(uri2, entry.getValue());
            }
        }
    }

    public void a(final Callback callback) {
        if (f2125a) {
            new GuardedResultAsyncTask<Boolean>(this.c) {
                /* class com.facebook.react.modules.network.ForwardingCookieHandler.AnonymousClass1 */

                /* access modifiers changed from: protected */
                /* renamed from: b */
                public Boolean a() {
                    ForwardingCookieHandler.this.c().removeAllCookie();
                    ForwardingCookieHandler.this.b.a();
                    return true;
                }

                /* access modifiers changed from: protected */
                public void a(Boolean bool) {
                    callback.a(bool);
                }
            }.execute(new Void[0]);
        } else {
            b(callback);
        }
    }

    private void b(final Callback callback) {
        c().removeAllCookies(new ValueCallback<Boolean>() {
            /* class com.facebook.react.modules.network.ForwardingCookieHandler.AnonymousClass2 */

            /* renamed from: a */
            public void onReceiveValue(Boolean bool) {
                ForwardingCookieHandler.this.b.a();
                callback.a(bool);
            }
        });
    }

    public void a() {
        if (f2125a) {
            c().removeExpiredCookie();
            this.b.b();
        }
    }

    private void a(final String str, final List<String> list) {
        if (f2125a) {
            a(new Runnable() {
                /* class com.facebook.react.modules.network.ForwardingCookieHandler.AnonymousClass3 */

                public void run() {
                    for (String str : list) {
                        ForwardingCookieHandler.this.c().setCookie(str, str);
                    }
                    ForwardingCookieHandler.this.b.a();
                }
            });
            return;
        }
        for (String str2 : list) {
            a(str, str2);
        }
        this.b.a();
    }

    @TargetApi(21)
    private void a(String str, String str2) {
        c().setCookie(str, str2, null);
    }

    private static boolean a(String str) {
        return str.equalsIgnoreCase("Set-cookie") || str.equalsIgnoreCase("Set-cookie2");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void a(final Runnable runnable) {
        new GuardedAsyncTask<Void, Void>(this.c) {
            /* class com.facebook.react.modules.network.ForwardingCookieHandler.AnonymousClass4 */

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public void b(Void... voidArr) {
                runnable.run();
            }
        }.execute(new Void[0]);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private CookieManager c() {
        if (this.d == null) {
            a(this.c);
            this.d = CookieManager.getInstance();
            if (f2125a) {
                this.d.removeExpiredCookie();
            }
        }
        return this.d;
    }

    private static void a(Context context) {
        if (f2125a) {
            CookieSyncManager.createInstance(context).sync();
        }
    }

    /* access modifiers changed from: private */
    public class CookieSaver {
        private final Handler b;

        public CookieSaver() {
            this.b = new Handler(Looper.getMainLooper(), new Handler.Callback(ForwardingCookieHandler.this) {
                /* class com.facebook.react.modules.network.ForwardingCookieHandler.CookieSaver.AnonymousClass1 */

                public boolean handleMessage(Message message) {
                    if (message.what != 1) {
                        return false;
                    }
                    CookieSaver.this.b();
                    return true;
                }
            });
        }

        public void a() {
            if (ForwardingCookieHandler.f2125a) {
                this.b.sendEmptyMessageDelayed(1, 30000);
            }
        }

        public void b() {
            this.b.removeMessages(1);
            ForwardingCookieHandler.this.a((ForwardingCookieHandler) new Runnable() {
                /* class com.facebook.react.modules.network.ForwardingCookieHandler.CookieSaver.AnonymousClass2 */

                public void run() {
                    if (ForwardingCookieHandler.f2125a) {
                        CookieSyncManager.getInstance().sync();
                    } else {
                        CookieSaver.this.c();
                    }
                }
            });
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        @TargetApi(21)
        private void c() {
            ForwardingCookieHandler.this.c().flush();
        }
    }
}
