package com.facebook.react.modules.storage;

import android.database.Cursor;
import android.database.sqlite.SQLiteStatement;
import com.facebook.common.logging.FLog;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.GuardedAsyncTask;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.module.annotations.ReactModule;
import com.facebook.react.modules.common.ModuleDataCleaner;
import java.util.HashSet;
import java.util.Iterator;

@ReactModule
public final class AsyncStorageModule extends ReactContextBaseJavaModule implements ModuleDataCleaner.Cleanable {
    private static final int MAX_SQL_KEYS = 999;
    protected static final String NAME = "AsyncSQLiteDBStorage";
    private ReactDatabaseSupplier mReactDatabaseSupplier;
    private boolean mShuttingDown = false;

    @Override // com.facebook.react.bridge.NativeModule
    public String getName() {
        return NAME;
    }

    public AsyncStorageModule(ReactApplicationContext reactApplicationContext) {
        super(reactApplicationContext);
        this.mReactDatabaseSupplier = ReactDatabaseSupplier.a(reactApplicationContext);
    }

    @Override // com.facebook.react.bridge.BaseJavaModule, com.facebook.react.bridge.NativeModule
    public void initialize() {
        super.initialize();
        this.mShuttingDown = false;
    }

    @Override // com.facebook.react.bridge.BaseJavaModule, com.facebook.react.bridge.NativeModule
    public void onCatalystInstanceDestroy() {
        this.mShuttingDown = true;
    }

    public void clearSensitiveData() {
        this.mReactDatabaseSupplier.c();
    }

    @ReactMethod
    public void multiGet(final ReadableArray readableArray, final Callback callback) {
        if (readableArray == null) {
            callback.a(AsyncStorageErrorUtil.a(null), null);
            return;
        }
        new GuardedAsyncTask<Void, Void>(getReactApplicationContext()) {
            /* class com.facebook.react.modules.storage.AsyncStorageModule.AnonymousClass1 */

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public void b(Void... voidArr) {
                if (!AsyncStorageModule.this.ensureDatabase()) {
                    callback.a(AsyncStorageErrorUtil.c(null), null);
                    return;
                }
                String[] strArr = {"key", "value"};
                HashSet hashSet = new HashSet();
                WritableArray a2 = Arguments.a();
                for (int i = 0; i < readableArray.a(); i += 999) {
                    int min = Math.min(readableArray.a() - i, 999);
                    Cursor query = AsyncStorageModule.this.mReactDatabaseSupplier.b().query("catalystLocalStorage", strArr, AsyncLocalStorageUtil.a(min), AsyncLocalStorageUtil.a(readableArray, i, min), null, null, null);
                    hashSet.clear();
                    try {
                        if (query.getCount() != readableArray.a()) {
                            for (int i2 = i; i2 < i + min; i2++) {
                                hashSet.add(readableArray.d(i2));
                            }
                        }
                        if (query.moveToFirst()) {
                            do {
                                WritableArray a3 = Arguments.a();
                                a3.pushString(query.getString(0));
                                a3.pushString(query.getString(1));
                                a2.a(a3);
                                hashSet.remove(query.getString(0));
                            } while (query.moveToNext());
                        }
                        query.close();
                        Iterator it = hashSet.iterator();
                        while (it.hasNext()) {
                            WritableArray a4 = Arguments.a();
                            a4.pushString((String) it.next());
                            a4.pushNull();
                            a2.a(a4);
                        }
                        hashSet.clear();
                    } catch (Exception e) {
                        FLog.b("ReactNative", e.getMessage(), e);
                        callback.a(AsyncStorageErrorUtil.a(null, e.getMessage()), null);
                        query.close();
                        return;
                    } catch (Throwable th) {
                        query.close();
                        throw th;
                    }
                }
                callback.a(null, a2);
            }
        }.execute(new Void[0]);
    }

    @ReactMethod
    public void multiSet(final ReadableArray readableArray, final Callback callback) {
        if (readableArray.a() == 0) {
            callback.a(AsyncStorageErrorUtil.a(null));
            return;
        }
        new GuardedAsyncTask<Void, Void>(getReactApplicationContext()) {
            /* class com.facebook.react.modules.storage.AsyncStorageModule.AnonymousClass2 */

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public void b(Void... voidArr) {
                WritableMap writableMap = null;
                if (!AsyncStorageModule.this.ensureDatabase()) {
                    callback.a(AsyncStorageErrorUtil.c(null));
                    return;
                }
                SQLiteStatement compileStatement = AsyncStorageModule.this.mReactDatabaseSupplier.b().compileStatement("INSERT OR REPLACE INTO catalystLocalStorage VALUES (?, ?);");
                try {
                    AsyncStorageModule.this.mReactDatabaseSupplier.b().beginTransaction();
                    for (int i = 0; i < readableArray.a(); i++) {
                        if (readableArray.j(i).a() != 2) {
                            WritableMap b2 = AsyncStorageErrorUtil.b(null);
                            try {
                                AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                                return;
                            } catch (Exception e) {
                                FLog.b("ReactNative", e.getMessage(), e);
                                if (b2 == null) {
                                    AsyncStorageErrorUtil.a(null, e.getMessage());
                                    return;
                                }
                                return;
                            }
                        } else if (readableArray.j(i).d(0) == null) {
                            WritableMap a2 = AsyncStorageErrorUtil.a(null);
                            try {
                                AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                                return;
                            } catch (Exception e2) {
                                FLog.b("ReactNative", e2.getMessage(), e2);
                                if (a2 == null) {
                                    AsyncStorageErrorUtil.a(null, e2.getMessage());
                                    return;
                                }
                                return;
                            }
                        } else if (readableArray.j(i).d(1) == null) {
                            WritableMap b3 = AsyncStorageErrorUtil.b(null);
                            try {
                                AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                                return;
                            } catch (Exception e3) {
                                FLog.b("ReactNative", e3.getMessage(), e3);
                                if (b3 == null) {
                                    AsyncStorageErrorUtil.a(null, e3.getMessage());
                                    return;
                                }
                                return;
                            }
                        } else {
                            compileStatement.clearBindings();
                            compileStatement.bindString(1, readableArray.j(i).d(0));
                            compileStatement.bindString(2, readableArray.j(i).d(1));
                            compileStatement.execute();
                        }
                    }
                    AsyncStorageModule.this.mReactDatabaseSupplier.b().setTransactionSuccessful();
                    try {
                        AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                    } catch (Exception e4) {
                        FLog.b("ReactNative", e4.getMessage(), e4);
                        writableMap = AsyncStorageErrorUtil.a(null, e4.getMessage());
                    }
                } catch (Exception e5) {
                    FLog.b("ReactNative", e5.getMessage(), e5);
                    WritableMap a3 = AsyncStorageErrorUtil.a(null, e5.getMessage());
                    try {
                        AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                    } catch (Exception e6) {
                        FLog.b("ReactNative", e6.getMessage(), e6);
                        if (a3 == null) {
                            a3 = AsyncStorageErrorUtil.a(null, e6.getMessage());
                        }
                    }
                    writableMap = a3;
                } catch (Throwable th) {
                    try {
                        AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                    } catch (Exception e7) {
                        FLog.b("ReactNative", e7.getMessage(), e7);
                        AsyncStorageErrorUtil.a(null, e7.getMessage());
                    }
                    throw th;
                }
                if (writableMap != null) {
                    callback.a(writableMap);
                    return;
                }
                callback.a(new Object[0]);
            }
        }.execute(new Void[0]);
    }

    @ReactMethod
    public void multiRemove(final ReadableArray readableArray, final Callback callback) {
        if (readableArray.a() == 0) {
            callback.a(AsyncStorageErrorUtil.a(null));
            return;
        }
        new GuardedAsyncTask<Void, Void>(getReactApplicationContext()) {
            /* class com.facebook.react.modules.storage.AsyncStorageModule.AnonymousClass3 */

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public void b(Void... voidArr) {
                WritableMap writableMap = null;
                if (!AsyncStorageModule.this.ensureDatabase()) {
                    callback.a(AsyncStorageErrorUtil.c(null));
                    return;
                }
                try {
                    AsyncStorageModule.this.mReactDatabaseSupplier.b().beginTransaction();
                    for (int i = 0; i < readableArray.a(); i += 999) {
                        int min = Math.min(readableArray.a() - i, 999);
                        AsyncStorageModule.this.mReactDatabaseSupplier.b().delete("catalystLocalStorage", AsyncLocalStorageUtil.a(min), AsyncLocalStorageUtil.a(readableArray, i, min));
                    }
                    AsyncStorageModule.this.mReactDatabaseSupplier.b().setTransactionSuccessful();
                    try {
                        AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                    } catch (Exception e) {
                        FLog.b("ReactNative", e.getMessage(), e);
                        writableMap = AsyncStorageErrorUtil.a(null, e.getMessage());
                    }
                } catch (Exception e2) {
                    FLog.b("ReactNative", e2.getMessage(), e2);
                    WritableMap a2 = AsyncStorageErrorUtil.a(null, e2.getMessage());
                    try {
                        AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                    } catch (Exception e3) {
                        FLog.b("ReactNative", e3.getMessage(), e3);
                        if (a2 == null) {
                            a2 = AsyncStorageErrorUtil.a(null, e3.getMessage());
                        }
                    }
                    writableMap = a2;
                } catch (Throwable th) {
                    try {
                        AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                    } catch (Exception e4) {
                        FLog.b("ReactNative", e4.getMessage(), e4);
                        AsyncStorageErrorUtil.a(null, e4.getMessage());
                    }
                    throw th;
                }
                if (writableMap != null) {
                    callback.a(writableMap);
                    return;
                }
                callback.a(new Object[0]);
            }
        }.execute(new Void[0]);
    }

    @ReactMethod
    public void multiMerge(final ReadableArray readableArray, final Callback callback) {
        new GuardedAsyncTask<Void, Void>(getReactApplicationContext()) {
            /* class com.facebook.react.modules.storage.AsyncStorageModule.AnonymousClass4 */

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public void b(Void... voidArr) {
                WritableMap writableMap = null;
                if (!AsyncStorageModule.this.ensureDatabase()) {
                    callback.a(AsyncStorageErrorUtil.c(null));
                    return;
                }
                try {
                    AsyncStorageModule.this.mReactDatabaseSupplier.b().beginTransaction();
                    for (int i = 0; i < readableArray.a(); i++) {
                        if (readableArray.j(i).a() != 2) {
                            WritableMap b2 = AsyncStorageErrorUtil.b(null);
                            try {
                                AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                                return;
                            } catch (Exception e) {
                                FLog.b("ReactNative", e.getMessage(), e);
                                if (b2 == null) {
                                    AsyncStorageErrorUtil.a(null, e.getMessage());
                                    return;
                                }
                                return;
                            }
                        } else if (readableArray.j(i).d(0) == null) {
                            WritableMap a2 = AsyncStorageErrorUtil.a(null);
                            try {
                                AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                                return;
                            } catch (Exception e2) {
                                FLog.b("ReactNative", e2.getMessage(), e2);
                                if (a2 == null) {
                                    AsyncStorageErrorUtil.a(null, e2.getMessage());
                                    return;
                                }
                                return;
                            }
                        } else if (readableArray.j(i).d(1) == null) {
                            WritableMap b3 = AsyncStorageErrorUtil.b(null);
                            try {
                                AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                                return;
                            } catch (Exception e3) {
                                FLog.b("ReactNative", e3.getMessage(), e3);
                                if (b3 == null) {
                                    AsyncStorageErrorUtil.a(null, e3.getMessage());
                                    return;
                                }
                                return;
                            }
                        } else if (!AsyncLocalStorageUtil.b(AsyncStorageModule.this.mReactDatabaseSupplier.b(), readableArray.j(i).d(0), readableArray.j(i).d(1))) {
                            WritableMap c2 = AsyncStorageErrorUtil.c(null);
                            try {
                                AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                                return;
                            } catch (Exception e4) {
                                FLog.b("ReactNative", e4.getMessage(), e4);
                                if (c2 == null) {
                                    AsyncStorageErrorUtil.a(null, e4.getMessage());
                                    return;
                                }
                                return;
                            }
                        }
                    }
                    AsyncStorageModule.this.mReactDatabaseSupplier.b().setTransactionSuccessful();
                    try {
                        AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                    } catch (Exception e5) {
                        FLog.b("ReactNative", e5.getMessage(), e5);
                        writableMap = AsyncStorageErrorUtil.a(null, e5.getMessage());
                    }
                } catch (Exception e6) {
                    FLog.b("ReactNative", e6.getMessage(), e6);
                    WritableMap a3 = AsyncStorageErrorUtil.a(null, e6.getMessage());
                    try {
                        AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                    } catch (Exception e7) {
                        FLog.b("ReactNative", e7.getMessage(), e7);
                        if (a3 == null) {
                            a3 = AsyncStorageErrorUtil.a(null, e7.getMessage());
                        }
                    }
                    writableMap = a3;
                } catch (Throwable th) {
                    try {
                        AsyncStorageModule.this.mReactDatabaseSupplier.b().endTransaction();
                    } catch (Exception e8) {
                        FLog.b("ReactNative", e8.getMessage(), e8);
                        AsyncStorageErrorUtil.a(null, e8.getMessage());
                    }
                    throw th;
                }
                if (writableMap != null) {
                    callback.a(writableMap);
                    return;
                }
                callback.a(new Object[0]);
            }
        }.execute(new Void[0]);
    }

    @ReactMethod
    public void clear(final Callback callback) {
        new GuardedAsyncTask<Void, Void>(getReactApplicationContext()) {
            /* class com.facebook.react.modules.storage.AsyncStorageModule.AnonymousClass5 */

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public void b(Void... voidArr) {
                if (!AsyncStorageModule.this.mReactDatabaseSupplier.a()) {
                    callback.a(AsyncStorageErrorUtil.c(null));
                    return;
                }
                try {
                    AsyncStorageModule.this.mReactDatabaseSupplier.d();
                    callback.a(new Object[0]);
                } catch (Exception e) {
                    FLog.b("ReactNative", e.getMessage(), e);
                    callback.a(AsyncStorageErrorUtil.a(null, e.getMessage()));
                }
            }
        }.execute(new Void[0]);
    }

    @ReactMethod
    public void getAllKeys(final Callback callback) {
        new GuardedAsyncTask<Void, Void>(getReactApplicationContext()) {
            /* class com.facebook.react.modules.storage.AsyncStorageModule.AnonymousClass6 */

            /* access modifiers changed from: protected */
            /* renamed from: a */
            public void b(Void... voidArr) {
                if (!AsyncStorageModule.this.ensureDatabase()) {
                    callback.a(AsyncStorageErrorUtil.c(null), null);
                    return;
                }
                WritableArray a2 = Arguments.a();
                Cursor query = AsyncStorageModule.this.mReactDatabaseSupplier.b().query("catalystLocalStorage", new String[]{"key"}, null, null, null, null, null);
                try {
                    if (query.moveToFirst()) {
                        do {
                            a2.pushString(query.getString(0));
                        } while (query.moveToNext());
                    }
                    query.close();
                    callback.a(null, a2);
                } catch (Exception e) {
                    FLog.b("ReactNative", e.getMessage(), e);
                    callback.a(AsyncStorageErrorUtil.a(null, e.getMessage()), null);
                    query.close();
                } catch (Throwable th) {
                    query.close();
                    throw th;
                }
            }
        }.execute(new Void[0]);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean ensureDatabase() {
        return !this.mShuttingDown && this.mReactDatabaseSupplier.a();
    }
}
