package com.facebook.react.uimanager;

import android.content.res.Resources;
import android.util.Log;
import android.util.SparseArray;
import android.util.SparseBooleanArray;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.widget.PopupMenu;
import com.facebook.infer.annotation.Assertions;
import com.facebook.react.animation.Animation;
import com.facebook.react.animation.AnimationListener;
import com.facebook.react.animation.AnimationRegistry;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.JSApplicationIllegalArgumentException;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.SoftAssertions;
import com.facebook.react.bridge.UiThreadUtil;
import com.facebook.react.touch.JSResponderHandler;
import com.facebook.react.uimanager.common.SizeMonitoringFrameLayout;
import com.facebook.react.uimanager.layoutanimation.LayoutAnimationController;
import com.facebook.react.uimanager.layoutanimation.LayoutAnimationListener;
import com.facebook.systrace.Systrace;
import com.facebook.systrace.SystraceMessage;
import javax.annotation.Nullable;
import javax.annotation.concurrent.NotThreadSafe;

@NotThreadSafe
public class NativeViewHierarchyManager {

    /* renamed from: a  reason: collision with root package name */
    private static final String f2221a = "NativeViewHierarchyManager";
    private final AnimationRegistry b;
    private final SparseArray<View> c;
    private final SparseArray<ViewManager> d;
    private final SparseBooleanArray e;
    private final ViewManagerRegistry f;
    private final JSResponderHandler g;
    private final RootViewManager h;
    private final LayoutAnimationController i;
    private boolean j;

    public NativeViewHierarchyManager(ViewManagerRegistry viewManagerRegistry) {
        this(viewManagerRegistry, new RootViewManager());
    }

    public NativeViewHierarchyManager(ViewManagerRegistry viewManagerRegistry, RootViewManager rootViewManager) {
        this.g = new JSResponderHandler();
        this.i = new LayoutAnimationController();
        this.b = new AnimationRegistry();
        this.f = viewManagerRegistry;
        this.c = new SparseArray<>();
        this.d = new SparseArray<>();
        this.e = new SparseBooleanArray();
        this.h = rootViewManager;
    }

    public final synchronized View b(int i2) {
        View view;
        view = this.c.get(i2);
        if (view == null) {
            throw new IllegalViewOperationException("Trying to resolve view with tag " + i2 + " which doesn't exist");
        }
        return view;
    }

    public final synchronized ViewManager c(int i2) {
        ViewManager viewManager;
        viewManager = this.d.get(i2);
        if (viewManager == null) {
            throw new IllegalViewOperationException("ViewManager for tag " + i2 + " could not be found");
        }
        return viewManager;
    }

    public AnimationRegistry a() {
        return this.b;
    }

    public void a(boolean z) {
        this.j = z;
    }

    public synchronized void a(int i2, ReactStylesDiffMap reactStylesDiffMap) {
        UiThreadUtil.b();
        try {
            c(i2).updateProperties(b(i2), reactStylesDiffMap);
        } catch (IllegalViewOperationException e2) {
            String str = f2221a;
            Log.e(str, "Unable to update properties for view tag " + i2, e2);
        }
    }

    public synchronized void a(int i2, Object obj) {
        UiThreadUtil.b();
        c(i2).updateExtraData(b(i2), obj);
    }

    public synchronized void a(int i2, int i3, int i4, int i5, int i6, int i7) {
        UiThreadUtil.b();
        SystraceMessage.a(0, "NativeViewHierarchyManager_updateLayout").a("parentTag", i2).a("tag", i3).a();
        try {
            View b2 = b(i3);
            b2.measure(View.MeasureSpec.makeMeasureSpec(i6, 1073741824), View.MeasureSpec.makeMeasureSpec(i7, 1073741824));
            ViewParent parent = b2.getParent();
            if (parent instanceof RootView) {
                parent.requestLayout();
            }
            if (!this.e.get(i2)) {
                ViewManager viewManager = this.d.get(i2);
                if (viewManager instanceof ViewGroupManager) {
                    ViewGroupManager viewGroupManager = (ViewGroupManager) viewManager;
                    if (viewGroupManager != null && !viewGroupManager.needsCustomLayoutForChildren()) {
                        a(b2, i4, i5, i6, i7);
                    }
                } else {
                    throw new IllegalViewOperationException("Trying to use view with tag " + i3 + " as a parent, but its Manager doesn't extends ViewGroupManager");
                }
            } else {
                a(b2, i4, i5, i6, i7);
            }
        } finally {
            Systrace.b(0);
        }
    }

    private void a(View view, int i2, int i3, int i4, int i5) {
        if (!this.j || !this.i.a(view)) {
            view.layout(i2, i3, i4 + i2, i5 + i3);
        } else {
            this.i.a(view, i2, i3, i4, i5);
        }
    }

    public synchronized void a(ThemedReactContext themedReactContext, int i2, String str, @Nullable ReactStylesDiffMap reactStylesDiffMap) {
        UiThreadUtil.b();
        SystraceMessage.a(0, "NativeViewHierarchyManager_createView").a("tag", i2).a("className", str).a();
        try {
            ViewManager a2 = this.f.a(str);
            View createView = a2.createView(themedReactContext, this.g);
            this.c.put(i2, createView);
            this.d.put(i2, a2);
            createView.setId(i2);
            if (reactStylesDiffMap != null) {
                a2.updateProperties(createView, reactStylesDiffMap);
            }
        } finally {
            Systrace.b(0);
        }
    }

    private static String a(ViewGroup viewGroup, ViewGroupManager viewGroupManager, @Nullable int[] iArr, @Nullable ViewAtIndex[] viewAtIndexArr, @Nullable int[] iArr2) {
        StringBuilder sb = new StringBuilder();
        if (viewGroup != null) {
            sb.append("View tag:" + viewGroup.getId() + "\n");
            sb.append("  children(" + viewGroupManager.getChildCount(viewGroup) + "): [\n");
            for (int i2 = 0; i2 < viewGroupManager.getChildCount(viewGroup); i2 += 16) {
                int i3 = 0;
                while (true) {
                    int i4 = i2 + i3;
                    if (i4 >= viewGroupManager.getChildCount(viewGroup) || i3 >= 16) {
                        sb.append("\n");
                    } else {
                        sb.append(viewGroupManager.getChildAt(viewGroup, i4).getId() + ",");
                        i3++;
                    }
                }
                sb.append("\n");
            }
            sb.append(" ],\n");
        }
        if (iArr != null) {
            sb.append("  indicesToRemove(" + iArr.length + "): [\n");
            for (int i5 = 0; i5 < iArr.length; i5 += 16) {
                int i6 = 0;
                while (true) {
                    int i7 = i5 + i6;
                    if (i7 >= iArr.length || i6 >= 16) {
                        sb.append("\n");
                    } else {
                        sb.append(iArr[i7] + ",");
                        i6++;
                    }
                }
                sb.append("\n");
            }
            sb.append(" ],\n");
        }
        if (viewAtIndexArr != null) {
            sb.append("  viewsToAdd(" + viewAtIndexArr.length + "): [\n");
            for (int i8 = 0; i8 < viewAtIndexArr.length; i8 += 16) {
                int i9 = 0;
                while (true) {
                    int i10 = i8 + i9;
                    if (i10 >= viewAtIndexArr.length || i9 >= 16) {
                        sb.append("\n");
                    } else {
                        sb.append("[" + viewAtIndexArr[i10].c + "," + viewAtIndexArr[i10].b + "],");
                        i9++;
                    }
                }
                sb.append("\n");
            }
            sb.append(" ],\n");
        }
        if (iArr2 != null) {
            sb.append("  tagsToDelete(" + iArr2.length + "): [\n");
            for (int i11 = 0; i11 < iArr2.length; i11 += 16) {
                int i12 = 0;
                while (true) {
                    int i13 = i11 + i12;
                    if (i13 >= iArr2.length || i12 >= 16) {
                        sb.append("\n");
                    } else {
                        sb.append(iArr2[i13] + ",");
                        i12++;
                    }
                }
                sb.append("\n");
            }
            sb.append(" ]\n");
        }
        return sb.toString();
    }

    public synchronized void a(int i2, @Nullable int[] iArr, @Nullable ViewAtIndex[] viewAtIndexArr, @Nullable int[] iArr2) {
        UiThreadUtil.b();
        final ViewGroup viewGroup = (ViewGroup) this.c.get(i2);
        final ViewGroupManager viewGroupManager = (ViewGroupManager) c(i2);
        if (viewGroup != null) {
            int childCount = viewGroupManager.getChildCount(viewGroup);
            if (iArr != null) {
                int length = iArr.length - 1;
                while (length >= 0) {
                    int i3 = iArr[length];
                    if (i3 < 0) {
                        throw new IllegalViewOperationException("Trying to remove a negative view index:" + i3 + " view tag: " + i2 + "\n detail: " + a(viewGroup, viewGroupManager, iArr, viewAtIndexArr, iArr2));
                    } else if (i3 >= viewGroupManager.getChildCount(viewGroup)) {
                        throw new IllegalViewOperationException("Trying to remove a view index above child count " + i3 + " view tag: " + i2 + "\n detail: " + a(viewGroup, viewGroupManager, iArr, viewAtIndexArr, iArr2));
                    } else if (i3 < childCount) {
                        View childAt = viewGroupManager.getChildAt(viewGroup, i3);
                        if (!this.j || !this.i.a(childAt) || !a(iArr2, childAt.getId())) {
                            viewGroupManager.removeViewAt(viewGroup, i3);
                        }
                        length--;
                        childCount = i3;
                    } else {
                        throw new IllegalViewOperationException("Trying to remove an out of order view index:" + i3 + " view tag: " + i2 + "\n detail: " + a(viewGroup, viewGroupManager, iArr, viewAtIndexArr, iArr2));
                    }
                }
            }
            if (viewAtIndexArr != null) {
                for (ViewAtIndex viewAtIndex : viewAtIndexArr) {
                    View view = this.c.get(viewAtIndex.b);
                    if (view != null) {
                        viewGroupManager.addView(viewGroup, view, viewAtIndex.c);
                    } else {
                        throw new IllegalViewOperationException("Trying to add unknown view tag: " + viewAtIndex.b + "\n detail: " + a(viewGroup, viewGroupManager, iArr, viewAtIndexArr, iArr2));
                    }
                }
            }
            if (iArr2 != null) {
                for (int i4 : iArr2) {
                    final View view2 = this.c.get(i4);
                    if (view2 != null) {
                        if (!this.j || !this.i.a(view2)) {
                            a(view2);
                        } else {
                            this.i.a(view2, new LayoutAnimationListener() {
                                /* class com.facebook.react.uimanager.NativeViewHierarchyManager.AnonymousClass1 */

                                @Override // com.facebook.react.uimanager.layoutanimation.LayoutAnimationListener
                                public void a() {
                                    viewGroupManager.removeView(viewGroup, view2);
                                    NativeViewHierarchyManager.this.a(view2);
                                }
                            });
                        }
                    } else {
                        throw new IllegalViewOperationException("Trying to destroy unknown view tag: " + i4 + "\n detail: " + a(viewGroup, viewGroupManager, iArr, viewAtIndexArr, iArr2));
                    }
                }
            }
        } else {
            throw new IllegalViewOperationException("Trying to manageChildren view with tag " + i2 + " which doesn't exist\n detail: " + a(viewGroup, viewGroupManager, iArr, viewAtIndexArr, iArr2));
        }
    }

    private boolean a(@Nullable int[] iArr, int i2) {
        if (iArr == null) {
            return false;
        }
        for (int i3 : iArr) {
            if (i3 == i2) {
                return true;
            }
        }
        return false;
    }

    private static String a(ViewGroup viewGroup, ViewGroupManager viewGroupManager, ReadableArray readableArray) {
        ViewAtIndex[] viewAtIndexArr = new ViewAtIndex[readableArray.a()];
        for (int i2 = 0; i2 < readableArray.a(); i2++) {
            viewAtIndexArr[i2] = new ViewAtIndex(readableArray.c(i2), i2);
        }
        return a(viewGroup, viewGroupManager, (int[]) null, viewAtIndexArr, (int[]) null);
    }

    public synchronized void a(int i2, ReadableArray readableArray) {
        UiThreadUtil.b();
        ViewGroup viewGroup = (ViewGroup) this.c.get(i2);
        ViewGroupManager viewGroupManager = (ViewGroupManager) c(i2);
        for (int i3 = 0; i3 < readableArray.a(); i3++) {
            View view = this.c.get(readableArray.c(i3));
            if (view != null) {
                viewGroupManager.addView(viewGroup, view, i3);
            } else {
                throw new IllegalViewOperationException("Trying to add unknown view tag: " + readableArray.c(i3) + "\n detail: " + a(viewGroup, viewGroupManager, readableArray));
            }
        }
    }

    public synchronized void a(int i2, SizeMonitoringFrameLayout sizeMonitoringFrameLayout, ThemedReactContext themedReactContext) {
        a(i2, (ViewGroup) sizeMonitoringFrameLayout, themedReactContext);
    }

    /* access modifiers changed from: protected */
    public final synchronized void a(int i2, ViewGroup viewGroup, ThemedReactContext themedReactContext) {
        if (viewGroup.getId() == -1) {
            this.c.put(i2, viewGroup);
            this.d.put(i2, this.h);
            this.e.put(i2, true);
            viewGroup.setId(i2);
        } else {
            throw new IllegalViewOperationException("Trying to add a root view with an explicit id already set. React Native uses the id field to track react tags and will overwrite this field. If that is fine, explicitly overwrite the id field to View.NO_ID before calling addRootView.");
        }
    }

    /* access modifiers changed from: protected */
    public synchronized void a(View view) {
        UiThreadUtil.b();
        if (!this.e.get(view.getId())) {
            c(view.getId()).onDropViewInstance(view);
        }
        ViewManager viewManager = this.d.get(view.getId());
        if ((view instanceof ViewGroup) && (viewManager instanceof ViewGroupManager)) {
            ViewGroup viewGroup = (ViewGroup) view;
            ViewGroupManager viewGroupManager = (ViewGroupManager) viewManager;
            for (int childCount = viewGroupManager.getChildCount(viewGroup) - 1; childCount >= 0; childCount--) {
                View childAt = viewGroupManager.getChildAt(viewGroup, childCount);
                if (this.c.get(childAt.getId()) != null) {
                    a(childAt);
                }
            }
            viewGroupManager.removeAllViews(viewGroup);
        }
        this.c.remove(view.getId());
        this.d.remove(view.getId());
    }

    public synchronized void d(int i2) {
        UiThreadUtil.b();
        if (!this.e.get(i2)) {
            SoftAssertions.a("View with tag " + i2 + " is not registered as a root view");
        }
        a(this.c.get(i2));
        this.e.delete(i2);
    }

    public synchronized void a(int i2, int[] iArr) {
        UiThreadUtil.b();
        View view = this.c.get(i2);
        if (view != null) {
            View view2 = (View) RootViewUtil.a(view);
            if (view2 != null) {
                view2.getLocationInWindow(iArr);
                int i3 = iArr[0];
                int i4 = iArr[1];
                view.getLocationInWindow(iArr);
                iArr[0] = iArr[0] - i3;
                iArr[1] = iArr[1] - i4;
                iArr[2] = view.getWidth();
                iArr[3] = view.getHeight();
            } else {
                throw new NoSuchNativeViewException("Native view " + i2 + " is no longer on screen");
            }
        } else {
            throw new NoSuchNativeViewException("No native view for " + i2 + " currently exists");
        }
    }

    public synchronized void b(int i2, int[] iArr) {
        UiThreadUtil.b();
        View view = this.c.get(i2);
        if (view != null) {
            view.getLocationOnScreen(iArr);
            Resources resources = view.getContext().getResources();
            int identifier = resources.getIdentifier("status_bar_height", "dimen", "android");
            if (identifier > 0) {
                iArr[1] = iArr[1] - ((int) resources.getDimension(identifier));
            }
            iArr[2] = view.getWidth();
            iArr[3] = view.getHeight();
        } else {
            throw new NoSuchNativeViewException("No native view for " + i2 + " currently exists");
        }
    }

    public synchronized int a(int i2, float f2, float f3) {
        View view;
        UiThreadUtil.b();
        view = this.c.get(i2);
        if (view != null) {
        } else {
            throw new JSApplicationIllegalArgumentException("Could not find view with tag " + i2);
        }
        return TouchTargetHelper.a(f2, f3, (ViewGroup) view);
    }

    public synchronized void a(int i2, int i3, boolean z) {
        if (!z) {
            this.g.a(i3, (ViewParent) null);
            return;
        }
        View view = this.c.get(i2);
        if (i3 == i2 || !(view instanceof ViewParent)) {
            if (this.e.get(i2)) {
                SoftAssertions.a("Cannot block native responder on " + i2 + " that is a root view");
            }
            this.g.a(i3, view.getParent());
            return;
        }
        this.g.a(i3, (ViewParent) view);
    }

    public void b() {
        this.g.a();
    }

    /* access modifiers changed from: package-private */
    public void a(ReadableMap readableMap) {
        this.i.a(readableMap);
    }

    /* access modifiers changed from: package-private */
    public void c() {
        this.i.a();
    }

    /* access modifiers changed from: package-private */
    public synchronized void a(int i2, Animation animation, @Nullable final Callback callback) {
        UiThreadUtil.b();
        View view = this.c.get(i2);
        final int d2 = animation.d();
        if (view != null) {
            animation.a(new AnimationListener() {
                /* class com.facebook.react.uimanager.NativeViewHierarchyManager.AnonymousClass2 */

                @Override // com.facebook.react.animation.AnimationListener
                public void a() {
                    Assertions.a(NativeViewHierarchyManager.this.b.b(d2), "Animation was already removed somehow!");
                    if (callback != null) {
                        callback.a(true);
                    }
                }

                @Override // com.facebook.react.animation.AnimationListener
                public void b() {
                    Assertions.a(NativeViewHierarchyManager.this.b.b(d2), "Animation was already removed somehow!");
                    if (callback != null) {
                        callback.a(false);
                    }
                }
            });
            animation.a(view);
        } else {
            throw new IllegalViewOperationException("View with tag " + i2 + " not found");
        }
    }

    public synchronized void a(int i2, int i3, @Nullable ReadableArray readableArray) {
        UiThreadUtil.b();
        View view = this.c.get(i2);
        if (view != null) {
            c(i2).receiveCommand(view, i3, readableArray);
        } else {
            throw new IllegalViewOperationException("Trying to send command to a non-existing view with tag " + i2);
        }
    }

    public synchronized void a(int i2, ReadableArray readableArray, Callback callback, Callback callback2) {
        UiThreadUtil.b();
        View view = this.c.get(i2);
        if (view == null) {
            callback2.a("Can't display popup. Could not find view with tag " + i2);
            return;
        }
        PopupMenu popupMenu = new PopupMenu(a(i2), view);
        Menu menu = popupMenu.getMenu();
        for (int i3 = 0; i3 < readableArray.a(); i3++) {
            menu.add(0, 0, i3, readableArray.d(i3));
        }
        PopupMenuCallbackHandler popupMenuCallbackHandler = new PopupMenuCallbackHandler(callback);
        popupMenu.setOnMenuItemClickListener(popupMenuCallbackHandler);
        popupMenu.setOnDismissListener(popupMenuCallbackHandler);
        popupMenu.show();
    }

    private static class PopupMenuCallbackHandler implements PopupMenu.OnDismissListener, PopupMenu.OnMenuItemClickListener {

        /* renamed from: a  reason: collision with root package name */
        final Callback f2224a;
        boolean b;

        private PopupMenuCallbackHandler(Callback callback) {
            this.b = false;
            this.f2224a = callback;
        }

        public void onDismiss(PopupMenu popupMenu) {
            if (!this.b) {
                this.f2224a.a("dismissed");
                this.b = true;
            }
        }

        public boolean onMenuItemClick(MenuItem menuItem) {
            if (this.b) {
                return false;
            }
            this.f2224a.a("itemSelected", Integer.valueOf(menuItem.getOrder()));
            this.b = true;
            return true;
        }
    }

    private ThemedReactContext a(int i2) {
        View view = this.c.get(i2);
        if (view != null) {
            return (ThemedReactContext) view.getContext();
        }
        throw new JSApplicationIllegalArgumentException("Could not find view with tag " + i2);
    }

    public void a(int i2, int i3) {
        View view = this.c.get(i2);
        if (view != null) {
            AccessibilityHelper.a(view, i3);
            return;
        }
        throw new JSApplicationIllegalArgumentException("Could not find view with tag " + i2);
    }
}
