package com.facebook.react.uimanager;

import android.os.SystemClock;
import android.view.View;
import com.facebook.common.logging.FLog;
import com.facebook.infer.annotation.Assertions;
import com.facebook.react.animation.Animation;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.UiThreadUtil;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.modules.i18nmanager.I18nUtil;
import com.facebook.react.uimanager.UIManagerModule;
import com.facebook.react.uimanager.common.MeasureSpecProvider;
import com.facebook.react.uimanager.common.SizeMonitoringFrameLayout;
import com.facebook.react.uimanager.debug.NotThreadSafeViewHierarchyUpdateDebugListener;
import com.facebook.react.uimanager.events.EventDispatcher;
import com.facebook.systrace.Systrace;
import com.facebook.systrace.SystraceMessage;
import com.facebook.yoga.YogaDirection;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import javax.annotation.Nullable;

public class UIImplementation {

    /* renamed from: a  reason: collision with root package name */
    protected final EventDispatcher f2239a;
    protected final ReactApplicationContext b;
    protected final ShadowNodeRegistry c;
    @Nullable
    protected LayoutUpdateListener d;
    private final Set<Integer> e;
    private final ViewManagerRegistry f;
    private final UIViewOperationQueue g;
    private final NativeViewHierarchyOptimizer h;
    private final int[] i;
    private long j;

    public interface LayoutUpdateListener {
        void a(ReactShadowNode reactShadowNode);
    }

    public void g() {
    }

    public UIImplementation(ReactApplicationContext reactApplicationContext, UIManagerModule.ViewManagerResolver viewManagerResolver, EventDispatcher eventDispatcher, int i2) {
        this(reactApplicationContext, new ViewManagerRegistry(viewManagerResolver), eventDispatcher, i2);
    }

    public UIImplementation(ReactApplicationContext reactApplicationContext, List<ViewManager> list, EventDispatcher eventDispatcher, int i2) {
        this(reactApplicationContext, new ViewManagerRegistry(list), eventDispatcher, i2);
    }

    private UIImplementation(ReactApplicationContext reactApplicationContext, ViewManagerRegistry viewManagerRegistry, EventDispatcher eventDispatcher, int i2) {
        this(reactApplicationContext, viewManagerRegistry, new UIViewOperationQueue(reactApplicationContext, new NativeViewHierarchyManager(viewManagerRegistry), i2), eventDispatcher);
    }

    protected UIImplementation(ReactApplicationContext reactApplicationContext, ViewManagerRegistry viewManagerRegistry, UIViewOperationQueue uIViewOperationQueue, EventDispatcher eventDispatcher) {
        this.c = new ShadowNodeRegistry();
        this.e = new HashSet();
        this.i = new int[4];
        this.j = 0;
        this.b = reactApplicationContext;
        this.f = viewManagerRegistry;
        this.g = uIViewOperationQueue;
        this.h = new NativeViewHierarchyOptimizer(this.g, this.c);
        this.f2239a = eventDispatcher;
    }

    /* access modifiers changed from: protected */
    public ReactShadowNode a() {
        ReactShadowNodeImpl reactShadowNodeImpl = new ReactShadowNodeImpl();
        if (I18nUtil.a().a(this.b)) {
            reactShadowNodeImpl.a(YogaDirection.RTL);
        }
        reactShadowNodeImpl.a("Root");
        return reactShadowNodeImpl;
    }

    /* access modifiers changed from: protected */
    public ReactShadowNode a(String str) {
        return this.f.a(str).createShadowNodeInstance(this.b);
    }

    public final ReactShadowNode b(int i2) {
        return this.c.c(i2);
    }

    /* access modifiers changed from: protected */
    public final ViewManager b(String str) {
        return this.f.a(str);
    }

    public void a(int i2, int i3, int i4) {
        ReactShadowNode c2 = this.c.c(i2);
        if (c2 == null) {
            FLog.c("ReactNative", "Tried to update non-existent root tag: " + i2);
            return;
        }
        a(c2, i3, i4);
    }

    public void a(ReactShadowNode reactShadowNode, int i2, int i3) {
        int mode = View.MeasureSpec.getMode(i2);
        int size = View.MeasureSpec.getSize(i2);
        if (mode == Integer.MIN_VALUE) {
            reactShadowNode.d((float) size);
        } else if (mode == 0) {
            reactShadowNode.ah();
        } else if (mode == 1073741824) {
            reactShadowNode.a((float) size);
        }
        int mode2 = View.MeasureSpec.getMode(i3);
        int size2 = View.MeasureSpec.getSize(i3);
        if (mode2 == Integer.MIN_VALUE) {
            reactShadowNode.e((float) size2);
        } else if (mode2 == 0) {
            reactShadowNode.ai();
        } else if (mode2 == 1073741824) {
            reactShadowNode.b((float) size2);
        }
    }

    public <T extends SizeMonitoringFrameLayout & MeasureSpecProvider> void a(T t, int i2, ThemedReactContext themedReactContext) {
        ReactShadowNode a2 = a();
        a2.c(i2);
        a2.a(themedReactContext);
        T t2 = t;
        a(a2, t2.getWidthMeasureSpec(), t2.getHeightMeasureSpec());
        this.c.a(a2);
        this.g.a(i2, t, themedReactContext);
    }

    public void a(int i2) {
        c(i2);
        this.g.a(i2);
    }

    public void c(int i2) {
        this.c.a(i2);
    }

    public void b(int i2, int i3, int i4) {
        ReactShadowNode c2 = this.c.c(i2);
        if (c2 == null) {
            FLog.c("ReactNative", "Tried to update size of non-existent tag: " + i2);
            return;
        }
        c2.a((float) i3);
        c2.b((float) i4);
        h();
    }

    public void a(int i2, Object obj) {
        ReactShadowNode c2 = this.c.c(i2);
        if (c2 == null) {
            FLog.c("ReactNative", "Attempt to set local data for view with unknown tag: " + i2);
            return;
        }
        c2.a(obj);
        h();
    }

    public Map<String, Long> c() {
        return this.g.e();
    }

    public void a(int i2, String str, int i3, ReadableMap readableMap) {
        ReactStylesDiffMap reactStylesDiffMap;
        ReactShadowNode a2 = a(str);
        ReactShadowNode c2 = this.c.c(i3);
        a2.c(i2);
        a2.a(str);
        a2.b(c2);
        a2.a(c2.Y());
        this.c.b(a2);
        if (readableMap != null) {
            reactStylesDiffMap = new ReactStylesDiffMap(readableMap);
            a2.b(reactStylesDiffMap);
        } else {
            reactStylesDiffMap = null;
        }
        a(a2, i3, reactStylesDiffMap);
    }

    /* access modifiers changed from: protected */
    public void a(ReactShadowNode reactShadowNode, int i2, @Nullable ReactStylesDiffMap reactStylesDiffMap) {
        if (!reactShadowNode.d()) {
            this.h.a(reactShadowNode, reactShadowNode.Y(), reactStylesDiffMap);
        }
    }

    public void a(int i2, String str, ReadableMap readableMap) {
        if (this.f.a(str) != null) {
            ReactShadowNode c2 = this.c.c(i2);
            if (c2 == null) {
                throw new IllegalViewOperationException("Trying to update non-existent view with tag " + i2);
            } else if (readableMap != null) {
                ReactStylesDiffMap reactStylesDiffMap = new ReactStylesDiffMap(readableMap);
                c2.b(reactStylesDiffMap);
                a(c2, str, reactStylesDiffMap);
            }
        } else {
            throw new IllegalViewOperationException("Got unknown view type: " + str);
        }
    }

    public void a(int i2, ReactStylesDiffMap reactStylesDiffMap) {
        UiThreadUtil.b();
        this.g.d().a(i2, reactStylesDiffMap);
    }

    /* access modifiers changed from: protected */
    public void a(ReactShadowNode reactShadowNode, String str, ReactStylesDiffMap reactStylesDiffMap) {
        if (!reactShadowNode.d()) {
            this.h.a(reactShadowNode, str, reactStylesDiffMap);
        }
    }

    public void a(int i2, @Nullable ReadableArray readableArray, @Nullable ReadableArray readableArray2, @Nullable ReadableArray readableArray3, @Nullable ReadableArray readableArray4, @Nullable ReadableArray readableArray5) {
        int i3;
        int i4;
        int i5;
        ReadableArray readableArray6 = readableArray;
        ReactShadowNode c2 = this.c.c(i2);
        if (readableArray6 == null) {
            i3 = 0;
        } else {
            i3 = readableArray.a();
        }
        if (readableArray3 == null) {
            i4 = 0;
        } else {
            i4 = readableArray3.a();
        }
        if (readableArray5 == null) {
            i5 = 0;
        } else {
            i5 = readableArray5.a();
        }
        if (i3 != 0 && (readableArray2 == null || i3 != readableArray2.a())) {
            throw new IllegalViewOperationException("Size of moveFrom != size of moveTo!");
        } else if (i4 == 0 || (readableArray4 != null && i4 == readableArray4.a())) {
            ViewAtIndex[] viewAtIndexArr = new ViewAtIndex[(i3 + i4)];
            int[] iArr = new int[(i3 + i5)];
            int[] iArr2 = new int[iArr.length];
            int[] iArr3 = new int[i5];
            if (i3 > 0) {
                Assertions.b(readableArray);
                Assertions.b(readableArray2);
                int i6 = 0;
                while (i6 < i3) {
                    int c3 = readableArray6.c(i6);
                    int V = c2.e(c3).V();
                    viewAtIndexArr[i6] = new ViewAtIndex(V, readableArray2.c(i6));
                    iArr[i6] = c3;
                    iArr2[i6] = V;
                    i6++;
                    iArr3 = iArr3;
                    readableArray6 = readableArray;
                }
            }
            if (i4 > 0) {
                Assertions.b(readableArray3);
                Assertions.b(readableArray4);
                for (int i7 = 0; i7 < i4; i7++) {
                    viewAtIndexArr[i3 + i7] = new ViewAtIndex(readableArray3.c(i7), readableArray4.c(i7));
                }
            }
            if (i5 > 0) {
                Assertions.b(readableArray5);
                for (int i8 = 0; i8 < i5; i8++) {
                    int c4 = readableArray5.c(i8);
                    int V2 = c2.e(c4).V();
                    int i9 = i3 + i8;
                    iArr[i9] = c4;
                    iArr2[i9] = V2;
                    iArr3[i8] = V2;
                }
            }
            Arrays.sort(viewAtIndexArr, ViewAtIndex.f2269a);
            Arrays.sort(iArr);
            int i10 = -1;
            for (int length = iArr.length - 1; length >= 0; length--) {
                if (iArr[length] != i10) {
                    c2.d(iArr[length]);
                    i10 = iArr[length];
                } else {
                    throw new IllegalViewOperationException("Repeated indices in Removal list for view tag: " + i2);
                }
            }
            for (ViewAtIndex viewAtIndex : viewAtIndexArr) {
                ReactShadowNode c5 = this.c.c(viewAtIndex.b);
                if (c5 != null) {
                    c2.a(c5, viewAtIndex.c);
                } else {
                    throw new IllegalViewOperationException("Trying to add unknown view tag: " + viewAtIndex.b);
                }
            }
            if (!c2.d() && !c2.e()) {
                this.h.a(c2, iArr, iArr2, viewAtIndexArr, iArr3);
            }
            for (int i11 : iArr3) {
                a(this.c.c(i11));
            }
        } else {
            throw new IllegalViewOperationException("Size of addChildTags != size of addAtIndices!");
        }
    }

    public void a(int i2, ReadableArray readableArray) {
        ReactShadowNode c2 = this.c.c(i2);
        for (int i3 = 0; i3 < readableArray.a(); i3++) {
            ReactShadowNode c3 = this.c.c(readableArray.c(i3));
            if (c3 != null) {
                c2.a(c3, i3);
            } else {
                throw new IllegalViewOperationException("Trying to add unknown view tag: " + readableArray.c(i3));
            }
        }
        if (!(c2.d() || c2.e())) {
            this.h.a(c2, readableArray);
        }
    }

    public void b(int i2, int i3) {
        if (this.c.d(i2) || this.c.d(i3)) {
            throw new IllegalViewOperationException("Trying to add or replace a root tag!");
        }
        ReactShadowNode c2 = this.c.c(i2);
        if (c2 != null) {
            ReactShadowNode X = c2.X();
            if (X != null) {
                int a2 = X.a(c2);
                if (a2 >= 0) {
                    WritableArray a3 = Arguments.a();
                    a3.pushInt(i3);
                    WritableArray a4 = Arguments.a();
                    a4.pushInt(a2);
                    WritableArray a5 = Arguments.a();
                    a5.pushInt(a2);
                    a(X.V(), null, null, a3, a4, a5);
                    return;
                }
                throw new IllegalStateException("Didn't find child tag in parent");
            }
            throw new IllegalViewOperationException("Node is not attached to a parent: " + i2);
        }
        throw new IllegalViewOperationException("Trying to replace unknown view tag: " + i2);
    }

    public void d(int i2) {
        ReactShadowNode c2 = this.c.c(i2);
        if (c2 != null) {
            WritableArray a2 = Arguments.a();
            for (int i3 = 0; i3 < c2.S(); i3++) {
                a2.pushInt(i3);
            }
            a(i2, null, null, null, null, a2);
            return;
        }
        throw new IllegalViewOperationException("Trying to remove subviews of an unknown view tag: " + i2);
    }

    public void a(int i2, float f2, float f3, Callback callback) {
        this.g.a(i2, f2, f3, callback);
    }

    public void b(int i2, int i3, Callback callback) {
        ReactShadowNode c2 = this.c.c(i2);
        ReactShadowNode c3 = this.c.c(i3);
        if (c2 == null || c3 == null) {
            callback.a(false);
            return;
        }
        callback.a(Boolean.valueOf(c2.d(c3)));
    }

    public void a(int i2, Callback callback) {
        this.g.a(i2, callback);
    }

    public void b(int i2, Callback callback) {
        this.g.b(i2, callback);
    }

    public void a(int i2, int i3, Callback callback, Callback callback2) {
        try {
            a(i2, i3, this.i);
            callback2.a(Float.valueOf(PixelUtil.c((float) this.i[0])), Float.valueOf(PixelUtil.c((float) this.i[1])), Float.valueOf(PixelUtil.c((float) this.i[2])), Float.valueOf(PixelUtil.c((float) this.i[3])));
        } catch (IllegalViewOperationException e2) {
            callback.a(e2.getMessage());
        }
    }

    public void a(int i2, Callback callback, Callback callback2) {
        try {
            a(i2, this.i);
            callback2.a(Float.valueOf(PixelUtil.c((float) this.i[0])), Float.valueOf(PixelUtil.c((float) this.i[1])), Float.valueOf(PixelUtil.c((float) this.i[2])), Float.valueOf(PixelUtil.c((float) this.i[3])));
        } catch (IllegalViewOperationException e2) {
            callback.a(e2.getMessage());
        }
    }

    public void e(int i2) {
        SystraceMessage.a(0, "UIImplementation.dispatchViewUpdates").a("batchId", i2).a();
        long uptimeMillis = SystemClock.uptimeMillis();
        try {
            b();
            this.h.a();
            this.g.a(i2, uptimeMillis, this.j);
        } finally {
            Systrace.b(0);
        }
    }

    private void h() {
        if (this.g.f()) {
            e(-1);
        }
    }

    /* JADX INFO: finally extract failed */
    /* access modifiers changed from: protected */
    public void b() {
        Systrace.a(0, "UIImplementation.updateViewHierarchy");
        for (int i2 = 0; i2 < this.c.a(); i2++) {
            try {
                int e2 = this.c.e(i2);
                ReactShadowNode c2 = this.c.c(e2);
                if (this.e.contains(Integer.valueOf(e2))) {
                    SystraceMessage.a(0, "UIImplementation.notifyOnBeforeLayoutRecursive").a("rootTag", c2.V()).a();
                    try {
                        e(c2);
                        Systrace.b(0);
                        b(c2);
                        SystraceMessage.a(0, "UIImplementation.applyUpdatesRecursive").a("rootTag", c2.V()).a();
                        try {
                            a(c2, 0.0f, 0.0f);
                            Systrace.b(0);
                            if (this.d != null) {
                                this.d.a(c2);
                            }
                        } catch (Throwable th) {
                            Systrace.b(0);
                            throw th;
                        }
                    } catch (Throwable th2) {
                        Systrace.b(0);
                        throw th2;
                    }
                }
            } catch (Throwable th3) {
                Systrace.b(0);
                throw th3;
            }
        }
        Systrace.b(0);
    }

    public void a(Animation animation) {
        this.g.a(animation);
    }

    public void a(int i2, int i3, Callback callback) {
        a(i2, "addAnimation");
        this.g.a(i2, i3, callback);
    }

    public void c(int i2, int i3) {
        a(i2, "removeAnimation");
        this.g.b(i3);
    }

    public void a(boolean z) {
        this.g.a(z);
    }

    public void a(ReadableMap readableMap, Callback callback, Callback callback2) {
        this.g.a(readableMap, callback, callback2);
    }

    public void a(int i2, boolean z) {
        a(i2, "setJSResponder");
        ReactShadowNode c2 = this.c.c(i2);
        while (true) {
            if (c2.d() || c2.ae()) {
                c2 = c2.X();
            } else {
                this.g.a(c2.V(), i2, z);
                return;
            }
        }
    }

    public void d() {
        this.g.g();
    }

    public void a(int i2, int i3, ReadableArray readableArray) {
        a(i2, "dispatchViewManagerCommand");
        this.g.b(i2, i3, readableArray);
    }

    public void a(int i2, ReadableArray readableArray, Callback callback, Callback callback2) {
        a(i2, "showPopupMenu");
        this.g.a(i2, readableArray, callback, callback2);
    }

    public void a(int i2, int i3) {
        this.g.a(i2, i3);
    }

    public void e() {
        this.g.h();
    }

    public void f() {
        this.g.i();
    }

    public void a(@Nullable NotThreadSafeViewHierarchyUpdateDebugListener notThreadSafeViewHierarchyUpdateDebugListener) {
        this.g.a(notThreadSafeViewHierarchyUpdateDebugListener);
    }

    /* access modifiers changed from: protected */
    public final void a(ReactShadowNode reactShadowNode) {
        c(reactShadowNode);
        reactShadowNode.aj();
    }

    private void c(ReactShadowNode reactShadowNode) {
        NativeViewHierarchyOptimizer.a(reactShadowNode);
        this.c.b(reactShadowNode.V());
        this.e.remove(Integer.valueOf(reactShadowNode.V()));
        for (int S = reactShadowNode.S() - 1; S >= 0; S--) {
            c(reactShadowNode.e(S));
        }
        reactShadowNode.T();
    }

    private void a(int i2, int i3, int[] iArr) {
        ReactShadowNode c2 = this.c.c(i2);
        ReactShadowNode c3 = this.c.c(i3);
        if (c2 == null || c3 == null) {
            StringBuilder sb = new StringBuilder();
            sb.append("Tag ");
            if (c2 != null) {
                i2 = i3;
            }
            sb.append(i2);
            sb.append(" does not exist");
            throw new IllegalViewOperationException(sb.toString());
        }
        if (c2 != c3) {
            for (ReactShadowNode X = c2.X(); X != c3; X = X.X()) {
                if (X == null) {
                    throw new IllegalViewOperationException("Tag " + i3 + " is not an ancestor of tag " + i2);
                }
            }
        }
        a(c2, c3, iArr);
    }

    private void a(int i2, int[] iArr) {
        ReactShadowNode c2 = this.c.c(i2);
        if (c2 != null) {
            ReactShadowNode X = c2.X();
            if (X != null) {
                a(c2, X, iArr);
                return;
            }
            throw new IllegalViewOperationException("View with tag " + i2 + " doesn't have a parent!");
        }
        throw new IllegalViewOperationException("No native view for tag " + i2 + " exists!");
    }

    private void a(ReactShadowNode reactShadowNode, ReactShadowNode reactShadowNode2, int[] iArr) {
        int i2;
        int i3;
        if (reactShadowNode != reactShadowNode2) {
            i3 = Math.round(reactShadowNode.af());
            i2 = Math.round(reactShadowNode.ag());
            for (ReactShadowNode X = reactShadowNode.X(); X != reactShadowNode2; X = X.X()) {
                Assertions.b(X);
                d(X);
                i3 += Math.round(X.af());
                i2 += Math.round(X.ag());
            }
            d(reactShadowNode2);
        } else {
            i3 = 0;
            i2 = 0;
        }
        iArr[0] = i3;
        iArr[1] = i2;
        iArr[2] = reactShadowNode.k();
        iArr[3] = reactShadowNode.l();
    }

    private void a(int i2, String str) {
        if (this.c.c(i2) == null) {
            throw new IllegalViewOperationException("Unable to execute operation " + str + " on view with tag: " + i2 + ", since the view does not exists");
        }
    }

    private void d(ReactShadowNode reactShadowNode) {
        ViewManager viewManager = (ViewManager) Assertions.b(this.f.a(reactShadowNode.N()));
        if (viewManager instanceof ViewGroupManager) {
            ViewGroupManager viewGroupManager = (ViewGroupManager) viewManager;
            if (viewGroupManager != null && viewGroupManager.needsCustomLayoutForChildren()) {
                throw new IllegalViewOperationException("Trying to measure a view using measureLayout/measureLayoutRelativeToParent relative to an ancestor that requires custom layout for it's children (" + reactShadowNode.N() + "). Use measure instead.");
            }
            return;
        }
        throw new IllegalViewOperationException("Trying to use view " + reactShadowNode.N() + " as a parent, but its Manager doesn't extends ViewGroupManager");
    }

    private void e(ReactShadowNode reactShadowNode) {
        if (reactShadowNode.O()) {
            for (int i2 = 0; i2 < reactShadowNode.S(); i2++) {
                e(reactShadowNode.e(i2));
            }
            reactShadowNode.U();
        }
    }

    /* access modifiers changed from: protected */
    public void b(ReactShadowNode reactShadowNode) {
        SystraceMessage.a(0, "cssRoot.calculateLayout").a("rootTag", reactShadowNode.V()).a();
        long uptimeMillis = SystemClock.uptimeMillis();
        try {
            reactShadowNode.aa();
        } finally {
            Systrace.b(0);
            this.j = SystemClock.uptimeMillis() - uptimeMillis;
        }
    }

    /* access modifiers changed from: protected */
    public void a(ReactShadowNode reactShadowNode, float f2, float f3) {
        if (reactShadowNode.O()) {
            if (!reactShadowNode.e()) {
                for (int i2 = 0; i2 < reactShadowNode.S(); i2++) {
                    a(reactShadowNode.e(i2), reactShadowNode.af() + f2, reactShadowNode.ag() + f3);
                }
            }
            int V = reactShadowNode.V();
            if (!this.c.d(V) && reactShadowNode.a(f2, f3, this.g, this.h) && reactShadowNode.Z()) {
                this.f2239a.a(OnLayoutEvent.a(V, reactShadowNode.i(), reactShadowNode.j(), reactShadowNode.k(), reactShadowNode.l()));
            }
            reactShadowNode.P();
        }
    }

    public void a(UIBlock uIBlock) {
        this.g.a(uIBlock);
    }

    public void b(UIBlock uIBlock) {
        this.g.b(uIBlock);
    }

    public int f(int i2) {
        if (this.c.d(i2)) {
            return i2;
        }
        ReactShadowNode b2 = b(i2);
        if (b2 != null) {
            return b2.W().V();
        }
        FLog.c("ReactNative", "Warning : attempted to resolve a non-existent react shadow node. reactTag=" + i2);
        return 0;
    }

    public void g(int i2) {
        this.e.add(Integer.valueOf(i2));
    }
}
