package com.facebook.react.uimanager;

import android.os.SystemClock;
import com.facebook.common.logging.FLog;
import com.facebook.react.animation.Animation;
import com.facebook.react.animation.AnimationRegistry;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.GuardedRunnable;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.SoftAssertions;
import com.facebook.react.bridge.UiThreadUtil;
import com.facebook.react.modules.core.ReactChoreographer;
import com.facebook.react.uimanager.common.SizeMonitoringFrameLayout;
import com.facebook.react.uimanager.debug.NotThreadSafeViewHierarchyUpdateDebugListener;
import com.facebook.systrace.Systrace;
import com.facebook.systrace.SystraceMessage;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import javax.annotation.Nullable;
import javax.annotation.concurrent.GuardedBy;

public class UIViewOperationQueue {

    /* renamed from: a  reason: collision with root package name */
    private final int[] f2245a = new int[4];
    private final NativeViewHierarchyManager b;
    private final AnimationRegistry c;
    private final Object d = new Object();
    private final Object e = new Object();
    private final DispatchUIFrameCallback f;
    private final ReactApplicationContext g;
    private ArrayList<UIOperation> h = new ArrayList<>();
    @GuardedBy
    private ArrayList<Runnable> i = new ArrayList<>();
    @GuardedBy
    private ArrayDeque<UIOperation> j = new ArrayDeque<>();
    @Nullable
    private NotThreadSafeViewHierarchyUpdateDebugListener k;
    private boolean l = false;
    private boolean m = false;
    private boolean n = false;
    private long o;
    private long p;
    private long q;
    private long r;
    private long s;
    private long t;
    private long u;

    public interface UIOperation {
        void a();
    }

    private abstract class ViewOperation implements UIOperation {
        public int b;

        public ViewOperation(int i) {
            this.b = i;
        }
    }

    /* access modifiers changed from: private */
    public final class RemoveRootViewOperation extends ViewOperation {
        public RemoveRootViewOperation(int i) {
            super(i);
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            UIViewOperationQueue.this.b.d(this.b);
        }
    }

    /* access modifiers changed from: private */
    public final class UpdatePropertiesOperation extends ViewOperation {
        private final ReactStylesDiffMap d;

        private UpdatePropertiesOperation(int i, ReactStylesDiffMap reactStylesDiffMap) {
            super(i);
            this.d = reactStylesDiffMap;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            UIViewOperationQueue.this.b.a(this.b, this.d);
        }
    }

    /* access modifiers changed from: private */
    public final class UpdateLayoutOperation extends ViewOperation {
        private final int d;
        private final int e;
        private final int f;
        private final int g;
        private final int h;

        public UpdateLayoutOperation(int i, int i2, int i3, int i4, int i5, int i6) {
            super(i2);
            this.d = i;
            this.e = i3;
            this.f = i4;
            this.g = i5;
            this.h = i6;
            Systrace.d(0, "updateLayout", this.b);
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            Systrace.e(0, "updateLayout", this.b);
            UIViewOperationQueue.this.b.a(this.d, this.b, this.e, this.f, this.g, this.h);
        }
    }

    /* access modifiers changed from: private */
    public final class CreateViewOperation extends ViewOperation {
        private final ThemedReactContext d;
        private final String e;
        @Nullable
        private final ReactStylesDiffMap f;

        public CreateViewOperation(ThemedReactContext themedReactContext, int i, String str, ReactStylesDiffMap reactStylesDiffMap) {
            super(i);
            this.d = themedReactContext;
            this.e = str;
            this.f = reactStylesDiffMap;
            Systrace.d(0, "createView", this.b);
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            Systrace.e(0, "createView", this.b);
            UIViewOperationQueue.this.b.a(this.d, this.b, this.e, this.f);
        }
    }

    private final class ManageChildrenOperation extends ViewOperation {
        @Nullable
        private final int[] d;
        @Nullable
        private final ViewAtIndex[] e;
        @Nullable
        private final int[] f;

        public ManageChildrenOperation(int i, int[] iArr, @Nullable ViewAtIndex[] viewAtIndexArr, @Nullable int[] iArr2) {
            super(i);
            this.d = iArr;
            this.e = viewAtIndexArr;
            this.f = iArr2;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            UIViewOperationQueue.this.b.a(this.b, this.d, this.e, this.f);
        }
    }

    private final class SetChildrenOperation extends ViewOperation {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ UIViewOperationQueue f2262a;
        private final ReadableArray d;

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            this.f2262a.b.a(this.b, this.d);
        }
    }

    /* access modifiers changed from: private */
    public final class UpdateViewExtraData extends ViewOperation {
        private final Object d;

        public UpdateViewExtraData(int i, Object obj) {
            super(i);
            this.d = obj;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            UIViewOperationQueue.this.b.a(this.b, this.d);
        }
    }

    /* access modifiers changed from: private */
    public final class ChangeJSResponderOperation extends ViewOperation {
        private final int d;
        private final boolean e;
        private final boolean f;

        public ChangeJSResponderOperation(int i, int i2, boolean z, boolean z2) {
            super(i);
            this.d = i2;
            this.f = z;
            this.e = z2;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            if (!this.f) {
                UIViewOperationQueue.this.b.a(this.b, this.d, this.e);
            } else {
                UIViewOperationQueue.this.b.b();
            }
        }
    }

    /* access modifiers changed from: private */
    public final class DispatchCommandOperation extends ViewOperation {
        private final int d;
        @Nullable
        private final ReadableArray e;

        public DispatchCommandOperation(int i, int i2, ReadableArray readableArray) {
            super(i);
            this.d = i2;
            this.e = readableArray;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            UIViewOperationQueue.this.b.a(this.b, this.d, this.e);
        }
    }

    /* access modifiers changed from: private */
    public final class ShowPopupMenuOperation extends ViewOperation {
        private final ReadableArray d;
        private final Callback e;
        private final Callback f;

        public ShowPopupMenuOperation(int i, ReadableArray readableArray, Callback callback, Callback callback2) {
            super(i);
            this.d = readableArray;
            this.e = callback;
            this.f = callback2;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            UIViewOperationQueue.this.b.a(this.b, this.d, this.f, this.e);
        }
    }

    private static abstract class AnimationOperation implements UIOperation {
        protected final int b;

        public AnimationOperation(int i) {
            this.b = i;
        }
    }

    /* access modifiers changed from: private */
    public class RegisterAnimationOperation extends AnimationOperation {
        private final Animation c;

        private RegisterAnimationOperation(Animation animation) {
            super(animation.d());
            this.c = animation;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            UIViewOperationQueue.this.c.a(this.c);
        }
    }

    /* access modifiers changed from: private */
    public class AddAnimationOperation extends AnimationOperation {
        private final int c;
        private final Callback d;

        private AddAnimationOperation(int i, int i2, Callback callback) {
            super(i2);
            this.c = i;
            this.d = callback;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            Animation a2 = UIViewOperationQueue.this.c.a(this.b);
            if (a2 != null) {
                UIViewOperationQueue.this.b.a(this.c, a2, this.d);
                return;
            }
            throw new IllegalViewOperationException("Animation with id " + this.b + " was not found");
        }
    }

    /* access modifiers changed from: private */
    public final class RemoveAnimationOperation extends AnimationOperation {
        private RemoveAnimationOperation(int i) {
            super(i);
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            Animation a2 = UIViewOperationQueue.this.c.a(this.b);
            if (a2 != null) {
                a2.c();
            }
        }
    }

    /* access modifiers changed from: private */
    public class SetLayoutAnimationEnabledOperation implements UIOperation {
        private final boolean b;

        private SetLayoutAnimationEnabledOperation(boolean z) {
            this.b = z;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            UIViewOperationQueue.this.b.a(this.b);
        }
    }

    /* access modifiers changed from: private */
    public class ConfigureLayoutAnimationOperation implements UIOperation {
        private final ReadableMap b;

        private ConfigureLayoutAnimationOperation(ReadableMap readableMap) {
            this.b = readableMap;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            UIViewOperationQueue.this.b.a(this.b);
        }
    }

    /* access modifiers changed from: private */
    public final class MeasureOperation implements UIOperation {
        private final int b;
        private final Callback c;

        private MeasureOperation(int i, Callback callback) {
            this.b = i;
            this.c = callback;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            try {
                UIViewOperationQueue.this.b.a(this.b, UIViewOperationQueue.this.f2245a);
                float c2 = PixelUtil.c((float) UIViewOperationQueue.this.f2245a[0]);
                float c3 = PixelUtil.c((float) UIViewOperationQueue.this.f2245a[1]);
                float c4 = PixelUtil.c((float) UIViewOperationQueue.this.f2245a[2]);
                float c5 = PixelUtil.c((float) UIViewOperationQueue.this.f2245a[3]);
                this.c.a(0, 0, Float.valueOf(c4), Float.valueOf(c5), Float.valueOf(c2), Float.valueOf(c3));
            } catch (NoSuchNativeViewException unused) {
                this.c.a(new Object[0]);
            }
        }
    }

    /* access modifiers changed from: private */
    public final class MeasureInWindowOperation implements UIOperation {
        private final int b;
        private final Callback c;

        private MeasureInWindowOperation(int i, Callback callback) {
            this.b = i;
            this.c = callback;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            try {
                UIViewOperationQueue.this.b.b(this.b, UIViewOperationQueue.this.f2245a);
                float c2 = PixelUtil.c((float) UIViewOperationQueue.this.f2245a[0]);
                float c3 = PixelUtil.c((float) UIViewOperationQueue.this.f2245a[1]);
                float c4 = PixelUtil.c((float) UIViewOperationQueue.this.f2245a[2]);
                float c5 = PixelUtil.c((float) UIViewOperationQueue.this.f2245a[3]);
                this.c.a(Float.valueOf(c2), Float.valueOf(c3), Float.valueOf(c4), Float.valueOf(c5));
            } catch (NoSuchNativeViewException unused) {
                this.c.a(new Object[0]);
            }
        }
    }

    /* access modifiers changed from: private */
    public final class FindTargetForTouchOperation implements UIOperation {
        private final int b;
        private final float c;
        private final float d;
        private final Callback e;

        private FindTargetForTouchOperation(int i, float f, float f2, Callback callback) {
            this.b = i;
            this.c = f;
            this.d = f2;
            this.e = callback;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            try {
                UIViewOperationQueue.this.b.a(this.b, UIViewOperationQueue.this.f2245a);
                float f = (float) UIViewOperationQueue.this.f2245a[0];
                float f2 = (float) UIViewOperationQueue.this.f2245a[1];
                int a2 = UIViewOperationQueue.this.b.a(this.b, this.c, this.d);
                try {
                    UIViewOperationQueue.this.b.a(a2, UIViewOperationQueue.this.f2245a);
                    float c2 = PixelUtil.c(((float) UIViewOperationQueue.this.f2245a[0]) - f);
                    float c3 = PixelUtil.c(((float) UIViewOperationQueue.this.f2245a[1]) - f2);
                    float c4 = PixelUtil.c((float) UIViewOperationQueue.this.f2245a[2]);
                    float c5 = PixelUtil.c((float) UIViewOperationQueue.this.f2245a[3]);
                    this.e.a(Integer.valueOf(a2), Float.valueOf(c2), Float.valueOf(c3), Float.valueOf(c4), Float.valueOf(c5));
                } catch (IllegalViewOperationException unused) {
                    this.e.a(new Object[0]);
                }
            } catch (IllegalViewOperationException unused2) {
                this.e.a(new Object[0]);
            }
        }
    }

    /* access modifiers changed from: private */
    public class UIBlockOperation implements UIOperation {
        private final UIBlock b;

        public UIBlockOperation(UIBlock uIBlock) {
            this.b = uIBlock;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            this.b.a(UIViewOperationQueue.this.b);
        }
    }

    /* access modifiers changed from: private */
    public final class SendAccessibilityEvent extends ViewOperation {
        private final int d;

        private SendAccessibilityEvent(int i, int i2) {
            super(i);
            this.d = i2;
        }

        @Override // com.facebook.react.uimanager.UIViewOperationQueue.UIOperation
        public void a() {
            UIViewOperationQueue.this.b.a(this.b, this.d);
        }
    }

    public UIViewOperationQueue(ReactApplicationContext reactApplicationContext, NativeViewHierarchyManager nativeViewHierarchyManager, int i2) {
        this.b = nativeViewHierarchyManager;
        this.c = nativeViewHierarchyManager.a();
        this.f = new DispatchUIFrameCallback(reactApplicationContext, i2 == -1 ? 8 : i2);
        this.g = reactApplicationContext;
    }

    /* access modifiers changed from: package-private */
    public NativeViewHierarchyManager d() {
        return this.b;
    }

    public void a(@Nullable NotThreadSafeViewHierarchyUpdateDebugListener notThreadSafeViewHierarchyUpdateDebugListener) {
        this.k = notThreadSafeViewHierarchyUpdateDebugListener;
    }

    public Map<String, Long> e() {
        HashMap hashMap = new HashMap();
        hashMap.put("CommitStartTime", Long.valueOf(this.p));
        hashMap.put("LayoutTime", Long.valueOf(this.q));
        hashMap.put("DispatchViewUpdatesTime", Long.valueOf(this.r));
        hashMap.put("RunStartTime", Long.valueOf(this.s));
        hashMap.put("BatchedExecutionTime", Long.valueOf(this.t));
        hashMap.put("NonBatchedExecutionTime", Long.valueOf(this.u));
        return hashMap;
    }

    public boolean f() {
        return this.h.isEmpty();
    }

    public void a(int i2, SizeMonitoringFrameLayout sizeMonitoringFrameLayout, ThemedReactContext themedReactContext) {
        this.b.a(i2, sizeMonitoringFrameLayout, themedReactContext);
    }

    /* access modifiers changed from: protected */
    public void b(UIOperation uIOperation) {
        SoftAssertions.a(uIOperation);
        this.h.add(uIOperation);
    }

    public void a(int i2) {
        this.h.add(new RemoveRootViewOperation(i2));
    }

    public void a(int i2, int i3, boolean z) {
        this.h.add(new ChangeJSResponderOperation(i2, i3, false, z));
    }

    public void g() {
        this.h.add(new ChangeJSResponderOperation(0, 0, true, false));
    }

    public void b(int i2, int i3, ReadableArray readableArray) {
        this.h.add(new DispatchCommandOperation(i2, i3, readableArray));
    }

    public void a(int i2, Object obj) {
        this.h.add(new UpdateViewExtraData(i2, obj));
    }

    public void a(int i2, ReadableArray readableArray, Callback callback, Callback callback2) {
        this.h.add(new ShowPopupMenuOperation(i2, readableArray, callback, callback2));
    }

    public void a(ThemedReactContext themedReactContext, int i2, String str, @Nullable ReactStylesDiffMap reactStylesDiffMap) {
        synchronized (this.e) {
            this.j.addLast(new CreateViewOperation(themedReactContext, i2, str, reactStylesDiffMap));
        }
    }

    public void a(int i2, String str, ReactStylesDiffMap reactStylesDiffMap) {
        this.h.add(new UpdatePropertiesOperation(i2, reactStylesDiffMap));
    }

    public void a(int i2, int i3, int i4, int i5, int i6, int i7) {
        this.h.add(new UpdateLayoutOperation(i2, i3, i4, i5, i6, i7));
    }

    public void a(int i2, @Nullable int[] iArr, @Nullable ViewAtIndex[] viewAtIndexArr, @Nullable int[] iArr2) {
        this.h.add(new ManageChildrenOperation(i2, iArr, viewAtIndexArr, iArr2));
    }

    public void a(Animation animation) {
        this.h.add(new RegisterAnimationOperation(animation));
    }

    public void a(int i2, int i3, Callback callback) {
        this.h.add(new AddAnimationOperation(i2, i3, callback));
    }

    public void b(int i2) {
        this.h.add(new RemoveAnimationOperation(i2));
    }

    public void a(boolean z) {
        this.h.add(new SetLayoutAnimationEnabledOperation(z));
    }

    public void a(ReadableMap readableMap, Callback callback, Callback callback2) {
        this.h.add(new ConfigureLayoutAnimationOperation(readableMap));
    }

    public void a(int i2, Callback callback) {
        this.h.add(new MeasureOperation(i2, callback));
    }

    public void b(int i2, Callback callback) {
        this.h.add(new MeasureInWindowOperation(i2, callback));
    }

    public void a(int i2, float f2, float f3, Callback callback) {
        this.h.add(new FindTargetForTouchOperation(i2, f2, f3, callback));
    }

    public void a(int i2, int i3) {
        this.h.add(new SendAccessibilityEvent(i2, i3));
    }

    public void a(UIBlock uIBlock) {
        this.h.add(new UIBlockOperation(uIBlock));
    }

    public void b(UIBlock uIBlock) {
        this.h.add(0, new UIBlockOperation(uIBlock));
    }

    /* JADX INFO: finally extract failed */
    public void a(final int i2, final long j2, final long j3) {
        final ArrayList<UIOperation> arrayList;
        SystraceMessage.a(0, "UIViewOperationQueue.dispatchViewUpdates").a("batchId", i2).a();
        try {
            final long uptimeMillis = SystemClock.uptimeMillis();
            final ArrayDeque<UIOperation> arrayDeque = null;
            if (!this.h.isEmpty()) {
                ArrayList<UIOperation> arrayList2 = this.h;
                this.h = new ArrayList<>();
                arrayList = arrayList2;
            } else {
                arrayList = null;
            }
            synchronized (this.e) {
                if (!this.j.isEmpty()) {
                    arrayDeque = this.j;
                    this.j = new ArrayDeque<>();
                }
            }
            if (this.k != null) {
                this.k.c();
            }
            AnonymousClass1 r15 = new Runnable() {
                /* class com.facebook.react.uimanager.UIViewOperationQueue.AnonymousClass1 */

                public void run() {
                    SystraceMessage.a(0, "DispatchUI").a("BatchId", i2).a();
                    try {
                        long uptimeMillis = SystemClock.uptimeMillis();
                        if (arrayDeque != null) {
                            Iterator it = arrayDeque.iterator();
                            while (it.hasNext()) {
                                ((UIOperation) it.next()).a();
                            }
                        }
                        if (arrayList != null) {
                            Iterator it2 = arrayList.iterator();
                            while (it2.hasNext()) {
                                ((UIOperation) it2.next()).a();
                            }
                        }
                        if (UIViewOperationQueue.this.n && UIViewOperationQueue.this.p == 0) {
                            UIViewOperationQueue.this.p = j2;
                            UIViewOperationQueue.this.q = j3;
                            UIViewOperationQueue.this.r = uptimeMillis;
                            UIViewOperationQueue.this.s = uptimeMillis;
                            Systrace.a(0, "delayBeforeDispatchViewUpdates", 0, UIViewOperationQueue.this.p * 1000000);
                            Systrace.b(0, "delayBeforeDispatchViewUpdates", 0, UIViewOperationQueue.this.r * 1000000);
                            Systrace.a(0, "delayBeforeBatchRunStart", 0, UIViewOperationQueue.this.r * 1000000);
                            Systrace.b(0, "delayBeforeBatchRunStart", 0, UIViewOperationQueue.this.s * 1000000);
                        }
                        UIViewOperationQueue.this.b.c();
                        if (UIViewOperationQueue.this.k != null) {
                            UIViewOperationQueue.this.k.d();
                        }
                        Systrace.b(0);
                    } catch (Exception e2) {
                        UIViewOperationQueue.this.m = true;
                        throw e2;
                    } catch (Throwable th) {
                        Systrace.b(0);
                        throw th;
                    }
                }
            };
            SystraceMessage.a(0, "acquiring mDispatchRunnablesLock").a("batchId", i2).a();
            synchronized (this.d) {
                Systrace.b(0);
                this.i.add(r15);
            }
            if (!this.l) {
                UiThreadUtil.a(new GuardedRunnable(this.g) {
                    /* class com.facebook.react.uimanager.UIViewOperationQueue.AnonymousClass2 */

                    @Override // com.facebook.react.bridge.GuardedRunnable
                    public void a() {
                        UIViewOperationQueue.this.a();
                    }
                });
            }
            Systrace.b(0);
        } catch (Throwable th) {
            Systrace.b(0);
            throw th;
        }
    }

    /* access modifiers changed from: package-private */
    public void h() {
        this.l = true;
        ReactChoreographer.b().a(ReactChoreographer.CallbackType.DISPATCH_UI, this.f);
    }

    /* access modifiers changed from: package-private */
    public void i() {
        this.l = false;
        ReactChoreographer.b().b(ReactChoreographer.CallbackType.DISPATCH_UI, this.f);
        a();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0021, code lost:
        r2 = android.os.SystemClock.uptimeMillis();
        r0 = r1.iterator();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x002d, code lost:
        if (r0.hasNext() == false) goto L_0x0039;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x002f, code lost:
        r0.next().run();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x003d, code lost:
        if (r12.n == false) goto L_0x005f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x003f, code lost:
        r12.t = android.os.SystemClock.uptimeMillis() - r2;
        r12.u = r12.o;
        r12.n = false;
        com.facebook.systrace.Systrace.a(0, "batchedExecutionTime", 0, 1000000 * r2);
        com.facebook.systrace.Systrace.b(0, "batchedExecutionTime", 0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x005f, code lost:
        r12.o = 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0061, code lost:
        return;
     */
    private void a() {
        if (this.m) {
            FLog.c("ReactNative", "Not flushing pending UI operations because of previously thrown Exception");
            return;
        }
        synchronized (this.d) {
            if (!this.i.isEmpty()) {
                ArrayList<Runnable> arrayList = this.i;
                this.i = new ArrayList<>();
            }
        }
    }

    /* access modifiers changed from: private */
    public class DispatchUIFrameCallback extends GuardedFrameCallback {
        private final int b;

        private DispatchUIFrameCallback(ReactContext reactContext, int i) {
            super(reactContext);
            this.b = i;
        }

        /* JADX INFO: finally extract failed */
        @Override // com.facebook.react.uimanager.GuardedFrameCallback
        public void a(long j) {
            if (UIViewOperationQueue.this.m) {
                FLog.c("ReactNative", "Not flushing pending UI operations because of previously thrown Exception");
                return;
            }
            Systrace.a(0, "dispatchNonBatchedUIOperations");
            try {
                c(j);
                Systrace.b(0);
                UIViewOperationQueue.this.a();
                ReactChoreographer.b().a(ReactChoreographer.CallbackType.DISPATCH_UI, this);
            } catch (Throwable th) {
                Systrace.b(0);
                throw th;
            }
        }

        /* JADX WARNING: Code restructure failed: missing block: B:11:?, code lost:
            r2 = android.os.SystemClock.uptimeMillis();
            r1.a();
            r8.f2253a.o += android.os.SystemClock.uptimeMillis() - r2;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:12:0x0050, code lost:
            r9 = move-exception;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:13:0x0051, code lost:
            r8.f2253a.m = true;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:14:0x0057, code lost:
            throw r9;
         */
        private void c(long j) {
            while (16 - ((System.nanoTime() - j) / 1000000) >= ((long) this.b)) {
                synchronized (UIViewOperationQueue.this.e) {
                    if (!UIViewOperationQueue.this.j.isEmpty()) {
                        UIOperation uIOperation = (UIOperation) UIViewOperationQueue.this.j.pollFirst();
                    } else {
                        return;
                    }
                }
            }
        }
    }
}
