package com.facebook.react.uimanager;

import android.view.View;
import com.facebook.common.logging.FLog;
import com.facebook.react.bridge.ReadableMapKeySetIterator;
import com.facebook.react.uimanager.ViewManagersPropertyCache;
import java.util.HashMap;
import java.util.Map;

public class ViewManagerPropertyUpdater {

    /* renamed from: a  reason: collision with root package name */
    private static final Map<Class<?>, ViewManagerSetter<?, ?>> f2272a = new HashMap();
    private static final Map<Class<?>, ShadowNodeSetter<?>> b = new HashMap();

    public interface Settable {
        void a(Map<String, String> map);
    }

    public interface ShadowNodeSetter<T extends ReactShadowNode> extends Settable {
        void a(T t, String str, ReactStylesDiffMap reactStylesDiffMap);
    }

    public interface ViewManagerSetter<T extends ViewManager, V extends View> extends Settable {
        void a(T t, V v, String str, ReactStylesDiffMap reactStylesDiffMap);
    }

    public static void a() {
        ViewManagersPropertyCache.a();
        f2272a.clear();
        b.clear();
    }

    public static <T extends ViewManager, V extends View> void a(T t, V v, ReactStylesDiffMap reactStylesDiffMap) {
        ViewManagerSetter a2 = a(t.getClass());
        ReadableMapKeySetIterator a3 = reactStylesDiffMap.f2232a.a();
        while (a3.hasNextKey()) {
            a2.a(t, v, a3.nextKey(), reactStylesDiffMap);
        }
    }

    public static <T extends ReactShadowNode> void a(T t, ReactStylesDiffMap reactStylesDiffMap) {
        ShadowNodeSetter b2 = b(t.getClass());
        ReadableMapKeySetIterator a2 = reactStylesDiffMap.f2232a.a();
        while (a2.hasNextKey()) {
            b2.a(t, a2.nextKey(), reactStylesDiffMap);
        }
    }

    public static Map<String, String> a(Class<? extends ViewManager> cls, Class<? extends ReactShadowNode> cls2) {
        HashMap hashMap = new HashMap();
        a(cls).a(hashMap);
        b(cls2).a(hashMap);
        return hashMap;
    }

    private static <T extends ViewManager, V extends View> ViewManagerSetter<T, V> a(Class<? extends ViewManager> cls) {
        FallbackViewManagerSetter fallbackViewManagerSetter = (ViewManagerSetter<T, V>) f2272a.get(cls);
        if (fallbackViewManagerSetter == null) {
            fallbackViewManagerSetter = (ViewManagerSetter) c(cls);
            if (fallbackViewManagerSetter == null) {
                fallbackViewManagerSetter = new FallbackViewManagerSetter(cls);
            }
            f2272a.put(cls, fallbackViewManagerSetter);
        }
        return fallbackViewManagerSetter;
    }

    private static <T extends ReactShadowNode> ShadowNodeSetter<T> b(Class<? extends ReactShadowNode> cls) {
        FallbackShadowNodeSetter fallbackShadowNodeSetter = (ShadowNodeSetter<T>) b.get(cls);
        if (fallbackShadowNodeSetter == null) {
            fallbackShadowNodeSetter = (ShadowNodeSetter) c(cls);
            if (fallbackShadowNodeSetter == null) {
                fallbackShadowNodeSetter = new FallbackShadowNodeSetter(cls);
            }
            b.put(cls, fallbackShadowNodeSetter);
        }
        return fallbackShadowNodeSetter;
    }

    private static <T> T c(Class<?> cls) {
        String name = cls.getName();
        try {
            return (T) Class.forName(name + "$$PropsSetter").newInstance();
        } catch (ClassNotFoundException unused) {
            FLog.c("ViewManagerPropertyUpdater", "Could not find generated setter for " + cls);
            return null;
        } catch (IllegalAccessException | InstantiationException e) {
            throw new RuntimeException("Unable to instantiate methods getter for " + name, e);
        }
    }

    /* access modifiers changed from: private */
    public static class FallbackViewManagerSetter<T extends ViewManager, V extends View> implements ViewManagerSetter<T, V> {

        /* renamed from: a  reason: collision with root package name */
        private final Map<String, ViewManagersPropertyCache.PropSetter> f2274a;

        private FallbackViewManagerSetter(Class<? extends ViewManager> cls) {
            this.f2274a = ViewManagersPropertyCache.a(cls);
        }

        @Override // com.facebook.react.uimanager.ViewManagerPropertyUpdater.ViewManagerSetter
        public void a(T t, V v, String str, ReactStylesDiffMap reactStylesDiffMap) {
            ViewManagersPropertyCache.PropSetter propSetter = this.f2274a.get(str);
            if (propSetter != null) {
                propSetter.a(t, v, reactStylesDiffMap);
            }
        }

        @Override // com.facebook.react.uimanager.ViewManagerPropertyUpdater.Settable
        public void a(Map<String, String> map) {
            for (ViewManagersPropertyCache.PropSetter propSetter : this.f2274a.values()) {
                map.put(propSetter.a(), propSetter.b());
            }
        }
    }

    /* access modifiers changed from: private */
    public static class FallbackShadowNodeSetter<T extends ReactShadowNode> implements ShadowNodeSetter<T> {

        /* renamed from: a  reason: collision with root package name */
        private final Map<String, ViewManagersPropertyCache.PropSetter> f2273a;

        private FallbackShadowNodeSetter(Class<? extends ReactShadowNode> cls) {
            this.f2273a = ViewManagersPropertyCache.b(cls);
        }

        @Override // com.facebook.react.uimanager.ViewManagerPropertyUpdater.ShadowNodeSetter
        public void a(ReactShadowNode reactShadowNode, String str, ReactStylesDiffMap reactStylesDiffMap) {
            ViewManagersPropertyCache.PropSetter propSetter = this.f2273a.get(str);
            if (propSetter != null) {
                propSetter.a(reactShadowNode, reactStylesDiffMap);
            }
        }

        @Override // com.facebook.react.uimanager.ViewManagerPropertyUpdater.Settable
        public void a(Map<String, String> map) {
            for (ViewManagersPropertyCache.PropSetter propSetter : this.f2273a.values()) {
                map.put(propSetter.a(), propSetter.b());
            }
        }
    }
}
