package com.facebook.react.uimanager;

import android.view.View;
import com.facebook.common.logging.FLog;
import com.facebook.react.bridge.Dynamic;
import com.facebook.react.bridge.JSApplicationIllegalArgumentException;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.uimanager.annotations.ReactProp;
import com.facebook.react.uimanager.annotations.ReactPropGroup;
import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import javax.annotation.Nullable;

/* access modifiers changed from: package-private */
public class ViewManagersPropertyCache {

    /* renamed from: a  reason: collision with root package name */
    private static final Map<Class, Map<String, PropSetter>> f2276a = new HashMap();
    private static final Map<String, PropSetter> b = new HashMap();

    ViewManagersPropertyCache() {
    }

    public static void a() {
        f2276a.clear();
        b.clear();
    }

    /* access modifiers changed from: package-private */
    public static abstract class PropSetter {
        private static final Object[] e = new Object[2];
        private static final Object[] f = new Object[3];
        private static final Object[] g = new Object[1];
        private static final Object[] h = new Object[2];

        /* renamed from: a  reason: collision with root package name */
        protected final String f2277a;
        protected final String b;
        protected final Method c;
        @Nullable
        protected final Integer d;

        /* access modifiers changed from: protected */
        @Nullable
        public abstract Object a(ReactStylesDiffMap reactStylesDiffMap);

        private PropSetter(ReactProp reactProp, String str, Method method) {
            this.f2277a = reactProp.a();
            this.b = !"__default_type__".equals(reactProp.b()) ? reactProp.b() : str;
            this.c = method;
            this.d = null;
        }

        private PropSetter(ReactPropGroup reactPropGroup, String str, Method method, int i) {
            this.f2277a = reactPropGroup.a()[i];
            this.b = !"__default_type__".equals(reactPropGroup.b()) ? reactPropGroup.b() : str;
            this.c = method;
            this.d = Integer.valueOf(i);
        }

        public String a() {
            return this.f2277a;
        }

        public String b() {
            return this.b;
        }

        public void a(ViewManager viewManager, View view, ReactStylesDiffMap reactStylesDiffMap) {
            try {
                if (this.d == null) {
                    e[0] = view;
                    e[1] = a(reactStylesDiffMap);
                    this.c.invoke(viewManager, e);
                    Arrays.fill(e, (Object) null);
                    return;
                }
                f[0] = view;
                f[1] = this.d;
                f[2] = a(reactStylesDiffMap);
                this.c.invoke(viewManager, f);
                Arrays.fill(f, (Object) null);
            } catch (Throwable th) {
                FLog.b((Class<?>) ViewManager.class, "Error while updating prop " + this.f2277a, th);
                throw new JSApplicationIllegalArgumentException("Error while updating property '" + this.f2277a + "' of a view managed by: " + viewManager.getName(), th);
            }
        }

        public void a(ReactShadowNode reactShadowNode, ReactStylesDiffMap reactStylesDiffMap) {
            try {
                if (this.d == null) {
                    g[0] = a(reactStylesDiffMap);
                    this.c.invoke(reactShadowNode, g);
                    Arrays.fill(g, (Object) null);
                    return;
                }
                h[0] = this.d;
                h[1] = a(reactStylesDiffMap);
                this.c.invoke(reactShadowNode, h);
                Arrays.fill(h, (Object) null);
            } catch (Throwable th) {
                FLog.b((Class<?>) ViewManager.class, "Error while updating prop " + this.f2277a, th);
                throw new JSApplicationIllegalArgumentException("Error while updating property '" + this.f2277a + "' in shadow node of type: " + reactShadowNode.N(), th);
            }
        }
    }

    /* access modifiers changed from: private */
    public static class DynamicPropSetter extends PropSetter {
        public DynamicPropSetter(ReactProp reactProp, Method method) {
            super(reactProp, "mixed", method);
        }

        public DynamicPropSetter(ReactPropGroup reactPropGroup, Method method, int i) {
            super(reactPropGroup, "mixed", method, i);
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.react.uimanager.ViewManagersPropertyCache.PropSetter
        public Object a(ReactStylesDiffMap reactStylesDiffMap) {
            return reactStylesDiffMap.f(this.f2277a);
        }
    }

    /* access modifiers changed from: private */
    public static class IntPropSetter extends PropSetter {
        private final int e;

        public IntPropSetter(ReactProp reactProp, Method method, int i) {
            super(reactProp, "number", method);
            this.e = i;
        }

        public IntPropSetter(ReactPropGroup reactPropGroup, Method method, int i, int i2) {
            super(reactPropGroup, "number", method, i);
            this.e = i2;
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.react.uimanager.ViewManagersPropertyCache.PropSetter
        public Object a(ReactStylesDiffMap reactStylesDiffMap) {
            return Integer.valueOf(reactStylesDiffMap.a(this.f2277a, this.e));
        }
    }

    /* access modifiers changed from: private */
    public static class DoublePropSetter extends PropSetter {
        private final double e;

        public DoublePropSetter(ReactProp reactProp, Method method, double d) {
            super(reactProp, "number", method);
            this.e = d;
        }

        public DoublePropSetter(ReactPropGroup reactPropGroup, Method method, int i, double d) {
            super(reactPropGroup, "number", method, i);
            this.e = d;
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.react.uimanager.ViewManagersPropertyCache.PropSetter
        public Object a(ReactStylesDiffMap reactStylesDiffMap) {
            return Double.valueOf(reactStylesDiffMap.a(this.f2277a, this.e));
        }
    }

    /* access modifiers changed from: private */
    public static class BooleanPropSetter extends PropSetter {
        private final boolean e;

        public BooleanPropSetter(ReactProp reactProp, Method method, boolean z) {
            super(reactProp, "boolean", method);
            this.e = z;
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.react.uimanager.ViewManagersPropertyCache.PropSetter
        public Object a(ReactStylesDiffMap reactStylesDiffMap) {
            return reactStylesDiffMap.a(this.f2277a, this.e) ? Boolean.TRUE : Boolean.FALSE;
        }
    }

    /* access modifiers changed from: private */
    public static class FloatPropSetter extends PropSetter {
        private final float e;

        public FloatPropSetter(ReactProp reactProp, Method method, float f) {
            super(reactProp, "number", method);
            this.e = f;
        }

        public FloatPropSetter(ReactPropGroup reactPropGroup, Method method, int i, float f) {
            super(reactPropGroup, "number", method, i);
            this.e = f;
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.react.uimanager.ViewManagersPropertyCache.PropSetter
        public Object a(ReactStylesDiffMap reactStylesDiffMap) {
            return Float.valueOf(reactStylesDiffMap.a(this.f2277a, this.e));
        }
    }

    /* access modifiers changed from: private */
    public static class ArrayPropSetter extends PropSetter {
        public ArrayPropSetter(ReactProp reactProp, Method method) {
            super(reactProp, "Array", method);
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.react.uimanager.ViewManagersPropertyCache.PropSetter
        @Nullable
        public Object a(ReactStylesDiffMap reactStylesDiffMap) {
            return reactStylesDiffMap.d(this.f2277a);
        }
    }

    /* access modifiers changed from: private */
    public static class MapPropSetter extends PropSetter {
        public MapPropSetter(ReactProp reactProp, Method method) {
            super(reactProp, "Map", method);
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.react.uimanager.ViewManagersPropertyCache.PropSetter
        @Nullable
        public Object a(ReactStylesDiffMap reactStylesDiffMap) {
            return reactStylesDiffMap.e(this.f2277a);
        }
    }

    /* access modifiers changed from: private */
    public static class StringPropSetter extends PropSetter {
        public StringPropSetter(ReactProp reactProp, Method method) {
            super(reactProp, "String", method);
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.react.uimanager.ViewManagersPropertyCache.PropSetter
        @Nullable
        public Object a(ReactStylesDiffMap reactStylesDiffMap) {
            return reactStylesDiffMap.c(this.f2277a);
        }
    }

    /* access modifiers changed from: private */
    public static class BoxedBooleanPropSetter extends PropSetter {
        public BoxedBooleanPropSetter(ReactProp reactProp, Method method) {
            super(reactProp, "boolean", method);
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.react.uimanager.ViewManagersPropertyCache.PropSetter
        @Nullable
        public Object a(ReactStylesDiffMap reactStylesDiffMap) {
            if (!reactStylesDiffMap.b(this.f2277a)) {
                return reactStylesDiffMap.a(this.f2277a, false) ? Boolean.TRUE : Boolean.FALSE;
            }
            return null;
        }
    }

    /* access modifiers changed from: private */
    public static class BoxedIntPropSetter extends PropSetter {
        public BoxedIntPropSetter(ReactProp reactProp, Method method) {
            super(reactProp, "number", method);
        }

        public BoxedIntPropSetter(ReactPropGroup reactPropGroup, Method method, int i) {
            super(reactPropGroup, "number", method, i);
        }

        /* access modifiers changed from: protected */
        @Override // com.facebook.react.uimanager.ViewManagersPropertyCache.PropSetter
        @Nullable
        public Object a(ReactStylesDiffMap reactStylesDiffMap) {
            if (!reactStylesDiffMap.b(this.f2277a)) {
                return Integer.valueOf(reactStylesDiffMap.a(this.f2277a, 0));
            }
            return null;
        }
    }

    static Map<String, PropSetter> a(Class<? extends ViewManager> cls) {
        if (cls == ViewManager.class) {
            return b;
        }
        Map<String, PropSetter> map = f2276a.get(cls);
        if (map != null) {
            return map;
        }
        HashMap hashMap = new HashMap(a(cls.getSuperclass()));
        a(cls, hashMap);
        f2276a.put(cls, hashMap);
        return hashMap;
    }

    static Map<String, PropSetter> b(Class<? extends ReactShadowNode> cls) {
        for (Class<?> cls2 : cls.getInterfaces()) {
            if (cls2 == ReactShadowNode.class) {
                return b;
            }
        }
        Map<String, PropSetter> map = f2276a.get(cls);
        if (map != null) {
            return map;
        }
        HashMap hashMap = new HashMap(b(cls.getSuperclass()));
        b(cls, hashMap);
        f2276a.put(cls, hashMap);
        return hashMap;
    }

    private static PropSetter a(ReactProp reactProp, Method method, Class<?> cls) {
        if (cls == Dynamic.class) {
            return new DynamicPropSetter(reactProp, method);
        }
        if (cls == Boolean.TYPE) {
            return new BooleanPropSetter(reactProp, method, reactProp.f());
        }
        if (cls == Integer.TYPE) {
            return new IntPropSetter(reactProp, method, reactProp.e());
        }
        if (cls == Float.TYPE) {
            return new FloatPropSetter(reactProp, method, reactProp.d());
        }
        if (cls == Double.TYPE) {
            return new DoublePropSetter(reactProp, method, reactProp.c());
        }
        if (cls == String.class) {
            return new StringPropSetter(reactProp, method);
        }
        if (cls == Boolean.class) {
            return new BoxedBooleanPropSetter(reactProp, method);
        }
        if (cls == Integer.class) {
            return new BoxedIntPropSetter(reactProp, method);
        }
        if (cls == ReadableArray.class) {
            return new ArrayPropSetter(reactProp, method);
        }
        if (cls == ReadableMap.class) {
            return new MapPropSetter(reactProp, method);
        }
        throw new RuntimeException("Unrecognized type: " + cls + " for method: " + method.getDeclaringClass().getName() + "#" + method.getName());
    }

    private static void a(ReactPropGroup reactPropGroup, Method method, Class<?> cls, Map<String, PropSetter> map) {
        String[] a2 = reactPropGroup.a();
        int i = 0;
        if (cls == Dynamic.class) {
            while (i < a2.length) {
                map.put(a2[i], new DynamicPropSetter(reactPropGroup, method, i));
                i++;
            }
        } else if (cls == Integer.TYPE) {
            while (i < a2.length) {
                map.put(a2[i], new IntPropSetter(reactPropGroup, method, i, reactPropGroup.e()));
                i++;
            }
        } else if (cls == Float.TYPE) {
            while (i < a2.length) {
                map.put(a2[i], new FloatPropSetter(reactPropGroup, method, i, reactPropGroup.c()));
                i++;
            }
        } else if (cls == Double.TYPE) {
            while (i < a2.length) {
                map.put(a2[i], new DoublePropSetter(reactPropGroup, method, i, reactPropGroup.d()));
                i++;
            }
        } else if (cls == Integer.class) {
            while (i < a2.length) {
                map.put(a2[i], new BoxedIntPropSetter(reactPropGroup, method, i));
                i++;
            }
        } else {
            throw new RuntimeException("Unrecognized type: " + cls + " for method: " + method.getDeclaringClass().getName() + "#" + method.getName());
        }
    }

    private static void a(Class<? extends ViewManager> cls, Map<String, PropSetter> map) {
        Method[] declaredMethods = cls.getDeclaredMethods();
        for (Method method : declaredMethods) {
            ReactProp reactProp = (ReactProp) method.getAnnotation(ReactProp.class);
            if (reactProp != null) {
                Class<?>[] parameterTypes = method.getParameterTypes();
                if (parameterTypes.length != 2) {
                    throw new RuntimeException("Wrong number of args for prop setter: " + cls.getName() + "#" + method.getName());
                } else if (View.class.isAssignableFrom(parameterTypes[0])) {
                    map.put(reactProp.a(), a(reactProp, method, parameterTypes[1]));
                } else {
                    throw new RuntimeException("First param should be a view subclass to be updated: " + cls.getName() + "#" + method.getName());
                }
            }
            ReactPropGroup reactPropGroup = (ReactPropGroup) method.getAnnotation(ReactPropGroup.class);
            if (reactPropGroup != null) {
                Class<?>[] parameterTypes2 = method.getParameterTypes();
                if (parameterTypes2.length != 3) {
                    throw new RuntimeException("Wrong number of args for group prop setter: " + cls.getName() + "#" + method.getName());
                } else if (!View.class.isAssignableFrom(parameterTypes2[0])) {
                    throw new RuntimeException("First param should be a view subclass to be updated: " + cls.getName() + "#" + method.getName());
                } else if (parameterTypes2[1] == Integer.TYPE) {
                    a(reactPropGroup, method, parameterTypes2[2], map);
                } else {
                    throw new RuntimeException("Second argument should be property index: " + cls.getName() + "#" + method.getName());
                }
            }
        }
    }

    private static void b(Class<? extends ReactShadowNode> cls, Map<String, PropSetter> map) {
        Method[] declaredMethods = cls.getDeclaredMethods();
        for (Method method : declaredMethods) {
            ReactProp reactProp = (ReactProp) method.getAnnotation(ReactProp.class);
            if (reactProp != null) {
                Class<?>[] parameterTypes = method.getParameterTypes();
                if (parameterTypes.length == 1) {
                    map.put(reactProp.a(), a(reactProp, method, parameterTypes[0]));
                } else {
                    throw new RuntimeException("Wrong number of args for prop setter: " + cls.getName() + "#" + method.getName());
                }
            }
            ReactPropGroup reactPropGroup = (ReactPropGroup) method.getAnnotation(ReactPropGroup.class);
            if (reactPropGroup != null) {
                Class<?>[] parameterTypes2 = method.getParameterTypes();
                if (parameterTypes2.length != 2) {
                    throw new RuntimeException("Wrong number of args for group prop setter: " + cls.getName() + "#" + method.getName());
                } else if (parameterTypes2[0] == Integer.TYPE) {
                    a(reactPropGroup, method, parameterTypes2[1], map);
                } else {
                    throw new RuntimeException("Second argument should be property index: " + cls.getName() + "#" + method.getName());
                }
            }
        }
    }
}
