package com.facebook.react.views.picker;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.SpinnerAdapter;
import android.widget.TextView;
import com.facebook.infer.annotation.Assertions;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.uimanager.SimpleViewManager;
import com.facebook.react.uimanager.ThemedReactContext;
import com.facebook.react.uimanager.UIManagerModule;
import com.facebook.react.uimanager.annotations.ReactProp;
import com.facebook.react.uimanager.events.EventDispatcher;
import com.facebook.react.views.picker.ReactPicker;
import com.facebook.react.views.picker.events.PickerItemSelectEvent;
import javax.annotation.Nullable;

public abstract class ReactPickerManager extends SimpleViewManager<ReactPicker> {
    @ReactProp(a = "items")
    public void setItems(ReactPicker reactPicker, @Nullable ReadableArray readableArray) {
        if (readableArray != null) {
            ReadableMap[] readableMapArr = new ReadableMap[readableArray.a()];
            for (int i = 0; i < readableArray.a(); i++) {
                readableMapArr[i] = readableArray.i(i);
            }
            ReactPickerAdapter reactPickerAdapter = new ReactPickerAdapter(reactPicker.getContext(), readableMapArr);
            reactPickerAdapter.a(reactPicker.getPrimaryColor());
            reactPicker.setAdapter((SpinnerAdapter) reactPickerAdapter);
            return;
        }
        reactPicker.setAdapter((SpinnerAdapter) null);
    }

    @ReactProp(a = "color", b = "Color")
    public void setColor(ReactPicker reactPicker, @Nullable Integer num) {
        reactPicker.setPrimaryColor(num);
        ReactPickerAdapter reactPickerAdapter = (ReactPickerAdapter) reactPicker.getAdapter();
        if (reactPickerAdapter != null) {
            reactPickerAdapter.a(num);
        }
    }

    @ReactProp(a = "prompt")
    public void setPrompt(ReactPicker reactPicker, @Nullable String str) {
        reactPicker.setPrompt(str);
    }

    @ReactProp(a = "enabled", f = true)
    public void setEnabled(ReactPicker reactPicker, boolean z) {
        reactPicker.setEnabled(z);
    }

    @ReactProp(a = "selected")
    public void setSelected(ReactPicker reactPicker, int i) {
        reactPicker.setStagedSelection(i);
    }

    /* access modifiers changed from: protected */
    public void onAfterUpdateTransaction(ReactPicker reactPicker) {
        super.onAfterUpdateTransaction((View) reactPicker);
        reactPicker.a();
    }

    /* access modifiers changed from: protected */
    public void addEventEmitters(ThemedReactContext themedReactContext, ReactPicker reactPicker) {
        reactPicker.setOnSelectListener(new PickerEventEmitter(reactPicker, ((UIManagerModule) themedReactContext.b(UIManagerModule.class)).getEventDispatcher()));
    }

    private static class ReactPickerAdapter extends ArrayAdapter<ReadableMap> {

        /* renamed from: a  reason: collision with root package name */
        private final LayoutInflater f2331a;
        @Nullable
        private Integer b;

        public ReactPickerAdapter(Context context, ReadableMap[] readableMapArr) {
            super(context, 0, readableMapArr);
            this.f2331a = (LayoutInflater) Assertions.b(context.getSystemService("layout_inflater"));
        }

        public View getView(int i, View view, ViewGroup viewGroup) {
            return a(i, view, viewGroup, false);
        }

        public View getDropDownView(int i, View view, ViewGroup viewGroup) {
            return a(i, view, viewGroup, true);
        }

        private View a(int i, View view, ViewGroup viewGroup, boolean z) {
            ReadableMap readableMap = (ReadableMap) getItem(i);
            if (view == null) {
                view = this.f2331a.inflate(z ? 17367049 : 17367048, viewGroup, false);
            }
            TextView textView = (TextView) view;
            textView.setText(readableMap.f("label"));
            if (!z && this.b != null) {
                textView.setTextColor(this.b.intValue());
            } else if (readableMap.a("color") && !readableMap.b("color")) {
                textView.setTextColor(readableMap.e("color"));
            }
            return view;
        }

        public void a(@Nullable Integer num) {
            this.b = num;
            notifyDataSetChanged();
        }
    }

    /* access modifiers changed from: private */
    public static class PickerEventEmitter implements ReactPicker.OnSelectListener {

        /* renamed from: a  reason: collision with root package name */
        private final ReactPicker f2330a;
        private final EventDispatcher b;

        public PickerEventEmitter(ReactPicker reactPicker, EventDispatcher eventDispatcher) {
            this.f2330a = reactPicker;
            this.b = eventDispatcher;
        }

        @Override // com.facebook.react.views.picker.ReactPicker.OnSelectListener
        public void a(int i) {
            this.b.a(new PickerItemSelectEvent(this.f2330a.getId(), i));
        }
    }
}
