package com.facebook.react.views.textinput;

import android.content.Context;
import android.graphics.Rect;
import android.graphics.Typeface;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.text.Editable;
import android.text.SpannableStringBuilder;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.text.method.KeyListener;
import android.text.method.QwertyKeyListener;
import android.text.style.AbsoluteSizeSpan;
import android.text.style.BackgroundColorSpan;
import android.text.style.ForegroundColorSpan;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.inputmethod.EditorInfo;
import android.view.inputmethod.InputConnection;
import android.view.inputmethod.InputMethodManager;
import android.widget.EditText;
import com.facebook.infer.annotation.Assertions;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.uimanager.PixelUtil;
import com.facebook.react.uimanager.UIManagerModule;
import com.facebook.react.views.text.CustomStyleSpan;
import com.facebook.react.views.text.ReactTagSpan;
import com.facebook.react.views.text.ReactTextUpdate;
import com.facebook.react.views.text.TextInlineImageSpan;
import com.facebook.react.views.view.ReactViewBackgroundManager;
import com.tencent.smtt.sdk.TbsListener;
import java.util.ArrayList;
import java.util.Iterator;
import javax.annotation.Nullable;

public class ReactEditText extends EditText {
    private static final KeyListener v = QwertyKeyListener.getInstanceForFullKeyboard();

    /* renamed from: a  reason: collision with root package name */
    private final InputMethodManager f2370a;
    private boolean b;
    private boolean c;
    private int d;
    private int e;
    private int f;
    private int g;
    @Nullable
    private ArrayList<TextWatcher> h;
    @Nullable
    private TextWatcherDelegator i;
    private int j;
    private boolean k;
    @Nullable
    private Boolean l;
    private boolean m;
    @Nullable
    private String n;
    @Nullable
    private SelectionWatcher o;
    @Nullable
    private ContentSizeWatcher p;
    @Nullable
    private ScrollWatcher q;
    private final InternalKeyListener r;
    private boolean s = false;
    private float t = 0.0f;
    private ReactViewBackgroundManager u;

    public boolean isLayoutRequested() {
        return false;
    }

    public ReactEditText(Context context) {
        super(context);
        setFocusableInTouchMode(false);
        this.u = new ReactViewBackgroundManager(this);
        this.f2370a = (InputMethodManager) Assertions.b(getContext().getSystemService("input_method"));
        this.d = getGravity() & 8388615;
        this.e = getGravity() & 112;
        this.f = 0;
        this.g = 0;
        this.b = false;
        this.c = false;
        this.l = null;
        this.m = false;
        this.h = null;
        this.i = null;
        this.j = getInputType();
        this.r = new InternalKeyListener();
        this.q = null;
    }

    /* access modifiers changed from: protected */
    public void onLayout(boolean z, int i2, int i3, int i4, int i5) {
        k();
    }

    public boolean onTouchEvent(MotionEvent motionEvent) {
        int action = motionEvent.getAction();
        if (action == 0) {
            this.s = true;
            getParent().requestDisallowInterceptTouchEvent(true);
        } else if (action == 2 && this.s) {
            if (!canScrollVertically(-1) && !canScrollVertically(1) && !canScrollHorizontally(-1) && !canScrollHorizontally(1)) {
                getParent().requestDisallowInterceptTouchEvent(false);
            }
            this.s = false;
        }
        return super.onTouchEvent(motionEvent);
    }

    public boolean onKeyUp(int i2, KeyEvent keyEvent) {
        if (i2 != 66 || i()) {
            return super.onKeyUp(i2, keyEvent);
        }
        h();
        return true;
    }

    /* access modifiers changed from: protected */
    public void onScrollChanged(int i2, int i3, int i4, int i5) {
        super.onScrollChanged(i2, i3, i4, i5);
        if (this.q != null) {
            this.q.a(i2, i3, i4, i5);
        }
    }

    public InputConnection onCreateInputConnection(EditorInfo editorInfo) {
        ReactContext reactContext = (ReactContext) getContext();
        InputConnection onCreateInputConnection = super.onCreateInputConnection(editorInfo);
        if (onCreateInputConnection != null) {
            onCreateInputConnection = new ReactEditTextInputConnectionWrapper(onCreateInputConnection, reactContext, this);
        }
        if (i() && getBlurOnSubmit()) {
            editorInfo.imeOptions &= -1073741825;
        }
        return onCreateInputConnection;
    }

    public void clearFocus() {
        setFocusableInTouchMode(false);
        super.clearFocus();
        h();
    }

    public boolean requestFocus(int i2, Rect rect) {
        if (isFocused()) {
            return true;
        }
        if (!this.c) {
            return false;
        }
        setFocusableInTouchMode(true);
        boolean requestFocus = super.requestFocus(i2, rect);
        g();
        return requestFocus;
    }

    public void addTextChangedListener(TextWatcher textWatcher) {
        if (this.h == null) {
            this.h = new ArrayList<>();
            super.addTextChangedListener(getTextWatcherDelegator());
        }
        this.h.add(textWatcher);
    }

    public void removeTextChangedListener(TextWatcher textWatcher) {
        if (this.h != null) {
            this.h.remove(textWatcher);
            if (this.h.isEmpty()) {
                this.h = null;
                super.removeTextChangedListener(getTextWatcherDelegator());
            }
        }
    }

    public void setContentSizeWatcher(ContentSizeWatcher contentSizeWatcher) {
        this.p = contentSizeWatcher;
    }

    public void setScrollWatcher(ScrollWatcher scrollWatcher) {
        this.q = scrollWatcher;
    }

    public void setSelection(int i2, int i3) {
        if (this.g >= this.f) {
            super.setSelection(i2, i3);
        }
    }

    /* access modifiers changed from: protected */
    public void onSelectionChanged(int i2, int i3) {
        super.onSelectionChanged(i2, i3);
        if (this.o != null && hasFocus()) {
            this.o.a(i2, i3);
        }
    }

    /* access modifiers changed from: protected */
    public void onFocusChanged(boolean z, int i2, Rect rect) {
        super.onFocusChanged(z, i2, rect);
        if (z && this.o != null) {
            this.o.a(getSelectionStart(), getSelectionEnd());
        }
    }

    public void setSelectionWatcher(SelectionWatcher selectionWatcher) {
        this.o = selectionWatcher;
    }

    public void setBlurOnSubmit(@Nullable Boolean bool) {
        this.l = bool;
    }

    public boolean getBlurOnSubmit() {
        if (this.l == null) {
            return !i();
        }
        return this.l.booleanValue();
    }

    public void setDisableFullscreenUI(boolean z) {
        this.m = z;
        m();
    }

    public boolean getDisableFullscreenUI() {
        return this.m;
    }

    public void setReturnKeyType(String str) {
        this.n = str;
        m();
    }

    public String getReturnKeyType() {
        return this.n;
    }

    /* access modifiers changed from: package-private */
    public int getStagedInputType() {
        return this.j;
    }

    /* access modifiers changed from: package-private */
    public void setStagedInputType(int i2) {
        this.j = i2;
    }

    /* access modifiers changed from: package-private */
    public void a() {
        if (getInputType() != this.j) {
            int selectionStart = getSelectionStart();
            int selectionEnd = getSelectionEnd();
            setInputType(this.j);
            setSelection(selectionStart, selectionEnd);
        }
    }

    public void setInputType(int i2) {
        Typeface typeface = super.getTypeface();
        super.setInputType(i2);
        this.j = i2;
        super.setTypeface(typeface);
        this.r.a(i2);
        setKeyListener(this.r);
    }

    public void b() {
        this.c = true;
        requestFocus();
        this.c = false;
    }

    /* access modifiers changed from: package-private */
    public void c() {
        clearFocus();
    }

    public int d() {
        int i2 = this.f + 1;
        this.f = i2;
        return i2;
    }

    public void a(ReactTextUpdate reactTextUpdate) {
        if (!j() || !TextUtils.equals(getText(), reactTextUpdate.a())) {
            this.g = reactTextUpdate.b();
            if (this.g >= this.f) {
                SpannableStringBuilder spannableStringBuilder = new SpannableStringBuilder(reactTextUpdate.a());
                a(spannableStringBuilder);
                this.k = reactTextUpdate.c();
                this.b = true;
                getText().replace(0, length(), spannableStringBuilder);
                this.b = false;
                if (Build.VERSION.SDK_INT >= 23 && getBreakStrategy() != reactTextUpdate.i()) {
                    setBreakStrategy(reactTextUpdate.i());
                }
            }
        }
    }

    private void a(SpannableStringBuilder spannableStringBuilder) {
        Object[] spans = getText().getSpans(0, length(), Object.class);
        for (int i2 = 0; i2 < spans.length; i2++) {
            if (ForegroundColorSpan.class.isInstance(spans[i2]) || BackgroundColorSpan.class.isInstance(spans[i2]) || AbsoluteSizeSpan.class.isInstance(spans[i2]) || CustomStyleSpan.class.isInstance(spans[i2]) || ReactTagSpan.class.isInstance(spans[i2])) {
                getText().removeSpan(spans[i2]);
            }
            if ((getText().getSpanFlags(spans[i2]) & 33) == 33) {
                Object obj = spans[i2];
                int spanStart = getText().getSpanStart(spans[i2]);
                int spanEnd = getText().getSpanEnd(spans[i2]);
                int spanFlags = getText().getSpanFlags(spans[i2]);
                getText().removeSpan(spans[i2]);
                if (a(getText(), spannableStringBuilder, spanStart, spanEnd)) {
                    spannableStringBuilder.setSpan(obj, spanStart, spanEnd, spanFlags);
                }
            }
        }
    }

    private static boolean a(Editable editable, SpannableStringBuilder spannableStringBuilder, int i2, int i3) {
        if (i2 > spannableStringBuilder.length() || i3 > spannableStringBuilder.length()) {
            return false;
        }
        while (i2 < i3) {
            if (editable.charAt(i2) != spannableStringBuilder.charAt(i2)) {
                return false;
            }
            i2++;
        }
        return true;
    }

    private boolean g() {
        return this.f2370a.showSoftInput(this, 0);
    }

    private void h() {
        this.f2370a.hideSoftInputFromWindow(getWindowToken(), 0);
    }

    private TextWatcherDelegator getTextWatcherDelegator() {
        if (this.i == null) {
            this.i = new TextWatcherDelegator();
        }
        return this.i;
    }

    private boolean i() {
        return (getInputType() & 131072) != 0;
    }

    private boolean j() {
        return (getInputType() & TbsListener.ErrorCode.NEEDDOWNLOAD_5) != 0;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void k() {
        if (this.p != null) {
            this.p.a();
        }
        l();
    }

    private void l() {
        ((UIManagerModule) ((ReactContext) getContext()).b(UIManagerModule.class)).setViewLocalData(getId(), new ReactTextInputLocalData(this));
    }

    /* access modifiers changed from: package-private */
    public void setGravityHorizontal(int i2) {
        if (i2 == 0) {
            i2 = this.d;
        }
        setGravity(i2 | (getGravity() & -8 & -8388616));
    }

    /* access modifiers changed from: package-private */
    public void setGravityVertical(int i2) {
        if (i2 == 0) {
            i2 = this.e;
        }
        setGravity(i2 | (getGravity() & -113));
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x006f  */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x0076  */
    private void m() {
        char c2;
        int i2 = 4;
        if (this.n != null) {
            String str = this.n;
            switch (str.hashCode()) {
                case -1273775369:
                    if (str.equals("previous")) {
                        c2 = 3;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -906336856:
                    if (str.equals("search")) {
                        c2 = 4;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3304:
                    if (str.equals("go")) {
                        c2 = 0;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3089282:
                    if (str.equals("done")) {
                        c2 = 6;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3377907:
                    if (str.equals("next")) {
                        c2 = 1;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3387192:
                    if (str.equals("none")) {
                        c2 = 2;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3526536:
                    if (str.equals("send")) {
                        c2 = 5;
                        break;
                    }
                    c2 = 65535;
                    break;
                default:
                    c2 = 65535;
                    break;
            }
            switch (c2) {
                case 0:
                    i2 = 2;
                    break;
                case 1:
                    i2 = 5;
                    break;
                case 2:
                    i2 = 1;
                    break;
                case 3:
                    i2 = 7;
                    break;
                case 4:
                    i2 = 3;
                    break;
            }
            if (!this.m) {
                setImeOptions(33554432 | i2);
                return;
            } else {
                setImeOptions(i2);
                return;
            }
        }
        i2 = 6;
        if (!this.m) {
        }
    }

    /* access modifiers changed from: protected */
    public boolean verifyDrawable(Drawable drawable) {
        if (this.k) {
            Editable text = getText();
            for (TextInlineImageSpan textInlineImageSpan : (TextInlineImageSpan[]) text.getSpans(0, text.length(), TextInlineImageSpan.class)) {
                if (textInlineImageSpan.a() == drawable) {
                    return true;
                }
            }
        }
        return super.verifyDrawable(drawable);
    }

    public void invalidateDrawable(Drawable drawable) {
        if (this.k) {
            Editable text = getText();
            for (TextInlineImageSpan textInlineImageSpan : (TextInlineImageSpan[]) text.getSpans(0, text.length(), TextInlineImageSpan.class)) {
                if (textInlineImageSpan.a() == drawable) {
                    invalidate();
                }
            }
        }
        super.invalidateDrawable(drawable);
    }

    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        if (this.k) {
            Editable text = getText();
            for (TextInlineImageSpan textInlineImageSpan : (TextInlineImageSpan[]) text.getSpans(0, text.length(), TextInlineImageSpan.class)) {
                textInlineImageSpan.b();
            }
        }
    }

    public void onStartTemporaryDetach() {
        super.onStartTemporaryDetach();
        if (this.k) {
            Editable text = getText();
            for (TextInlineImageSpan textInlineImageSpan : (TextInlineImageSpan[]) text.getSpans(0, text.length(), TextInlineImageSpan.class)) {
                textInlineImageSpan.c();
            }
        }
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        if (this.k) {
            Editable text = getText();
            for (TextInlineImageSpan textInlineImageSpan : (TextInlineImageSpan[]) text.getSpans(0, text.length(), TextInlineImageSpan.class)) {
                textInlineImageSpan.d();
            }
        }
    }

    public void onFinishTemporaryDetach() {
        super.onFinishTemporaryDetach();
        if (this.k) {
            Editable text = getText();
            for (TextInlineImageSpan textInlineImageSpan : (TextInlineImageSpan[]) text.getSpans(0, text.length(), TextInlineImageSpan.class)) {
                textInlineImageSpan.e();
            }
        }
    }

    public void setBackgroundColor(int i2) {
        this.u.a(i2);
    }

    public void a(int i2, float f2) {
        this.u.a(i2, f2);
    }

    public void a(int i2, float f2, float f3) {
        this.u.a(i2, f2, f3);
    }

    public void setBorderRadius(float f2) {
        this.u.a(f2);
    }

    public void a(float f2, int i2) {
        this.u.a(f2, i2);
    }

    public void setBorderStyle(@Nullable String str) {
        this.u.a(str);
    }

    public void setLetterSpacingPt(float f2) {
        this.t = f2;
        e();
    }

    public void setTextSize(float f2) {
        super.setTextSize(f2);
        e();
    }

    public void setTextSize(int i2, float f2) {
        super.setTextSize(i2, f2);
        e();
    }

    /* access modifiers changed from: protected */
    public void e() {
        if (Build.VERSION.SDK_INT >= 21) {
            setLetterSpacing(PixelUtil.b(this.t) / getTextSize());
        }
    }

    /* access modifiers changed from: private */
    public class TextWatcherDelegator implements TextWatcher {
        private TextWatcherDelegator() {
        }

        public void beforeTextChanged(CharSequence charSequence, int i, int i2, int i3) {
            if (!ReactEditText.this.b && ReactEditText.this.h != null) {
                Iterator it = ReactEditText.this.h.iterator();
                while (it.hasNext()) {
                    ((TextWatcher) it.next()).beforeTextChanged(charSequence, i, i2, i3);
                }
            }
        }

        public void onTextChanged(CharSequence charSequence, int i, int i2, int i3) {
            if (!ReactEditText.this.b && ReactEditText.this.h != null) {
                Iterator it = ReactEditText.this.h.iterator();
                while (it.hasNext()) {
                    ((TextWatcher) it.next()).onTextChanged(charSequence, i, i2, i3);
                }
            }
            ReactEditText.this.k();
        }

        public void afterTextChanged(Editable editable) {
            if (!ReactEditText.this.b && ReactEditText.this.h != null) {
                Iterator it = ReactEditText.this.h.iterator();
                while (it.hasNext()) {
                    ((TextWatcher) it.next()).afterTextChanged(editable);
                }
            }
        }
    }

    /* access modifiers changed from: private */
    public static class InternalKeyListener implements KeyListener {

        /* renamed from: a  reason: collision with root package name */
        private int f2371a = 0;

        public void a(int i) {
            this.f2371a = i;
        }

        public int getInputType() {
            return this.f2371a;
        }

        public boolean onKeyDown(View view, Editable editable, int i, KeyEvent keyEvent) {
            return ReactEditText.v.onKeyDown(view, editable, i, keyEvent);
        }

        public boolean onKeyUp(View view, Editable editable, int i, KeyEvent keyEvent) {
            return ReactEditText.v.onKeyUp(view, editable, i, keyEvent);
        }

        public boolean onKeyOther(View view, Editable editable, KeyEvent keyEvent) {
            return ReactEditText.v.onKeyOther(view, editable, keyEvent);
        }

        public void clearMetaKeyState(View view, Editable editable, int i) {
            ReactEditText.v.clearMetaKeyState(view, editable, i);
        }
    }
}
