package com.lockscreen.xvolley.toolbox;

import android.os.SystemClock;
import android.support.annotation.VisibleForTesting;
import android.text.TextUtils;
import com.facebook.stetho.common.Utf8Charset;
import com.lockscreen.xvolley.XCache;
import com.lockscreen.xvolley.XHeader;
import com.lockscreen.xvolley.XVolleyLog;
import com.tencent.smtt.sdk.WebView;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.DataInputStream;
import java.io.EOFException;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.FilterInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

public class XDiskBasedCache implements XCache {

    /* renamed from: a  reason: collision with root package name */
    private final Map<String, CacheHeader> f2553a;
    private long b;
    private final File c;
    private final int d;

    public XDiskBasedCache(File file, int i) {
        this.f2553a = new LinkedHashMap(16, 0.75f, true);
        this.b = 0;
        this.c = file;
        this.d = i;
    }

    public XDiskBasedCache(File file) {
        this(file, 5242880);
    }

    @Override // com.lockscreen.xvolley.XCache
    public synchronized XCache.Entry a(String str) {
        CacheHeader cacheHeader = this.f2553a.get(str);
        if (cacheHeader == null) {
            return null;
        }
        File c2 = c(str);
        try {
            CountingInputStream countingInputStream = new CountingInputStream(new BufferedInputStream(a(c2)), c2.length());
            try {
                CacheHeader a2 = CacheHeader.a(countingInputStream);
                if (!TextUtils.equals(str, a2.b)) {
                    XVolleyLog.b("%s: key=%s, found=%s", c2.getAbsolutePath(), str, a2.b);
                    e(str);
                    return null;
                }
                XCache.Entry a3 = cacheHeader.a(a(countingInputStream, countingInputStream.a()));
                countingInputStream.close();
                return a3;
            } finally {
                countingInputStream.close();
            }
        } catch (IOException e) {
            XVolleyLog.b("%s: %s", c2.getAbsolutePath(), e.toString());
            b(str);
            return null;
        }
    }

    @Override // com.lockscreen.xvolley.XCache
    public synchronized void a() {
        if (!this.c.exists()) {
            if (!this.c.mkdirs()) {
                XVolleyLog.c("Unable to create cache dir %s", this.c.getAbsolutePath());
            }
            return;
        }
        File[] listFiles = this.c.listFiles();
        if (listFiles != null) {
            for (File file : listFiles) {
                try {
                    long length = file.length();
                    CountingInputStream countingInputStream = new CountingInputStream(new BufferedInputStream(a(file)), length);
                    try {
                        CacheHeader a2 = CacheHeader.a(countingInputStream);
                        a2.f2554a = length;
                        a(a2.b, a2);
                    } finally {
                        countingInputStream.close();
                    }
                } catch (IOException unused) {
                    file.delete();
                }
            }
        }
    }

    @Override // com.lockscreen.xvolley.XCache
    public synchronized void a(String str, XCache.Entry entry) {
        a(entry.f2531a.length);
        File c2 = c(str);
        try {
            BufferedOutputStream bufferedOutputStream = new BufferedOutputStream(b(c2));
            CacheHeader cacheHeader = new CacheHeader(str, entry);
            if (cacheHeader.a(bufferedOutputStream)) {
                bufferedOutputStream.write(entry.f2531a);
                bufferedOutputStream.close();
                a(str, cacheHeader);
            } else {
                bufferedOutputStream.close();
                XVolleyLog.b("Failed to write header for %s", c2.getAbsolutePath());
                throw new IOException();
            }
        } catch (IOException unused) {
            if (!c2.delete()) {
                XVolleyLog.b("Could not clean up file %s", c2.getAbsolutePath());
            }
        }
    }

    public synchronized void b(String str) {
        boolean delete = c(str).delete();
        e(str);
        if (!delete) {
            XVolleyLog.b("Could not delete cache entry for key=%s, filename=%s", str, d(str));
        }
    }

    private String d(String str) {
        int length = str.length() / 2;
        String valueOf = String.valueOf(str.substring(0, length).hashCode());
        return valueOf + String.valueOf(str.substring(length).hashCode());
    }

    public File c(String str) {
        return new File(this.c, d(str));
    }

    private void a(int i) {
        long j;
        long j2 = (long) i;
        if (this.b + j2 >= ((long) this.d)) {
            if (XVolleyLog.b) {
                XVolleyLog.a("Pruning old cache entries.", new Object[0]);
            }
            long j3 = this.b;
            long elapsedRealtime = SystemClock.elapsedRealtime();
            Iterator<Map.Entry<String, CacheHeader>> it = this.f2553a.entrySet().iterator();
            int i2 = 0;
            while (it.hasNext()) {
                CacheHeader value = it.next().getValue();
                if (c(value.b).delete()) {
                    j = j2;
                    this.b -= value.f2554a;
                } else {
                    j = j2;
                    XVolleyLog.b("Could not delete cache entry for key=%s, filename=%s", value.b, d(value.b));
                }
                it.remove();
                i2++;
                if (((float) (this.b + j)) < ((float) this.d) * 0.9f) {
                    break;
                }
                j2 = j;
            }
            if (XVolleyLog.b) {
                XVolleyLog.a("pruned %d files, %d bytes, %d ms", Integer.valueOf(i2), Long.valueOf(this.b - j3), Long.valueOf(SystemClock.elapsedRealtime() - elapsedRealtime));
            }
        }
    }

    private void a(String str, CacheHeader cacheHeader) {
        if (!this.f2553a.containsKey(str)) {
            this.b += cacheHeader.f2554a;
        } else {
            this.b += cacheHeader.f2554a - this.f2553a.get(str).f2554a;
        }
        this.f2553a.put(str, cacheHeader);
    }

    private void e(String str) {
        CacheHeader remove = this.f2553a.remove(str);
        if (remove != null) {
            this.b -= remove.f2554a;
        }
    }

    static byte[] a(CountingInputStream countingInputStream, long j) {
        long a2 = countingInputStream.a();
        if (j >= 0 && j <= a2) {
            int i = (int) j;
            if (((long) i) == j) {
                byte[] bArr = new byte[i];
                new DataInputStream(countingInputStream).readFully(bArr);
                return bArr;
            }
        }
        throw new IOException("streamToBytes length=" + j + ", maxLength=" + a2);
    }

    /* access modifiers changed from: package-private */
    public InputStream a(File file) {
        return new FileInputStream(file);
    }

    /* access modifiers changed from: package-private */
    public OutputStream b(File file) {
        return new FileOutputStream(file);
    }

    /* access modifiers changed from: package-private */
    public static class CacheHeader {

        /* renamed from: a  reason: collision with root package name */
        long f2554a;
        final String b;
        final String c;
        final long d;
        final long e;
        final long f;
        final long g;
        final List<XHeader> h;

        private CacheHeader(String str, String str2, long j, long j2, long j3, long j4, List<XHeader> list) {
            this.b = str;
            this.c = "".equals(str2) ? null : str2;
            this.d = j;
            this.e = j2;
            this.f = j3;
            this.g = j4;
            this.h = list;
        }

        CacheHeader(String str, XCache.Entry entry) {
            this(str, entry.b, entry.c, entry.d, entry.e, entry.f, a(entry));
            this.f2554a = (long) entry.f2531a.length;
        }

        private static List<XHeader> a(XCache.Entry entry) {
            if (entry.h != null) {
                return entry.h;
            }
            return XHttpHeaderParser.b(entry.g);
        }

        static CacheHeader a(CountingInputStream countingInputStream) {
            if (XDiskBasedCache.a((InputStream) countingInputStream) == 538247942) {
                return new CacheHeader(XDiskBasedCache.a(countingInputStream), XDiskBasedCache.a(countingInputStream), XDiskBasedCache.b((InputStream) countingInputStream), XDiskBasedCache.b((InputStream) countingInputStream), XDiskBasedCache.b((InputStream) countingInputStream), XDiskBasedCache.b((InputStream) countingInputStream), XDiskBasedCache.b(countingInputStream));
            }
            throw new IOException();
        }

        /* access modifiers changed from: package-private */
        public XCache.Entry a(byte[] bArr) {
            XCache.Entry entry = new XCache.Entry();
            entry.f2531a = bArr;
            entry.b = this.c;
            entry.c = this.d;
            entry.d = this.e;
            entry.e = this.f;
            entry.f = this.g;
            entry.g = XHttpHeaderParser.a(this.h);
            entry.h = Collections.unmodifiableList(this.h);
            return entry;
        }

        /* access modifiers changed from: package-private */
        public boolean a(OutputStream outputStream) {
            try {
                XDiskBasedCache.a(outputStream, 538247942);
                XDiskBasedCache.a(outputStream, this.b);
                XDiskBasedCache.a(outputStream, this.c == null ? "" : this.c);
                XDiskBasedCache.a(outputStream, this.d);
                XDiskBasedCache.a(outputStream, this.e);
                XDiskBasedCache.a(outputStream, this.f);
                XDiskBasedCache.a(outputStream, this.g);
                XDiskBasedCache.a(this.h, outputStream);
                outputStream.flush();
                return true;
            } catch (IOException e2) {
                XVolleyLog.b("%s", e2.toString());
                return false;
            }
        }
    }

    /* access modifiers changed from: package-private */
    @VisibleForTesting
    public static class CountingInputStream extends FilterInputStream {

        /* renamed from: a  reason: collision with root package name */
        private final long f2555a;
        private long b;

        CountingInputStream(InputStream inputStream, long j) {
            super(inputStream);
            this.f2555a = j;
        }

        @Override // java.io.FilterInputStream, java.io.InputStream
        public int read() {
            int read = super.read();
            if (read != -1) {
                this.b++;
            }
            return read;
        }

        @Override // java.io.FilterInputStream, java.io.InputStream
        public int read(byte[] bArr, int i, int i2) {
            int read = super.read(bArr, i, i2);
            if (read != -1) {
                this.b += (long) read;
            }
            return read;
        }

        /* access modifiers changed from: package-private */
        public long a() {
            return this.f2555a - this.b;
        }
    }

    private static int c(InputStream inputStream) {
        int read = inputStream.read();
        if (read != -1) {
            return read;
        }
        throw new EOFException();
    }

    static void a(OutputStream outputStream, int i) {
        outputStream.write((i >> 0) & WebView.NORMAL_MODE_ALPHA);
        outputStream.write((i >> 8) & WebView.NORMAL_MODE_ALPHA);
        outputStream.write((i >> 16) & WebView.NORMAL_MODE_ALPHA);
        outputStream.write((i >> 24) & WebView.NORMAL_MODE_ALPHA);
    }

    static int a(InputStream inputStream) {
        return (c(inputStream) << 24) | (c(inputStream) << 0) | 0 | (c(inputStream) << 8) | (c(inputStream) << 16);
    }

    static void a(OutputStream outputStream, long j) {
        outputStream.write((byte) ((int) (j >>> 0)));
        outputStream.write((byte) ((int) (j >>> 8)));
        outputStream.write((byte) ((int) (j >>> 16)));
        outputStream.write((byte) ((int) (j >>> 24)));
        outputStream.write((byte) ((int) (j >>> 32)));
        outputStream.write((byte) ((int) (j >>> 40)));
        outputStream.write((byte) ((int) (j >>> 48)));
        outputStream.write((byte) ((int) (j >>> 56)));
    }

    static long b(InputStream inputStream) {
        return ((((long) c(inputStream)) & 255) << 0) | 0 | ((((long) c(inputStream)) & 255) << 8) | ((((long) c(inputStream)) & 255) << 16) | ((((long) c(inputStream)) & 255) << 24) | ((((long) c(inputStream)) & 255) << 32) | ((((long) c(inputStream)) & 255) << 40) | ((((long) c(inputStream)) & 255) << 48) | ((255 & ((long) c(inputStream))) << 56);
    }

    static void a(OutputStream outputStream, String str) {
        byte[] bytes = str.getBytes(Utf8Charset.NAME);
        a(outputStream, (long) bytes.length);
        outputStream.write(bytes, 0, bytes.length);
    }

    static String a(CountingInputStream countingInputStream) {
        return new String(a(countingInputStream, b((InputStream) countingInputStream)), Utf8Charset.NAME);
    }

    static void a(List<XHeader> list, OutputStream outputStream) {
        if (list != null) {
            a(outputStream, list.size());
            for (XHeader xHeader : list) {
                a(outputStream, xHeader.a());
                a(outputStream, xHeader.b());
            }
            return;
        }
        a(outputStream, 0);
    }

    static List<XHeader> b(CountingInputStream countingInputStream) {
        int a2 = a((InputStream) countingInputStream);
        if (a2 >= 0) {
            List<XHeader> emptyList = a2 == 0 ? Collections.emptyList() : new ArrayList<>();
            for (int i = 0; i < a2; i++) {
                emptyList.add(new XHeader(a(countingInputStream).intern(), a(countingInputStream).intern()));
            }
            return emptyList;
        }
        throw new IOException("readHeaderList size=" + a2);
    }
}
