package com.nimbusds.jose;

import com.nimbusds.jose.jwk.JWK;
import com.nimbusds.jose.util.Base64;
import com.nimbusds.jose.util.Base64URL;
import com.nimbusds.jose.util.JSONObjectUtils;
import com.nimbusds.jose.util.X509CertChainUtils;
import java.net.URI;
import java.text.ParseException;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import net.jcip.annotations.Immutable;
import net.minidev.json.JSONObject;

@Immutable
public final class JWSHeader extends CommonSEHeader {

    /* renamed from: a  reason: collision with root package name */
    private static final Set<String> f2652a;
    private static final long serialVersionUID = 1;

    @Override // com.nimbusds.jose.Header, com.nimbusds.jose.CommonSEHeader
    public /* bridge */ /* synthetic */ JSONObject a() {
        return super.a();
    }

    static {
        HashSet hashSet = new HashSet();
        hashSet.add("alg");
        hashSet.add("jku");
        hashSet.add("jwk");
        hashSet.add("x5u");
        hashSet.add("x5t");
        hashSet.add("x5t#S256");
        hashSet.add("x5c");
        hashSet.add("kid");
        hashSet.add("typ");
        hashSet.add("cty");
        hashSet.add("crit");
        f2652a = Collections.unmodifiableSet(hashSet);
    }

    public static class Builder {

        /* renamed from: a  reason: collision with root package name */
        private final JWSAlgorithm f2653a;
        private JOSEObjectType b;
        private String c;
        private Set<String> d;
        private URI e;
        private JWK f;
        private URI g;
        @Deprecated
        private Base64URL h;
        private Base64URL i;
        private List<Base64> j;
        private String k;
        private Map<String, Object> l;
        private Base64URL m;

        public Builder(JWSAlgorithm jWSAlgorithm) {
            if (!jWSAlgorithm.a().equals(Algorithm.f2641a.a())) {
                this.f2653a = jWSAlgorithm;
                return;
            }
            throw new IllegalArgumentException("The JWS algorithm \"alg\" cannot be \"none\"");
        }

        public Builder a(JOSEObjectType jOSEObjectType) {
            this.b = jOSEObjectType;
            return this;
        }

        public Builder a(String str) {
            this.c = str;
            return this;
        }

        public Builder a(Set<String> set) {
            this.d = set;
            return this;
        }

        public Builder a(URI uri) {
            this.e = uri;
            return this;
        }

        public Builder a(JWK jwk) {
            this.f = jwk;
            return this;
        }

        public Builder b(URI uri) {
            this.g = uri;
            return this;
        }

        @Deprecated
        public Builder a(Base64URL base64URL) {
            this.h = base64URL;
            return this;
        }

        public Builder b(Base64URL base64URL) {
            this.i = base64URL;
            return this;
        }

        public Builder a(List<Base64> list) {
            this.j = list;
            return this;
        }

        public Builder b(String str) {
            this.k = str;
            return this;
        }

        public Builder a(String str, Object obj) {
            if (!JWSHeader.d().contains(str)) {
                if (this.l == null) {
                    this.l = new HashMap();
                }
                this.l.put(str, obj);
                return this;
            }
            throw new IllegalArgumentException("The parameter name \"" + str + "\" matches a registered name");
        }

        public Builder c(Base64URL base64URL) {
            this.m = base64URL;
            return this;
        }

        public JWSHeader a() {
            return new JWSHeader(this.f2653a, this.b, this.c, this.d, this.e, this.f, this.g, this.h, this.i, this.j, this.k, this.l, this.m);
        }
    }

    public JWSHeader(JWSAlgorithm jWSAlgorithm, JOSEObjectType jOSEObjectType, String str, Set<String> set, URI uri, JWK jwk, URI uri2, Base64URL base64URL, Base64URL base64URL2, List<Base64> list, String str2, Map<String, Object> map, Base64URL base64URL3) {
        super(jWSAlgorithm, jOSEObjectType, str, set, uri, jwk, uri2, base64URL, base64URL2, list, str2, map, base64URL3);
        if (jWSAlgorithm.a().equals(Algorithm.f2641a.a())) {
            throw new IllegalArgumentException("The JWS algorithm \"alg\" cannot be \"none\"");
        }
    }

    public static Set<String> d() {
        return f2652a;
    }

    /* renamed from: e */
    public JWSAlgorithm b() {
        return (JWSAlgorithm) super.b();
    }

    public static JWSHeader a(JSONObject jSONObject, Base64URL base64URL) throws ParseException {
        Algorithm a2 = Header.a(jSONObject);
        if (a2 instanceof JWSAlgorithm) {
            Builder c = new Builder((JWSAlgorithm) a2).c(base64URL);
            for (String str : jSONObject.keySet()) {
                if (!"alg".equals(str)) {
                    if ("typ".equals(str)) {
                        c = c.a(new JOSEObjectType(JSONObjectUtils.b(jSONObject, str)));
                    } else if ("cty".equals(str)) {
                        c = c.a(JSONObjectUtils.b(jSONObject, str));
                    } else if ("crit".equals(str)) {
                        c = c.a(new HashSet(JSONObjectUtils.f(jSONObject, str)));
                    } else if ("jku".equals(str)) {
                        c = c.a(JSONObjectUtils.c(jSONObject, str));
                    } else if ("jwk".equals(str)) {
                        c = c.a(JWK.b(JSONObjectUtils.g(jSONObject, str)));
                    } else if ("x5u".equals(str)) {
                        c = c.b(JSONObjectUtils.c(jSONObject, str));
                    } else if ("x5t".equals(str)) {
                        c = c.a(new Base64URL(JSONObjectUtils.b(jSONObject, str)));
                    } else if ("x5t#S256".equals(str)) {
                        c = c.b(new Base64URL(JSONObjectUtils.b(jSONObject, str)));
                    } else if ("x5c".equals(str)) {
                        c = c.a(X509CertChainUtils.a(JSONObjectUtils.d(jSONObject, str)));
                    } else if ("kid".equals(str)) {
                        c = c.b(JSONObjectUtils.b(jSONObject, str));
                    } else {
                        c = c.a(str, jSONObject.get(str));
                    }
                }
            }
            return c.a();
        }
        throw new ParseException("The algorithm \"alg\" header parameter must be for signatures", 0);
    }

    public static JWSHeader a(String str, Base64URL base64URL) throws ParseException {
        return a(JSONObjectUtils.a(str), base64URL);
    }

    public static JWSHeader a(Base64URL base64URL) throws ParseException {
        return a(base64URL.d(), base64URL);
    }
}
