package com.nimbusds.jose.jwk;

import com.nimbusds.jose.Algorithm;
import com.nimbusds.jose.crypto.utils.ECChecks;
import com.nimbusds.jose.util.Base64;
import com.nimbusds.jose.util.Base64URL;
import com.nimbusds.jose.util.JSONObjectUtils;
import java.net.URI;
import java.security.KeyStore;
import java.security.PrivateKey;
import java.text.ParseException;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import net.jcip.annotations.Immutable;
import net.minidev.json.JSONObject;

@Immutable
public final class ECKey extends JWK implements AssymetricJWK, CurveBasedJWK {

    /* renamed from: a  reason: collision with root package name */
    public static final Set<Curve> f2681a = Collections.unmodifiableSet(new HashSet(Arrays.asList(Curve.f2680a, Curve.b, Curve.c)));
    private static final long serialVersionUID = 1;
    private final Curve b;
    private final Base64URL c;
    private final Base64URL d;
    private final Base64URL e;
    private final PrivateKey f;

    public static class Builder {
    }

    private static void a(Curve curve, Base64URL base64URL, Base64URL base64URL2) {
        if (!f2681a.contains(curve)) {
            throw new IllegalArgumentException("Unknown / unsupported curve: " + curve);
        } else if (!ECChecks.a(base64URL.c(), base64URL2.c(), curve.b())) {
            throw new IllegalArgumentException("Invalid EC JWK: The 'x' and 'y' public coordinates are not on the " + curve + " curve");
        }
    }

    public ECKey(Curve curve, Base64URL base64URL, Base64URL base64URL2, KeyUse keyUse, Set<KeyOperation> set, Algorithm algorithm, String str, URI uri, Base64URL base64URL3, Base64URL base64URL4, List<Base64> list, KeyStore keyStore) {
        super(KeyType.f2689a, keyUse, set, algorithm, str, uri, base64URL3, base64URL4, list, keyStore);
        if (curve != null) {
            this.b = curve;
            if (base64URL != null) {
                this.c = base64URL;
                if (base64URL2 != null) {
                    this.d = base64URL2;
                    a(curve, base64URL, base64URL2);
                    this.e = null;
                    this.f = null;
                    return;
                }
                throw new IllegalArgumentException("The 'y' coordinate must not be null");
            }
            throw new IllegalArgumentException("The 'x' coordinate must not be null");
        }
        throw new IllegalArgumentException("The curve must not be null");
    }

    public ECKey(Curve curve, Base64URL base64URL, Base64URL base64URL2, Base64URL base64URL3, KeyUse keyUse, Set<KeyOperation> set, Algorithm algorithm, String str, URI uri, Base64URL base64URL4, Base64URL base64URL5, List<Base64> list, KeyStore keyStore) {
        super(KeyType.f2689a, keyUse, set, algorithm, str, uri, base64URL4, base64URL5, list, keyStore);
        if (curve != null) {
            this.b = curve;
            if (base64URL != null) {
                this.c = base64URL;
                if (base64URL2 != null) {
                    this.d = base64URL2;
                    a(curve, base64URL, base64URL2);
                    if (base64URL3 != null) {
                        this.e = base64URL3;
                        this.f = null;
                        return;
                    }
                    throw new IllegalArgumentException("The 'd' coordinate must not be null");
                }
                throw new IllegalArgumentException("The 'y' coordinate must not be null");
            }
            throw new IllegalArgumentException("The 'x' coordinate must not be null");
        }
        throw new IllegalArgumentException("The curve must not be null");
    }

    public Curve a() {
        return this.b;
    }

    public Base64URL c() {
        return this.c;
    }

    public Base64URL d() {
        return this.d;
    }

    /* renamed from: e */
    public ECKey g() {
        return new ECKey(a(), c(), d(), h(), i(), j(), k(), l(), m(), n(), o(), p());
    }

    @Override // com.nimbusds.jose.jwk.JWK
    public JSONObject f() {
        JSONObject f2 = super.f();
        f2.put("crv", this.b.toString());
        f2.put("x", this.c.toString());
        f2.put("y", this.d.toString());
        if (this.e != null) {
            f2.put("d", this.e.toString());
        }
        return f2;
    }

    public static ECKey a(JSONObject jSONObject) throws ParseException {
        Curve a2 = Curve.a(JSONObjectUtils.b(jSONObject, "crv"));
        Base64URL base64URL = new Base64URL(JSONObjectUtils.b(jSONObject, "x"));
        Base64URL base64URL2 = new Base64URL(JSONObjectUtils.b(jSONObject, "y"));
        if (JWKMetadata.a(jSONObject) == KeyType.f2689a) {
            Base64URL base64URL3 = null;
            if (jSONObject.get("d") != null) {
                base64URL3 = new Base64URL(JSONObjectUtils.b(jSONObject, "d"));
            }
            if (base64URL3 != null) {
                return new ECKey(a2, base64URL, base64URL2, base64URL3, JWKMetadata.b(jSONObject), JWKMetadata.c(jSONObject), JWKMetadata.d(jSONObject), JWKMetadata.e(jSONObject), JWKMetadata.f(jSONObject), JWKMetadata.g(jSONObject), JWKMetadata.h(jSONObject), JWKMetadata.i(jSONObject), null);
            }
            try {
                return new ECKey(a2, base64URL, base64URL2, JWKMetadata.b(jSONObject), JWKMetadata.c(jSONObject), JWKMetadata.d(jSONObject), JWKMetadata.e(jSONObject), JWKMetadata.f(jSONObject), JWKMetadata.g(jSONObject), JWKMetadata.h(jSONObject), JWKMetadata.i(jSONObject), null);
            } catch (IllegalArgumentException e2) {
                throw new ParseException(e2.getMessage(), 0);
            }
        } else {
            throw new ParseException("The key type \"kty\" must be EC", 0);
        }
    }
}
