package com.nimbusds.jose.jwk;

import com.nimbusds.jose.Algorithm;
import com.nimbusds.jose.util.Base64;
import com.nimbusds.jose.util.Base64URL;
import com.nimbusds.jose.util.JSONObjectUtils;
import java.io.Serializable;
import java.net.URI;
import java.security.KeyStore;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Set;
import net.minidev.json.JSONAware;
import net.minidev.json.JSONObject;

public abstract class JWK implements Serializable, JSONAware {
    private static final long serialVersionUID = 1;

    /* renamed from: a  reason: collision with root package name */
    private final KeyType f2684a;
    private final KeyUse b;
    private final Set<KeyOperation> c;
    private final Algorithm d;
    private final String e;
    private final URI f;
    @Deprecated
    private final Base64URL g;
    private Base64URL h;
    private final List<Base64> i;
    private final KeyStore j;

    public abstract JWK g();

    protected JWK(KeyType keyType, KeyUse keyUse, Set<KeyOperation> set, Algorithm algorithm, String str, URI uri, Base64URL base64URL, Base64URL base64URL2, List<Base64> list, KeyStore keyStore) {
        if (keyType != null) {
            this.f2684a = keyType;
            if (KeyUseAndOpsConsistency.a(keyUse, set)) {
                this.b = keyUse;
                this.c = set;
                this.d = algorithm;
                this.e = str;
                this.f = uri;
                this.g = base64URL;
                this.h = base64URL2;
                this.i = list;
                this.j = keyStore;
                return;
            }
            throw new IllegalArgumentException("The key use \"use\" and key options \"key_opts\" parameters are not consistent, see RFC 7517, section 4.3");
        }
        throw new IllegalArgumentException("The key type \"kty\" parameter must not be null");
    }

    public KeyUse h() {
        return this.b;
    }

    public Set<KeyOperation> i() {
        return this.c;
    }

    public Algorithm j() {
        return this.d;
    }

    public String k() {
        return this.e;
    }

    public URI l() {
        return this.f;
    }

    @Deprecated
    public Base64URL m() {
        return this.g;
    }

    public Base64URL n() {
        return this.h;
    }

    public List<Base64> o() {
        if (this.i == null) {
            return null;
        }
        return Collections.unmodifiableList(this.i);
    }

    public KeyStore p() {
        return this.j;
    }

    public JSONObject f() {
        JSONObject jSONObject = new JSONObject();
        jSONObject.put("kty", this.f2684a.a());
        if (this.b != null) {
            jSONObject.put("use", this.b.a());
        }
        if (this.c != null) {
            ArrayList arrayList = new ArrayList(this.c.size());
            for (KeyOperation keyOperation : this.c) {
                arrayList.add(keyOperation.a());
            }
            jSONObject.put("key_ops", arrayList);
        }
        if (this.d != null) {
            jSONObject.put("alg", this.d.a());
        }
        if (this.e != null) {
            jSONObject.put("kid", this.e);
        }
        if (this.f != null) {
            jSONObject.put("x5u", this.f.toString());
        }
        if (this.g != null) {
            jSONObject.put("x5t", this.g.toString());
        }
        if (this.h != null) {
            jSONObject.put("x5t#S256", this.h.toString());
        }
        if (this.i != null) {
            jSONObject.put("x5c", this.i);
        }
        return jSONObject;
    }

    @Override // net.minidev.json.JSONAware
    public String b() {
        return f().toString();
    }

    public String toString() {
        return f().toString();
    }

    public static JWK b(JSONObject jSONObject) throws ParseException {
        KeyType a2 = KeyType.a(JSONObjectUtils.b(jSONObject, "kty"));
        if (a2 == KeyType.f2689a) {
            return ECKey.a(jSONObject);
        }
        if (a2 == KeyType.b) {
            return RSAKey.a(jSONObject);
        }
        if (a2 == KeyType.c) {
            return OctetSequenceKey.a(jSONObject);
        }
        if (a2 == KeyType.d) {
            return OctetKeyPair.a(jSONObject);
        }
        throw new ParseException("Unsupported key type \"kty\" parameter: " + a2, 0);
    }
}
