package com.nimbusds.jose.jwk;

import com.nimbusds.jose.Algorithm;
import com.nimbusds.jose.util.Base64;
import com.nimbusds.jose.util.Base64URL;
import com.nimbusds.jose.util.JSONObjectUtils;
import java.net.URI;
import java.security.KeyStore;
import java.text.ParseException;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import net.jcip.annotations.Immutable;
import net.minidev.json.JSONObject;

@Immutable
public class OctetKeyPair extends JWK implements AssymetricJWK, CurveBasedJWK {

    /* renamed from: a  reason: collision with root package name */
    public static final Set<Curve> f2692a = Collections.unmodifiableSet(new HashSet(Arrays.asList(Curve.d, Curve.e, Curve.f, Curve.g)));
    private static final long serialVersionUID = 1;
    private final Curve b;
    private final Base64URL c;
    private final Base64URL d;

    public static class Builder {
    }

    public OctetKeyPair(Curve curve, Base64URL base64URL, KeyUse keyUse, Set<KeyOperation> set, Algorithm algorithm, String str, URI uri, Base64URL base64URL2, Base64URL base64URL3, List<Base64> list, KeyStore keyStore) {
        super(KeyType.d, keyUse, set, algorithm, str, uri, base64URL2, base64URL3, list, keyStore);
        if (curve == null) {
            throw new IllegalArgumentException("The curve must not be null");
        } else if (f2692a.contains(curve)) {
            this.b = curve;
            if (base64URL != null) {
                this.c = base64URL;
                this.d = null;
                return;
            }
            throw new IllegalArgumentException("The 'x' parameter must not be null");
        } else {
            throw new IllegalArgumentException("Unknown / unsupported curve: " + curve);
        }
    }

    public OctetKeyPair(Curve curve, Base64URL base64URL, Base64URL base64URL2, KeyUse keyUse, Set<KeyOperation> set, Algorithm algorithm, String str, URI uri, Base64URL base64URL3, Base64URL base64URL4, List<Base64> list, KeyStore keyStore) {
        super(KeyType.d, keyUse, set, algorithm, str, uri, base64URL3, base64URL4, list, keyStore);
        if (curve == null) {
            throw new IllegalArgumentException("The curve must not be null");
        } else if (f2692a.contains(curve)) {
            this.b = curve;
            if (base64URL != null) {
                this.c = base64URL;
                if (base64URL2 != null) {
                    this.d = base64URL2;
                    return;
                }
                throw new IllegalArgumentException("The 'd' parameter must not be null");
            }
            throw new IllegalArgumentException("The 'x' parameter must not be null");
        } else {
            throw new IllegalArgumentException("Unknown / unsupported curve: " + curve);
        }
    }

    public Curve a() {
        return this.b;
    }

    public Base64URL c() {
        return this.c;
    }

    /* renamed from: d */
    public OctetKeyPair g() {
        return new OctetKeyPair(a(), c(), h(), i(), j(), k(), l(), m(), n(), o(), p());
    }

    @Override // com.nimbusds.jose.jwk.JWK
    public JSONObject f() {
        JSONObject f = super.f();
        f.put("crv", this.b.toString());
        f.put("x", this.c.toString());
        if (this.d != null) {
            f.put("d", this.d.toString());
        }
        return f;
    }

    public static OctetKeyPair a(JSONObject jSONObject) throws ParseException {
        Curve a2 = Curve.a(JSONObjectUtils.b(jSONObject, "crv"));
        Base64URL base64URL = new Base64URL(JSONObjectUtils.b(jSONObject, "x"));
        if (JWKMetadata.a(jSONObject) == KeyType.d) {
            Base64URL base64URL2 = null;
            if (jSONObject.get("d") != null) {
                base64URL2 = new Base64URL(JSONObjectUtils.b(jSONObject, "d"));
            }
            if (base64URL2 != null) {
                return new OctetKeyPair(a2, base64URL, base64URL2, JWKMetadata.b(jSONObject), JWKMetadata.c(jSONObject), JWKMetadata.d(jSONObject), JWKMetadata.e(jSONObject), JWKMetadata.f(jSONObject), JWKMetadata.g(jSONObject), JWKMetadata.h(jSONObject), JWKMetadata.i(jSONObject), null);
            }
            try {
                return new OctetKeyPair(a2, base64URL, JWKMetadata.b(jSONObject), JWKMetadata.c(jSONObject), JWKMetadata.d(jSONObject), JWKMetadata.e(jSONObject), JWKMetadata.f(jSONObject), JWKMetadata.g(jSONObject), JWKMetadata.h(jSONObject), JWKMetadata.i(jSONObject), null);
            } catch (IllegalArgumentException e) {
                throw new ParseException(e.getMessage(), 0);
            }
        } else {
            throw new ParseException("The key type \"kty\" must be OKP", 0);
        }
    }
}
