package com.nimbusds.jwt;

import com.nimbusds.jose.util.DateUtils;
import com.nimbusds.jose.util.JSONObjectUtils;
import java.io.Serializable;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Date;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import net.jcip.annotations.Immutable;
import net.minidev.json.JSONArray;
import net.minidev.json.JSONObject;

@Immutable
public final class JWTClaimsSet implements Serializable {

    /* renamed from: a  reason: collision with root package name */
    private static final Set<String> f2702a;
    private static final long serialVersionUID = 1;
    private final Map<String, Object> b;

    static {
        HashSet hashSet = new HashSet();
        hashSet.add("iss");
        hashSet.add("sub");
        hashSet.add("aud");
        hashSet.add("exp");
        hashSet.add("nbf");
        hashSet.add("iat");
        hashSet.add("jti");
        f2702a = Collections.unmodifiableSet(hashSet);
    }

    public static class Builder {

        /* renamed from: a  reason: collision with root package name */
        private final Map<String, Object> f2703a = new LinkedHashMap();

        public Builder a(String str) {
            this.f2703a.put("iss", str);
            return this;
        }

        public Builder b(String str) {
            this.f2703a.put("sub", str);
            return this;
        }

        public Builder a(List<String> list) {
            this.f2703a.put("aud", list);
            return this;
        }

        public Builder a(Date date) {
            this.f2703a.put("exp", date);
            return this;
        }

        public Builder b(Date date) {
            this.f2703a.put("nbf", date);
            return this;
        }

        public Builder c(Date date) {
            this.f2703a.put("iat", date);
            return this;
        }

        public Builder c(String str) {
            this.f2703a.put("jti", str);
            return this;
        }

        public Builder a(String str, Object obj) {
            this.f2703a.put(str, obj);
            return this;
        }

        public JWTClaimsSet a() {
            return new JWTClaimsSet(this.f2703a, null);
        }
    }

    private JWTClaimsSet(Map<String, Object> map) {
        this.b = new LinkedHashMap();
        this.b.putAll(map);
    }

    /* synthetic */ JWTClaimsSet(Map map, JWTClaimsSet jWTClaimsSet) {
        this(map);
    }

    public List<String> a() {
        Object a2 = a("aud");
        if (a2 instanceof String) {
            return Collections.singletonList((String) a2);
        }
        try {
            List<String> c = c("aud");
            return c != null ? Collections.unmodifiableList(c) : Collections.emptyList();
        } catch (ParseException unused) {
            return Collections.emptyList();
        }
    }

    public Object a(String str) {
        return this.b.get(str);
    }

    public String[] b(String str) throws ParseException {
        if (a(str) == null) {
            return null;
        }
        try {
            List list = (List) a(str);
            String[] strArr = new String[list.size()];
            for (int i = 0; i < strArr.length; i++) {
                try {
                    strArr[i] = (String) list.get(i);
                } catch (ClassCastException unused) {
                    throw new ParseException("The \"" + str + "\" claim is not a list / JSON array of strings", 0);
                }
            }
            return strArr;
        } catch (ClassCastException unused2) {
            throw new ParseException("The \"" + str + "\" claim is not a list / JSON array", 0);
        }
    }

    public List<String> c(String str) throws ParseException {
        String[] b2 = b(str);
        if (b2 == null) {
            return null;
        }
        return Collections.unmodifiableList(Arrays.asList(b2));
    }

    public Map<String, Object> b() {
        return Collections.unmodifiableMap(this.b);
    }

    public JSONObject c() {
        JSONObject jSONObject = new JSONObject();
        for (Map.Entry<String, Object> entry : this.b.entrySet()) {
            if (entry.getValue() instanceof Date) {
                jSONObject.put(entry.getKey(), Long.valueOf(DateUtils.a((Date) entry.getValue())));
            } else if ("aud".equals(entry.getKey())) {
                List<String> a2 = a();
                if (a2 != null && !a2.isEmpty()) {
                    if (a2.size() == 1) {
                        jSONObject.put("aud", a2.get(0));
                    } else {
                        JSONArray jSONArray = new JSONArray();
                        jSONArray.addAll(a2);
                        jSONObject.put("aud", jSONArray);
                    }
                }
            } else if (entry.getValue() != null) {
                jSONObject.put(entry.getKey(), entry.getValue());
            }
        }
        return jSONObject;
    }

    public String toString() {
        return c().b();
    }

    public static JWTClaimsSet a(JSONObject jSONObject) throws ParseException {
        Builder builder = new Builder();
        for (String str : jSONObject.keySet()) {
            if (str.equals("iss")) {
                builder.a(JSONObjectUtils.b(jSONObject, "iss"));
            } else if (str.equals("sub")) {
                builder.b(JSONObjectUtils.b(jSONObject, "sub"));
            } else if (str.equals("aud")) {
                Object obj = jSONObject.get("aud");
                if (obj instanceof String) {
                    ArrayList arrayList = new ArrayList();
                    arrayList.add(JSONObjectUtils.b(jSONObject, "aud"));
                    builder.a(arrayList);
                } else if (obj instanceof List) {
                    builder.a(JSONObjectUtils.f(jSONObject, "aud"));
                }
            } else if (str.equals("exp")) {
                builder.a(new Date(JSONObjectUtils.a(jSONObject, "exp") * 1000));
            } else if (str.equals("nbf")) {
                builder.b(new Date(JSONObjectUtils.a(jSONObject, "nbf") * 1000));
            } else if (str.equals("iat")) {
                builder.c(new Date(JSONObjectUtils.a(jSONObject, "iat") * 1000));
            } else if (str.equals("jti")) {
                builder.c(JSONObjectUtils.b(jSONObject, "jti"));
            } else {
                builder.a(str, jSONObject.get(str));
            }
        }
        return builder.a();
    }
}
