package fi.iki.elonen;

import com.facebook.stetho.common.Utf8Charset;
import com.facebook.stetho.server.http.HttpHeaders;
import com.tencent.smtt.sdk.TbsListener;
import com.tencent.smtt.sdk.TbsReaderView;
import com.tencent.smtt.sdk.TbsVideoCacheTask;
import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.Closeable;
import java.io.DataOutput;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FilterOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.io.RandomAccessFile;
import java.io.UnsupportedEncodingException;
import java.io.Writer;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.ServerSocket;
import java.net.Socket;
import java.net.SocketException;
import java.net.SocketTimeoutException;
import java.net.URL;
import java.net.URLDecoder;
import java.nio.ByteBuffer;
import java.nio.channels.FileChannel;
import java.nio.charset.Charset;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Properties;
import java.util.StringTokenizer;
import java.util.TimeZone;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.zip.GZIPOutputStream;
import javax.net.ssl.SSLException;
import javax.net.ssl.SSLServerSocket;
import javax.net.ssl.SSLServerSocketFactory;

public abstract class NanoHTTPD {

    /* renamed from: a  reason: collision with root package name */
    protected static Map<String, String> f3195a;
    private static final Pattern c = Pattern.compile("([ |\t]*Content-Disposition[ |\t]*:)(.*)", 2);
    private static final Pattern d = Pattern.compile("([ |\t]*content-type[ |\t]*:)(.*)", 2);
    private static final Pattern e = Pattern.compile("[ |\t]*([a-zA-Z]*)[ |\t]*=[ |\t]*['|\"]([^\"^']*)['|\"]");
    private static final Logger f = Logger.getLogger(NanoHTTPD.class.getName());
    protected AsyncRunner b;
    private final String g;
    private final int h;
    private volatile ServerSocket i;
    private ServerSocketFactory j = new DefaultServerSocketFactory();
    private Thread k;
    private TempFileManagerFactory l;

    public interface AsyncRunner {
        void a();

        void a(ClientHandler clientHandler);

        void b(ClientHandler clientHandler);
    }

    public interface IHTTPSession {
        void a(Map<String, String> map) throws IOException, ResponseException;

        Map<String, String> b();

        Method c();

        @Deprecated
        Map<String, String> d();

        String e();

        String f();
    }

    public interface ServerSocketFactory {
        ServerSocket a() throws IOException;
    }

    public interface TempFile {
        void a() throws Exception;

        String b();
    }

    public interface TempFileManager {
        TempFile a(String str) throws Exception;

        void a();
    }

    public interface TempFileManagerFactory {
        TempFileManager a();
    }

    public class ClientHandler implements Runnable {
        private final InputStream b;
        private final Socket c;

        public ClientHandler(InputStream inputStream, Socket socket) {
            this.b = inputStream;
            this.c = socket;
        }

        public void a() {
            NanoHTTPD.b(this.b);
            NanoHTTPD.b(this.c);
        }

        public void run() {
            OutputStream outputStream;
            Throwable th;
            Exception e;
            try {
                outputStream = this.c.getOutputStream();
                try {
                    HTTPSession hTTPSession = new HTTPSession(NanoHTTPD.this.l.a(), this.b, outputStream, this.c.getInetAddress());
                    while (!this.c.isClosed()) {
                        hTTPSession.a();
                    }
                } catch (Exception e2) {
                    e = e2;
                    try {
                        if ((!(e instanceof SocketException) || !"NanoHttpd Shutdown".equals(e.getMessage())) && !(e instanceof SocketTimeoutException)) {
                            NanoHTTPD.f.log(Level.SEVERE, "Communication with the client broken, or an bug in the handler code", (Throwable) e);
                        }
                        NanoHTTPD.b(outputStream);
                        NanoHTTPD.b(this.b);
                        NanoHTTPD.b(this.c);
                        NanoHTTPD.this.b.a(this);
                    } catch (Throwable th2) {
                        th = th2;
                        NanoHTTPD.b(outputStream);
                        NanoHTTPD.b(this.b);
                        NanoHTTPD.b(this.c);
                        NanoHTTPD.this.b.a(this);
                        throw th;
                    }
                }
            } catch (Exception e3) {
                outputStream = null;
                e = e3;
                NanoHTTPD.f.log(Level.SEVERE, "Communication with the client broken, or an bug in the handler code", (Throwable) e);
                NanoHTTPD.b(outputStream);
                NanoHTTPD.b(this.b);
                NanoHTTPD.b(this.c);
                NanoHTTPD.this.b.a(this);
            } catch (Throwable th3) {
                outputStream = null;
                th = th3;
                NanoHTTPD.b(outputStream);
                NanoHTTPD.b(this.b);
                NanoHTTPD.b(this.c);
                NanoHTTPD.this.b.a(this);
                throw th;
            }
            NanoHTTPD.b(outputStream);
            NanoHTTPD.b(this.b);
            NanoHTTPD.b(this.c);
            NanoHTTPD.this.b.a(this);
        }
    }

    public static class Cookie {

        /* renamed from: a  reason: collision with root package name */
        private final String f3198a;
        private final String b;
        private final String c;

        public String a() {
            return String.format("%s=%s; expires=%s", this.f3198a, this.b, this.c);
        }
    }

    public class CookieHandler implements Iterable<String> {
        private final HashMap<String, String> b = new HashMap<>();
        private final ArrayList<Cookie> c = new ArrayList<>();

        public CookieHandler(Map<String, String> map) {
            String str = map.get("cookie");
            if (str != null) {
                for (String str2 : str.split(";")) {
                    String[] split = str2.trim().split("=");
                    if (split.length == 2) {
                        this.b.put(split[0], split[1]);
                    }
                }
            }
        }

        @Override // java.lang.Iterable
        public Iterator<String> iterator() {
            return this.b.keySet().iterator();
        }

        public void a(Response response) {
            Iterator<Cookie> it = this.c.iterator();
            while (it.hasNext()) {
                response.a("Set-Cookie", it.next().a());
            }
        }
    }

    public static class DefaultAsyncRunner implements AsyncRunner {

        /* renamed from: a  reason: collision with root package name */
        private long f3200a;
        private final List<ClientHandler> b = Collections.synchronizedList(new ArrayList());

        @Override // fi.iki.elonen.NanoHTTPD.AsyncRunner
        public void a() {
            Iterator it = new ArrayList(this.b).iterator();
            while (it.hasNext()) {
                ((ClientHandler) it.next()).a();
            }
        }

        @Override // fi.iki.elonen.NanoHTTPD.AsyncRunner
        public void a(ClientHandler clientHandler) {
            this.b.remove(clientHandler);
        }

        @Override // fi.iki.elonen.NanoHTTPD.AsyncRunner
        public void b(ClientHandler clientHandler) {
            this.f3200a++;
            Thread thread = new Thread(clientHandler);
            thread.setDaemon(true);
            thread.setName("NanoHttpd Request Processor (#" + this.f3200a + ")");
            this.b.add(clientHandler);
            thread.start();
        }
    }

    public static class DefaultTempFile implements TempFile {

        /* renamed from: a  reason: collision with root package name */
        private final File f3201a;
        private final OutputStream b = new FileOutputStream(this.f3201a);

        public DefaultTempFile(File file) throws IOException {
            this.f3201a = File.createTempFile("NanoHTTPD-", "", file);
        }

        @Override // fi.iki.elonen.NanoHTTPD.TempFile
        public void a() throws Exception {
            NanoHTTPD.b(this.b);
            if (!this.f3201a.delete()) {
                throw new Exception("could not delete temporary file: " + this.f3201a.getAbsolutePath());
            }
        }

        @Override // fi.iki.elonen.NanoHTTPD.TempFile
        public String b() {
            return this.f3201a.getAbsolutePath();
        }
    }

    public static class DefaultTempFileManager implements TempFileManager {

        /* renamed from: a  reason: collision with root package name */
        private final File f3202a = new File(System.getProperty("java.io.tmpdir"));
        private final List<TempFile> b;

        public DefaultTempFileManager() {
            if (!this.f3202a.exists()) {
                this.f3202a.mkdirs();
            }
            this.b = new ArrayList();
        }

        @Override // fi.iki.elonen.NanoHTTPD.TempFileManager
        public void a() {
            for (TempFile tempFile : this.b) {
                try {
                    tempFile.a();
                } catch (Exception e) {
                    NanoHTTPD.f.log(Level.WARNING, "could not delete file ", (Throwable) e);
                }
            }
            this.b.clear();
        }

        @Override // fi.iki.elonen.NanoHTTPD.TempFileManager
        public TempFile a(String str) throws Exception {
            DefaultTempFile defaultTempFile = new DefaultTempFile(this.f3202a);
            this.b.add(defaultTempFile);
            return defaultTempFile;
        }
    }

    private class DefaultTempFileManagerFactory implements TempFileManagerFactory {
        private DefaultTempFileManagerFactory() {
        }

        @Override // fi.iki.elonen.NanoHTTPD.TempFileManagerFactory
        public TempFileManager a() {
            return new DefaultTempFileManager();
        }
    }

    public static class DefaultServerSocketFactory implements ServerSocketFactory {
        @Override // fi.iki.elonen.NanoHTTPD.ServerSocketFactory
        public ServerSocket a() throws IOException {
            return new ServerSocket();
        }
    }

    public static class SecureServerSocketFactory implements ServerSocketFactory {

        /* renamed from: a  reason: collision with root package name */
        private SSLServerSocketFactory f3210a;
        private String[] b;

        @Override // fi.iki.elonen.NanoHTTPD.ServerSocketFactory
        public ServerSocket a() throws IOException {
            SSLServerSocket sSLServerSocket = (SSLServerSocket) this.f3210a.createServerSocket();
            if (this.b != null) {
                sSLServerSocket.setEnabledProtocols(this.b);
            } else {
                sSLServerSocket.setEnabledProtocols(sSLServerSocket.getSupportedProtocols());
            }
            sSLServerSocket.setUseClientMode(false);
            sSLServerSocket.setWantClientAuth(false);
            sSLServerSocket.setNeedClientAuth(false);
            return sSLServerSocket;
        }
    }

    /* access modifiers changed from: protected */
    public static class ContentType {

        /* renamed from: a  reason: collision with root package name */
        private static final Pattern f3197a = Pattern.compile("[ |\t]*([^/^ ^;^,]+/[^ ^;^,]+)", 2);
        private static final Pattern b = Pattern.compile("[ |\t]*(charset)[ |\t]*=[ |\t]*['|\"]?([^\"^'^;^,]*)['|\"]?", 2);
        private static final Pattern c = Pattern.compile("[ |\t]*(boundary)[ |\t]*=[ |\t]*['|\"]?([^\"^'^;^,]*)['|\"]?", 2);
        private final String d;
        private final String e;
        private final String f;
        private final String g;

        public ContentType(String str) {
            this.d = str;
            if (str != null) {
                this.e = a(str, f3197a, "", 1);
                this.f = a(str, b, null, 2);
            } else {
                this.e = "";
                this.f = Utf8Charset.NAME;
            }
            if ("multipart/form-data".equalsIgnoreCase(this.e)) {
                this.g = a(str, c, null, 2);
            } else {
                this.g = null;
            }
        }

        private String a(String str, Pattern pattern, String str2, int i) {
            Matcher matcher = pattern.matcher(str);
            return matcher.find() ? matcher.group(i) : str2;
        }

        public String a() {
            return this.d;
        }

        public String b() {
            return this.e;
        }

        public String c() {
            return this.f == null ? "US-ASCII" : this.f;
        }

        public String d() {
            return this.g;
        }

        public boolean e() {
            return "multipart/form-data".equalsIgnoreCase(this.e);
        }

        public ContentType f() {
            if (this.f != null) {
                return this;
            }
            return new ContentType(this.d + "; charset=UTF-8");
        }
    }

    protected class HTTPSession implements IHTTPSession {
        private final TempFileManager b;
        private final OutputStream c;
        private final BufferedInputStream d;
        private int e;
        private int f;
        private String g;
        private Method h;
        private Map<String, List<String>> i;
        private Map<String, String> j;
        private CookieHandler k;
        private String l;
        private String m;
        private String n;
        private String o;

        public HTTPSession(TempFileManager tempFileManager, InputStream inputStream, OutputStream outputStream, InetAddress inetAddress) {
            this.b = tempFileManager;
            this.d = new BufferedInputStream(inputStream, 8192);
            this.c = outputStream;
            this.m = (inetAddress.isLoopbackAddress() || inetAddress.isAnyLocalAddress()) ? "127.0.0.1" : inetAddress.getHostAddress().toString();
            this.n = (inetAddress.isLoopbackAddress() || inetAddress.isAnyLocalAddress()) ? "localhost" : inetAddress.getHostName().toString();
            this.j = new HashMap();
        }

        private void a(BufferedReader bufferedReader, Map<String, String> map, Map<String, List<String>> map2, Map<String, String> map3) throws ResponseException {
            String str;
            try {
                String readLine = bufferedReader.readLine();
                if (readLine != null) {
                    StringTokenizer stringTokenizer = new StringTokenizer(readLine);
                    if (stringTokenizer.hasMoreTokens()) {
                        map.put("method", stringTokenizer.nextToken());
                        if (stringTokenizer.hasMoreTokens()) {
                            String nextToken = stringTokenizer.nextToken();
                            int indexOf = nextToken.indexOf(63);
                            if (indexOf >= 0) {
                                a(nextToken.substring(indexOf + 1), map2);
                                str = NanoHTTPD.b(nextToken.substring(0, indexOf));
                            } else {
                                str = NanoHTTPD.b(nextToken);
                            }
                            if (stringTokenizer.hasMoreTokens()) {
                                this.o = stringTokenizer.nextToken();
                            } else {
                                this.o = "HTTP/1.1";
                                NanoHTTPD.f.log(Level.FINE, "no protocol version specified, strange. Assuming HTTP/1.1.");
                            }
                            String readLine2 = bufferedReader.readLine();
                            while (readLine2 != null && !readLine2.trim().isEmpty()) {
                                int indexOf2 = readLine2.indexOf(58);
                                if (indexOf2 >= 0) {
                                    map3.put(readLine2.substring(0, indexOf2).trim().toLowerCase(Locale.US), readLine2.substring(indexOf2 + 1).trim());
                                }
                                readLine2 = bufferedReader.readLine();
                            }
                            map.put("uri", str);
                            return;
                        }
                        throw new ResponseException(Response.Status.BAD_REQUEST, "BAD REQUEST: Missing URI. Usage: GET /example/file.html");
                    }
                    throw new ResponseException(Response.Status.BAD_REQUEST, "BAD REQUEST: Syntax error. Usage: GET /example/file.html");
                }
            } catch (IOException e2) {
                Response.Status status = Response.Status.INTERNAL_ERROR;
                throw new ResponseException(status, "SERVER INTERNAL ERROR: IOException: " + e2.getMessage(), e2);
            }
        }

        private void a(ContentType contentType, ByteBuffer byteBuffer, Map<String, List<String>> map, Map<String, String> map2) throws ResponseException {
            String str;
            try {
                int[] a2 = a(byteBuffer, contentType.d().getBytes());
                int i2 = 2;
                if (a2.length >= 2) {
                    int i3 = 1024;
                    byte[] bArr = new byte[1024];
                    int i4 = 0;
                    int i5 = 0;
                    int i6 = 0;
                    while (true) {
                        int i7 = 1;
                        if (i5 < a2.length - 1) {
                            byteBuffer.position(a2[i5]);
                            int remaining = byteBuffer.remaining() < i3 ? byteBuffer.remaining() : 1024;
                            byteBuffer.get(bArr, i4, remaining);
                            BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(new ByteArrayInputStream(bArr, i4, remaining), Charset.forName(contentType.c())), remaining);
                            String readLine = bufferedReader.readLine();
                            if (readLine != null && readLine.contains(contentType.d())) {
                                String readLine2 = bufferedReader.readLine();
                                String str2 = null;
                                int i8 = i6;
                                String str3 = null;
                                String str4 = null;
                                int i9 = 2;
                                while (readLine2 != null && readLine2.trim().length() > 0) {
                                    Matcher matcher = NanoHTTPD.c.matcher(readLine2);
                                    if (matcher.matches()) {
                                        Matcher matcher2 = NanoHTTPD.e.matcher(matcher.group(i2));
                                        while (matcher2.find()) {
                                            String group = matcher2.group(i7);
                                            if ("name".equalsIgnoreCase(group)) {
                                                str = matcher2.group(2);
                                            } else {
                                                if (TbsVideoCacheTask.KEY_VIDEO_CACHE_PARAM_FILENAME.equalsIgnoreCase(group)) {
                                                    String group2 = matcher2.group(2);
                                                    if (!group2.isEmpty()) {
                                                        if (i8 > 0) {
                                                            str = str2 + String.valueOf(i8);
                                                            str3 = group2;
                                                            i8++;
                                                        } else {
                                                            i8++;
                                                        }
                                                    }
                                                    str3 = group2;
                                                }
                                                i7 = 1;
                                            }
                                            str2 = str;
                                            i7 = 1;
                                        }
                                    }
                                    Matcher matcher3 = NanoHTTPD.d.matcher(readLine2);
                                    if (matcher3.matches()) {
                                        str4 = matcher3.group(2).trim();
                                    }
                                    readLine2 = bufferedReader.readLine();
                                    i9++;
                                    i2 = 2;
                                    i7 = 1;
                                }
                                int i10 = 0;
                                while (true) {
                                    int i11 = i9 - 1;
                                    if (i9 <= 0) {
                                        break;
                                    }
                                    i10 = a(bArr, i10);
                                    i9 = i11;
                                }
                                if (i10 < remaining - 4) {
                                    int i12 = a2[i5] + i10;
                                    i5++;
                                    int i13 = a2[i5] - 4;
                                    byteBuffer.position(i12);
                                    List<String> list = map.get(str2);
                                    if (list == null) {
                                        list = new ArrayList<>();
                                        map.put(str2, list);
                                    }
                                    if (str4 == null) {
                                        byte[] bArr2 = new byte[(i13 - i12)];
                                        byteBuffer.get(bArr2);
                                        list.add(new String(bArr2, contentType.c()));
                                    } else {
                                        String a3 = a(byteBuffer, i12, i13 - i12, str3);
                                        if (!map2.containsKey(str2)) {
                                            map2.put(str2, a3);
                                        } else {
                                            int i14 = 2;
                                            while (true) {
                                                if (!map2.containsKey(str2 + i14)) {
                                                    break;
                                                }
                                                i14++;
                                            }
                                            map2.put(str2 + i14, a3);
                                        }
                                        list.add(str3);
                                    }
                                    i6 = i8;
                                    i3 = 1024;
                                    i2 = 2;
                                    i4 = 0;
                                } else {
                                    throw new ResponseException(Response.Status.INTERNAL_ERROR, "Multipart header size exceeds MAX_HEADER_SIZE.");
                                }
                            }
                        } else {
                            return;
                        }
                    }
                    throw new ResponseException(Response.Status.BAD_REQUEST, "BAD REQUEST: Content type is multipart/form-data but chunk does not start with boundary.");
                }
                throw new ResponseException(Response.Status.BAD_REQUEST, "BAD REQUEST: Content type is multipart/form-data but contains less than two boundary strings.");
            } catch (ResponseException e2) {
                throw e2;
            } catch (Exception e3) {
                throw new ResponseException(Response.Status.INTERNAL_ERROR, e3.toString());
            }
        }

        private int a(byte[] bArr, int i2) {
            while (bArr[i2] != 10) {
                i2++;
            }
            return i2 + 1;
        }

        private void a(String str, Map<String, List<String>> map) {
            String str2;
            String str3;
            if (str == null) {
                this.l = "";
                return;
            }
            this.l = str;
            StringTokenizer stringTokenizer = new StringTokenizer(str, "&");
            while (stringTokenizer.hasMoreTokens()) {
                String nextToken = stringTokenizer.nextToken();
                int indexOf = nextToken.indexOf(61);
                if (indexOf >= 0) {
                    str3 = NanoHTTPD.b(nextToken.substring(0, indexOf)).trim();
                    str2 = NanoHTTPD.b(nextToken.substring(indexOf + 1));
                } else {
                    str3 = NanoHTTPD.b(nextToken).trim();
                    str2 = "";
                }
                List<String> list = map.get(str3);
                if (list == null) {
                    list = new ArrayList<>();
                    map.put(str3, list);
                }
                list.add(str2);
            }
        }

        /* JADX WARNING: Code restructure failed: missing block: B:70:0x019f, code lost:
            r0 = e;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:75:0x01c1, code lost:
            r0 = e;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:77:0x01ea, code lost:
            r0 = e;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:80:0x0214, code lost:
            r0 = move-exception;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:81:0x0216, code lost:
            r0 = move-exception;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:86:?, code lost:
            throw r0;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:88:?, code lost:
            throw r0;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Removed duplicated region for block: B:70:0x019f A[ExcHandler: ResponseException (e fi.iki.elonen.NanoHTTPD$ResponseException), Splitter:B:1:0x0003] */
        /* JADX WARNING: Removed duplicated region for block: B:80:0x0214 A[ExcHandler: SocketTimeoutException (r0v3 'e' java.net.SocketTimeoutException A[CUSTOM_DECLARE]), Splitter:B:1:0x0003] */
        /* JADX WARNING: Removed duplicated region for block: B:81:0x0216 A[ExcHandler: SocketException (r0v2 'e' java.net.SocketException A[CUSTOM_DECLARE]), Splitter:B:1:0x0003] */
        public void a() throws IOException {
            Throwable th;
            Response response = null;
            try {
                byte[] bArr = new byte[8192];
                boolean z = false;
                this.e = 0;
                this.f = 0;
                this.d.mark(8192);
                int read = this.d.read(bArr, 0, 8192);
                if (read != -1) {
                    while (read > 0) {
                        this.f += read;
                        this.e = b(bArr, this.f);
                        if (this.e > 0) {
                            break;
                        }
                        read = this.d.read(bArr, this.f, 8192 - this.f);
                    }
                    if (this.e < this.f) {
                        this.d.reset();
                        this.d.skip((long) this.e);
                    }
                    this.i = new HashMap();
                    if (this.j == null) {
                        this.j = new HashMap();
                    } else {
                        this.j.clear();
                    }
                    BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(new ByteArrayInputStream(bArr, 0, this.f)));
                    HashMap hashMap = new HashMap();
                    a(bufferedReader, hashMap, this.i, this.j);
                    if (this.m != null) {
                        this.j.put("remote-addr", this.m);
                        this.j.put("http-client-ip", this.m);
                    }
                    this.h = Method.a(hashMap.get("method"));
                    if (this.h != null) {
                        this.g = hashMap.get("uri");
                        this.k = new CookieHandler(this.j);
                        String str = this.j.get("connection");
                        boolean z2 = "HTTP/1.1".equals(this.o) && (str == null || !str.matches("(?i).*close.*"));
                        Response a2 = NanoHTTPD.this.a((IHTTPSession) this);
                        if (a2 != null) {
                            try {
                                String str2 = this.j.get("accept-encoding");
                                this.k.a(a2);
                                a2.a(this.h);
                                if (NanoHTTPD.this.a(a2) && str2 != null && str2.contains("gzip")) {
                                    z = true;
                                }
                                a2.a(z);
                                a2.b(z2);
                                a2.a(this.c);
                                if (!z2 || a2.c()) {
                                    throw new SocketException("NanoHttpd Shutdown");
                                }
                                NanoHTTPD.b(a2);
                                this.b.a();
                            } catch (SocketException e2) {
                                throw e2;
                            } catch (SocketTimeoutException e3) {
                                throw e3;
                            } catch (SSLException e4) {
                                SSLException e5 = e4;
                                response = a2;
                                NanoHTTPD.a(Response.Status.INTERNAL_ERROR, "text/plain", "SSL PROTOCOL FAILURE: " + e5.getMessage()).a(this.c);
                                NanoHTTPD.b(this.c);
                                NanoHTTPD.b(response);
                                this.b.a();
                            } catch (IOException e6) {
                                IOException e7 = e6;
                                response = a2;
                                NanoHTTPD.a(Response.Status.INTERNAL_ERROR, "text/plain", "SERVER INTERNAL ERROR: IOException: " + e7.getMessage()).a(this.c);
                                NanoHTTPD.b(this.c);
                                NanoHTTPD.b(response);
                                this.b.a();
                            } catch (ResponseException e8) {
                                ResponseException e9 = e8;
                                response = a2;
                                try {
                                    NanoHTTPD.a(e9.a(), "text/plain", e9.getMessage()).a(this.c);
                                    NanoHTTPD.b(this.c);
                                    NanoHTTPD.b(response);
                                    this.b.a();
                                } catch (Throwable th2) {
                                    th = th2;
                                    NanoHTTPD.b(response);
                                    this.b.a();
                                    throw th;
                                }
                            } catch (Throwable th3) {
                                th = th3;
                                response = a2;
                                NanoHTTPD.b(response);
                                this.b.a();
                                throw th;
                            }
                        } else {
                            throw new ResponseException(Response.Status.INTERNAL_ERROR, "SERVER INTERNAL ERROR: Serve() returned a null response.");
                        }
                    } else {
                        throw new ResponseException(Response.Status.BAD_REQUEST, "BAD REQUEST: Syntax error. HTTP verb " + hashMap.get("method") + " unhandled.");
                    }
                } else {
                    NanoHTTPD.b(this.d);
                    NanoHTTPD.b(this.c);
                    throw new SocketException("NanoHttpd Shutdown");
                }
            } catch (SSLException e10) {
                throw e10;
            } catch (IOException unused) {
                NanoHTTPD.b(this.d);
                NanoHTTPD.b(this.c);
                throw new SocketException("NanoHttpd Shutdown");
            } catch (SocketException e11) {
            } catch (SocketTimeoutException e12) {
            } catch (ResponseException e13) {
            }
        }

        private int b(byte[] bArr, int i2) {
            int i3;
            int i4 = 0;
            while (true) {
                int i5 = i4 + 1;
                if (i5 >= i2) {
                    return 0;
                }
                if (bArr[i4] == 13 && bArr[i5] == 10 && (i3 = i4 + 3) < i2 && bArr[i4 + 2] == 13 && bArr[i3] == 10) {
                    return i4 + 4;
                }
                if (bArr[i4] == 10 && bArr[i5] == 10) {
                    return i4 + 2;
                }
                i4 = i5;
            }
        }

        private int[] a(ByteBuffer byteBuffer, byte[] bArr) {
            int[] iArr = new int[0];
            if (byteBuffer.remaining() < bArr.length) {
                return iArr;
            }
            byte[] bArr2 = new byte[(bArr.length + 4096)];
            int remaining = byteBuffer.remaining() < bArr2.length ? byteBuffer.remaining() : bArr2.length;
            byteBuffer.get(bArr2, 0, remaining);
            int length = remaining - bArr.length;
            int[] iArr2 = iArr;
            int i2 = 0;
            while (true) {
                int[] iArr3 = iArr2;
                int i3 = 0;
                while (i3 < length) {
                    int[] iArr4 = iArr3;
                    int i4 = 0;
                    while (i4 < bArr.length && bArr2[i3 + i4] == bArr[i4]) {
                        if (i4 == bArr.length - 1) {
                            int[] iArr5 = new int[(iArr4.length + 1)];
                            System.arraycopy(iArr4, 0, iArr5, 0, iArr4.length);
                            iArr5[iArr4.length] = i2 + i3;
                            iArr4 = iArr5;
                        }
                        i4++;
                    }
                    i3++;
                    iArr3 = iArr4;
                }
                i2 += length;
                System.arraycopy(bArr2, bArr2.length - bArr.length, bArr2, 0, bArr.length);
                length = bArr2.length - bArr.length;
                if (byteBuffer.remaining() < length) {
                    length = byteBuffer.remaining();
                }
                byteBuffer.get(bArr2, bArr.length, length);
                if (length <= 0) {
                    return iArr3;
                }
                iArr2 = iArr3;
            }
        }

        @Override // fi.iki.elonen.NanoHTTPD.IHTTPSession
        public final Map<String, String> b() {
            return this.j;
        }

        @Override // fi.iki.elonen.NanoHTTPD.IHTTPSession
        public final Method c() {
            return this.h;
        }

        @Override // fi.iki.elonen.NanoHTTPD.IHTTPSession
        @Deprecated
        public final Map<String, String> d() {
            HashMap hashMap = new HashMap();
            for (String str : this.i.keySet()) {
                hashMap.put(str, this.i.get(str).get(0));
            }
            return hashMap;
        }

        @Override // fi.iki.elonen.NanoHTTPD.IHTTPSession
        public String e() {
            return this.l;
        }

        private RandomAccessFile h() {
            try {
                return new RandomAccessFile(this.b.a(null).b(), "rw");
            } catch (Exception e2) {
                throw new Error(e2);
            }
        }

        @Override // fi.iki.elonen.NanoHTTPD.IHTTPSession
        public final String f() {
            return this.g;
        }

        public long g() {
            if (this.j.containsKey("content-length")) {
                return Long.parseLong(this.j.get("content-length"));
            }
            if (this.e < this.f) {
                return (long) (this.f - this.e);
            }
            return 0;
        }

        @Override // fi.iki.elonen.NanoHTTPD.IHTTPSession
        public void a(Map<String, String> map) throws IOException, ResponseException {
            RandomAccessFile randomAccessFile;
            Throwable th;
            DataOutput dataOutput;
            ByteArrayOutputStream byteArrayOutputStream;
            ByteBuffer byteBuffer;
            try {
                long g2 = g();
                if (g2 < 1024) {
                    ByteArrayOutputStream byteArrayOutputStream2 = new ByteArrayOutputStream();
                    dataOutput = new DataOutputStream(byteArrayOutputStream2);
                    byteArrayOutputStream = byteArrayOutputStream2;
                    randomAccessFile = null;
                } else {
                    randomAccessFile = h();
                    byteArrayOutputStream = null;
                    dataOutput = randomAccessFile;
                }
                try {
                    byte[] bArr = new byte[512];
                    while (this.f >= 0 && g2 > 0) {
                        this.f = this.d.read(bArr, 0, (int) Math.min(g2, 512L));
                        g2 -= (long) this.f;
                        if (this.f > 0) {
                            dataOutput.write(bArr, 0, this.f);
                        }
                    }
                    if (byteArrayOutputStream != null) {
                        byteBuffer = ByteBuffer.wrap(byteArrayOutputStream.toByteArray(), 0, byteArrayOutputStream.size());
                    } else {
                        byteBuffer = randomAccessFile.getChannel().map(FileChannel.MapMode.READ_ONLY, 0, randomAccessFile.length());
                        randomAccessFile.seek(0);
                    }
                    if (Method.POST.equals(this.h)) {
                        ContentType contentType = new ContentType(this.j.get("content-type"));
                        if (!contentType.e()) {
                            byte[] bArr2 = new byte[byteBuffer.remaining()];
                            byteBuffer.get(bArr2);
                            String trim = new String(bArr2, contentType.c()).trim();
                            if ("application/x-www-form-urlencoded".equalsIgnoreCase(contentType.b())) {
                                a(trim, this.i);
                            } else if (trim.length() != 0) {
                                map.put("postData", trim);
                            }
                        } else if (contentType.d() != null) {
                            a(contentType, byteBuffer, this.i, map);
                        } else {
                            throw new ResponseException(Response.Status.BAD_REQUEST, "BAD REQUEST: Content type is multipart/form-data but boundary missing. Usage: GET /example/file.html");
                        }
                    } else if (Method.PUT.equals(this.h)) {
                        map.put("content", a(byteBuffer, 0, byteBuffer.limit(), (String) null));
                    }
                    NanoHTTPD.b(randomAccessFile);
                } catch (Throwable th2) {
                    th = th2;
                    NanoHTTPD.b(randomAccessFile);
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                randomAccessFile = null;
                NanoHTTPD.b(randomAccessFile);
                throw th;
            }
        }

        private String a(ByteBuffer byteBuffer, int i2, int i3, String str) {
            Throwable th;
            Exception e2;
            String str2 = "";
            if (i3 > 0) {
                FileOutputStream fileOutputStream = null;
                try {
                    TempFile a2 = this.b.a(str);
                    ByteBuffer duplicate = byteBuffer.duplicate();
                    FileOutputStream fileOutputStream2 = new FileOutputStream(a2.b());
                    try {
                        FileChannel channel = fileOutputStream2.getChannel();
                        duplicate.position(i2).limit(i2 + i3);
                        channel.write(duplicate.slice());
                        str2 = a2.b();
                        NanoHTTPD.b(fileOutputStream2);
                    } catch (Exception e3) {
                        e2 = e3;
                        fileOutputStream = fileOutputStream2;
                        try {
                            throw new Error(e2);
                        } catch (Throwable th2) {
                            th = th2;
                            NanoHTTPD.b(fileOutputStream);
                            throw th;
                        }
                    } catch (Throwable th3) {
                        th = th3;
                        fileOutputStream = fileOutputStream2;
                        NanoHTTPD.b(fileOutputStream);
                        throw th;
                    }
                } catch (Exception e4) {
                    e2 = e4;
                    throw new Error(e2);
                }
            }
            return str2;
        }
    }

    public enum Method {
        GET,
        PUT,
        POST,
        DELETE,
        HEAD,
        OPTIONS,
        TRACE,
        CONNECT,
        PATCH,
        PROPFIND,
        PROPPATCH,
        MKCOL,
        MOVE,
        COPY,
        LOCK,
        UNLOCK;

        static Method a(String str) {
            if (str == null) {
                return null;
            }
            try {
                return valueOf(str);
            } catch (IllegalArgumentException unused) {
                return null;
            }
        }
    }

    public static class Response implements Closeable {

        /* renamed from: a  reason: collision with root package name */
        private IStatus f3206a;
        private String b;
        private InputStream c;
        private long d;
        private final Map<String, String> e = new HashMap<String, String>() {
            /* class fi.iki.elonen.NanoHTTPD.Response.AnonymousClass1 */

            /* renamed from: a */
            public String put(String str, String str2) {
                Response.this.f.put(str == null ? str : str.toLowerCase(), str2);
                return (String) super.put(str, str2);
            }
        };
        private final Map<String, String> f = new HashMap();
        private Method g;
        private boolean h;
        private boolean i;
        private boolean j;

        public interface IStatus {
            String a();
        }

        public enum Status implements IStatus {
            SWITCH_PROTOCOL(101, "Switching Protocols"),
            OK(200, "OK"),
            CREATED(TbsListener.ErrorCode.EXCEED_UNZIP_RETRY_NUM, "Created"),
            ACCEPTED(TbsListener.ErrorCode.APK_PATH_ERROR, "Accepted"),
            NO_CONTENT(TbsListener.ErrorCode.APK_INVALID, "No Content"),
            PARTIAL_CONTENT(TbsListener.ErrorCode.UNZIP_IO_ERROR, "Partial Content"),
            MULTI_STATUS(TbsListener.ErrorCode.UNZIP_OTHER_ERROR, "Multi-Status"),
            REDIRECT(301, "Moved Permanently"),
            FOUND(TbsListener.ErrorCode.ERROR_UNMATCH_TBSCORE_VER_THIRDPARTY, "Found"),
            REDIRECT_SEE_OTHER(TbsListener.ErrorCode.ERROR_UNMATCH_TBSCORE_VER, "See Other"),
            NOT_MODIFIED(TbsListener.ErrorCode.ERROR_HOST_UNAVAILABLE, "Not Modified"),
            TEMPORARY_REDIRECT(307, "Temporary Redirect"),
            BAD_REQUEST(TbsListener.ErrorCode.INFO_CODE_BASE, "Bad Request"),
            UNAUTHORIZED(TbsListener.ErrorCode.INFO_FORCE_SYSTEM_WEBVIEW_INNER, "Unauthorized"),
            FORBIDDEN(TbsListener.ErrorCode.INFO_MISS_SDKEXTENSION_JAR, "Forbidden"),
            NOT_FOUND(404, "Not Found"),
            METHOD_NOT_ALLOWED(TbsListener.ErrorCode.INFO_CAN_NOT_LOAD_TBS, "Method Not Allowed"),
            NOT_ACCEPTABLE(TbsListener.ErrorCode.INFO_MISS_SDKEXTENSION_JAR_OLD, "Not Acceptable"),
            REQUEST_TIMEOUT(TbsListener.ErrorCode.INFO_CAN_NOT_DISABLED_BY_CRASH, "Request Timeout"),
            CONFLICT(TbsListener.ErrorCode.INFO_CAN_NOT_USE_X5_TBS_AVAILABLE, "Conflict"),
            GONE(TbsListener.ErrorCode.INFO_CAN_NOT_USE_X5_TBS_NOTAVAILABLE, "Gone"),
            LENGTH_REQUIRED(TbsListener.ErrorCode.INFO_CAN_NOT_USE_X5_FINAL_REASON, "Length Required"),
            PRECONDITION_FAILED(TbsListener.ErrorCode.INFO_MISS_SDKEXTENSION_JAR_WITHOUT_FUSION_DEX, "Precondition Failed"),
            PAYLOAD_TOO_LARGE(TbsListener.ErrorCode.INFO_MISS_SDKEXTENSION_JAR_WITH_FUSION_DEX, "Payload Too Large"),
            UNSUPPORTED_MEDIA_TYPE(TbsListener.ErrorCode.INFO_INITX5_FALSE_DEFAULT, "Unsupported Media Type"),
            RANGE_NOT_SATISFIABLE(TbsListener.ErrorCode.INFO_USE_BACKUP_FILE_INSTALL_BY_SERVER, "Requested Range Not Satisfiable"),
            EXPECTATION_FAILED(TbsListener.ErrorCode.INFO_TEMP_CORE_EXIST_CONF_ERROR, "Expectation Failed"),
            TOO_MANY_REQUESTS(429, "Too Many Requests"),
            INTERNAL_ERROR(500, "Internal Server Error"),
            NOT_IMPLEMENTED(501, "Not Implemented"),
            SERVICE_UNAVAILABLE(TbsListener.ErrorCode.INFO_CODE_MINIQB_STARTMINIQBTOLOADURL_SUCCESS, "Service Unavailable"),
            UNSUPPORTED_HTTP_VERSION(TbsListener.ErrorCode.INFO_CODE_FILEREADER_OPENFILEREADER_COUNTS, "HTTP Version Not Supported");
            
            private final int G;
            private final String H;

            private Status(int i, String str) {
                this.G = i;
                this.H = str;
            }

            @Override // fi.iki.elonen.NanoHTTPD.Response.IStatus
            public String a() {
                return "" + this.G + " " + this.H;
            }
        }

        /* access modifiers changed from: private */
        public static class ChunkedOutputStream extends FilterOutputStream {
            public ChunkedOutputStream(OutputStream outputStream) {
                super(outputStream);
            }

            @Override // java.io.OutputStream, java.io.FilterOutputStream
            public void write(int i) throws IOException {
                write(new byte[]{(byte) i}, 0, 1);
            }

            @Override // java.io.OutputStream, java.io.FilterOutputStream
            public void write(byte[] bArr) throws IOException {
                write(bArr, 0, bArr.length);
            }

            @Override // java.io.OutputStream, java.io.FilterOutputStream
            public void write(byte[] bArr, int i, int i2) throws IOException {
                if (i2 != 0) {
                    this.out.write(String.format("%x\r\n", Integer.valueOf(i2)).getBytes());
                    this.out.write(bArr, i, i2);
                    this.out.write("\r\n".getBytes());
                }
            }

            public void a() throws IOException {
                this.out.write("0\r\n\r\n".getBytes());
            }
        }

        protected Response(IStatus iStatus, String str, InputStream inputStream, long j2) {
            this.f3206a = iStatus;
            this.b = str;
            boolean z = false;
            if (inputStream == null) {
                this.c = new ByteArrayInputStream(new byte[0]);
                this.d = 0;
            } else {
                this.c = inputStream;
                this.d = j2;
            }
            this.h = this.d < 0 ? true : z;
            this.j = true;
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
            if (this.c != null) {
                this.c.close();
            }
        }

        public void a(String str, String str2) {
            this.e.put(str, str2);
        }

        public boolean c() {
            return "close".equals(a("connection"));
        }

        public String a(String str) {
            return this.f.get(str.toLowerCase());
        }

        public String d() {
            return this.b;
        }

        public IStatus e() {
            return this.f3206a;
        }

        public void a(boolean z) {
            this.i = z;
        }

        public void b(boolean z) {
            this.j = z;
        }

        /* access modifiers changed from: protected */
        public void a(OutputStream outputStream) {
            SimpleDateFormat simpleDateFormat = new SimpleDateFormat("E, d MMM yyyy HH:mm:ss 'GMT'", Locale.US);
            simpleDateFormat.setTimeZone(TimeZone.getTimeZone("GMT"));
            try {
                if (this.f3206a != null) {
                    PrintWriter printWriter = new PrintWriter((Writer) new BufferedWriter(new OutputStreamWriter(outputStream, new ContentType(this.b).c())), false);
                    printWriter.append("HTTP/1.1 ").append((CharSequence) this.f3206a.a()).append(" \r\n");
                    if (this.b != null) {
                        a(printWriter, HttpHeaders.CONTENT_TYPE, this.b);
                    }
                    if (a("date") == null) {
                        a(printWriter, "Date", simpleDateFormat.format(new Date()));
                    }
                    for (Map.Entry<String, String> entry : this.e.entrySet()) {
                        a(printWriter, entry.getKey(), entry.getValue());
                    }
                    if (a("connection") == null) {
                        a(printWriter, "Connection", this.j ? "keep-alive" : "close");
                    }
                    if (a("content-length") != null) {
                        this.i = false;
                    }
                    if (this.i) {
                        a(printWriter, "Content-Encoding", "gzip");
                        c(true);
                    }
                    long j2 = this.c != null ? this.d : 0;
                    if (this.g != Method.HEAD && this.h) {
                        a(printWriter, "Transfer-Encoding", "chunked");
                    } else if (!this.i) {
                        j2 = a(printWriter, j2);
                    }
                    printWriter.append("\r\n");
                    printWriter.flush();
                    a(outputStream, j2);
                    outputStream.flush();
                    NanoHTTPD.b(this.c);
                    return;
                }
                throw new Error("sendResponse(): Status can't be null.");
            } catch (IOException e2) {
                NanoHTTPD.f.log(Level.SEVERE, "Could not send response to the client", (Throwable) e2);
            }
        }

        /* access modifiers changed from: protected */
        public void a(PrintWriter printWriter, String str, String str2) {
            printWriter.append((CharSequence) str).append(": ").append((CharSequence) str2).append("\r\n");
        }

        /* access modifiers changed from: protected */
        public long a(PrintWriter printWriter, long j2) {
            String a2 = a("content-length");
            if (a2 != null) {
                try {
                    j2 = Long.parseLong(a2);
                } catch (NumberFormatException unused) {
                    Logger logger = NanoHTTPD.f;
                    logger.severe("content-length was no number " + a2);
                }
            }
            printWriter.print("Content-Length: " + j2 + "\r\n");
            return j2;
        }

        private void a(OutputStream outputStream, long j2) throws IOException {
            if (this.g == Method.HEAD || !this.h) {
                b(outputStream, j2);
                return;
            }
            ChunkedOutputStream chunkedOutputStream = new ChunkedOutputStream(outputStream);
            b(chunkedOutputStream, -1);
            chunkedOutputStream.a();
        }

        private void b(OutputStream outputStream, long j2) throws IOException {
            if (this.i) {
                GZIPOutputStream gZIPOutputStream = new GZIPOutputStream(outputStream);
                c(gZIPOutputStream, -1);
                gZIPOutputStream.finish();
                return;
            }
            c(outputStream, j2);
        }

        private void c(OutputStream outputStream, long j2) throws IOException {
            long j3;
            byte[] bArr = new byte[((int) 16384)];
            boolean z = j2 == -1;
            while (true) {
                if (j2 > 0 || z) {
                    if (z) {
                        j3 = 16384;
                    } else {
                        j3 = Math.min(j2, 16384L);
                    }
                    int read = this.c.read(bArr, 0, (int) j3);
                    if (read > 0) {
                        outputStream.write(bArr, 0, read);
                        if (!z) {
                            j2 -= (long) read;
                        }
                    } else {
                        return;
                    }
                } else {
                    return;
                }
            }
        }

        public void c(boolean z) {
            this.h = z;
        }

        public void a(Method method) {
            this.g = method;
        }
    }

    public static final class ResponseException extends Exception {
        private static final long serialVersionUID = 6569838532917408380L;

        /* renamed from: a  reason: collision with root package name */
        private final Response.Status f3209a;

        public ResponseException(Response.Status status, String str) {
            super(str);
            this.f3209a = status;
        }

        public ResponseException(Response.Status status, String str, Exception exc) {
            super(str, exc);
            this.f3209a = status;
        }

        public Response.Status a() {
            return this.f3209a;
        }
    }

    public class ServerRunnable implements Runnable {
        private final int b;
        private IOException c;
        private boolean d = false;

        public ServerRunnable(int i) {
            this.b = i;
        }

        public void run() {
            try {
                NanoHTTPD.this.i.bind(NanoHTTPD.this.g != null ? new InetSocketAddress(NanoHTTPD.this.g, NanoHTTPD.this.h) : new InetSocketAddress(NanoHTTPD.this.h));
                this.d = true;
                do {
                    try {
                        Socket accept = NanoHTTPD.this.i.accept();
                        if (this.b > 0) {
                            accept.setSoTimeout(this.b);
                        }
                        NanoHTTPD.this.b.b(NanoHTTPD.this.a(accept, accept.getInputStream()));
                    } catch (IOException e) {
                        NanoHTTPD.f.log(Level.FINE, "Communication with the client broken", (Throwable) e);
                    }
                } while (!NanoHTTPD.this.i.isClosed());
            } catch (IOException e2) {
                this.c = e2;
            }
        }
    }

    public static Map<String, String> a() {
        if (f3195a == null) {
            f3195a = new HashMap();
            a(f3195a, "META-INF/nanohttpd/default-mimetypes.properties");
            a(f3195a, "META-INF/nanohttpd/mimetypes.properties");
            if (f3195a.isEmpty()) {
                f.log(Level.WARNING, "no mime types found in the classpath! please provide mimetypes.properties");
            }
        }
        return f3195a;
    }

    private static void a(Map<String, String> map, String str) {
        Throwable th;
        InputStream inputStream;
        IOException e2;
        try {
            Enumeration<URL> resources = NanoHTTPD.class.getClassLoader().getResources(str);
            while (resources.hasMoreElements()) {
                URL nextElement = resources.nextElement();
                Properties properties = new Properties();
                try {
                    inputStream = nextElement.openStream();
                    try {
                        properties.load(inputStream);
                    } catch (IOException e3) {
                        e2 = e3;
                        try {
                            f.log(Level.SEVERE, "could not load mimetypes from " + nextElement, (Throwable) e2);
                            b(inputStream);
                            map.putAll(properties);
                        } catch (Throwable th2) {
                            th = th2;
                        }
                    }
                } catch (IOException e4) {
                    inputStream = null;
                    e2 = e4;
                    f.log(Level.SEVERE, "could not load mimetypes from " + nextElement, (Throwable) e2);
                    b(inputStream);
                    map.putAll(properties);
                } catch (Throwable th3) {
                    th = th3;
                    inputStream = null;
                    b(inputStream);
                    throw th;
                }
                b(inputStream);
                map.putAll(properties);
            }
        } catch (IOException unused) {
            f.log(Level.INFO, "no mime types available at " + str);
        }
    }

    public static String a(String str) {
        int lastIndexOf = str.lastIndexOf(46);
        String str2 = lastIndexOf >= 0 ? a().get(str.substring(lastIndexOf + 1).toLowerCase()) : null;
        return str2 == null ? "application/octet-stream" : str2;
    }

    /* access modifiers changed from: private */
    public static final void b(Object obj) {
        if (obj != null) {
            try {
                if (obj instanceof Closeable) {
                    ((Closeable) obj).close();
                } else if (obj instanceof Socket) {
                    ((Socket) obj).close();
                } else if (obj instanceof ServerSocket) {
                    ((ServerSocket) obj).close();
                } else {
                    throw new IllegalArgumentException("Unknown object to close");
                }
            } catch (IOException e2) {
                f.log(Level.SEVERE, "Could not close", (Throwable) e2);
            }
        }
    }

    public NanoHTTPD(String str, int i2) {
        this.g = str;
        this.h = i2;
        a((TempFileManagerFactory) new DefaultTempFileManagerFactory());
        a((AsyncRunner) new DefaultAsyncRunner());
    }

    /* access modifiers changed from: protected */
    public ClientHandler a(Socket socket, InputStream inputStream) {
        return new ClientHandler(inputStream, socket);
    }

    /* access modifiers changed from: protected */
    public ServerRunnable a(int i2) {
        return new ServerRunnable(i2);
    }

    protected static String b(String str) {
        try {
            return URLDecoder.decode(str, "UTF8");
        } catch (UnsupportedEncodingException e2) {
            f.log(Level.WARNING, "Encoding not supported, ignored", (Throwable) e2);
            return null;
        }
    }

    /* access modifiers changed from: protected */
    public boolean a(Response response) {
        return response.d() != null && (response.d().toLowerCase().contains("text/") || response.d().toLowerCase().contains("/json"));
    }

    public final boolean b() {
        return f() && !this.i.isClosed() && this.k.isAlive();
    }

    public ServerSocketFactory c() {
        return this.j;
    }

    public static Response a(Response.IStatus iStatus, String str, InputStream inputStream, long j2) {
        return new Response(iStatus, str, inputStream, j2);
    }

    public static Response a(Response.IStatus iStatus, String str, String str2) {
        byte[] bArr;
        ContentType contentType = new ContentType(str);
        if (str2 == null) {
            return a(iStatus, str, new ByteArrayInputStream(new byte[0]), 0);
        }
        try {
            if (!Charset.forName(contentType.c()).newEncoder().canEncode(str2)) {
                contentType = contentType.f();
            }
            bArr = str2.getBytes(contentType.c());
        } catch (UnsupportedEncodingException e2) {
            f.log(Level.SEVERE, "encoding problem, responding nothing", (Throwable) e2);
            bArr = new byte[0];
        }
        return a(iStatus, contentType.a(), new ByteArrayInputStream(bArr), (long) bArr.length);
    }

    public Response a(IHTTPSession iHTTPSession) {
        HashMap hashMap = new HashMap();
        Method c2 = iHTTPSession.c();
        if (Method.PUT.equals(c2) || Method.POST.equals(c2)) {
            try {
                iHTTPSession.a(hashMap);
            } catch (IOException e2) {
                Response.Status status = Response.Status.INTERNAL_ERROR;
                return a(status, "text/plain", "SERVER INTERNAL ERROR: IOException: " + e2.getMessage());
            } catch (ResponseException e3) {
                return a(e3.a(), "text/plain", e3.getMessage());
            }
        }
        Map<String, String> d2 = iHTTPSession.d();
        d2.put("NanoHttpd.QUERY_STRING", iHTTPSession.e());
        return a(iHTTPSession.f(), c2, iHTTPSession.b(), d2, hashMap);
    }

    @Deprecated
    public Response a(String str, Method method, Map<String, String> map, Map<String, String> map2, Map<String, String> map3) {
        return a(Response.Status.NOT_FOUND, "text/plain", "Not Found");
    }

    public void a(AsyncRunner asyncRunner) {
        this.b = asyncRunner;
    }

    public void a(TempFileManagerFactory tempFileManagerFactory) {
        this.l = tempFileManagerFactory;
    }

    public void d() throws IOException {
        b(TbsReaderView.ReaderCallback.GET_BAR_ANIMATING);
    }

    public void b(int i2) throws IOException {
        a(i2, true);
    }

    public void a(int i2, boolean z) throws IOException {
        this.i = c().a();
        this.i.setReuseAddress(true);
        ServerRunnable a2 = a(i2);
        this.k = new Thread(a2);
        this.k.setDaemon(z);
        this.k.setName("NanoHttpd Main Listener");
        this.k.start();
        while (!a2.d && a2.c == null) {
            try {
                Thread.sleep(10);
            } catch (Throwable unused) {
            }
        }
        if (a2.c != null) {
            throw a2.c;
        }
    }

    public void e() {
        try {
            b(this.i);
            this.b.a();
            if (this.k != null) {
                this.k.join();
            }
        } catch (Exception e2) {
            f.log(Level.SEVERE, "Could not stop all connections", (Throwable) e2);
        }
    }

    public final boolean f() {
        return (this.i == null || this.k == null) ? false : true;
    }
}
