package net.minidev.json.reader;

import java.io.IOException;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.Date;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import net.minidev.json.JSONAware;
import net.minidev.json.JSONAwareEx;
import net.minidev.json.JSONStreamAware;
import net.minidev.json.JSONStreamAwareEx;
import net.minidev.json.JSONStyle;
import net.minidev.json.JSONValue;

public class JsonWriter {

    /* renamed from: a  reason: collision with root package name */
    public static final JsonWriterI<JSONStreamAwareEx> f3296a = new JsonWriterI<JSONStreamAwareEx>() {
        /* class net.minidev.json.reader.JsonWriter.AnonymousClass1 */

        public <E extends JSONStreamAwareEx> void a(E e, Appendable appendable, JSONStyle jSONStyle) throws IOException {
            e.a(appendable);
        }
    };
    public static final JsonWriterI<JSONStreamAwareEx> b = new JsonWriterI<JSONStreamAwareEx>() {
        /* class net.minidev.json.reader.JsonWriter.AnonymousClass2 */

        public <E extends JSONStreamAwareEx> void a(E e, Appendable appendable, JSONStyle jSONStyle) throws IOException {
            e.a(appendable, jSONStyle);
        }
    };
    public static final JsonWriterI<JSONAwareEx> c = new JsonWriterI<JSONAwareEx>() {
        /* class net.minidev.json.reader.JsonWriter.AnonymousClass3 */

        public <E extends JSONAwareEx> void a(E e, Appendable appendable, JSONStyle jSONStyle) throws IOException {
            appendable.append(e.a(jSONStyle));
        }
    };
    public static final JsonWriterI<JSONAware> d = new JsonWriterI<JSONAware>() {
        /* class net.minidev.json.reader.JsonWriter.AnonymousClass4 */

        public <E extends JSONAware> void a(E e, Appendable appendable, JSONStyle jSONStyle) throws IOException {
            appendable.append(e.b());
        }
    };
    public static final JsonWriterI<Iterable<? extends Object>> e = new JsonWriterI<Iterable<? extends Object>>() {
        /* class net.minidev.json.reader.JsonWriter.AnonymousClass5 */

        public <E extends Iterable<? extends Object>> void a(E e, Appendable appendable, JSONStyle jSONStyle) throws IOException {
            jSONStyle.g(appendable);
            boolean z = true;
            for (Object obj : e) {
                if (z) {
                    z = false;
                    jSONStyle.i(appendable);
                } else {
                    jSONStyle.j(appendable);
                }
                if (obj == null) {
                    appendable.append("null");
                } else {
                    JSONValue.a(obj, appendable, jSONStyle);
                }
                jSONStyle.k(appendable);
            }
            jSONStyle.h(appendable);
        }
    };
    public static final JsonWriterI<Enum<?>> f = new JsonWriterI<Enum<?>>() {
        /* class net.minidev.json.reader.JsonWriter.AnonymousClass6 */

        public <E extends Enum<?>> void a(E e, Appendable appendable, JSONStyle jSONStyle) throws IOException {
            jSONStyle.a(appendable, e.name());
        }
    };
    public static final JsonWriterI<Map<String, ? extends Object>> g = new JsonWriterI<Map<String, ? extends Object>>() {
        /* class net.minidev.json.reader.JsonWriter.AnonymousClass7 */

        public <E extends Map<String, ? extends Object>> void a(E e, Appendable appendable, JSONStyle jSONStyle) throws IOException {
            jSONStyle.a(appendable);
            boolean z = true;
            for (Map.Entry entry : e.entrySet()) {
                Object value = entry.getValue();
                if (value != null || !jSONStyle.a()) {
                    if (z) {
                        jSONStyle.c(appendable);
                        z = false;
                    } else {
                        jSONStyle.d(appendable);
                    }
                    JsonWriter.a(entry.getKey().toString(), value, appendable, jSONStyle);
                }
            }
            jSONStyle.b(appendable);
        }
    };
    public static final JsonWriterI<Object> h = new BeansWriterASM();
    public static final JsonWriterI<Object> i = new BeansWriter();
    public static final JsonWriterI<Object> j = new ArrayWriter();
    public static final JsonWriterI<Object> k = new JsonWriterI<Object>() {
        /* class net.minidev.json.reader.JsonWriter.AnonymousClass8 */

        @Override // net.minidev.json.reader.JsonWriterI
        public void a(Object obj, Appendable appendable, JSONStyle jSONStyle) throws IOException {
            appendable.append(obj.toString());
        }
    };
    private ConcurrentHashMap<Class<?>, JsonWriterI<?>> l = new ConcurrentHashMap<>();
    private LinkedList<WriterByInterface> m = new LinkedList<>();

    public JsonWriter() {
        a();
    }

    /* access modifiers changed from: package-private */
    public static class WriterByInterface {

        /* renamed from: a  reason: collision with root package name */
        public Class<?> f3307a;
        public JsonWriterI<?> b;

        public WriterByInterface(Class<?> cls, JsonWriterI<?> jsonWriterI) {
            this.f3307a = cls;
            this.b = jsonWriterI;
        }
    }

    public JsonWriterI a(Class<?> cls) {
        Iterator<WriterByInterface> it = this.m.iterator();
        while (it.hasNext()) {
            WriterByInterface next = it.next();
            if (next.f3307a.isAssignableFrom(cls)) {
                return next.b;
            }
        }
        return null;
    }

    public JsonWriterI b(Class cls) {
        return this.l.get(cls);
    }

    public void a() {
        a(new JsonWriterI<String>() {
            /* class net.minidev.json.reader.JsonWriter.AnonymousClass9 */

            public void a(String str, Appendable appendable, JSONStyle jSONStyle) throws IOException {
                jSONStyle.a(appendable, str);
            }
        }, String.class);
        a(new JsonWriterI<Double>() {
            /* class net.minidev.json.reader.JsonWriter.AnonymousClass10 */

            public void a(Double d, Appendable appendable, JSONStyle jSONStyle) throws IOException {
                if (d.isInfinite()) {
                    appendable.append("null");
                } else {
                    appendable.append(d.toString());
                }
            }
        }, Double.class);
        a(new JsonWriterI<Date>() {
            /* class net.minidev.json.reader.JsonWriter.AnonymousClass11 */

            public void a(Date date, Appendable appendable, JSONStyle jSONStyle) throws IOException {
                appendable.append('\"');
                JSONValue.a(date.toString(), appendable, jSONStyle);
                appendable.append('\"');
            }
        }, Date.class);
        a(new JsonWriterI<Float>() {
            /* class net.minidev.json.reader.JsonWriter.AnonymousClass12 */

            public void a(Float f, Appendable appendable, JSONStyle jSONStyle) throws IOException {
                if (f.isInfinite()) {
                    appendable.append("null");
                } else {
                    appendable.append(f.toString());
                }
            }
        }, Float.class);
        a(k, Integer.class, Long.class, Byte.class, Short.class, BigInteger.class, BigDecimal.class);
        a(k, Boolean.class);
        a(new JsonWriterI<int[]>() {
            /* class net.minidev.json.reader.JsonWriter.AnonymousClass13 */

            public void a(int[] iArr, Appendable appendable, JSONStyle jSONStyle) throws IOException {
                jSONStyle.g(appendable);
                boolean z = false;
                for (int i : iArr) {
                    if (z) {
                        jSONStyle.d(appendable);
                    } else {
                        z = true;
                    }
                    appendable.append(Integer.toString(i));
                }
                jSONStyle.h(appendable);
            }
        }, int[].class);
        a(new JsonWriterI<short[]>() {
            /* class net.minidev.json.reader.JsonWriter.AnonymousClass14 */

            public void a(short[] sArr, Appendable appendable, JSONStyle jSONStyle) throws IOException {
                jSONStyle.g(appendable);
                boolean z = false;
                for (short s : sArr) {
                    if (z) {
                        jSONStyle.d(appendable);
                    } else {
                        z = true;
                    }
                    appendable.append(Short.toString(s));
                }
                jSONStyle.h(appendable);
            }
        }, short[].class);
        a(new JsonWriterI<long[]>() {
            /* class net.minidev.json.reader.JsonWriter.AnonymousClass15 */

            public void a(long[] jArr, Appendable appendable, JSONStyle jSONStyle) throws IOException {
                jSONStyle.g(appendable);
                boolean z = false;
                for (long j : jArr) {
                    if (z) {
                        jSONStyle.d(appendable);
                    } else {
                        z = true;
                    }
                    appendable.append(Long.toString(j));
                }
                jSONStyle.h(appendable);
            }
        }, long[].class);
        a(new JsonWriterI<float[]>() {
            /* class net.minidev.json.reader.JsonWriter.AnonymousClass16 */

            public void a(float[] fArr, Appendable appendable, JSONStyle jSONStyle) throws IOException {
                jSONStyle.g(appendable);
                boolean z = false;
                for (float f : fArr) {
                    if (z) {
                        jSONStyle.d(appendable);
                    } else {
                        z = true;
                    }
                    appendable.append(Float.toString(f));
                }
                jSONStyle.h(appendable);
            }
        }, float[].class);
        a(new JsonWriterI<double[]>() {
            /* class net.minidev.json.reader.JsonWriter.AnonymousClass17 */

            public void a(double[] dArr, Appendable appendable, JSONStyle jSONStyle) throws IOException {
                jSONStyle.g(appendable);
                boolean z = false;
                for (double d : dArr) {
                    if (z) {
                        jSONStyle.d(appendable);
                    } else {
                        z = true;
                    }
                    appendable.append(Double.toString(d));
                }
                jSONStyle.h(appendable);
            }
        }, double[].class);
        a(new JsonWriterI<boolean[]>() {
            /* class net.minidev.json.reader.JsonWriter.AnonymousClass18 */

            public void a(boolean[] zArr, Appendable appendable, JSONStyle jSONStyle) throws IOException {
                jSONStyle.g(appendable);
                boolean z = false;
                for (boolean z2 : zArr) {
                    if (z) {
                        jSONStyle.d(appendable);
                    } else {
                        z = true;
                    }
                    appendable.append(Boolean.toString(z2));
                }
                jSONStyle.h(appendable);
            }
        }, boolean[].class);
        b(JSONStreamAwareEx.class, b);
        b(JSONStreamAware.class, f3296a);
        b(JSONAwareEx.class, c);
        b(JSONAware.class, d);
        b(Map.class, g);
        b(Iterable.class, e);
        b(Enum.class, f);
        b(Number.class, k);
    }

    public void a(Class<?> cls, JsonWriterI<?> jsonWriterI) {
        this.m.addLast(new WriterByInterface(cls, jsonWriterI));
    }

    public void b(Class<?> cls, JsonWriterI<?> jsonWriterI) {
        a(cls, jsonWriterI);
    }

    public <T> void a(JsonWriterI<T> jsonWriterI, Class<?>... clsArr) {
        for (Class<?> cls : clsArr) {
            this.l.put(cls, jsonWriterI);
        }
    }

    public static void a(String str, Object obj, Appendable appendable, JSONStyle jSONStyle) throws IOException {
        if (str == null) {
            appendable.append("null");
        } else if (!jSONStyle.a(str)) {
            appendable.append(str);
        } else {
            appendable.append('\"');
            JSONValue.a(str, appendable, jSONStyle);
            appendable.append('\"');
        }
        jSONStyle.f(appendable);
        if (obj instanceof String) {
            jSONStyle.a(appendable, (String) obj);
        } else {
            JSONValue.a(obj, appendable, jSONStyle);
        }
        jSONStyle.e(appendable);
    }
}
