package net.minidev.json.writer;

import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import net.minidev.json.JSONArray;
import net.minidev.json.JSONAware;
import net.minidev.json.JSONAwareEx;
import net.minidev.json.JSONObject;
import net.minidev.json.writer.ArraysMapper;
import net.minidev.json.writer.BeansMapper;
import net.minidev.json.writer.CollectionMapper;

public class JsonReader {

    /* renamed from: a  reason: collision with root package name */
    public JsonReaderI<JSONAwareEx> f3319a;
    public JsonReaderI<JSONAwareEx> b;
    private final ConcurrentHashMap<Type, JsonReaderI<?>> c = new ConcurrentHashMap<>(100);

    public JsonReader() {
        this.c.put(Date.class, BeansMapper.f3309a);
        this.c.put(int[].class, ArraysMapper.f3308a);
        this.c.put(Integer[].class, ArraysMapper.b);
        this.c.put(short[].class, ArraysMapper.f3308a);
        this.c.put(Short[].class, ArraysMapper.b);
        this.c.put(long[].class, ArraysMapper.i);
        this.c.put(Long[].class, ArraysMapper.j);
        this.c.put(byte[].class, ArraysMapper.e);
        this.c.put(Byte[].class, ArraysMapper.f);
        this.c.put(char[].class, ArraysMapper.g);
        this.c.put(Character[].class, ArraysMapper.h);
        this.c.put(float[].class, ArraysMapper.k);
        this.c.put(Float[].class, ArraysMapper.l);
        this.c.put(double[].class, ArraysMapper.m);
        this.c.put(Double[].class, ArraysMapper.n);
        this.c.put(boolean[].class, ArraysMapper.o);
        this.c.put(Boolean[].class, ArraysMapper.p);
        this.f3319a = new DefaultMapper(this);
        this.b = new DefaultMapperOrdered(this);
        this.c.put(JSONAwareEx.class, this.f3319a);
        this.c.put(JSONAware.class, this.f3319a);
        this.c.put(JSONArray.class, this.f3319a);
        this.c.put(JSONObject.class, this.f3319a);
    }

    public <T> JsonReaderI<T> a(Type type) {
        if (type instanceof ParameterizedType) {
            return a((ParameterizedType) type);
        }
        return a((Class) ((Class) type));
    }

    public <T> JsonReaderI<T> a(Class<T> cls) {
        JsonReaderI<T> jsonReaderI;
        DefaultMapperCollection defaultMapperCollection = (JsonReaderI<T>) this.c.get(cls);
        if (defaultMapperCollection != null) {
            return defaultMapperCollection;
        }
        if (cls instanceof Class) {
            if (Map.class.isAssignableFrom(cls)) {
                defaultMapperCollection = new DefaultMapperCollection(this, cls);
            } else if (List.class.isAssignableFrom(cls)) {
                defaultMapperCollection = new DefaultMapperCollection(this, cls);
            }
            if (defaultMapperCollection != null) {
                this.c.put(cls, defaultMapperCollection);
                return defaultMapperCollection;
            }
        }
        if (cls.isArray()) {
            jsonReaderI = new ArraysMapper.GenericMapper<>(this, cls);
        } else if (List.class.isAssignableFrom(cls)) {
            jsonReaderI = new CollectionMapper.ListClass<>(this, cls);
        } else if (Map.class.isAssignableFrom(cls)) {
            jsonReaderI = new CollectionMapper.MapClass<>(this, cls);
        } else {
            jsonReaderI = new BeansMapper.Bean<>(this, cls);
        }
        this.c.putIfAbsent(cls, jsonReaderI);
        return jsonReaderI;
    }

    public <T> JsonReaderI<T> a(ParameterizedType parameterizedType) {
        CollectionMapper.MapType mapType = (JsonReaderI<T>) this.c.get(parameterizedType);
        if (mapType != null) {
            return mapType;
        }
        Class cls = (Class) parameterizedType.getRawType();
        if (List.class.isAssignableFrom(cls)) {
            mapType = new CollectionMapper.ListType(this, parameterizedType);
        } else if (Map.class.isAssignableFrom(cls)) {
            mapType = new CollectionMapper.MapType(this, parameterizedType);
        }
        this.c.putIfAbsent(parameterizedType, mapType);
        return mapType;
    }
}
