package org.apache.commons.lang3.reflect;

import java.lang.reflect.AccessibleObject;
import java.lang.reflect.Member;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import org.apache.commons.lang3.ClassUtils;

/* access modifiers changed from: package-private */
public abstract class MemberUtils {

    /* renamed from: a  reason: collision with root package name */
    private static final Class<?>[] f3455a = {Byte.TYPE, Short.TYPE, Character.TYPE, Integer.TYPE, Long.TYPE, Float.TYPE, Double.TYPE};

    static boolean a(int i) {
        return (i & 7) == 0;
    }

    MemberUtils() {
    }

    static boolean a(AccessibleObject accessibleObject) {
        if (accessibleObject == null || accessibleObject.isAccessible()) {
            return false;
        }
        Member member = (Member) accessibleObject;
        if (!accessibleObject.isAccessible() && Modifier.isPublic(member.getModifiers()) && a(member.getDeclaringClass().getModifiers())) {
            try {
                accessibleObject.setAccessible(true);
                return true;
            } catch (SecurityException unused) {
            }
        }
        return false;
    }

    static boolean a(Member member) {
        return member != null && Modifier.isPublic(member.getModifiers()) && !member.isSynthetic();
    }

    static int a(Method method, Method method2, Class<?>[] clsArr) {
        return a(Executable.b(method), Executable.b(method2), clsArr);
    }

    private static int a(Executable executable, Executable executable2, Class<?>[] clsArr) {
        float a2 = a(clsArr, executable);
        float a3 = a(clsArr, executable2);
        if (a2 < a3) {
            return -1;
        }
        return a3 < a2 ? 1 : 0;
    }

    private static float a(Class<?>[] clsArr, Executable executable) {
        Class<?>[] a2 = executable.a();
        boolean b = executable.b();
        long length = (long) (b ? a2.length - 1 : a2.length);
        if (((long) clsArr.length) < length) {
            return Float.MAX_VALUE;
        }
        boolean z = false;
        float f = 0.0f;
        for (int i = 0; ((long) i) < length; i++) {
            f += a(clsArr[i], a2[i]);
        }
        if (!b) {
            return f;
        }
        boolean z2 = clsArr.length < a2.length;
        if (clsArr.length == a2.length && clsArr[clsArr.length - 1].isArray()) {
            z = true;
        }
        Class<?> componentType = a2[a2.length - 1].getComponentType();
        if (z2) {
            return f + a(componentType, Object.class) + 0.001f;
        }
        if (z) {
            return f + a(clsArr[clsArr.length - 1].getComponentType(), componentType) + 0.001f;
        }
        for (int length2 = a2.length - 1; length2 < clsArr.length; length2++) {
            f += a(clsArr[length2], componentType) + 0.001f;
        }
        return f;
    }

    private static float a(Class<?> cls, Class<?> cls2) {
        if (cls2.isPrimitive()) {
            return b(cls, cls2);
        }
        float f = 0.0f;
        while (true) {
            if (cls != null && !cls2.equals(cls)) {
                if (cls2.isInterface() && ClassUtils.a(cls, cls2)) {
                    f += 0.25f;
                    break;
                }
                f += 1.0f;
                cls = cls.getSuperclass();
            } else {
                break;
            }
        }
        return cls == null ? f + 1.5f : f;
    }

    private static float b(Class<?> cls, Class<?> cls2) {
        float f;
        if (!cls.isPrimitive()) {
            cls = ClassUtils.f(cls);
            f = 0.1f;
        } else {
            f = 0.0f;
        }
        int i = 0;
        while (cls != cls2 && i < f3455a.length) {
            if (cls == f3455a[i]) {
                f += 0.1f;
                if (i < f3455a.length - 1) {
                    cls = f3455a[i + 1];
                }
            }
            i++;
        }
        return f;
    }

    static boolean a(Method method, Class<?>[] clsArr) {
        return a(Executable.b(method), clsArr);
    }

    private static boolean a(Executable executable, Class<?>[] clsArr) {
        Class<?>[] a2 = executable.a();
        if (ClassUtils.a(clsArr, a2, true)) {
            return true;
        }
        if (!executable.b()) {
            return false;
        }
        int i = 0;
        while (i < a2.length - 1 && i < clsArr.length) {
            if (!ClassUtils.a(clsArr[i], a2[i], true)) {
                return false;
            }
            i++;
        }
        Class<?> componentType = a2[a2.length - 1].getComponentType();
        while (i < clsArr.length) {
            if (!ClassUtils.a(clsArr[i], componentType, true)) {
                return false;
            }
            i++;
        }
        return true;
    }

    /* access modifiers changed from: private */
    public static final class Executable {

        /* renamed from: a  reason: collision with root package name */
        private final Class<?>[] f3456a;
        private final boolean b;

        /* access modifiers changed from: private */
        public static Executable b(Method method) {
            return new Executable(method);
        }

        private Executable(Method method) {
            this.f3456a = method.getParameterTypes();
            this.b = method.isVarArgs();
        }

        public Class<?>[] a() {
            return this.f3456a;
        }

        public boolean b() {
            return this.b;
        }
    }
}
