package org.apache.commons.lang3.reflect;

import java.lang.reflect.GenericArrayType;
import java.lang.reflect.GenericDeclaration;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.lang.reflect.WildcardType;
import java.util.Arrays;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Objects;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.ClassUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.Validate;
import org.apache.commons.lang3.builder.Builder;

public class TypeUtils {

    /* renamed from: a  reason: collision with root package name */
    public static final WildcardType f3458a = a().a(Object.class).a();

    /* access modifiers changed from: package-private */
    /* renamed from: org.apache.commons.lang3.reflect.TypeUtils$1  reason: invalid class name */
    public static class AnonymousClass1 implements Typed<T> {
    }

    public static class WildcardTypeBuilder implements Builder<WildcardType> {

        /* renamed from: a  reason: collision with root package name */
        private Type[] f3461a;
        private Type[] b;

        /* synthetic */ WildcardTypeBuilder(AnonymousClass1 r1) {
            this();
        }

        private WildcardTypeBuilder() {
        }

        public WildcardTypeBuilder a(Type... typeArr) {
            this.f3461a = typeArr;
            return this;
        }

        public WildcardType a() {
            return new WildcardTypeImpl(this.f3461a, this.b, null);
        }
    }

    private static final class GenericArrayTypeImpl implements GenericArrayType {

        /* renamed from: a  reason: collision with root package name */
        private final Type f3459a;

        public Type getGenericComponentType() {
            return this.f3459a;
        }

        public String toString() {
            return TypeUtils.a((Type) this);
        }

        public boolean equals(Object obj) {
            return obj == this || ((obj instanceof GenericArrayType) && TypeUtils.b(this, (GenericArrayType) obj));
        }

        public int hashCode() {
            return this.f3459a.hashCode() | 1072;
        }
    }

    private static final class ParameterizedTypeImpl implements ParameterizedType {

        /* renamed from: a  reason: collision with root package name */
        private final Class<?> f3460a;
        private final Type b;
        private final Type[] c;

        public Type getRawType() {
            return this.f3460a;
        }

        public Type getOwnerType() {
            return this.b;
        }

        public Type[] getActualTypeArguments() {
            return (Type[]) this.c.clone();
        }

        public String toString() {
            return TypeUtils.a((Type) this);
        }

        public boolean equals(Object obj) {
            return obj == this || ((obj instanceof ParameterizedType) && TypeUtils.b(this, (ParameterizedType) obj));
        }

        public int hashCode() {
            return ((((this.f3460a.hashCode() | 1136) << 4) | Objects.hashCode(this.b)) << 8) | Arrays.hashCode(this.c);
        }
    }

    /* access modifiers changed from: private */
    public static final class WildcardTypeImpl implements WildcardType {

        /* renamed from: a  reason: collision with root package name */
        private static final Type[] f3462a = new Type[0];
        private final Type[] b;
        private final Type[] c;

        /* synthetic */ WildcardTypeImpl(Type[] typeArr, Type[] typeArr2, AnonymousClass1 r3) {
            this(typeArr, typeArr2);
        }

        private WildcardTypeImpl(Type[] typeArr, Type[] typeArr2) {
            this.b = (Type[]) ObjectUtils.a(typeArr, f3462a);
            this.c = (Type[]) ObjectUtils.a(typeArr2, f3462a);
        }

        public Type[] getUpperBounds() {
            return (Type[]) this.b.clone();
        }

        public Type[] getLowerBounds() {
            return (Type[]) this.c.clone();
        }

        public String toString() {
            return TypeUtils.a((Type) this);
        }

        public boolean equals(Object obj) {
            return obj == this || ((obj instanceof WildcardType) && TypeUtils.b(this, (WildcardType) obj));
        }

        public int hashCode() {
            return ((Arrays.hashCode(this.b) | 18688) << 8) | Arrays.hashCode(this.c);
        }
    }

    public static boolean a(Type type, Type type2) {
        return a(type, type2, (Map<TypeVariable<?>, Type>) null);
    }

    private static boolean a(Type type, Type type2, Map<TypeVariable<?>, Type> map) {
        if (type2 == null || (type2 instanceof Class)) {
            return b(type, (Class<?>) ((Class) type2));
        }
        if (type2 instanceof ParameterizedType) {
            return a(type, (ParameterizedType) type2, map);
        }
        if (type2 instanceof GenericArrayType) {
            return a(type, (GenericArrayType) type2, map);
        }
        if (type2 instanceof WildcardType) {
            return a(type, (WildcardType) type2, map);
        }
        if (type2 instanceof TypeVariable) {
            return a(type, (TypeVariable<?>) ((TypeVariable) type2), map);
        }
        throw new IllegalStateException("found an unhandled type: " + type2);
    }

    private static boolean b(Type type, Class<?> cls) {
        if (type == null) {
            return cls == null || !cls.isPrimitive();
        }
        if (cls == null) {
            return false;
        }
        if (cls.equals(type)) {
            return true;
        }
        if (type instanceof Class) {
            return ClassUtils.a((Class) type, cls);
        }
        if (type instanceof ParameterizedType) {
            return b((Type) a((ParameterizedType) type), cls);
        }
        if (type instanceof TypeVariable) {
            for (Type type2 : ((TypeVariable) type).getBounds()) {
                if (b(type2, cls)) {
                    return true;
                }
            }
            return false;
        } else if (type instanceof GenericArrayType) {
            if (cls.equals(Object.class)) {
                return true;
            }
            if (!cls.isArray() || !b(((GenericArrayType) type).getGenericComponentType(), cls.getComponentType())) {
                return false;
            }
            return true;
        } else if (type instanceof WildcardType) {
            return false;
        } else {
            throw new IllegalStateException("found an unhandled type: " + type);
        }
    }

    private static boolean a(Type type, ParameterizedType parameterizedType, Map<TypeVariable<?>, Type> map) {
        if (type == null) {
            return true;
        }
        if (parameterizedType == null) {
            return false;
        }
        if (parameterizedType.equals(type)) {
            return true;
        }
        Class<?> a2 = a(parameterizedType);
        Map<TypeVariable<?>, Type> a3 = a(type, a2, (Map<TypeVariable<?>, Type>) null);
        if (a3 == null) {
            return false;
        }
        if (a3.isEmpty()) {
            return true;
        }
        Map<TypeVariable<?>, Type> a4 = a(parameterizedType, a2, map);
        for (TypeVariable<?> typeVariable : a4.keySet()) {
            Type a5 = a(typeVariable, a4);
            Type a6 = a(typeVariable, a3);
            if ((a5 != null || !(a6 instanceof Class)) && a6 != null && !a5.equals(a6)) {
                if (!(a5 instanceof WildcardType) || !a(a6, a5, map)) {
                    return false;
                }
            }
        }
        return true;
    }

    private static Type a(TypeVariable<?> typeVariable, Map<TypeVariable<?>, Type> map) {
        Type type;
        while (true) {
            type = map.get(typeVariable);
            if (!(type instanceof TypeVariable) || type.equals(typeVariable)) {
                return type;
            }
            typeVariable = (TypeVariable) type;
        }
        return type;
    }

    private static boolean a(Type type, GenericArrayType genericArrayType, Map<TypeVariable<?>, Type> map) {
        if (type == null) {
            return true;
        }
        if (genericArrayType == null) {
            return false;
        }
        if (genericArrayType.equals(type)) {
            return true;
        }
        Type genericComponentType = genericArrayType.getGenericComponentType();
        if (type instanceof Class) {
            Class cls = (Class) type;
            if (!cls.isArray() || !a(cls.getComponentType(), genericComponentType, map)) {
                return false;
            }
            return true;
        } else if (type instanceof GenericArrayType) {
            return a(((GenericArrayType) type).getGenericComponentType(), genericComponentType, map);
        } else {
            if (type instanceof WildcardType) {
                for (Type type2 : a((WildcardType) type)) {
                    if (a(type2, genericArrayType)) {
                        return true;
                    }
                }
                return false;
            } else if (type instanceof TypeVariable) {
                for (Type type3 : a((TypeVariable<?>) ((TypeVariable) type))) {
                    if (a(type3, genericArrayType)) {
                        return true;
                    }
                }
                return false;
            } else if (type instanceof ParameterizedType) {
                return false;
            } else {
                throw new IllegalStateException("found an unhandled type: " + type);
            }
        }
    }

    private static boolean a(Type type, WildcardType wildcardType, Map<TypeVariable<?>, Type> map) {
        if (type == null) {
            return true;
        }
        if (wildcardType == null) {
            return false;
        }
        if (wildcardType.equals(type)) {
            return true;
        }
        Type[] a2 = a(wildcardType);
        Type[] b = b(wildcardType);
        if (type instanceof WildcardType) {
            WildcardType wildcardType2 = (WildcardType) type;
            Type[] a3 = a(wildcardType2);
            Type[] b2 = b(wildcardType2);
            for (Type type2 : a2) {
                Type a4 = a(type2, map);
                for (Type type3 : a3) {
                    if (!a(type3, a4, map)) {
                        return false;
                    }
                }
            }
            for (Type type4 : b) {
                Type a5 = a(type4, map);
                for (Type type5 : b2) {
                    if (!a(a5, type5, map)) {
                        return false;
                    }
                }
            }
            return true;
        }
        for (Type type6 : a2) {
            if (!a(type, a(type6, map), map)) {
                return false;
            }
        }
        for (Type type7 : b) {
            if (!a(a(type7, map), type, map)) {
                return false;
            }
        }
        return true;
    }

    private static boolean a(Type type, TypeVariable<?> typeVariable, Map<TypeVariable<?>, Type> map) {
        if (type == null) {
            return true;
        }
        if (typeVariable == null) {
            return false;
        }
        if (typeVariable.equals(type)) {
            return true;
        }
        if (type instanceof TypeVariable) {
            for (Type type2 : a((TypeVariable<?>) ((TypeVariable) type))) {
                if (a(type2, typeVariable, map)) {
                    return true;
                }
            }
        }
        if ((type instanceof Class) || (type instanceof ParameterizedType) || (type instanceof GenericArrayType) || (type instanceof WildcardType)) {
            return false;
        }
        throw new IllegalStateException("found an unhandled type: " + type);
    }

    private static Type a(Type type, Map<TypeVariable<?>, Type> map) {
        if (!(type instanceof TypeVariable) || map == null) {
            return type;
        }
        Type type2 = map.get(type);
        if (type2 != null) {
            return type2;
        }
        throw new IllegalArgumentException("missing assignment type for type variable " + type);
    }

    public static Map<TypeVariable<?>, Type> a(Type type, Class<?> cls) {
        return a(type, cls, (Map<TypeVariable<?>, Type>) null);
    }

    private static Map<TypeVariable<?>, Type> a(Type type, Class<?> cls, Map<TypeVariable<?>, Type> map) {
        if (type instanceof Class) {
            return a((Class<?>) ((Class) type), cls, map);
        }
        if (type instanceof ParameterizedType) {
            return a((ParameterizedType) type, cls, map);
        }
        if (type instanceof GenericArrayType) {
            Type genericComponentType = ((GenericArrayType) type).getGenericComponentType();
            if (cls.isArray()) {
                cls = cls.getComponentType();
            }
            return a(genericComponentType, cls, map);
        }
        int i = 0;
        if (type instanceof WildcardType) {
            Type[] a2 = a((WildcardType) type);
            int length = a2.length;
            while (i < length) {
                Type type2 = a2[i];
                if (b(type2, cls)) {
                    return a(type2, cls, map);
                }
                i++;
            }
            return null;
        } else if (type instanceof TypeVariable) {
            Type[] a3 = a((TypeVariable<?>) ((TypeVariable) type));
            int length2 = a3.length;
            while (i < length2) {
                Type type3 = a3[i];
                if (b(type3, cls)) {
                    return a(type3, cls, map);
                }
                i++;
            }
            return null;
        } else {
            throw new IllegalStateException("found an unhandled type: " + type);
        }
    }

    private static Map<TypeVariable<?>, Type> a(ParameterizedType parameterizedType, Class<?> cls, Map<TypeVariable<?>, Type> map) {
        Map<TypeVariable<?>, Type> map2;
        Class<?> a2 = a(parameterizedType);
        if (!b((Type) a2, cls)) {
            return null;
        }
        Type ownerType = parameterizedType.getOwnerType();
        if (ownerType instanceof ParameterizedType) {
            ParameterizedType parameterizedType2 = (ParameterizedType) ownerType;
            map2 = a(parameterizedType2, a(parameterizedType2), map);
        } else {
            map2 = map == null ? new HashMap<>() : new HashMap(map);
        }
        Type[] actualTypeArguments = parameterizedType.getActualTypeArguments();
        TypeVariable<Class<?>>[] typeParameters = a2.getTypeParameters();
        for (int i = 0; i < typeParameters.length; i++) {
            Type type = actualTypeArguments[i];
            TypeVariable<Class<?>> typeVariable = typeParameters[i];
            if (map2.containsKey(type)) {
                type = map2.get(type);
            }
            map2.put(typeVariable, type);
        }
        if (cls.equals(a2)) {
            return map2;
        }
        return a(a(a2, cls), cls, map2);
    }

    private static Map<TypeVariable<?>, Type> a(Class<?> cls, Class<?> cls2, Map<TypeVariable<?>, Type> map) {
        if (!b((Type) cls, cls2)) {
            return null;
        }
        if (cls.isPrimitive()) {
            if (cls2.isPrimitive()) {
                return new HashMap();
            }
            cls = ClassUtils.e(cls);
        }
        HashMap hashMap = map == null ? new HashMap() : new HashMap(map);
        if (cls2.equals(cls)) {
            return hashMap;
        }
        return a(a(cls, cls2), cls2, (Map<TypeVariable<?>, Type>) hashMap);
    }

    private static Type a(Class<?> cls, Class<?> cls2) {
        Class<?> cls3;
        if (cls2.isInterface()) {
            Type[] genericInterfaces = cls.getGenericInterfaces();
            Type type = null;
            for (Type type2 : genericInterfaces) {
                if (type2 instanceof ParameterizedType) {
                    cls3 = a((ParameterizedType) type2);
                } else if (type2 instanceof Class) {
                    cls3 = (Class) type2;
                } else {
                    throw new IllegalStateException("Unexpected generic interface type found: " + type2);
                }
                if (b((Type) cls3, cls2) && a(type, (Type) cls3)) {
                    type = type2;
                }
            }
            if (type != null) {
                return type;
            }
        }
        return cls.getGenericSuperclass();
    }

    public static Type[] a(Type[] typeArr) {
        boolean z;
        Validate.a((Object) typeArr, "null value specified for bounds array", new Object[0]);
        if (typeArr.length < 2) {
            return typeArr;
        }
        HashSet hashSet = new HashSet(typeArr.length);
        for (Type type : typeArr) {
            int length = typeArr.length;
            int i = 0;
            while (true) {
                if (i >= length) {
                    z = false;
                    break;
                }
                Type type2 = typeArr[i];
                if (type != type2 && a(type2, type, (Map<TypeVariable<?>, Type>) null)) {
                    z = true;
                    break;
                }
                i++;
            }
            if (!z) {
                hashSet.add(type);
            }
        }
        return (Type[]) hashSet.toArray(new Type[hashSet.size()]);
    }

    public static Type[] a(TypeVariable<?> typeVariable) {
        Validate.a(typeVariable, "typeVariable is null", new Object[0]);
        Type[] bounds = typeVariable.getBounds();
        if (bounds.length != 0) {
            return a(bounds);
        }
        return new Type[]{Object.class};
    }

    public static Type[] a(WildcardType wildcardType) {
        Validate.a(wildcardType, "wildcardType is null", new Object[0]);
        Type[] upperBounds = wildcardType.getUpperBounds();
        if (upperBounds.length != 0) {
            return a(upperBounds);
        }
        return new Type[]{Object.class};
    }

    public static Type[] b(WildcardType wildcardType) {
        Validate.a(wildcardType, "wildcardType is null", new Object[0]);
        Type[] lowerBounds = wildcardType.getLowerBounds();
        if (lowerBounds.length != 0) {
            return lowerBounds;
        }
        return new Type[]{null};
    }

    private static Class<?> a(ParameterizedType parameterizedType) {
        Type rawType = parameterizedType.getRawType();
        if (rawType instanceof Class) {
            return (Class) rawType;
        }
        throw new IllegalStateException("Wait... What!? Type of rawType: " + rawType);
    }

    public static WildcardTypeBuilder a() {
        return new WildcardTypeBuilder(null);
    }

    public static boolean b(Type type, Type type2) {
        if (Objects.equals(type, type2)) {
            return true;
        }
        if (type instanceof ParameterizedType) {
            return b((ParameterizedType) type, type2);
        }
        if (type instanceof GenericArrayType) {
            return b((GenericArrayType) type, type2);
        }
        if (type instanceof WildcardType) {
            return b((WildcardType) type, type2);
        }
        return false;
    }

    /* access modifiers changed from: private */
    public static boolean b(ParameterizedType parameterizedType, Type type) {
        if (!(type instanceof ParameterizedType)) {
            return false;
        }
        ParameterizedType parameterizedType2 = (ParameterizedType) type;
        if (!b(parameterizedType.getRawType(), parameterizedType2.getRawType()) || !b(parameterizedType.getOwnerType(), parameterizedType2.getOwnerType())) {
            return false;
        }
        return a(parameterizedType.getActualTypeArguments(), parameterizedType2.getActualTypeArguments());
    }

    /* access modifiers changed from: private */
    public static boolean b(GenericArrayType genericArrayType, Type type) {
        return (type instanceof GenericArrayType) && b(genericArrayType.getGenericComponentType(), ((GenericArrayType) type).getGenericComponentType());
    }

    /* access modifiers changed from: private */
    public static boolean b(WildcardType wildcardType, Type type) {
        if (!(type instanceof WildcardType)) {
            return false;
        }
        WildcardType wildcardType2 = (WildcardType) type;
        if (!a(b(wildcardType), b(wildcardType2)) || !a(a(wildcardType), a(wildcardType2))) {
            return false;
        }
        return true;
    }

    private static boolean a(Type[] typeArr, Type[] typeArr2) {
        if (typeArr.length != typeArr2.length) {
            return false;
        }
        for (int i = 0; i < typeArr.length; i++) {
            if (!b(typeArr[i], typeArr2[i])) {
                return false;
            }
        }
        return true;
    }

    public static String a(Type type) {
        Validate.a(type);
        if (type instanceof Class) {
            return a((Class<?>) ((Class) type));
        }
        if (type instanceof ParameterizedType) {
            return b((ParameterizedType) type);
        }
        if (type instanceof WildcardType) {
            return c((WildcardType) type);
        }
        if (type instanceof TypeVariable) {
            return c((TypeVariable) type);
        }
        if (type instanceof GenericArrayType) {
            return a((GenericArrayType) type);
        }
        throw new IllegalArgumentException(ObjectUtils.a(type));
    }

    public static String b(TypeVariable<?> typeVariable) {
        Validate.a(typeVariable, "var is null", new Object[0]);
        StringBuilder sb = new StringBuilder();
        GenericDeclaration genericDeclaration = typeVariable.getGenericDeclaration();
        if (genericDeclaration instanceof Class) {
            Class<?> cls = (Class) genericDeclaration;
            while (cls.getEnclosingClass() != null) {
                sb.insert(0, cls.getSimpleName()).insert(0, '.');
                cls = cls.getEnclosingClass();
            }
            sb.insert(0, cls.getName());
        } else if (genericDeclaration instanceof Type) {
            sb.append(a((Type) genericDeclaration));
        } else {
            sb.append(genericDeclaration);
        }
        sb.append(':');
        sb.append(c(typeVariable));
        return sb.toString();
    }

    private static String a(Class<?> cls) {
        if (cls.isArray()) {
            return a((Type) cls.getComponentType()) + "[]";
        }
        StringBuilder sb = new StringBuilder();
        if (cls.getEnclosingClass() != null) {
            sb.append(a(cls.getEnclosingClass()));
            sb.append('.');
            sb.append(cls.getSimpleName());
        } else {
            sb.append(cls.getName());
        }
        if (cls.getTypeParameters().length > 0) {
            sb.append('<');
            a(sb, ", ", cls.getTypeParameters());
            sb.append('>');
        }
        return sb.toString();
    }

    private static String c(TypeVariable<?> typeVariable) {
        StringBuilder sb = new StringBuilder(typeVariable.getName());
        Type[] bounds = typeVariable.getBounds();
        if (bounds.length > 0 && (bounds.length != 1 || !Object.class.equals(bounds[0]))) {
            sb.append(" extends ");
            a(sb, " & ", typeVariable.getBounds());
        }
        return sb.toString();
    }

    private static String b(ParameterizedType parameterizedType) {
        StringBuilder sb = new StringBuilder();
        Type ownerType = parameterizedType.getOwnerType();
        Class cls = (Class) parameterizedType.getRawType();
        if (ownerType == null) {
            sb.append(cls.getName());
        } else {
            if (ownerType instanceof Class) {
                sb.append(((Class) ownerType).getName());
            } else {
                sb.append(ownerType.toString());
            }
            sb.append('.');
            sb.append(cls.getSimpleName());
        }
        int[] c = c(parameterizedType);
        if (c.length > 0) {
            a(sb, c, parameterizedType.getActualTypeArguments());
        } else {
            sb.append('<');
            a(sb, ", ", parameterizedType.getActualTypeArguments()).append('>');
        }
        return sb.toString();
    }

    private static void a(StringBuilder sb, int[] iArr, Type[] typeArr) {
        for (int i = 0; i < iArr.length; i++) {
            sb.append('<');
            a(sb, ", ", typeArr[i].toString()).append('>');
        }
        Type[] typeArr2 = (Type[]) ArrayUtils.a((Object[]) typeArr, iArr);
        if (typeArr2.length > 0) {
            sb.append('<');
            a(sb, ", ", typeArr2).append('>');
        }
    }

    private static int[] c(ParameterizedType parameterizedType) {
        Type[] typeArr = (Type[]) Arrays.copyOf(parameterizedType.getActualTypeArguments(), parameterizedType.getActualTypeArguments().length);
        int[] iArr = new int[0];
        for (int i = 0; i < typeArr.length; i++) {
            if ((typeArr[i] instanceof TypeVariable) && a((TypeVariable<?>) ((TypeVariable) typeArr[i]), parameterizedType)) {
                iArr = ArrayUtils.a(iArr, i);
            }
        }
        return iArr;
    }

    private static boolean a(TypeVariable<?> typeVariable, ParameterizedType parameterizedType) {
        return ArrayUtils.b(typeVariable.getBounds(), parameterizedType);
    }

    private static String c(WildcardType wildcardType) {
        StringBuilder sb = new StringBuilder();
        sb.append('?');
        Type[] lowerBounds = wildcardType.getLowerBounds();
        Type[] upperBounds = wildcardType.getUpperBounds();
        if (lowerBounds.length > 1 || (lowerBounds.length == 1 && lowerBounds[0] != null)) {
            sb.append(" super ");
            a(sb, " & ", lowerBounds);
        } else if (upperBounds.length > 1 || (upperBounds.length == 1 && !Object.class.equals(upperBounds[0]))) {
            sb.append(" extends ");
            a(sb, " & ", upperBounds);
        }
        return sb.toString();
    }

    private static String a(GenericArrayType genericArrayType) {
        return String.format("%s[]", a(genericArrayType.getGenericComponentType()));
    }

    private static <T> StringBuilder a(StringBuilder sb, String str, T... tArr) {
        Validate.a(Validate.b(tArr));
        if (tArr.length > 0) {
            sb.append(a((Object) tArr[0]));
            for (int i = 1; i < tArr.length; i++) {
                sb.append(str);
                sb.append(a((Object) tArr[i]));
            }
        }
        return sb;
    }

    private static <T> String a(T t) {
        return t instanceof Type ? a((Type) t) : t.toString();
    }
}
